/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2018 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.40                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for xxx eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "Apollo.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0        34
#define LED1        33
#define LED2        28
#define LED3        26
#define LED4        25

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  GPIO->PADKEY = 0x73;                 // Unlock writes to the GPIO and PAD configuration registers
  //
  // LED 0
  //
  GPIO->PADREGI_b.PAD34FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGE_b.GPIO34INCFG    = 0x00;  // Disable In
  GPIO->CFGE_b.GPIO34OUTCFG   = 0x01;  // Set Push Pull
  //
  // LED 1
  //
  GPIO->PADREGI_b.PAD33FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGE_b.GPIO33INCFG    = 0x00;  // Disable In
  GPIO->CFGE_b.GPIO33OUTCFG   = 0x01;  // Set Push Pull
  //
  // LED 2
  //
  GPIO->PADREGH_b.PAD28FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGD_b.GPIO28INCFG    = 0x00;  // Disable In
  GPIO->CFGD_b.GPIO28OUTCFG   = 0x01;  // Set Push Pull
  //
  // LED 3
  //
  GPIO->PADREGG_b.PAD26FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGD_b.GPIO26INCFG    = 0x00;  // Disable In
  GPIO->CFGD_b.GPIO26OUTCFG   = 0x01;  // Set Push Pull
  //
  // LED 4
  //
  GPIO->PADREGG_b.PAD25FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGD_b.GPIO25INCFG    = 0x00;  // Disable In
  GPIO->CFGD_b.GPIO25OUTCFG   = 0x01;  // Set Push Pull
  //
  // Set LED to high in order to disable them
  //
  GPIO->WTSB = (0x01u << (LED0-32));
  GPIO->WTSB = (0x01u << (LED1-32));
  GPIO->WTSA = (0x01u << (LED2));
  GPIO->WTSA = (0x01u << (LED3));
  GPIO->WTSA = (0x01u << (LED4));
  //
  // Lock PAD configuration registers.
  //
  GPIO->PADKEY = 0;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO->WTCB = (0x01u << (LED0-32));
  } else if (Index == 1) {
    GPIO->WTCB = (0x01u << (LED1-32));
  } else if (Index == 2) {
    GPIO->WTCA = (0x01u << (LED2));
  } else if (Index == 3) {
    GPIO->WTCA = (0x01u << (LED3));
  } else if (Index == 4) {
    GPIO->WTCA = (0x01u << (LED4));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO->WTSB = (0x01u << (LED0-32));
  } else if (Index == 1) {
    GPIO->WTSB = (0x01u << (LED1-32));
  } else if (Index == 2) {
    GPIO->WTSA = (0x01u << (LED2));
  } else if (Index == 3) {
    GPIO->WTSA = (0x01u << (LED3));
  } else if (Index == 4) {
    GPIO->WTSA = (0x01u << (LED4));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if ((GPIO->WTB >> (LED0 - 32)) & 0x01) {
      BSP_SetLED(Index);
    } else {
      BSP_ClrLED(Index);
    }
  } else if (Index == 1) {
    if ((GPIO->WTB >> (LED1 - 32)) & 0x01) {
      BSP_SetLED(Index);
    } else {
      BSP_ClrLED(Index);
    }
  } else if (Index == 2) {
    if ((GPIO->WTA >> (LED2)) & 0x01) {
      BSP_SetLED(Index);
    } else {
      BSP_ClrLED(Index);
    }
  } else if (Index == 3) {
    if ((GPIO->WTA >> (LED3)) & 0x01) {
      BSP_SetLED(Index);
    } else {
      BSP_ClrLED(Index);
    }
  } else if (Index == 4) {
    if ((GPIO->WTA >> (LED4)) & 0x01) {
      BSP_SetLED(Index);
    } else {
      BSP_ClrLED(Index);
    }
  }
}

/****** End Of File *************************************************/
