/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2018 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.40                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for the IAR STM32F429 EXP eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define RCC_BASE_ADDR             ((unsigned int)(0x40023800u))
#define RCC_AHB1RSTR              (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x10u))
#define RCC_AHB1ENR               (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x30u))
#define RCC_LEDPORT_BIT           (1u << 4u)

#define GPIOE_BASE_ADDR           ((unsigned int)0x40021000)
#define GPIOE_MODER               (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x00u))
#define GPIOE_ODR                 (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x14u))

#define LED0_BIT                  (0u)  // Port PE.0, LED1, green
#define LED1_BIT                  (1u)  // Port PE.1, LED2, orange

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Initialize port for LEDs
  //
  RCC_AHB1RSTR &= ~RCC_LEDPORT_BIT;
  RCC_AHB1ENR  |=  RCC_LEDPORT_BIT;
  GPIOE_MODER  |= (1u << (LED0_BIT * 2)) | (1u << (LED1_BIT * 2));  // Sets ports to output
  GPIOE_ODR    |= (1u << LED0_BIT) | (1u << LED1_BIT);              // Clears both LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOE_ODR &= ~(1u << LED0_BIT);
  } else if (Index == 1) {
    GPIOE_ODR &= ~(1u << LED1_BIT);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOE_ODR |= (1u << LED0_BIT);
  } else if (Index == 1) {
    GPIOE_ODR |= (1u << LED1_BIT);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIOE_ODR ^= (1u << LED0_BIT);
  } else if (Index == 1) {
    GPIOE_ODR ^= (1u << LED1_BIT);
  }
}

/****** End Of File *************************************************/
