/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2018 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.40                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for STM32F053 Discovery
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT                  (4u)  // (Green) user LD3 is connected to PB4
#define LED1_BIT                  (5u)  // (Red)   user LD4 is connected to PA5

#define GPIOA_BASE_ADDR           (0x50000000)
#define GPIOA_MODER               (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x00u))
#define GPIOA_ODR                 (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x14u))
#define GPIOA_BRR                 (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x28u))

#define GPIOB_BASE_ADDR           (0x50000400)
#define GPIOB_MODER               (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))
#define GPIOB_ODR                 (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))
#define GPIOB_BRR                 (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x28u))

#define RCC_IOPENR                (*(volatile unsigned int*)(0x4002102Cu))
#define IOPAEN_BIT                (0u)
#define IOPBEN_BIT                (1u)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCC_IOPENR  |= (1u << IOPAEN_BIT)                // Enable clock to Port A
              |  (1u << IOPBEN_BIT)                // Enable clock to Port B
              ;
  GPIOA_MODER &= ~(1u << (LED1_BIT << 1u) << 1u);  // Alternate function PA5
  GPIOB_MODER &= ~(1u << (LED0_BIT << 1u) << 1u);  // Alternate function PB4
  GPIOA_BRR    = (1u << LED1_BIT);                 // Initially clear LD4
  GPIOB_BRR    = (1u << LED0_BIT);                 // Initially clear LD3
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if        (Index == 0) {
    GPIOB_ODR ^= (1u << LED0_BIT);                 /* Switch LD3 on */
  } else if (Index == 1) {
    GPIOA_ODR ^= (1u << LED1_BIT);                 /* Switch LD4 on */
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if        (Index == 0) {    
    GPIOB_ODR ^= (1u << LED0_BIT);                /* Switch LD3 off */
  } else if (Index == 1) {  
    GPIOA_ODR ^= (1u << LED1_BIT);                /* Switch LD4 off */
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if        (Index == 0) {
    GPIOB_ODR ^= (1u << LED0_BIT);                    /* Toggle LD3 */
  } else if (Index == 1) {
    GPIOA_ODR ^= (1u << LED1_BIT);                    /* Toggle LD4 */
  }
}

/****** End Of File *************************************************/
