/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2018 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.40                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Silicon Labs Giant Gecko Series 1 Starter Kit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "em_device.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT      (10u)  // User LED UIF_LED0R on STK board, active high, Port pin H10
#define LED1_BIT      (11u)  // User LED UIF_LED0G on STK board, active high, Port pin H11
#define LED2_BIT      (12u)  // User LED UIF_LED0B on STK board, active high, Port pin H12
#define LEDMASK_ALL   ((1u << LED0_BIT) | (1u << LED1_BIT) | (1u << LED2_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  GPIO_TypeDef *gpio = GPIO;
  uint32_t     gpiomode;
  unsigned int Data;
  //
  // Enable GPIO
  //
  CMU->HFPERCLKEN0 |= CMU_CTRL_HFPERCLKEN;
  CMU->HFBUSCLKEN0 |= CMU_HFBUSCLKEN0_GPIO;
  //
  // Configure GPIO port H10-12 as LED control outputs
  //
  gpiomode  = GPIO->P[7].MODEH;
  gpiomode &= ~(_GPIO_P_MODEH_MODE10_MASK |
                _GPIO_P_MODEH_MODE11_MASK |
                _GPIO_P_MODEH_MODE12_MASK);
  gpiomode |= GPIO_P_MODEH_MODE10_PUSHPULL;
  gpiomode |= GPIO_P_MODEH_MODE11_PUSHPULL;
  gpiomode |= GPIO_P_MODEH_MODE12_PUSHPULL;
  gpio->P[7].MODEH = gpiomode;

  // Initially all LEDS off
  Data  = GPIO->P[7].DOUT;
  Data |= (LEDMASK_ALL);
  GPIO->P[7].DOUT = Data;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < 3) {
    GPIO->P[7].DOUT &= ~(1u << (LED0_BIT + Index));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < 3) {
    GPIO->P[7].DOUT |= (1u << (LED0_BIT + Index));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < 3) {
    if (GPIO->P[7].DOUT & (1u << (LED0_BIT + Index))) {
      GPIO->P[7].DOUT &= ~(1u << (LED0_BIT + Index));
    } else {
      GPIO->P[7].DOUT |=  (1u << (LED0_BIT + Index));
    }
  }
}

/****** End Of File *************************************************/
