/**
  ******************************************************************************
  * @file    stm32h743xx.h
  * @author  MCD Application Team
  * @version V0.2.0
  * @date    11-November-2016
  * @brief   CMSIS STM32H743xx Device Peripheral Access Layer Header File.
  *
  *          This file contains:
  *           - Data structures and the address mapping for all peripherals
  *           - Peripheral's registers declarations and bits definition
  *           - Macros to access peripherals registers hardware
  *
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2016 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/** @addtogroup CMSIS_Device
  * @{
  */

/** @addtogroup stm32h743xx
  * @{
  */

#ifndef __STM32H743xx_H
#define __STM32H743xx_H

#ifdef __cplusplus
 extern "C" {
#endif /* __cplusplus */

/** @addtogroup Peripheral_interrupt_number_definition
  * @{
  */

/**
 * @brief STM32H7XX Interrupt Number Definition, according to the selected device
 *        in @ref Library_configuration_section
 */
typedef enum
{
/******  Cortex-M Processor Exceptions Numbers *****************************************************************/
  NonMaskableInt_IRQn         = -14,    /*!< 2 Non Maskable Interrupt                                          */
  HardFault_IRQn              = -13,    /*!< 4 Cortex-M Memory Management Interrupt                            */
  MemoryManagement_IRQn       = -12,    /*!< 4 Cortex-M Memory Management Interrupt                            */
  BusFault_IRQn               = -11,    /*!< 5 Cortex-M Bus Fault Interrupt                                    */
  UsageFault_IRQn             = -10,    /*!< 6 Cortex-M Usage Fault Interrupt                                  */
  SVCall_IRQn                 = -5,     /*!< 11 Cortex-M SV Call Interrupt                                     */
  DebugMonitor_IRQn           = -4,     /*!< 12 Cortex-M Debug Monitor Interrupt                               */
  PendSV_IRQn                 = -2,     /*!< 14 Cortex-M Pend SV Interrupt                                     */
  SysTick_IRQn                = -1,     /*!< 15 Cortex-M System Tick Interrupt                                 */
/******  STM32 specific Interrupt Numbers **********************************************************************/
  WWDG_IRQn                   = 0,      /*!< Window WatchDog Interrupt ( wwdg1_it, wwdg2_it)                   */
  PVD_AVD_IRQn                = 1,      /*!< PVD/AVD through EXTI Line detection Interrupt                     */
  TAMP_STAMP_IRQn             = 2,      /*!< Tamper and TimeStamp interrupts through the EXTI line             */
  RTC_WKUP_IRQn               = 3,      /*!< RTC Wakeup interrupt through the EXTI line                        */
  FLASH_IRQn                  = 4,      /*!< FLASH global Interrupt                                            */
  RCC_IRQn                    = 5,      /*!< RCC global Interrupt                                              */
  EXTI0_IRQn                  = 6,      /*!< EXTI Line0 Interrupt                                              */
  EXTI1_IRQn                  = 7,      /*!< EXTI Line1 Interrupt                                              */
  EXTI2_IRQn                  = 8,      /*!< EXTI Line2 Interrupt                                              */
  EXTI3_IRQn                  = 9,      /*!< EXTI Line3 Interrupt                                              */
  EXTI4_IRQn                  = 10,     /*!< EXTI Line4 Interrupt                                              */
  DMA1_Stream0_IRQn           = 11,     /*!< DMA1 Stream 0 global Interrupt                                    */
  DMA1_Stream1_IRQn           = 12,     /*!< DMA1 Stream 1 global Interrupt                                    */
  DMA1_Stream2_IRQn           = 13,     /*!< DMA1 Stream 2 global Interrupt                                    */
  DMA1_Stream3_IRQn           = 14,     /*!< DMA1 Stream 3 global Interrupt                                    */
  DMA1_Stream4_IRQn           = 15,     /*!< DMA1 Stream 4 global Interrupt                                    */
  DMA1_Stream5_IRQn           = 16,     /*!< DMA1 Stream 5 global Interrupt                                    */
  DMA1_Stream6_IRQn           = 17,     /*!< DMA1 Stream 6 global Interrupt                                    */
  ADC_IRQn                    = 18,     /*!< ADC1 and  ADC2 global Interrupts                                  */
  TTCAN_IT0_IRQn              = 19,     /*!< TTCAN Interrupt line 0                                            */
  FDCAN_IT0_IRQn              = 20,     /*!< FDCAN Interrupt line 0                                            */
  TTCAN_IT1_IRQn              = 21,     /*!< TTCAN Interrupt line 1                                            */
  FDCAN_IT1_IRQn              = 22,     /*!< FDCAN Interrupt line 1                                            */
  EXTI9_5_IRQn                = 23,     /*!< External Line[9:5] Interrupts                                     */
  TIM1_BRK_IRQn               = 24,     /*!< TIM1 Break Interrupt                                              */
  TIM1_UP_IRQn                = 25,     /*!< TIM1 Update Interrupt                                             */
  TIM1_TRG_COM_TIM11_IRQn     = 26,     /*!< TIM1 Trigger and Commutation Interrupt and TIM11 global interrupt */
  TIM1_CC_IRQn                = 27,     /*!< TIM1 Capture Compare Interrupt                                    */
  TIM2_IRQn                   = 28,     /*!< TIM2 global Interrupt                                             */
  TIM3_IRQn                   = 29,     /*!< TIM3 global Interrupt                                             */
  TIM4_IRQn                   = 30,     /*!< TIM4 global Interrupt                                             */
  I2C1_EV_IRQn                = 31,     /*!< I2C1 Event Interrupt                                              */
  I2C1_ER_IRQn                = 32,     /*!< I2C1 Error Interrupt                                              */
  I2C2_EV_IRQn                = 33,     /*!< I2C2 Event Interrupt                                              */
  I2C2_ER_IRQn                = 34,     /*!< I2C2 Error Interrupt                                              */  
  SPI1_IRQn                   = 35,     /*!< SPI1 global Interrupt                                             */
  SPI2_IRQn                   = 36,     /*!< SPI2 global Interrupt                                             */
  USART1_IRQn                 = 37,     /*!< USART1 global Interrupt                                           */
  USART2_IRQn                 = 38,     /*!< USART2 global Interrupt                                           */
  USART3_IRQn                 = 39,     /*!< USART3 global Interrupt                                           */
  EXTI15_10_IRQn              = 40,     /*!< External Line[15:10] Interrupts                                   */
  RTC_Alarm_IRQn              = 41,     /*!< RTC Alarm (A and B) through EXTI Line Interrupt                   */   
  TIM8_BRK_TIM12_IRQn         = 43,     /*!< TIM8 Break Interrupt and TIM12 global interrupt                   */
  TIM8_UP_TIM13_IRQn          = 44,     /*!< TIM8 Update Interrupt and TIM13 global interrupt                  */
  TIM8_TRG_COM_TIM14_IRQn     = 45,     /*!< TIM8 Trigger and Commutation Interrupt and TIM14 global interrupt */
  TIM8_CC_IRQn                = 46,     /*!< TIM8 Capture Compare Interrupt                                    */
  DMA1_Stream7_IRQn           = 47,     /*!< DMA1 Stream7 Interrupt                                            */
  FMC_IRQn                    = 48,     /*!< FMC global Interrupt                                              */
  SDMMC1_IRQn                 = 49,     /*!< SDMMC1 global Interrupt                                           */
  TIM5_IRQn                   = 50,     /*!< TIM5 global Interrupt                                             */
  SPI3_IRQn                   = 51,     /*!< SPI3 global Interrupt                                             */
  UART4_IRQn                  = 52,     /*!< UART4 global Interrupt                                            */
  UART5_IRQn                  = 53,     /*!< UART5 global Interrupt                                            */
  TIM6_DAC_IRQn               = 54,     /*!< TIM6 global and DAC1&2 underrun error  interrupts                 */
  TIM7_IRQn                   = 55,     /*!< TIM7 global interrupt                                             */
  DMA2_Stream0_IRQn           = 56,     /*!<   DMA2 Stream 0 global Interrupt                                  */
  DMA2_Stream1_IRQn           = 57,     /*!<   DMA2 Stream 1 global Interrupt                                  */
  DMA2_Stream2_IRQn           = 58,     /*!<   DMA2 Stream 2 global Interrupt                                  */
  DMA2_Stream3_IRQn           = 59,     /*!<   DMA2 Stream 3 global Interrupt                                  */
  DMA2_Stream4_IRQn           = 60,     /*!<   DMA2 Stream 4 global Interrupt                                  */
  ETH_IRQn                    = 61,     /*!< Ethernet global Interrupt                                         */
  ETH_WKUP_IRQn               = 62,     /*!< Ethernet Wakeup through EXTI line Interrupt                       */
  FDCAN_CU_IRQn               = 63,     /*!< FDCAN Calibration unit Interrupt                                  */
  DMA2_Stream5_IRQn           = 68,     /*!< DMA2 Stream 5 global interrupt                                    */
  DMA2_Stream6_IRQn           = 69,     /*!< DMA2 Stream 6 global interrupt                                    */
  DMA2_Stream7_IRQn           = 70,     /*!< DMA2 Stream 7 global interrupt                                    */
  USART6_IRQn                 = 71,     /*!< USART6 global interrupt                                           */
  I2C3_EV_IRQn                = 72,     /*!< I2C3 event interrupt                                              */
  I2C3_ER_IRQn                = 73,     /*!< I2C3 error interrupt                                              */
  OTG_HS_EP1_OUT_IRQn         = 74,     /*!< USB OTG HS End Point 1 Out global interrupt                       */
  OTG_HS_EP1_IN_IRQn          = 75,     /*!< USB OTG HS End Point 1 In global interrupt                        */
  OTG_HS_WKUP_IRQn            = 76,     /*!< USB OTG HS Wakeup through EXTI interrupt                          */
  OTG_HS_IRQn                 = 77,     /*!< USB OTG HS global interrupt                                       */
  DCMI_IRQn                   = 78,     /*!< DCMI global interrupt                                             */
  CRYP_IRQn                   = 79,     /*!< CRYP crypto global interrupt                                      */
  HASH_RNG_IRQn               = 80,     /*!< Hash and Rng global interrupt                                     */
  FPU_IRQn                    = 81,     /*!< FPU global interrupt                                              */
  UART7_IRQn                  = 82,     /*!< UART7 global interrupt                                            */
  UART8_IRQn                  = 83,     /*!< UART8 global interrupt                                            */
  SPI4_IRQn                   = 84,     /*!< SPI4 global Interrupt                                             */
  SPI5_IRQn                   = 85,     /*!< SPI5 global Interrupt                                             */
  SPI6_IRQn                   = 86,     /*!< SPI6 global Interrupt                                             */
  SAI1_IRQn                   = 87,     /*!< SAI1 global Interrupt                                             */
  LTDC_IRQn                   = 88,     /*!< LTDC global Interrupt                                             */
  LTDC_ER_IRQn                = 89,     /*!< LTDC Error global Interrupt                                       */
  DMA2D_IRQn                  = 90,     /*!< DMA2D global Interrupt                                            */
  SAI2_IRQn                   = 91,     /*!< SAI2 global Interrupt                                             */
  QUADSPI_IRQn                = 92,     /*!< Quad SPI global interrupt                                         */
  LPTIM1_IRQn                 = 93,     /*!< LP TIM1 interrupt                                                 */
  CEC_IRQn                    = 94,     /*!< HDMI-CEC global Interrupt                                         */
  I2C4_EV_IRQn                = 95,     /*!< I2C4 Event Interrupt                                              */
  I2C4_ER_IRQn                = 96,     /*!< I2C4 Error Interrupt                                              */
  SPDIF_RX_IRQn               = 97,     /*!< SPDIF-RX global Interrupt                                         */
  OTG_FS_EP1_OUT_IRQn         = 98,     /*!< USB OTG HS2 global interrupt                                      */
  OTG_FS_EP1_IN_IRQn          = 99,     /*!< USB OTG HS2 End Point 1 Out global interrupt                      */
  OTG_FS_WKUP_IRQn            = 100,    /*!< USB OTG HS2 End Point 1 In global interrupt                       */
  OTG_FS_IRQn                 = 101,    /*!< USB OTG HS2 Wakeup through EXTI interrupt                         */ 
  DMAMUX1_OVR_IRQn	          = 102,    /*!<DMAMUX1 Overrun interrupt                                          */
  HRTIM1_Master_IRQn          = 103,    /*!< HRTIM Master Timer global Interrupts                              */
  HRTIM1_TIMA_IRQn            = 104,    /*!< HRTIM Timer A global Interrupt                                    */
  HRTIM1_TIMB_IRQn            = 105,    /*!< HRTIM Timer B global Interrupt                                    */
  HRTIM1_TIMC_IRQn            = 106,    /*!< HRTIM Timer C global Interrupt                                    */
  HRTIM1_TIMD_IRQn            = 107,    /*!< HRTIM Timer D global Interrupt                                    */
  HRTIM1_TIME_IRQn            = 108,    /*!< HRTIM Timer E global Interrupt                                    */
  HRTIM1_FLT_IRQn             = 109,    /*!< HRTIM Fault global Interrupt                                      */
  DFSDM1_FLT0_IRQn            = 110,    /*!<DFSDM Filter1 Interrupt                                            */
  DFSDM1_FLT1_IRQn            = 111,    /*!<DFSDM Filter2 Interrupt                                            */
  DFSDM1_FLT2_IRQn            = 112,    /*!<DFSDM Filter3 Interrupt                                            */
  DFSDM1_FLT3_IRQn            = 113,    /*!<DFSDM Filter4 Interrupt                                            */
  SAI3_IRQn                   = 114,    /*!< SAI3 global Interrupt                                             */
  SWPMI1_IRQn                 = 115,    /*!< Serial Wire Interface 1 global interrupt                          */
  TIM15_IRQn                  = 116,    /*!< TIM15 global Interrupt                                            */
  TIM16_IRQn                  = 117,    /*!< TIM16 global Interrupt                                            */
  TIM17_IRQn                  = 118,    /*!< TIM17 global Interrupt                                            */
  MDIOS_WKUP_IRQn             = 119,    /*!< MDIOS Wakeup  Interrupt                                           */
  MDIOS_IRQn                  = 120,    /*!< MDIOS global Interrupt                                            */
  JPEG_IRQn                   = 121,    /*!< JPEG global Interrupt                                             */
  MDMA_IRQn                   = 122,    /*!< MDMA global Interrupt                                             */
  SDMMC2_IRQn                 = 124,    /*!< SDMMC2 global Interrupt                                           */
  HSEM1_IRQn                  = 125,    /*!< HSEM1 global Interrupt                                            */
  ADC3_IRQn                   = 127,    /*!< ADC3 global Interrupt                                             */
  DMAMUX2_OVR_IRQn            = 128,    /*!<DMAMUX2 Overrun interrupt                                          */
  BDMA_Channel0_IRQn          = 129,    /*!< BDMA Channel 0 global Interrupt                                   */
  BDMA_Channel1_IRQn          = 130,    /*!< BDMA Channel 1 global Interrupt                                   */
  BDMA_Channel2_IRQn          = 131,    /*!< BDMA Channel 2 global Interrupt                                   */
  BDMA_Channel3_IRQn          = 132,    /*!< BDMA Channel 3 global Interrupt                                   */
  BDMA_Channel4_IRQn          = 133,    /*!< BDMA Channel 4 global Interrupt                                   */
  BDMA_Channel5_IRQn          = 134,    /*!< BDMA Channel 5 global Interrupt                                   */
  BDMA_Channel6_IRQn          = 135,    /*!< BDMA Channel 6 global Interrupt                                   */
  BDMA_Channel7_IRQn          = 136,    /*!< BDMA Channel 7 global Interrupt                                   */
  COMP_IRQn                   = 137 ,   /*!< COMP global Interrupt                                             */
  LPTIM2_IRQn                 = 138,    /*!< LP TIM2 global interrupt                                          */
  LPTIM3_IRQn                 = 139,    /*!< LP TIM3 global interrupt                                          */
  LPTIM4_IRQn                 = 140,    /*!< LP TIM4 global interrupt                                          */
  LPTIM5_IRQn                 = 141,    /*!< LP TIM5 global interrupt                                          */
  LPUART1_IRQn                = 142,    /*!< LP UART1 interrupt                                                */
  CRS_IRQn                    = 144,    /*!< Clock Recovery Global Interrupt                                   */
  SAI4_IRQn                   = 146,    /*!< SAI4 global interrupt                                             */
  WAKEUP_PIN_IRQn             = 149,    /*!< Interrupt for all 6 wake-up pins                                  */
} IRQn_Type;

/**
  * @}
  */

/** @addtogroup Configuration_section_for_CMSIS
  * @{
  */




/**
  * @brief Configuration of the Cortex-M7 Processor and Core Peripherals
   */
#define __CM7_REV               0x0100U   /*!< Cortex-M7 revision r1p0                       */
#define __MPU_PRESENT             1       /*!< CM7 provides an MPU                           */
#define __NVIC_PRIO_BITS          4       /*!< CM7 uses 4 Bits for the Priority Levels       */
#define __Vendor_SysTickConfig    0       /*!< Set to 1 if different SysTick Config is used  */
#define __FPU_PRESENT             1       /*!< FPU present                                   */
#define __ICACHE_PRESENT          1       /*!< CM7 instruction cache present                 */
#define __DCACHE_PRESENT          1       /*!< CM7 data cache present                        */
#include "core_cm7.h"                     /*!< Cortex-M7 processor and core peripherals      */

/**
  * @}
  */




#include "system_stm32h7xx.h"
#include <stdint.h>

/** @addtogroup Peripheral_registers_structures
  * @{
  */

/**
  * @brief Analog to Digital Converter
  */

typedef struct
{
  __IO uint32_t ISR;              /*!< ADC Interrupt and Status Register,                 Address offset: 0x00 */
  __IO uint32_t IER;              /*!< ADC Interrupt Enable Register,                     Address offset: 0x04 */
  __IO uint32_t CR;               /*!< ADC control register,                              Address offset: 0x08 */
  __IO uint32_t CFGR;             /*!< ADC Configuration register,                        Address offset: 0x0C */
  __IO uint32_t CFGR2;            /*!< ADC Configuration register 2,                      Address offset: 0x10 */
  __IO uint32_t SMPR1;            /*!< ADC sample time register 1,                        Address offset: 0x14 */
  __IO uint32_t SMPR2;            /*!< ADC sample time register 2,                        Address offset: 0x18 */
  __IO uint32_t PCSEL;            /*!< ADC pre-channel selection,                         Address offset: 0x1C */
  __IO uint32_t LTR1;             /*!< ADC watchdog Lower threshold register 1,           Address offset: 0x20 */
  __IO uint32_t HTR1;             /*!< ADC watchdog higher threshold register 1,          Address offset: 0x24 */
  uint32_t      RESERVED1;        /*!< Reserved, 0x028                                                         */
  uint32_t      RESERVED2;        /*!< Reserved, 0x02C                                                         */
  __IO uint32_t SQR1;             /*!< ADC regular sequence register 1,                   Address offset: 0x30 */
  __IO uint32_t SQR2;             /*!< ADC regular sequence register 2,                   Address offset: 0x34 */
  __IO uint32_t SQR3;             /*!< ADC regular sequence register 3,                   Address offset: 0x38 */
  __IO uint32_t SQR4;             /*!< ADC regular sequence register 4,                   Address offset: 0x3C */
  __IO uint32_t DR;               /*!< ADC regular data register,                         Address offset: 0x40 */
  uint32_t      RESERVED3;        /*!< Reserved, 0x044                                                         */
  uint32_t      RESERVED4;        /*!< Reserved, 0x048                                                         */
  __IO uint32_t JSQR;             /*!< ADC injected sequence register,                    Address offset: 0x4C */
  uint32_t      RESERVED5[4];     /*!< Reserved, 0x050 - 0x05C                                                 */
  __IO uint32_t OFR1;             /*!< ADC offset register 1,                             Address offset: 0x60 */
  __IO uint32_t OFR2;             /*!< ADC offset register 2,                             Address offset: 0x64 */
  __IO uint32_t OFR3;             /*!< ADC offset register 3,                             Address offset: 0x68 */
  __IO uint32_t OFR4;             /*!< ADC offset register 4,                             Address offset: 0x6C */
  uint32_t      RESERVED6[4];     /*!< Reserved, 0x070 - 0x07C                                                 */
  __IO uint32_t JDR1;             /*!< ADC injected data register 1,                      Address offset: 0x80 */
  __IO uint32_t JDR2;             /*!< ADC injected data register 2,                      Address offset: 0x84 */
  __IO uint32_t JDR3;             /*!< ADC injected data register 3,                      Address offset: 0x88 */
  __IO uint32_t JDR4;             /*!< ADC injected data register 4,                      Address offset: 0x8C */
  uint32_t      RESERVED7[4];     /*!< Reserved, 0x090 - 0x09C                                                 */
  __IO uint32_t AWD2CR;           /*!< ADC  Analog Watchdog 2 Configuration Register,     Address offset: 0xA0 */
  __IO uint32_t AWD3CR;           /*!< ADC  Analog Watchdog 3 Configuration Register,     Address offset: 0xA4 */
  uint32_t      RESERVED8;        /*!< Reserved, 0x0A8                                                         */
  uint32_t      RESERVED9;        /*!< Reserved, 0x0AC                                                         */
  __IO uint32_t LTR2;             /*!< ADC watchdog Lower threshold register 2,           Address offset: 0xB0 */
  __IO uint32_t HTR2;             /*!< ADC watchdog Higher threshold register 2,          Address offset: 0xB4 */
  __IO uint32_t LTR3;             /*!< ADC watchdog Lower threshold register 3,           Address offset: 0xB8 */
  __IO uint32_t HTR3;             /*!< ADC watchdog Higher threshold register 3,          Address offset: 0xBC */
  __IO uint32_t DIFSEL;           /*!< ADC  Differential Mode Selection Register,         Address offset: 0xC0 */
  __IO uint32_t CALFACT;          /*!< ADC  Calibration Factors,                          Address offset: 0xC4 */
  __IO uint32_t CALFACT2;         /*!< ADC  Linearity Calibration Factors,                Address offset: 0xC8 */
  uint32_t      RESERVED10;       /*!< Reserved, 0x0CC                                                         */
  __IO uint32_t OR;               /*!< ADC  Calibration Factors,                          Address offset: 0xD0 */
} ADC_TypeDef;


typedef struct
{
__IO uint32_t CSR; /*!< ADC Common status register, Address offset: ADC1/3 base address + 0x300 */
uint32_t RESERVED; /*!< Reserved, ADC1/3 base address + 0x304 */
__IO uint32_t CCR; /*!< ADC common control register, Address offset: ADC1/3 base address + 0x308 */
__IO uint32_t CDR; /*!< ADC common regular data register for dual Address offset: ADC1/3 base address + 0x30C */
__IO uint32_t CDR2; /*!< ADC common regular data register for 32-bit dual mode Address offset: ADC1/3 base address + 0x310 */

} ADC_Common_TypeDef;

/**
  * @brief FD Controller Area Network
  */

typedef struct
{
  __IO uint32_t              CREL;                 /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              ENDN;                 /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              CUST;                 /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              DBTP;                 /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              TEST;                 /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              RWD;                  /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              CCCR;                 /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              NBTP;                 /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              TSCC;                 /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              TSCV;                 /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              TOCC;                 /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              TOCV;                 /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              RESERVED0[4];         /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              ECR;                  /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              PSR;                  /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              TDCR;                 /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              RESERVED1;            /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              IR;                   /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              IE;                   /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              ILS;                  /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              ILE;                  /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              RESERVED2[8];         /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              GFC;                  /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              SIDFC;                /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              XIDFC;                /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              RESERVED3;            /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              XIDAM;                /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              HPMS;                 /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              NDAT1;                /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              NDAT2;                /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              RXF0C;                /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              RXF0S;                /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              RXF0A;                /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              RXBC;                 /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              RXF1C;                /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              RXF1S;                /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              RXF1A;                /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              RXESC;                /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              TXBC;                 /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              TXFQS;                /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              TXESC;                /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              TXBRP;                /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              TXBAR;                /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              TXBCR;                /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              TXBTO;                /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              TXBCF;                /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              TXBTIE;               /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              TXBCIE;               /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              RESERVED4[2];         /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              TXEFC;                /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              TXEFS;                /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              TXEFA;                /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              RESERVED5;            /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
} FDCAN_TypeDef;

/**
  * @brief TTFD Controller Area Network
  */

typedef struct
{
  __IO uint32_t              CREL;                 /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              ENDN;                 /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              CUST;                 /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              DBTP;                 /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              TEST;                 /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              RWD;                  /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              CCCR;                 /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              NBTP;                 /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              TSCC;                 /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              TSCV;                 /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              TOCC;                 /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              TOCV;                 /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              RESERVED0[4];         /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              ECR;                  /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              PSR;                  /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              TDCR;                 /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              RESERVED1;            /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              IR;                   /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              IE;                   /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              ILS;                  /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              ILE;                  /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              RESERVED2[8];         /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              GFC;                  /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              SIDFC;                /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              XIDFC;                /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              RESERVED3;            /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              XIDAM;                /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              HPMS;                 /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              NDAT1;                /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              NDAT2;                /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              RXF0C;                /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              RXF0S;                /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              RXF0A;                /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              RXBC;                 /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              RXF1C;                /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              RXF1S;                /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              RXF1A;                /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              RXESC;                /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              TXBC;                 /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              TXFQS;                /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              TXESC;                /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              TXBRP;                /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              TXBAR;                /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              TXBCR;                /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              TXBTO;                /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              TXBCF;                /*!< CAN interrupt enable register,       Address offset: 0x14          */
  __IO uint32_t              TXBTIE;               /*!< CAN error status register,           Address offset: 0x18          */
  __IO uint32_t              TXBCIE;               /*!< CAN bit timing register,             Address offset: 0x1C          */
  __IO uint32_t              RESERVED4[2];         /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              TXEFC;                /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              TXEFS;                /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              TXEFA;                /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              RESERVED5;            /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              TTTMC;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTRMC;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTOCF;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTMLM;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TURCF;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTOCN;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTGTP;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTTMK;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTIR;                 /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTIE;                 /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTILS;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTOST;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TURNA;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTLGT;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTCTC;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTCPT;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              TTCSM;                /*!< TT Trigger Memory Configuration,     Address offset: 0x10          */
  __IO uint32_t              RESERVED6[111];       /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              TTTS;                 /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              RESERVED7;            /*!< CAN master control register,         Address offset: 0x00          */
} TTFDCAN_TypeDef;

/**
  * @brief FD Controller Area Network
  */

typedef struct
{
  __IO uint32_t              CREL;                 /*!< CAN master control register,         Address offset: 0x00          */
  __IO uint32_t              CCFG;                 /*!< CAN master status register,          Address offset: 0x04          */
  __IO uint32_t              CSTAT;                /*!< CAN transmit status register,        Address offset: 0x08          */
  __IO uint32_t              CWD;                  /*!< CAN receive FIFO 0 register,         Address offset: 0x0C          */
  __IO uint32_t              CUIR;                 /*!< CAN receive FIFO 1 register,         Address offset: 0x10          */
  __IO uint32_t              CUIE;                 /*!< CAN interrupt enable register,       Address offset: 0x14          */
} CAN_Calibration_Unit_TypeDef;


/**
  * @brief Consumer Electronics Control
  */

typedef struct
{
  __IO uint32_t CR;           /*!< CEC control register,              Address offset:0x00 */
  __IO uint32_t CFGR;         /*!< CEC configuration register,        Address offset:0x04 */
  __IO uint32_t TXDR;         /*!< CEC Tx data register ,             Address offset:0x08 */
  __IO uint32_t RXDR;         /*!< CEC Rx Data Register,              Address offset:0x0C */
  __IO uint32_t ISR;          /*!< CEC Interrupt and Status Register, Address offset:0x10 */
  __IO uint32_t IER;          /*!< CEC interrupt enable register,     Address offset:0x14 */
}CEC_TypeDef;

/**
  * @brief CRC calculation unit
  */

typedef struct
{
  __IO uint32_t DR;          /*!< CRC Data register,                           Address offset: 0x00 */
  __IO uint32_t IDR;         /*!< CRC Independent data register,               Address offset: 0x04 */
  __IO uint32_t CR;          /*!< CRC Control register,                        Address offset: 0x08 */
  uint32_t      RESERVED2;   /*!< Reserved,                                                    0x0C */
  __IO uint32_t INIT;        /*!< Initial CRC value register,                  Address offset: 0x10 */
  __IO uint32_t POL;         /*!< CRC polynomial register,                     Address offset: 0x14 */
} CRC_TypeDef;


/**
  * @brief Clock Recovery System
  */
typedef struct 
{
__IO uint32_t CR;            /*!< CRS ccontrol register,              Address offset: 0x00 */
__IO uint32_t CFGR;          /*!< CRS configuration register,         Address offset: 0x04 */
__IO uint32_t ISR;           /*!< CRS interrupt and status register,  Address offset: 0x08 */
__IO uint32_t ICR;           /*!< CRS interrupt flag clear register,  Address offset: 0x0C */
} CRS_TypeDef;


/**
  * @brief Digital to Analog Converter
  */

typedef struct
{
  __IO uint32_t CR;       /*!< DAC control register,                                    Address offset: 0x00 */
  __IO uint32_t SWTRIGR;  /*!< DAC software trigger register,                           Address offset: 0x04 */
  __IO uint32_t DHR12R1;  /*!< DAC channel1 12-bit right-aligned data holding register, Address offset: 0x08 */
  __IO uint32_t DHR12L1;  /*!< DAC channel1 12-bit left aligned data holding register,  Address offset: 0x0C */
  __IO uint32_t DHR8R1;   /*!< DAC channel1 8-bit right aligned data holding register,  Address offset: 0x10 */
  __IO uint32_t DHR12R2;  /*!< DAC channel2 12-bit right aligned data holding register, Address offset: 0x14 */
  __IO uint32_t DHR12L2;  /*!< DAC channel2 12-bit left aligned data holding register,  Address offset: 0x18 */
  __IO uint32_t DHR8R2;   /*!< DAC channel2 8-bit right-aligned data holding register,  Address offset: 0x1C */
  __IO uint32_t DHR12RD;  /*!< Dual DAC 12-bit right-aligned data holding register,     Address offset: 0x20 */
  __IO uint32_t DHR12LD;  /*!< DUAL DAC 12-bit left aligned data holding register,      Address offset: 0x24 */
  __IO uint32_t DHR8RD;   /*!< DUAL DAC 8-bit right aligned data holding register,      Address offset: 0x28 */
  __IO uint32_t DOR1;     /*!< DAC channel1 data output register,                       Address offset: 0x2C */
  __IO uint32_t DOR2;     /*!< DAC channel2 data output register,                       Address offset: 0x30 */
  __IO uint32_t SR;       /*!< DAC status register,                                     Address offset: 0x34 */
  __IO uint32_t CCR;      /*!< DAC calibration control register,                        Address offset: 0x38 */
  __IO uint32_t MCR;      /*!< DAC mode control register,                               Address offset: 0x3C */
  __IO uint32_t SHSR1;    /*!< DAC Sample and Hold sample time register 1,              Address offset: 0x40 */
  __IO uint32_t SHSR2;    /*!< DAC Sample and Hold sample time register 2,              Address offset: 0x44 */
  __IO uint32_t SHHR;     /*!< DAC Sample and Hold hold time register,                  Address offset: 0x48 */
  __IO uint32_t SHRR;     /*!< DAC Sample and Hold refresh time register,               Address offset: 0x4C */
} DAC_TypeDef;

/**
  * @brief DFSDM module registers
  */
typedef struct
{
  __IO uint32_t CR1;          /*!< DFSDM control register1,                          Address offset: 0x100 */
  __IO uint32_t CR2;          /*!< DFSDM control register2,                          Address offset: 0x104 */
  __IO uint32_t ISR;          /*!< DFSDM interrupt and status register,              Address offset: 0x108 */
  __IO uint32_t ICR;          /*!< DFSDM interrupt flag clear register,              Address offset: 0x10C */
  __IO uint32_t JCHGR;        /*!< DFSDM injected channel group selection register,  Address offset: 0x110 */
  __IO uint32_t FCR;          /*!< DFSDM filter control register,                    Address offset: 0x114 */
  __IO uint32_t JDATAR;       /*!< DFSDM data register for injected group,           Address offset: 0x118 */
  __IO uint32_t RDATAR;       /*!< DFSDM data register for regular group,            Address offset: 0x11C */
  __IO uint32_t AWHTR;        /*!< DFSDM analog watchdog high threshold register,    Address offset: 0x120 */
  __IO uint32_t AWLTR;        /*!< DFSDM analog watchdog low threshold register,     Address offset: 0x124 */
  __IO uint32_t AWSR;         /*!< DFSDM analog watchdog status register             Address offset: 0x128 */
  __IO uint32_t AWCFR;        /*!< DFSDM analog watchdog clear flag register         Address offset: 0x12C */
  __IO uint32_t EXMAX;        /*!< DFSDM extreme detector maximum register,          Address offset: 0x130 */
  __IO uint32_t EXMIN;        /*!< DFSDM extreme detector minimum register           Address offset: 0x134 */
  __IO uint32_t CNVTIMR;      /*!< DFSDM conversion timer,                           Address offset: 0x138 */
} DFSDM_Filter_TypeDef;

/**
  * @brief DFSDM channel configuration registers
  */
typedef struct
{
  __IO uint32_t CHCFGR1;      /*!< DFSDM channel configuration register1,            Address offset: 0x00 */
  __IO uint32_t CHCFGR2;      /*!< DFSDM channel configuration register2,            Address offset: 0x04 */
  __IO uint32_t AWSCDR;       /*!< DFSDM channel analog watchdog and
                                   short circuit detector register,                  Address offset: 0x08 */
  __IO uint32_t CHWDATAR;     /*!< DFSDM channel watchdog filter data register,      Address offset: 0x0C */
  __IO uint32_t CHDATINR;     /*!< DFSDM channel data input register,                Address offset: 0x10 */
} DFSDM_Channel_TypeDef;

/**
  * @brief Debug MCU
  */

typedef struct
{
  __IO uint32_t IDCODE;        /*!< MCU device ID code,                     Address offset: 0x00 */
  __IO uint32_t CR;            /*!< Debug MCU configuration register,       Address offset: 0x04 */
  __IO uint32_t  RESERVED4[5]; /*!< Reserved,                               Address offset: 0x08 */
  __IO uint32_t D1AHB1FZ1;     /*!< Debug MCU D1AHB1FZ1 freeze register,    Address offset: 0x1C */
  __IO uint32_t D1AHB1FZ2;     /*!< Debug MCU D1AHB1FZ2 freeze register,    Address offset: 0x20 */
  __IO uint32_t D2AHB1FZ1;     /*!< Debug MCU D2AHB1FZ1 freeze register,    Address offset: 0x24 */
  __IO uint32_t D2AHB1FZ2;     /*!< Debug MCU D2AHB1FZ2 freeze register,    Address offset: 0x28 */
  __IO uint32_t D3AHB1FZ1;     /*!< Debug MCU D3AHB1FZ1 freeze register,    Address offset: 0x2C */
  __IO uint32_t D3AHB1FZ2;     /*!< Debug MCU D3AHB1FZ2 freeze register,    Address offset: 0x30 */
  __IO uint32_t D1APB1FZ1;     /*!< Debug MCU D1APB1FZ1 freeze register,    Address offset: 0x34 */
  __IO uint32_t D1APB1FZ2;     /*!< Debug MCU D1APB1FZ2 freeze register,    Address offset: 0x38 */
  __IO uint32_t D2APB1LFZ1;    /*!< Debug MCU D2APB1LFZ1 freeze register,   Address offset: 0x3C */
  __IO uint32_t D2APB1LFZ2;    /*!< Debug MCU D2APB1LFZ2 freeze register,   Address offset: 0x40 */
  __IO uint32_t D2APB1HFZ1;    /*!< Debug MCU D2APB1LFZ1 freeze register,   Address offset: 0x44 */
  __IO uint32_t D2APB1HFZ2;    /*!< Debug MCU D2APB1LFZ2 freeze register,   Address offset: 0x48 */
  __IO uint32_t D2APB2FZ1;     /*!< Debug MCU D2APB2FZ1 freeze register,    Address offset: 0x4C */
  __IO uint32_t D2APB2FZ2;     /*!< Debug MCU D2APB2FZ2 freeze register,    Address offset: 0x50 */
  __IO uint32_t D3APB1FZ1;     /*!< Debug MCU D3APB1FZ1 freeze register,    Address offset: 0x54 */
  __IO uint32_t D3APB1FZ2;     /*!< Debug MCU D3APB1FZ2 freeze register,    Address offset: 0x58 */

}DBGMCU_TypeDef;

/** 
  * @brief DCMI
  */

typedef struct
{
  __IO uint32_t CR;       /*!< DCMI control register 1,                       Address offset: 0x00 */
  __IO uint32_t SR;       /*!< DCMI status register,                          Address offset: 0x04 */
  __IO uint32_t RISR;     /*!< DCMI raw interrupt status register,            Address offset: 0x08 */
  __IO uint32_t IER;      /*!< DCMI interrupt enable register,                Address offset: 0x0C */
  __IO uint32_t MISR;     /*!< DCMI masked interrupt status register,         Address offset: 0x10 */
  __IO uint32_t ICR;      /*!< DCMI interrupt clear register,                 Address offset: 0x14 */
  __IO uint32_t ESCR;     /*!< DCMI embedded synchronization code register,   Address offset: 0x18 */
  __IO uint32_t ESUR;     /*!< DCMI embedded synchronization unmask register, Address offset: 0x1C */
  __IO uint32_t CWSTRTR;  /*!< DCMI crop window start,                        Address offset: 0x20 */
  __IO uint32_t CWSIZER;  /*!< DCMI crop window size,                         Address offset: 0x24 */
  __IO uint32_t DR;       /*!< DCMI data register,                            Address offset: 0x28 */
} DCMI_TypeDef;

/**
  * @brief DMA Controller
  */

typedef struct
{
  __IO uint32_t CR;     /*!< DMA stream x configuration register      */
  __IO uint32_t NDTR;   /*!< DMA stream x number of data register     */
  __IO uint32_t PAR;    /*!< DMA stream x peripheral address register */
  __IO uint32_t M0AR;   /*!< DMA stream x memory 0 address register   */
  __IO uint32_t M1AR;   /*!< DMA stream x memory 1 address register   */
  __IO uint32_t FCR;    /*!< DMA stream x FIFO control register       */
} DMA_Stream_TypeDef;

typedef struct
{
  __IO uint32_t LISR;   /*!< DMA low interrupt status register,      Address offset: 0x00 */
  __IO uint32_t HISR;   /*!< DMA high interrupt status register,     Address offset: 0x04 */
  __IO uint32_t LIFCR;  /*!< DMA low interrupt flag clear register,  Address offset: 0x08 */
  __IO uint32_t HIFCR;  /*!< DMA high interrupt flag clear register, Address offset: 0x0C */
} DMA_TypeDef;

typedef struct
{
  __IO uint32_t CCR;          /*!< DMA channel x configuration register        */
  __IO uint32_t CNDTR;        /*!< DMA channel x number of data register       */
  __IO uint32_t CPAR;         /*!< DMA channel x peripheral address register   */
  __IO uint32_t CMAR;         /*!< DMA channel x memory address register       */
} BDMA_Channel_TypeDef;

typedef struct
{
  __IO uint32_t ISR;          /*!< DMA interrupt status register,               Address offset: 0x00 */
  __IO uint32_t IFCR;         /*!< DMA interrupt flag clear register,           Address offset: 0x04 */
} BDMA_TypeDef; 

typedef struct
{
  __IO uint32_t  CCR;        /*!< DMA Multiplexer Channel x Control Register   */
}DMAMUX_Channel_TypeDef;

typedef struct
{
  __IO uint32_t  CSR;      /*!< DMA Channel Status Register     */
  __IO uint32_t  CFR;      /*!< DMA Channel Clear Flag Register */
}DMAMUX_ChannelStatus_TypeDef;

typedef struct
{
  __IO uint32_t  RGCR;        /*!< DMA Request Generator x Control Register   */
}DMAMUX_RequestGen_TypeDef;

typedef struct
{
  __IO uint32_t  RGSR;        /*!< DMA Request Generator Status Register       */
  __IO uint32_t  RGCFR;       /*!< DMA Request Generator Clear Flag Register   */
}DMAMUX_RequestGenStatus_TypeDef;

/** 
  * @brief MDMA Controller
  */
typedef struct
{
  __IO uint32_t  GISR0;   /*!< MDMA Global Interrupt/Status Register 0,          Address offset: 0x00 */
  __IO uint32_t  GISR1;   /*!< MDMA Global Interrupt/Status Register 1,          Address offset: 0x04 */
}MDMA_TypeDef;

typedef struct
{
  __IO uint32_t  CISR;      /*!< MDMA channel x interrupt/status register,             Address offset: 0x40 */
  __IO uint32_t  CIFCR;     /*!< MDMA channel x interrupt flag clear register,         Address offset: 0x44 */
  __IO uint32_t  CESR;      /*!< MDMA Channel x error status register,                 Address offset: 0x48 */
  __IO uint32_t  CCR;       /*!< MDMA channel x control register,                      Address offset: 0x4C */ 
  __IO uint32_t  CTCR;      /*!< MDMA channel x Transfer Configuration register,       Address offset: 0x50 */
  __IO uint32_t  CBNDTR;    /*!< MDMA Channel x block number of data register,         Address offset: 0x54 */
  __IO uint32_t  CSAR;      /*!< MDMA channel x source address register,               Address offset: 0x58 */
  __IO uint32_t  CDAR;      /*!< MDMA channel x destination address register,          Address offset: 0x5C */
  __IO uint32_t  CBRUR;     /*!< MDMA channel x Block Repeat address Update register,  Address offset: 0x60 */
  __IO uint32_t  CLAR;      /*!< MDMA channel x Link Address register,                 Address offset: 0x64 */
  __IO uint32_t  CTBR;      /*!< MDMA channel x Trigger and Bus selection Register,    Address offset: 0x68 */
  uint32_t       RESERVED0; /*!< Reserved, 0x68                                                             */  
 __IO uint32_t    CMAR;      /*!< MDMA channel x Mask address register,                Address offset: 0x70 */
 __IO uint32_t   CMDR;       /*!< MDMA channel x Mask Data register,                   Address offset: 0x74 */
}MDMA_Channel_TypeDef;
/** 
  * @brief DMA2D Controller
  */

typedef struct
{
  __IO uint32_t CR;            /*!< DMA2D Control Register,                         Address offset: 0x00 */
  __IO uint32_t ISR;           /*!< DMA2D Interrupt Status Register,                Address offset: 0x04 */
  __IO uint32_t IFCR;          /*!< DMA2D Interrupt Flag Clear Register,            Address offset: 0x08 */
  __IO uint32_t FGMAR;         /*!< DMA2D Foreground Memory Address Register,       Address offset: 0x0C */
  __IO uint32_t FGOR;          /*!< DMA2D Foreground Offset Register,               Address offset: 0x10 */
  __IO uint32_t BGMAR;         /*!< DMA2D Background Memory Address Register,       Address offset: 0x14 */
  __IO uint32_t BGOR;          /*!< DMA2D Background Offset Register,               Address offset: 0x18 */
  __IO uint32_t FGPFCCR;       /*!< DMA2D Foreground PFC Control Register,          Address offset: 0x1C */
  __IO uint32_t FGCOLR;        /*!< DMA2D Foreground Color Register,                Address offset: 0x20 */
  __IO uint32_t BGPFCCR;       /*!< DMA2D Background PFC Control Register,          Address offset: 0x24 */
  __IO uint32_t BGCOLR;        /*!< DMA2D Background Color Register,                Address offset: 0x28 */
  __IO uint32_t FGCMAR;        /*!< DMA2D Foreground CLUT Memory Address Register,  Address offset: 0x2C */
  __IO uint32_t BGCMAR;        /*!< DMA2D Background CLUT Memory Address Register,  Address offset: 0x30 */
  __IO uint32_t OPFCCR;        /*!< DMA2D Output PFC Control Register,              Address offset: 0x34 */
  __IO uint32_t OCOLR;         /*!< DMA2D Output Color Register,                    Address offset: 0x38 */
  __IO uint32_t OMAR;          /*!< DMA2D Output Memory Address Register,           Address offset: 0x3C */
  __IO uint32_t OOR;           /*!< DMA2D Output Offset Register,                   Address offset: 0x40 */
  __IO uint32_t NLR;           /*!< DMA2D Number of Line Register,                  Address offset: 0x44 */
  __IO uint32_t LWR;           /*!< DMA2D Line Watermark Register,                  Address offset: 0x48 */
  __IO uint32_t AMTCR;         /*!< DMA2D AHB Master Timer Configuration Register,  Address offset: 0x4C */
  uint32_t      RESERVED[236]; /*!< Reserved, 0x50-0x3FF */
  __IO uint32_t FGCLUT[256];   /*!< DMA2D Foreground CLUT,                          Address offset:400-7FF */
  __IO uint32_t BGCLUT[256];   /*!< DMA2D Background CLUT,                          Address offset:800-BFF */
} DMA2D_TypeDef;

/** 
  * @brief Ethernet MAC
  */
typedef struct
{
  __IO uint32_t MACCR;
  __IO uint32_t MACECR;
  __IO uint32_t MACPFR;
  __IO uint32_t MACWTR;
  __IO uint32_t MACHTHR;
  __IO uint32_t MACHTLR;
  uint32_t      RESERVED1[14];
  __IO uint32_t MACVTR;
  uint32_t      RESERVED2; 
  __IO uint32_t MACVHTR;
  uint32_t      RESERVED3;
  __IO uint32_t MACVIR; 
  __IO uint32_t MACIVIR;
  uint32_t      RESERVED4[2];
  __IO uint32_t MACTFCR;
  uint32_t      RESERVED5[7];
  __IO uint32_t MACRFCR;
  uint32_t      RESERVED6[7];
  __IO uint32_t MACISR;
  __IO uint32_t MACIER;
  __IO uint32_t MACRTSR;
  uint32_t      RESERVED7;
  __IO uint32_t MACPCSR;
  __IO uint32_t MACRWKPFR;
  uint32_t      RESERVED8[2];
  __IO uint32_t MACLPICSR;
  __IO uint32_t MACLPITCR;
  __IO uint32_t MACLPIETR;            
  __IO uint32_t MAC1USTCR;            
  uint32_t      RESERVED9[12];
  __IO uint32_t MACVR;
  __IO uint32_t MACDR;
  uint32_t      RESERVED10;
  __IO uint32_t MACHWF0R;
  __IO uint32_t MACHWF1R;
  __IO uint32_t MACHWF2R;
  uint32_t      RESERVED11[54];
  __IO uint32_t MACMDIOAR;
  __IO uint32_t MACMDIODR;
  uint32_t      RESERVED12[2];
  __IO uint32_t MACARPAR;
  uint32_t      RESERVED13[59];
  __IO uint32_t MACA0HR;
  __IO uint32_t MACA0LR;
  __IO uint32_t MACA1HR;
  __IO uint32_t MACA1LR;
  __IO uint32_t MACA2HR;
  __IO uint32_t MACA2LR;
  __IO uint32_t MACA3HR;
  __IO uint32_t MACA3LR;
  uint32_t      RESERVED14[248];
  __IO uint32_t MMCCR;
  __IO uint32_t MMCRIR;
  __IO uint32_t MMCTIR;
  __IO uint32_t MMCRIMR;
  __IO uint32_t MMCTIMR;
  uint32_t      RESERVED15[14];
  __IO uint32_t MMCTSCGPR;
  __IO uint32_t MMCTMCGPR;
  int32_t       RESERVED16[5];
  __IO uint32_t MMCTPCGR;
  uint32_t      RESERVED17[10];
  __IO uint32_t MMCRCRCEPR;
  __IO uint32_t MMCRAEPR;
  uint32_t      RESERVED18[10];
  __IO uint32_t MMCRUPGR;
  uint32_t      RESERVED19[9];
  __IO uint32_t MMCTLPIMSTR;
  __IO uint32_t MMCTLPITCR;
  __IO uint32_t MMCRLPIMSTR;
  __IO uint32_t MMCRLPITCR;
  uint32_t      RESERVED20[65];
  __IO uint32_t MACL3L4C0R;
  __IO uint32_t MACL4A0R;
  uint32_t      RESERVED21[2];
  __IO uint32_t MACL3A0R0R;
  __IO uint32_t MACL3A1R0R;
  __IO uint32_t MACL3A2R0R;
  __IO uint32_t MACL3A3R0R;
  uint32_t      RESERVED22[4];
  __IO uint32_t MACL3L4C1R;
  __IO uint32_t MACL4A1R;
  uint32_t      RESERVED23[2];
  __IO uint32_t MACL3A0R1R;
  __IO uint32_t MACL3A1R1R;
  __IO uint32_t MACL3A2R1R;
  __IO uint32_t MACL3A3R1R;
  uint32_t      RESERVED24[108];
  __IO uint32_t MACTSCR;
  __IO uint32_t MACSSIR;
  __IO uint32_t MACSTSR;
  __IO uint32_t MACSTNR;
  __IO uint32_t MACSTSUR;
  __IO uint32_t MACSTNUR;
  __IO uint32_t MACTSAR;
  uint32_t      RESERVED25;          
  __IO uint32_t MACTSSR;
  uint32_t      RESERVED26[3];
  __IO uint32_t MACTTSSNR;
  __IO uint32_t MACTTSSSR;
  uint32_t      RESERVED27[2];
  __IO uint32_t MACACR;
  uint32_t      RESERVED28;
  __IO uint32_t MACATSNR;
  __IO uint32_t MACATSSR;
  __IO uint32_t MACTSIACR;
  __IO uint32_t MACTSEACR;
  __IO uint32_t MACTSICNR;
  __IO uint32_t MACTSECNR;
  uint32_t      RESERVED29[4];
  __IO uint32_t MACPPSCR;
  uint32_t      RESERVED30[3];
  __IO uint32_t MACPPSTTSR;
  __IO uint32_t MACPPSTTNR;
  __IO uint32_t MACPPSIR;
  __IO uint32_t MACPPSWR;
  uint32_t      RESERVED31[12];
  __IO uint32_t MACPOCR;
  __IO uint32_t MACSPI0R;
  __IO uint32_t MACSPI1R;
  __IO uint32_t MACSPI2R;
  __IO uint32_t MACLMIR;
  uint32_t      RESERVED32[11];
  __IO uint32_t MTLOMR;
  uint32_t      RESERVED33[7];
  __IO uint32_t MTLISR;
  uint32_t      RESERVED34[55];
  __IO uint32_t MTLTQOMR;
  __IO uint32_t MTLTQUR;
  __IO uint32_t MTLTQDR;
  uint32_t      RESERVED35[8];
  __IO uint32_t MTLQICSR;
  __IO uint32_t MTLRQOMR;
  __IO uint32_t MTLRQMPOCR;
  __IO uint32_t MTLRQDR;
  uint32_t      RESERVED36[177];
  __IO uint32_t DMAMR;
  __IO uint32_t DMASBMR;
  __IO uint32_t DMAISR;
  __IO uint32_t DMADSR;
  uint32_t      RESERVED37[60];
  __IO uint32_t DMACCR;
  __IO uint32_t DMACTCR;
  __IO uint32_t DMACRCR;
  uint32_t      RESERVED38[2];
  __IO uint32_t DMACTDLAR;
  uint32_t      RESERVED39;
  __IO uint32_t DMACRDLAR;
  __IO uint32_t DMACTDTPR;
  uint32_t      RESERVED40;
  __IO uint32_t DMACRDTPR;
  __IO uint32_t DMACTDRLR;
  __IO uint32_t DMACRDRLR;
  __IO uint32_t DMACIER;
  __IO uint32_t DMACRIWTR;
__IO uint32_t DMACSFCSR;
  uint32_t      RESERVED41;
  __IO uint32_t DMACCATDR;
  uint32_t      RESERVED42;
  __IO uint32_t DMACCARDR;
  uint32_t      RESERVED43;
  __IO uint32_t DMACCATBR;
  uint32_t      RESERVED44;
  __IO uint32_t DMACCARBR;
  __IO uint32_t DMACSR;
uint32_t      RESERVED45[2];
__IO uint32_t DMACMFCR;
}ETH_TypeDef;

/**
  * @brief External Interrupt/Event Controller
  */

typedef struct
{
__IO uint32_t RTSR1;               /*!< EXTI Rising trigger selection register,       Address offset: 0x00 */      
__IO uint32_t FTSR1;               /*!< EXTI Falling trigger selection register,      Address offset: 0x04 */      
__IO uint32_t SWIER1;              /*!< EXTI Software interrupt event register,       Address offset: 0x08 */      
__IO uint32_t D3PMR1;              /*!< EXTI D3 Pending mask register,                Address offset: 0x0C */      
__IO uint32_t D3PCR1L;             /*!< EXTI D3 Pending clear selection register low, Address offset: 0x10 */      
__IO uint32_t D3PCR1H;             /*!< EXTI D3 Pending clear selection register High,Address offset: 0x14 */      
uint32_t      RESERVED1;           /*!< Reserved, 0x18                                                     */       
uint32_t      RESERVED2;           /*!< Reserved, 0x1C                                                     */       
__IO uint32_t RTSR2;               /*!< EXTI Rising trigger selection register,       Address offset: 0x20 */      
__IO uint32_t FTSR2;               /*!< EXTI Falling trigger selection register,      Address offset: 0x24 */      
__IO uint32_t SWIER2;              /*!< EXTI Software interrupt event register,       Address offset: 0x28 */      
__IO uint32_t D3PMR2;              /*!< EXTI D3 Pending mask register,                Address offset: 0x2C */      
__IO uint32_t D3PCR2L;             /*!< EXTI D3 Pending clear selection register low, Address offset: 0x30 */      
__IO uint32_t D3PCR2H;             /*!< EXTI D3 Pending clear selection register High,Address offset: 0x34 */      
uint32_t      RESERVED3;           /*!< Reserved, 0x38                                                     */       
uint32_t      RESERVED4;           /*!< Reserved, 0x3C                                                     */      
__IO uint32_t RTSR3;               /*!< EXTI Rising trigger selection register,       Address offset: 0x40 */      
__IO uint32_t FTSR3;               /*!< EXTI Falling trigger selection register,      Address offset: 0x44 */      
__IO uint32_t SWIER3;              /*!< EXTI Software interrupt event register,       Address offset: 0x48 */      
__IO uint32_t D3PMR3;              /*!< EXTI D3 Pending mask register,                Address offset: 0x4C */      
__IO uint32_t D3PCR3L;             /*!< EXTI D3 Pending clear selection register low, Address offset: 0x50 */      
__IO uint32_t D3PCR3H;             /*!< EXTI D3 Pending clear selection register High,Address offset: 0x54 */      
}EXTI_TypeDef;

typedef struct
{
__IO uint32_t IMR1;                /*!< EXTI Interrupt mask register,                Address offset: 0x00 */      
__IO uint32_t EMR1;                /*!< EXTI Event mask register,                    Address offset: 0x04 */      
__IO uint32_t PR1;                 /*!< EXTI Pending register,                       Address offset: 0x08 */      
uint32_t      RESERVED1;           /*!< Reserved, 0x0C                                                    */                                                  
__IO uint32_t IMR2;                /*!< EXTI Interrupt mask register,                Address offset: 0x10 */      
__IO uint32_t EMR2;                /*!< EXTI Event mask register,                    Address offset: 0x14 */      
__IO uint32_t PR2;                 /*!< EXTI Pending register,                       Address offset: 0x18 */      
uint32_t      RESERVED2;           /*!< Reserved, 0x1C                                                    */      
__IO uint32_t IMR3;                /*!< EXTI Interrupt mask register,                Address offset: 0x20 */      
__IO uint32_t EMR3;                /*!< EXTI Event mask register,                    Address offset: 0x24 */      
__IO uint32_t PR3;                 /*!< EXTI Pending register,                       Address offset: 0x28 */      
}EXTI_Core_TypeDef;


/**
  * @brief FLASH Registers
  */

typedef struct
{
  __IO uint32_t ACR;              /*!< FLASH access control register,                           Address offset: 0x00 */
  __IO uint32_t KEYR1;           /*!< Flash Key Register for bank1,                            Address offset: 0x04 */
  __IO uint32_t OPTKEYR;         /*!< Flash Option Key Register,                                Address offset: 0x08 */
  __IO uint32_t CR1;             /*!< Flash Control Register for bank1,                        Address offset: 0x0C */
  __IO uint32_t SR1;             /*!< Flash Status Register for bank1,                         Address offset: 0x10 */
  __IO uint32_t CCR1;            /*!< Flash Control Register for bank1,                        Address offset: 0x14 */
  __IO uint32_t OPTCR;           /*!< Flash Option Control Register,                            Address offset: 0x18 */
  __IO uint32_t OPTSR_CUR;       /*!< Flash Option Status Current Register,                     Address offset: 0x1C */
  __IO uint32_t OPTSR_PRG;       /*!< Flash Option Status Current Register,                     Address offset: 0x20 */
  __IO uint32_t OPTCCR;          /*!< Flash Option Clear Control Register,                      Address offset: 0x24 */
  __IO uint32_t PRAR_CUR1;       /*!< Flash Current Protection Address Register for bank1,     Address offset: 0x28 */
  __IO uint32_t PRAR_PRG1;       /*!< Flash Protection Address to Program Register for bank1,  Address offset: 0x2C */
  __IO uint32_t SCAR_CUR1;       /*!< Flash Current Secure Address Register for bank1,         Address offset: 0x30 */
  __IO uint32_t SCAR_PRG1;       /*!< Flash Secure Address Register for bank1,                 Address offset: 0x34 */
  __IO uint32_t WPSN_CUR1;       /*!< Flash Current Write Protection Register on bank1,        Address offset: 0x38 */
  __IO uint32_t WPSN_PRG1;       /*!< Flash Write Protection to Program Register on bank1,     Address offset: 0x3C */
  __IO uint32_t BOOT7_CUR;       /*!< Flash Current Boot Address for Pelican Core Register,     Address offset: 0x40 */
  __IO uint32_t BOOT7_PRG;       /*!< Flash Boot Address to Program for Pelican Core Register,  Address offset: 0x44 */
  uint32_t      RESERVED0[2];    /*!< Reserved, 0x48 to 0x4C                                                        */
  __IO uint32_t CRCCR1;          /*!< Flash CRC Control register For Bank1 Register ,          Address offset: 0x50 */
  __IO uint32_t CRCSADD1;        /*!< Flash CRC Start Address Register for Bank1 ,             Address offset: 0x54 */
  __IO uint32_t CRCEADD1;        /*!< Flash CRC End Address Register for Bank1 ,               Address offset: 0x58 */
  __IO uint32_t CRCDATA1;        /*!< Flash CRC Data Register for Bank1 ,                      Address offset: 0x5C */
  __IO uint32_t ECC_FA1;         /*!< Flash ECC Fail Address For Bank1 Register ,              Address offset: 0x60 */
  uint32_t      RESERVED1[40];   /*!< Reserved, 0x64 to 0x100                                                       */
  __IO uint32_t KEYR2;           /*!< Flash Key Register for bank2,                           Address offset: 0x104 */
  uint32_t      RESERVED2;       /*!< Reserved, 0x108                                                               */
  __IO uint32_t CR2;             /*!< Flash Control Register for bank2,                       Address offset: 0x10C */
  __IO uint32_t SR2;             /*!< Flash Status Register for bank2,                        Address offset: 0x110 */
  __IO uint32_t CCR2;            /*!< Flash Status Register for bank2,                        Address offset: 0x114 */
  uint32_t      RESERVED3[4];    /*!< Reserved, 0x118 to 0x124                                                      */
  __IO uint32_t PRAR_CUR2;       /*!< Flash Current Protection Address Register for bank2,    Address offset: 0x128 */
  __IO uint32_t PRAR_PRG2;       /*!< Flash Protection Address to Program Register for bank2, Address offset: 0x12C */
  __IO uint32_t SCAR_CUR2;       /*!< Flash Current Secure Address Register for bank2,        Address offset: 0x130 */
  __IO uint32_t SCAR_PRG2;       /*!< Flash Secure Address Register for bank2,                Address offset: 0x134 */
  __IO uint32_t WPSN_CUR2;       /*!< Flash Current Write Protection Register on bank2,       Address offset: 0x138 */
  __IO uint32_t WPSN_PRG2;       /*!< Flash Write Protection to Program Register on bank2,    Address offset: 0x13C */
  uint32_t      RESERVED4[4];    /*!< Reserved, 0x140 to 0x14C                                                      */
  __IO uint32_t CRCCR2;          /*!< Flash CRC Control register For Bank2 Register ,         Address offset: 0x150 */
  __IO uint32_t CRCSADD2;        /*!< Flash CRC Start Address Register for Bank2 ,            Address offset: 0x154 */
  __IO uint32_t CRCEADD2;        /*!< Flash CRC End Address Register for Bank2 ,              Address offset: 0x158 */
  __IO uint32_t CRCDATA2;        /*!< Flash CRC Data Register for Bank2 ,                     Address offset: 0x15C */
  __IO uint32_t ECC_FA2;         /*!< Flash ECC Fail Address For Bank2 Register ,             Address offset: 0x160 */
} FLASH_TypeDef;

/**
  * @brief Flexible Memory Controller
  */

typedef struct
{
  __IO uint32_t BTCR[8];    /*!< NOR/PSRAM chip-select control register(BCR) and chip-select timing register(BTR), Address offset: 0x00-1C */
} FMC_Bank1_TypeDef;

/**
  * @brief Flexible Memory Controller Bank1E
  */

typedef struct
{
  __IO uint32_t BWTR[7];    /*!< NOR/PSRAM write timing registers, Address offset: 0x104-0x11C */
} FMC_Bank1E_TypeDef;

/**
  * @brief Flexible Memory Controller Bank2
  */

typedef struct
{
  __IO uint32_t PCR2;       /*!< NAND Flash control register 2,                       Address offset: 0x60 */
  __IO uint32_t SR2;        /*!< NAND Flash FIFO status and interrupt register 2,     Address offset: 0x64 */
  __IO uint32_t PMEM2;      /*!< NAND Flash Common memory space timing register 2,    Address offset: 0x68 */
  __IO uint32_t PATT2;      /*!< NAND Flash Attribute memory space timing register 2, Address offset: 0x6C */
  uint32_t      RESERVED0;  /*!< Reserved, 0x70                                                            */
  __IO uint32_t ECCR2;      /*!< NAND Flash ECC result registers 2,                   Address offset: 0x74 */
} FMC_Bank2_TypeDef;

/**
  * @brief Flexible Memory Controller Bank3
  */

typedef struct
{
  __IO uint32_t PCR;       /*!< NAND Flash control register 3,                       Address offset: 0x80 */
  __IO uint32_t SR;        /*!< NAND Flash FIFO status and interrupt register 3,     Address offset: 0x84 */
  __IO uint32_t PMEM;      /*!< NAND Flash Common memory space timing register 3,    Address offset: 0x88 */
  __IO uint32_t PATT;      /*!< NAND Flash Attribute memory space timing register 3, Address offset: 0x8C */
  uint32_t      RESERVED;  /*!< Reserved, 0x90                                                            */
  __IO uint32_t ECCR;      /*!< NAND Flash ECC result registers 3,                   Address offset: 0x94 */
} FMC_Bank3_TypeDef;

/**
  * @brief Flexible Memory Controller Bank5 and 6
  */


typedef struct
{
  __IO uint32_t SDCR[2];        /*!< SDRAM Control registers ,      Address offset: 0x140-0x144  */
  __IO uint32_t SDTR[2];        /*!< SDRAM Timing registers ,       Address offset: 0x148-0x14C  */
  __IO uint32_t SDCMR;       /*!< SDRAM Command Mode register,    Address offset: 0x150  */
  __IO uint32_t SDRTR;       /*!< SDRAM Refresh Timer register,   Address offset: 0x154  */
  __IO uint32_t SDSR;        /*!< SDRAM Status register,          Address offset: 0x158  */
} FMC_Bank5_6_TypeDef; 

/**
  * @brief General Purpose I/O
  */

typedef struct
{
  __IO uint32_t MODER;    /*!< GPIO port mode register,               Address offset: 0x00      */
  __IO uint32_t OTYPER;   /*!< GPIO port output type register,        Address offset: 0x04      */
  __IO uint32_t OSPEEDR;  /*!< GPIO port output speed register,       Address offset: 0x08      */
  __IO uint32_t PUPDR;    /*!< GPIO port pull-up/pull-down register,  Address offset: 0x0C      */
  __IO uint32_t IDR;      /*!< GPIO port input data register,         Address offset: 0x10      */
  __IO uint32_t ODR;      /*!< GPIO port output data register,        Address offset: 0x14      */
  __IO uint16_t BSRRL;    /*!< GPIO port bit set/reset low register,  Address offset: 0x18      */
  __IO uint16_t BSRRH;    /*!< GPIO port bit set/reset high register, Address offset: 0x1A      */
  __IO uint32_t LCKR;     /*!< GPIO port configuration lock register, Address offset: 0x1C      */
  __IO uint32_t AFR[2];   /*!< GPIO alternate function registers,     Address offset: 0x20-0x24 */
} GPIO_TypeDef;

/**
  * @brief Operational Amplifier (OPAMP)
  */

typedef struct
{
  __IO uint32_t CSR;          /*!< OPAMP control/status register,                     Address offset: 0x00 */
  __IO uint32_t OTR;          /*!< OPAMP offset trimming register for normal mode,    Address offset: 0x04 */
  __IO uint32_t HSOTR;        /*!< OPAMP offset trimming register for high speed mode, Address offset: 0x08 */
} OPAMP_TypeDef;

/**
  * @brief System configuration controller
  */

typedef struct
{
 uint32_t RESERVED1;           /*!< Reserved,                                           Address offset: 0x00        */
 __IO uint32_t PMCR;           /*!< SYSCFG peripheral mode configuration register,      Address offset: 0x04        */
 __IO uint32_t EXTICR[4];      /*!< SYSCFG external interrupt configuration registers,  Address offset: 0x08-0x14   */
 uint32_t RESERVED2[2];        /*!< Reserved,                                            Address offset: 0x18-0x1C  */
 __IO uint32_t CCCSR;          /*!< SYSCFG compensation cell control/status register,   Address offset: 0x20        */
 __IO uint32_t CCVR;           /*!< SYSCFG compensation cell value register,            Address offset: 0x24        */
 __IO uint32_t CCCR;           /*!< SYSCFG compensation cell code register,             Address offset: 0x28        */
  uint32_t     RESERVED3[62];  /*!< Reserved, 0x2C-0x120                                                            */
 __IO uint32_t PKGR;           /*!< SYSCFG package register,                            Address offset: 0x124       */
  uint32_t     RESERVED4[118]; /*!< Reserved, 0x128-0x2FC                                                           */
 __IO uint32_t UR0;            /*!< SYSCFG user register 0,                             Address offset: 0x300       */
 __IO uint32_t UR1;            /*!< SYSCFG user register 1,                             Address offset: 0x304       */
 __IO uint32_t UR2;            /*!< SYSCFG user register 2,                             Address offset: 0x308       */
 __IO uint32_t UR3;            /*!< SYSCFG user register 3,                             Address offset: 0x30C       */
 __IO uint32_t UR4;            /*!< SYSCFG user register 4,                             Address offset: 0x310       */
 __IO uint32_t UR5;            /*!< SYSCFG user register 5,                             Address offset: 0x314       */
 __IO uint32_t UR6;            /*!< SYSCFG user register 6,                             Address offset: 0x318       */
 __IO uint32_t UR7;            /*!< SYSCFG user register 7,                             Address offset: 0x31C       */
 __IO uint32_t UR8;            /*!< SYSCFG user register 8,                             Address offset: 0x320       */
 __IO uint32_t UR9;            /*!< SYSCFG user register 9,                             Address offset: 0x324       */
 __IO uint32_t UR10;           /*!< SYSCFG user register 10,                            Address offset: 0x328       */
 __IO uint32_t UR11;           /*!< SYSCFG user register 11,                            Address offset: 0x32C       */
 __IO uint32_t UR12;           /*!< SYSCFG user register 12,                            Address offset: 0x330       */
 __IO uint32_t UR13;           /*!< SYSCFG user register 13,                            Address offset: 0x334       */
 __IO uint32_t UR14;           /*!< SYSCFG user register 14,                            Address offset: 0x338       */
 __IO uint32_t UR15;           /*!< SYSCFG user register 15,                            Address offset: 0x33C       */
 __IO uint32_t UR16;           /*!< SYSCFG user register 16,                            Address offset: 0x340       */
 __IO uint32_t UR17;           /*!< SYSCFG user register 17,                            Address offset: 0x344       */

} SYSCFG_TypeDef;

/**
  * @brief Inter-integrated Circuit Interface
  */

typedef struct
{
  __IO uint32_t CR1;      /*!< I2C Control register 1,            Address offset: 0x00 */
  __IO uint32_t CR2;      /*!< I2C Control register 2,            Address offset: 0x04 */
  __IO uint32_t OAR1;     /*!< I2C Own address 1 register,        Address offset: 0x08 */
  __IO uint32_t OAR2;     /*!< I2C Own address 2 register,        Address offset: 0x0C */
  __IO uint32_t TIMINGR;  /*!< I2C Timing register,               Address offset: 0x10 */
  __IO uint32_t TIMEOUTR; /*!< I2C Timeout register,              Address offset: 0x14 */
  __IO uint32_t ISR;      /*!< I2C Interrupt and status register, Address offset: 0x18 */
  __IO uint32_t ICR;      /*!< I2C Interrupt clear register,      Address offset: 0x1C */
  __IO uint32_t PECR;     /*!< I2C PEC register,                  Address offset: 0x20 */
  __IO uint32_t RXDR;     /*!< I2C Receive data register,         Address offset: 0x24 */
  __IO uint32_t TXDR;     /*!< I2C Transmit data register,        Address offset: 0x28 */
} I2C_TypeDef;

/**
  * @brief Independent WATCHDOG
  */

typedef struct
{
  __IO uint32_t KR;   /*!< IWDG Key register,       Address offset: 0x00 */
  __IO uint32_t PR;   /*!< IWDG Prescaler register, Address offset: 0x04 */
  __IO uint32_t RLR;  /*!< IWDG Reload register,    Address offset: 0x08 */
  __IO uint32_t SR;   /*!< IWDG Status register,    Address offset: 0x0C */
  __IO uint32_t WINR; /*!< IWDG Window register,    Address offset: 0x10 */
} IWDG_TypeDef;


/**
  * @brief JPEG Codec
  */
typedef struct
{
  __IO uint32_t CONFR0;          /*!< JPEG Codec Control Register (JPEG_CONFR0),        Address offset: 00h       */
  __IO uint32_t CONFR1;          /*!< JPEG Codec Control Register (JPEG_CONFR1),        Address offset: 04h       */
  __IO uint32_t CONFR2;          /*!< JPEG Codec Control Register (JPEG_CONFR2),        Address offset: 08h       */
  __IO uint32_t CONFR3;          /*!< JPEG Codec Control Register (JPEG_CONFR3),        Address offset: 0Ch       */ 
  __IO uint32_t CONFR4;          /*!< JPEG Codec Control Register (JPEG_CONFR4),        Address offset: 10h       */ 
  __IO uint32_t CONFR5;          /*!< JPEG Codec Control Register (JPEG_CONFR5),        Address offset: 14h       */ 
  __IO uint32_t CONFR6;          /*!< JPEG Codec Control Register (JPEG_CONFR6),        Address offset: 18h       */ 
  __IO uint32_t CONFR7;          /*!< JPEG Codec Control Register (JPEG_CONFR7),        Address offset: 1Ch       */
  uint32_t  Reserved20[4];       /* Reserved                                            Address offset: 20h-2Ch   */
  __IO uint32_t CR;              /*!< JPEG Control Register (JPEG_CR),                  Address offset: 30h       */ 
  __IO uint32_t SR;              /*!< JPEG Status Register (JPEG_SR),                   Address offset: 34h       */ 
  __IO uint32_t CFR;             /*!< JPEG Clear Flag Register (JPEG_CFR),              Address offset: 38h       */ 
  uint32_t  Reserved3c;          /* Reserved                                            Address offset: 3Ch       */
  __IO uint32_t DIR;             /*!< JPEG Data Input Register (JPEG_DIR),              Address offset: 40h       */
  __IO uint32_t DOR;             /*!< JPEG Data Output Register (JPEG_DOR),             Address offset: 44h       */
  uint32_t  Reserved48[2];       /* Reserved                                            Address offset: 48h-4Ch   */
  __IO uint32_t QMEM0[16];       /*!< JPEG quantization tables 0,                       Address offset: 50h-8Ch   */
  __IO uint32_t QMEM1[16];       /*!< JPEG quantization tables 1,                       Address offset: 90h-CCh   */
  __IO uint32_t QMEM2[16];       /*!< JPEG quantization tables 2,                       Address offset: D0h-10Ch  */
  __IO uint32_t QMEM3[16];       /*!< JPEG quantization tables 3,                       Address offset: 110h-14Ch */
  __IO uint32_t HUFFMIN[16];     /*!< JPEG HuffMin tables,                              Address offset: 150h-18Ch */
  __IO uint32_t HUFFBASE[32];    /*!< JPEG HuffSymb tables,                             Address offset: 190h-20Ch */
  __IO uint32_t HUFFSYMB[84];    /*!< JPEG HUFFSYMB tables,                             Address offset: 210h-35Ch */
  __IO uint32_t DHTMEM[103];     /*!< JPEG DHTMem tables,                               Address offset: 360h-4F8h */
  uint32_t  Reserved4FC;         /* Reserved                                            Address offset: 4FCh      */
  __IO uint32_t HUFFENC_AC0[88]; /*!< JPEG encodor, AC Huffman table 0,                 Address offset: 500h-65Ch */
  __IO uint32_t HUFFENC_AC1[88]; /*!< JPEG encodor, AC Huffman table 1,                 Address offset: 660h-7BCh */
  __IO uint32_t HUFFENC_DC0[8];  /*!< JPEG encodor, DC Huffman table 0,                 Address offset: 7C0h-7DCh */
  __IO uint32_t HUFFENC_DC1[8];  /*!< JPEG encodor, DC Huffman table 1,                 Address offset: 7E0h-7FCh */

} JPEG_TypeDef;


/**
  * @brief LCD
  */

typedef struct
{
  __IO uint32_t CR;        /*!< LCD control register,              Address offset: 0x00 */
  __IO uint32_t FCR;       /*!< LCD frame control register,        Address offset: 0x04 */
  __IO uint32_t SR;        /*!< LCD status register,               Address offset: 0x08 */
  __IO uint32_t CLR;       /*!< LCD clear register,                Address offset: 0x0C */
  uint32_t RESERVED;       /*!< Reserved,                          Address offset: 0x10 */
  __IO uint32_t RAM[16];   /*!< LCD display memory,           Address offset: 0x14-0x50 */
} LCD_TypeDef;

/** 
  * @brief LCD-TFT Display Controller
  */

typedef struct
{
  uint32_t      RESERVED0[2];  /*!< Reserved, 0x00-0x04 */
  __IO uint32_t SSCR;          /*!< LTDC Synchronization Size Configuration Register,    Address offset: 0x08 */
  __IO uint32_t BPCR;          /*!< LTDC Back Porch Configuration Register,              Address offset: 0x0C */
  __IO uint32_t AWCR;          /*!< LTDC Active Width Configuration Register,            Address offset: 0x10 */
  __IO uint32_t TWCR;          /*!< LTDC Total Width Configuration Register,             Address offset: 0x14 */
  __IO uint32_t GCR;           /*!< LTDC Global Control Register,                        Address offset: 0x18 */
  uint32_t      RESERVED1[2];  /*!< Reserved, 0x1C-0x20 */
  __IO uint32_t SRCR;          /*!< LTDC Shadow Reload Configuration Register,           Address offset: 0x24 */
  uint32_t      RESERVED2[1];  /*!< Reserved, 0x28 */
  __IO uint32_t BCCR;          /*!< LTDC Background Color Configuration Register,        Address offset: 0x2C */
  uint32_t      RESERVED3[1];  /*!< Reserved, 0x30 */
  __IO uint32_t IER;           /*!< LTDC Interrupt Enable Register,                      Address offset: 0x34 */
  __IO uint32_t ISR;           /*!< LTDC Interrupt Status Register,                      Address offset: 0x38 */
  __IO uint32_t ICR;           /*!< LTDC Interrupt Clear Register,                       Address offset: 0x3C */
  __IO uint32_t LIPCR;         /*!< LTDC Line Interrupt Position Configuration Register, Address offset: 0x40 */
  __IO uint32_t CPSR;          /*!< LTDC Current Position Status Register,               Address offset: 0x44 */
  __IO uint32_t CDSR;         /*!< LTDC Current Display Status Register,                       Address offset: 0x48 */
} LTDC_TypeDef;  

/**
  * @brief LCD-TFT Display layer x Controller
  */
  
typedef struct
{  
  __IO uint32_t CR;            /*!< LTDC Layerx Control Register                                  Address offset: 0x84 */
  __IO uint32_t WHPCR;         /*!< LTDC Layerx Window Horizontal Position Configuration Register Address offset: 0x88 */
  __IO uint32_t WVPCR;         /*!< LTDC Layerx Window Vertical Position Configuration Register   Address offset: 0x8C */
  __IO uint32_t CKCR;          /*!< LTDC Layerx Color Keying Configuration Register               Address offset: 0x90 */
  __IO uint32_t PFCR;          /*!< LTDC Layerx Pixel Format Configuration Register               Address offset: 0x94 */
  __IO uint32_t CACR;          /*!< LTDC Layerx Constant Alpha Configuration Register             Address offset: 0x98 */
  __IO uint32_t DCCR;          /*!< LTDC Layerx Default Color Configuration Register              Address offset: 0x9C */
  __IO uint32_t BFCR;          /*!< LTDC Layerx Blending Factors Configuration Register           Address offset: 0xA0 */
  uint32_t      RESERVED0[2];  /*!< Reserved */
  __IO uint32_t CFBAR;         /*!< LTDC Layerx Color Frame Buffer Address Register               Address offset: 0xAC */
  __IO uint32_t CFBLR;         /*!< LTDC Layerx Color Frame Buffer Length Register                Address offset: 0xB0 */
  __IO uint32_t CFBLNR;        /*!< LTDC Layerx ColorFrame Buffer Line Number Register            Address offset: 0xB4 */
  uint32_t      RESERVED1[3];  /*!< Reserved */
  __IO uint32_t CLUTWR;         /*!< LTDC Layerx CLUT Write Register                               Address offset: 0x144 */

} LTDC_Layer_TypeDef;


/**
  * @brief Power Control
  */

typedef struct
{
  __IO uint32_t CR1;          /*!< PWR power control register 1,        Address offset: 0x00 */
  __IO uint32_t CSR1;      /*!< PWR power control status register 1,     Address offset: 0x04 */
  __IO uint32_t CR2;       /*!< PWR power control register 2,            Address offset: 0x08 */
  __IO uint32_t CR3;       /*!< PWR power control register 3,            Address offset: 0x0C */
  __IO uint32_t CPUCR;     /*!< PWR CPU control register,                Address offset: 0x10 */
       uint32_t RESERVED0; /*!< Reserved,                                Address offset: 0x14 */
  __IO uint32_t D3CR;      /*!< PWR D3 domain control register,          Address offset: 0x18 */
       uint32_t RESERVED1; /*!< Reserved,                                Address offset: 0x1C */
  __IO uint32_t WKUPCR;    /*!< PWR wakeup clear register,               Address offset: 0x20 */
  __IO uint32_t WKUPFR;    /*!< PWR wakeup flag register,                Address offset: 0x24 */
  __IO uint32_t WKUPEPR;   /*!< PWR wakeup enable and polarity register, Address offset: 0x28 */
} PWR_TypeDef;

/**
  * @brief Reset and Clock Control
  */

typedef struct
{
 __IO uint32_t CR;             /*!< RCC clock control register,                                              Address offset: 0x00  */
 __IO uint32_t ICSCR;          /*!< RCC Internal Clock Sources Calibration Register,                         Address offset: 0x04  */
 __IO uint32_t CRRCR;          /*!< Clock Recovery RC  Register,                                             Address offset: 0x08  */
 uint32_t     RESERVED0;       /*!< Reserved,                                                                Address offset: 0x0C  */
 __IO uint32_t CFGR;           /*!< RCC clock configuration register,                                        Address offset: 0x10  */
 uint32_t     RESERVED1;       /*!< Reserved,                                                                Address offset: 0x14  */
 __IO uint32_t D1CFGR;         /*!< RCC Domain 1 configuration register,                                     Address offset: 0x18  */
 __IO uint32_t D2CFGR;         /*!< RCC Domain 2 configuration register,                                     Address offset: 0x1C  */
 __IO uint32_t D3CFGR;         /*!< RCC Domain 3 configuration register,                                     Address offset: 0x20  */
 uint32_t     RESERVED2;       /*!< Reserved,                                                                Address offset: 0x24  */
 __IO uint32_t PLLCKSELR;      /*!< RCC PLLs Clock Source Selection Register,                                Address offset: 0x28  */
 __IO uint32_t PLLCFGR;        /*!< RCC PLLs  Configuration Register,                                        Address offset: 0x2C  */
 __IO uint32_t PLL1DIVR;       /*!< RCC PLL1 Dividers Configuration Register,                                Address offset: 0x30  */
 __IO uint32_t PLL1FRACR;      /*!< RCC PLL1 Fractional Divider Configuration Register,                      Address offset: 0x34  */
 __IO uint32_t PLL2DIVR;       /*!< RCC PLL2 Dividers Configuration Register,                                Address offset: 0x38  */
 __IO uint32_t PLL2FRACR;      /*!< RCC PLL2 Fractional Divider Configuration Register,                      Address offset: 0x3C  */
 __IO uint32_t PLL3DIVR;       /*!< RCC PLL3 Dividers Configuration Register,                                Address offset: 0x40  */
 __IO uint32_t PLL3FRACR;      /*!< RCC PLL3 Fractional Divider Configuration Register,                      Address offset: 0x44  */
 uint32_t      RESERVED3;      /*!< Reserved,                                                                Address offset: 0x48  */
 __IO uint32_t  D1CCIPR;       /*!< RCC Domain 1 Kernel Clock Configuration Register                         Address offset: 0x4C  */
 __IO uint32_t  D2CCIP1R;      /*!< RCC Domain 2 Kernel Clock Configuration Register                         Address offset: 0x50  */
 __IO uint32_t  D2CCIP2R;      /*!< RCC Domain 2 Kernel Clock Configuration Register                         Address offset: 0x54  */
 __IO uint32_t  D3CCIPR;       /*!< RCC Domain 3 Kernel Clock Configuration Register                         Address offset: 0x58  */
 uint32_t      RESERVED4;      /*!< Reserved,                                                                Address offset: 0x5C  */
 __IO uint32_t  CIER;          /*!< RCC Clock Source Interrupt Enable Register                               Address offset: 0x60  */
 __IO uint32_t  CIFR;          /*!< RCC Clock Source Interrupt Flag Register                                 Address offset: 0x64  */
 __IO uint32_t  CICR;          /*!< RCC Clock Source Interrupt Clear Register                                Address offset: 0x68  */
 uint32_t     RESERVED5;       /*!< Reserved,                                                                Address offset: 0x6C  */
 __IO uint32_t  BDCR;          /*!< RCC Vswitch Backup Domain Control Register,                              Address offset: 0x70  */
 __IO uint32_t  CSR;           /*!< RCC clock control & status register,                                     Address offset: 0x74  */
 uint32_t     RESERVED6;       /*!< Reserved,                                                                Address offset: 0x78  */
 __IO uint32_t D1AHB1RSTR;     /*!< RCC Domain 1 AHB1 peripheral reset register,                             Address offset: 0x7C  */
 __IO uint32_t D2AHB1RSTR;     /*!< RCC Domain 2 AHB1 peripheral reset register,                             Address offset: 0x80  */
 __IO uint32_t D2AHB2RSTR;     /*!< RCC Domain 2 AHB2 peripheral reset register,                             Address offset: 0x84  */
 __IO uint32_t D3AHB1RSTR;     /*!< RCC Domain 3 AHB1 peripheral reset register,                             Address offset: 0x88  */
 __IO uint32_t D1APB1RSTR;     /*!< RCC Domain 1 APB1 peripheral reset register,                             Address offset: 0x8C  */
 __IO uint32_t D2APB1LRSTR;    /*!< RCC Domain 2 APB1 peripheral reset Low Word register,                    Address offset: 0x90  */
 __IO uint32_t D2APB1HRSTR;    /*!< RCC Domain 2 APB1 peripheral reset High Word register,                   Address offset: 0x94  */
 __IO uint32_t D2APB2RSTR;     /*!< RCC Domain 2 APB2 peripheral reset register,                             Address offset: 0x98  */
 __IO uint32_t D3APB1RSTR;     /*!< RCC Domain 3 APB1 peripheral reset register,                             Address offset: 0x9C  */
 __IO uint32_t GCR;            /*!< RCC RCC Global Control  Register,                                        Address offset: 0xA0  */
 uint32_t     RESERVED7;       /*!< Reserved,                                                                Address offset: 0xA4  */ 
 __IO uint32_t D3AMR;          /*!< RCC Domain 3 Autonomous Mode Register,                                   Address offset: 0xA8  */
 uint32_t     RESERVED8[9];    /*!< Reserved, 0xAC-0xCC                                                      Address offset: 0xAC  */
 __IO uint32_t RSR;            /*!< RCC Reset status register,                                               Address offset: 0xD0  */
 __IO uint32_t D1AHB1ENR;      /*!< RCC Domain 1 AHB1 peripheral clock  register,                            Address offset: 0xD4  */
 __IO uint32_t D2AHB1ENR;      /*!< RCC Domain 2 AHB1 peripheral clock  register,                            Address offset: 0xD8  */
 __IO uint32_t D2AHB2ENR;      /*!< RCC Domain 2 AHB2 peripheral clock  register,                            Address offset: 0xDC  */
 __IO uint32_t D3AHB1ENR;      /*!< RCC Domain 3 AHB1 peripheral clock  register,                            Address offset: 0xE0  */
 __IO uint32_t D1APB1ENR;      /*!< RCC Domain 1 APB1 peripheral clock  register,                            Address offset: 0xE4  */
 __IO uint32_t D2APB1LENR;     /*!< RCC Domain 2 APB1 peripheral clock  Low Word register,                   Address offset: 0xE8  */
 __IO uint32_t D2APB1HENR;     /*!< RCC Domain 2 APB1 peripheral clock  High Word register,                  Address offset: 0xEC  */
 __IO uint32_t D2APB2ENR;      /*!< RCC Domain 2 APB2 peripheral clock  register,                            Address offset: 0xF0  */
 __IO uint32_t D3APB1ENR;      /*!< RCC Domain 3 APB1 peripheral clock  register,                            Address offset: 0xF4  */
 uint32_t      RESERVED9;      /*!< Reserved,                                                                Address offset: 0xF8  */
 __IO uint32_t D1AHB1SMENR;    /*!< RCC Domain 1 AHB1 peripheral sleep clock  register,                      Address offset: 0xFC  */
 __IO uint32_t D2AHB1SMENR;    /*!< RCC Domain 2 AHB1 peripheral sleep clock  register,                      Address offset: 0x100 */
 __IO uint32_t D2AHB2SMENR;    /*!< RCC Domain 2 AHB2 peripheral sleep clock  register,                      Address offset: 0x104 */
 __IO uint32_t D3AHB1SMENR;    /*!< RCC Domain 3 AHB1 peripheral sleep clock  register,                      Address offset: 0x108 */
 __IO uint32_t D1APB1SMENR;    /*!< RCC Domain 1 APB1 peripheral sleep clock  register,                      Address offset: 0x10C */
 __IO uint32_t D2APB1LSMENR;   /*!< RCC Domain 2 APB1 peripheral sleep clock  Low Word register,             Address offset: 0x110 */
 __IO uint32_t D2APB1HSMENR;   /*!< RCC Domain 2 APB1 peripheral sleep clock  High Word register,            Address offset: 0x114 */
 __IO uint32_t D2APB2SMENR;    /*!< RCC Domain 2 APB2 peripheral sleep clock  register,                      Address offset: 0x118 */
 __IO uint32_t D3APB1SMENR;    /*!< RCC Domain 3 APB1 peripheral sleep clock  register,                      Address offset: 0x11C */
 uint32_t     RESERVED10[4];   /*!< Reserved, 0x120-0x12C                                                    Address offset: 0x120 */

} RCC_TypeDef;


/**
  * @brief Real-Time Clock
  */

typedef struct
{
  __IO uint32_t TR;         /*!< RTC time register,                                         Address offset: 0x00 */
  __IO uint32_t DR;         /*!< RTC date register,                                         Address offset: 0x04 */
  __IO uint32_t CR;         /*!< RTC control register,                                      Address offset: 0x08 */
  __IO uint32_t ISR;        /*!< RTC initialization and status register,                    Address offset: 0x0C */
  __IO uint32_t PRER;       /*!< RTC prescaler register,                                    Address offset: 0x10 */
  __IO uint32_t WUTR;       /*!< RTC wakeup timer register,                                 Address offset: 0x14 */
       uint32_t reserved;   /*!< Reserved  */
  __IO uint32_t ALRMAR;     /*!< RTC alarm A register,                                      Address offset: 0x1C */
  __IO uint32_t ALRMBR;     /*!< RTC alarm B register,                                      Address offset: 0x20 */
  __IO uint32_t WPR;        /*!< RTC write protection register,                             Address offset: 0x24 */
  __IO uint32_t SSR;        /*!< RTC sub second register,                                   Address offset: 0x28 */
  __IO uint32_t SHIFTR;     /*!< RTC shift control register,                                Address offset: 0x2C */
  __IO uint32_t TSTR;       /*!< RTC time stamp time register,                              Address offset: 0x30 */
  __IO uint32_t TSDR;       /*!< RTC time stamp date register,                              Address offset: 0x34 */
  __IO uint32_t TSSSR;      /*!< RTC time-stamp sub second register,                        Address offset: 0x38 */
  __IO uint32_t CALR;       /*!< RTC calibration register,                                  Address offset: 0x3C */
  __IO uint32_t TAMPCR;     /*!< RTC tamper and alternate function configuration register,  Address offset: 0x40 */
  __IO uint32_t ALRMASSR;   /*!< RTC alarm A sub second register,                           Address offset: 0x44 */
  __IO uint32_t ALRMBSSR;   /*!< RTC alarm B sub second register,                           Address offset: 0x48 */
  __IO uint32_t OR;         /*!< RTC option register,                                       Address offset: 0x4C */
  __IO uint32_t BKP0R;      /*!< RTC backup register 0,                                     Address offset: 0x50 */
  __IO uint32_t BKP1R;      /*!< RTC backup register 1,                                     Address offset: 0x54 */
  __IO uint32_t BKP2R;      /*!< RTC backup register 2,                                     Address offset: 0x58 */
  __IO uint32_t BKP3R;      /*!< RTC backup register 3,                                     Address offset: 0x5C */
  __IO uint32_t BKP4R;      /*!< RTC backup register 4,                                     Address offset: 0x60 */
  __IO uint32_t BKP5R;      /*!< RTC backup register 5,                                     Address offset: 0x64 */
  __IO uint32_t BKP6R;      /*!< RTC backup register 6,                                     Address offset: 0x68 */
  __IO uint32_t BKP7R;      /*!< RTC backup register 7,                                     Address offset: 0x6C */
  __IO uint32_t BKP8R;      /*!< RTC backup register 8,                                     Address offset: 0x70 */
  __IO uint32_t BKP9R;      /*!< RTC backup register 9,                                     Address offset: 0x74 */
  __IO uint32_t BKP10R;     /*!< RTC backup register 10,                                    Address offset: 0x78 */
  __IO uint32_t BKP11R;     /*!< RTC backup register 11,                                    Address offset: 0x7C */
  __IO uint32_t BKP12R;     /*!< RTC backup register 12,                                    Address offset: 0x80 */
  __IO uint32_t BKP13R;     /*!< RTC backup register 13,                                    Address offset: 0x84 */
  __IO uint32_t BKP14R;     /*!< RTC backup register 14,                                    Address offset: 0x88 */
  __IO uint32_t BKP15R;     /*!< RTC backup register 15,                                    Address offset: 0x8C */
  __IO uint32_t BKP16R;     /*!< RTC backup register 16,                                    Address offset: 0x90 */
  __IO uint32_t BKP17R;     /*!< RTC backup register 17,                                    Address offset: 0x94 */
  __IO uint32_t BKP18R;     /*!< RTC backup register 18,                                    Address offset: 0x98 */
  __IO uint32_t BKP19R;     /*!< RTC backup register 19,                                    Address offset: 0x9C */
  __IO uint32_t BKP20R;     /*!< RTC backup register 20,                                    Address offset: 0xA0 */
  __IO uint32_t BKP21R;     /*!< RTC backup register 21,                                    Address offset: 0xA4 */
  __IO uint32_t BKP22R;     /*!< RTC backup register 22,                                    Address offset: 0xA8 */
  __IO uint32_t BKP23R;     /*!< RTC backup register 23,                                    Address offset: 0xAC */
  __IO uint32_t BKP24R;     /*!< RTC backup register 24,                                    Address offset: 0xB0 */
  __IO uint32_t BKP25R;     /*!< RTC backup register 25,                                    Address offset: 0xB4 */
  __IO uint32_t BKP26R;     /*!< RTC backup register 26,                                    Address offset: 0xB8 */
  __IO uint32_t BKP27R;     /*!< RTC backup register 27,                                    Address offset: 0xBC */
  __IO uint32_t BKP28R;     /*!< RTC backup register 28,                                    Address offset: 0xC0 */
  __IO uint32_t BKP29R;     /*!< RTC backup register 29,                                    Address offset: 0xC4 */
  __IO uint32_t BKP30R;     /*!< RTC backup register 30,                                    Address offset: 0xC8 */
  __IO uint32_t BKP31R;     /*!< RTC backup register 31,                                    Address offset: 0xCC */
} RTC_TypeDef;


/**
  * @brief Serial Audio Interface
  */

typedef struct
{
  __IO uint32_t GCR;           /*!< SAI global configuration register, Address offset: 0x00 */
  uint32_t      RESERVED0[16]; /*!< Reserved, 0x04 - 0x43                                   */
  __IO uint32_t PDMCR;         /*!< SAI PDM control register,          Address offset: 0x44 */
  __IO uint32_t PDMDLY;        /*!< SAI PDM delay register,            Address offset: 0x48 */
} SAI_TypeDef;

typedef struct
{
  __IO uint32_t CR1;      /*!< SAI block x configuration register 1,     Address offset: 0x04 */
  __IO uint32_t CR2;      /*!< SAI block x configuration register 2,     Address offset: 0x08 */
  __IO uint32_t FRCR;     /*!< SAI block x frame configuration register, Address offset: 0x0C */
  __IO uint32_t SLOTR;    /*!< SAI block x slot register,                Address offset: 0x10 */
  __IO uint32_t IMR;      /*!< SAI block x interrupt mask register,      Address offset: 0x14 */
  __IO uint32_t SR;       /*!< SAI block x status register,              Address offset: 0x18 */
  __IO uint32_t CLRFR;    /*!< SAI block x clear flag register,          Address offset: 0x1C */
  __IO uint32_t DR;       /*!< SAI block x data register,                Address offset: 0x20 */
} SAI_Block_TypeDef;

/** 
  * @brief SPDIF-RX Interface
  */

typedef struct
{
  __IO uint32_t   CR;           /*!< Control register,                   Address offset: 0x00 */
  __IO uint32_t   IMR;          /*!< Interrupt mask register,            Address offset: 0x04 */
  __IO uint32_t   SR;           /*!< Status register,                    Address offset: 0x08 */
  __IO uint32_t   IFCR;         /*!< Interrupt Flag Clear register,      Address offset: 0x0C */
  __IO uint32_t   DR;           /*!< Data input register,                Address offset: 0x10 */
  __IO uint32_t   CSR;          /*!< Channel Status register,            Address offset: 0x14 */
  __IO uint32_t   DIR;          /*!< Debug Information register,         Address offset: 0x18 */
  uint32_t        RESERVED2;    /*!< Reserved,  0x1A                                          */   
} SPDIFRX_TypeDef;


/**
  * @brief Secure digital input/output Interface
  */

typedef struct
{
  __IO uint32_t POWER;          /*!< SDMMC power control register,             Address offset: 0x00 */
  __IO uint32_t CLKCR;          /*!< SDMMC clock control register,             Address offset: 0x04 */
  __IO uint32_t ARG;            /*!< SDMMC argument register,                  Address offset: 0x08 */
  __IO uint32_t CMD;            /*!< SDMMC command register,                   Address offset: 0x0C */
  __I uint32_t  RESPCMD;        /*!< SDMMC command response register,          Address offset: 0x10 */
  __I uint32_t  RESP1;          /*!< SDMMC response 1 register,                Address offset: 0x14 */
  __I uint32_t  RESP2;          /*!< SDMMC response 2 register,                Address offset: 0x18 */
  __I uint32_t  RESP3;          /*!< SDMMC response 3 register,                Address offset: 0x1C */
  __I uint32_t  RESP4;          /*!< SDMMC response 4 register,                Address offset: 0x20 */
  __IO uint32_t DTIMER;         /*!< SDMMC data timer register,                Address offset: 0x24 */
  __IO uint32_t DLEN;           /*!< SDMMC data length register,               Address offset: 0x28 */
  __IO uint32_t DCTRL;          /*!< SDMMC data control register,              Address offset: 0x2C */
  __I uint32_t  DCOUNT;         /*!< SDMMC data counter register,              Address offset: 0x30 */
  __I uint32_t  STA;            /*!< SDMMC status register,                    Address offset: 0x34 */
  __IO uint32_t ICR;            /*!< SDMMC interrupt clear register,           Address offset: 0x38 */
  __IO uint32_t MASK;           /*!< SDMMC mask register,                      Address offset: 0x3C */
  __IO uint32_t ACKTIME;        /*!< SDMMC Acknowledgement timer register,     Address offset: 0x40 */
  uint32_t      RESERVED0[3];   /*!< Reserved, 0x44 - 0x4C - 0x4C                                   */
  __IO uint32_t IDMACTRL;       /*!< SDMMC DMA control register,               Address offset: 0x50 */
  __IO uint32_t IDMABSIZE;      /*!< SDMMC DMA buffer size register,           Address offset: 0x54 */
  __IO uint32_t IDMABASE0;      /*!< SDMMC DMA buffer 0 base address register, Address offset: 0x58 */
  __IO uint32_t IDMABASE1;      /*!< SDMMC DMA buffer 1 base address register, Address offset: 0x5C */
  uint32_t      RESERVED1[8];   /*!< Reserved, 0x60-0x7C                                            */
  __IO uint32_t FIFO;           /*!< SDMMC data FIFO register,                 Address offset: 0x80 */
  uint32_t      RESERVED2[222]; /*!< Reserved, 0x84-0x3F8                                           */  
  __IO uint32_t IPVR;           /*!< SDMMC data FIFO register,                Address offset: 0x3FC */  
} SDMMC_TypeDef;


/**
  * @brief HW Semaphore HSEM
  */

typedef struct
{
  __IO uint32_t HSEM_R[32];      /*!< 2-step write lock and read back registers,     Address offset: 00h-7Ch  */
  __IO uint32_t HSEM_RLR[32];    /*!< 1-step read lock registers,                    Address offset: 80h-FCh  */
  __IO uint32_t HSEM_IER0;       /*!< HSEM Interrupt 0 enable register ,             Address offset: 100h     */
  __IO uint32_t HSEM_ICR0;       /*!< HSEM Interrupt 0 clear register ,              Address offset: 104h     */  
  __IO uint32_t HSEM_ISR0;       /*!< HSEM Interrupt 0 Status register ,             Address offset: 108h     */ 
  __IO uint32_t HSEM_MISR0;      /*!< HSEM Interrupt 0 Masked Status register ,      Address offset: 10Ch     */ 
  __IO uint32_t HSEM_IER1;       /*!< HSEM Interrupt 1 enable register ,             Address offset: 110h     */
  __IO uint32_t HSEM_ICR1;       /*!< HSEM Interrupt 1 clear register ,              Address offset: 114h     */  
  __IO uint32_t HSEM_ISR1;       /*!< HSEM Interrupt 1 Status register ,             Address offset: 118h     */ 
  __IO uint32_t HSEM_MISR1;      /*!< HSEM Interrupt 1 Masked Status register ,      Address offset: 11Ch     */
   uint32_t  Reserved[8];        /* Reserved                                         Address offset: 120h-13Ch*/
  __IO uint32_t HSEM_CR;         /*!< HSEM Semaphore clear register ,               Address offset: 140h      */
  __IO uint32_t HSEM_KEYR;       /*!< HSEM Semaphore clear key register ,           Address offset: 144h      */

} HSEM_TypeDef;

/**
  * @brief Serial Peripheral Interface
  */

typedef struct
{
  __IO uint32_t CR1;          /*!< SPI Control register 1,                             Address offset: 0x00 */
  __IO uint32_t CR2;          /*!< SPI Control register 2,                             Address offset: 0x04 */
  __IO uint32_t CFG1;         /*!< SPI Status register,                                Address offset: 0x08 */
  __IO uint32_t CFG2;         /*!< SPI Status register,                                Address offset: 0x0C */
  __IO uint32_t IER;          /*!< SPI data register,                                  Address offset: 0x10 */
  __IO uint32_t SR;           /*!< SPI data register,                                  Address offset: 0x14 */
  __IO uint32_t IFCR;         /*!< SPI data register,                                  Address offset: 0x18 */
  uint32_t      RESERVED0;    /*!< SPI data register,                                  Address offset: 0x1C */
  __IO uint32_t TXDR;         /*!< SPI data register,                                  Address offset: 0x20 */
  uint32_t      RESERVED1[3]; /*!< Reserved, 0x24-0x2C                                                      */
  __IO uint32_t RXDR;         /*!< SPI data register,                                  Address offset: 0x30 */
  uint32_t      RESERVED2[3]; /*!< Reserved, 0x34-0x3C                                                      */
  __IO uint32_t CRCPOLY;     /*!< SPI data register,                                   Address offset: 0x40 */
  __IO uint32_t TXCRC;       /*!< SPI data register,                                   Address offset: 0x44 */
  __IO uint32_t RXCRC;       /*!< SPI data register,                                   Address offset: 0x48 */
  __IO uint32_t UDRDR;       /*!< SPI data register,                                   Address offset: 0x4C */
  __IO uint32_t I2SCGFR;         /*!< SPI data register,                               Address offset: 0x50 */

} SPI_TypeDef;

/**
  * @brief QUAD Serial Peripheral Interface
  */

typedef struct
{
  __IO uint32_t CR;       /*!< QUADSPI Control register,                           Address offset: 0x00 */
  __IO uint32_t DCR;      /*!< QUADSPI Device Configuration register,              Address offset: 0x04 */
  __IO uint32_t SR;       /*!< QUADSPI Status register,                            Address offset: 0x08 */
  __IO uint32_t FCR;      /*!< QUADSPI Flag Clear register,                        Address offset: 0x0C */
  __IO uint32_t DLR;      /*!< QUADSPI Data Length register,                       Address offset: 0x10 */
  __IO uint32_t CCR;      /*!< QUADSPI Communication Configuration register,       Address offset: 0x14 */
  __IO uint32_t AR;       /*!< QUADSPI Address register,                           Address offset: 0x18 */
  __IO uint32_t ABR;      /*!< QUADSPI Alternate Bytes register,                   Address offset: 0x1C */
  __IO uint32_t DR;       /*!< QUADSPI Data register,                              Address offset: 0x20 */
  __IO uint32_t PSMKR;    /*!< QUADSPI Polling Status Mask register,               Address offset: 0x24 */
  __IO uint32_t PSMAR;    /*!< QUADSPI Polling Status Match register,              Address offset: 0x28 */
  __IO uint32_t PIR;      /*!< QUADSPI Polling Interval register,                  Address offset: 0x2C */
  __IO uint32_t LPTR;     /*!< QUADSPI Low Power Timeout register,                 Address offset: 0x30 */
} QUADSPI_TypeDef;


/**
  * @brief TIM
  */

typedef struct
{
  __IO uint16_t CR1;         /*!< TIM control register 1,                   Address offset: 0x00 */
  uint16_t      RESERVED0;   /*!< Reserved, 0x02                                                 */
  __IO uint32_t CR2;         /*!< TIM control register 2,                   Address offset: 0x04 */
  __IO uint32_t SMCR;        /*!< TIM slave mode control register,          Address offset: 0x08 */
  __IO uint32_t DIER;        /*!< TIM DMA/interrupt enable register,        Address offset: 0x0C */
  __IO uint32_t SR;          /*!< TIM status register,                      Address offset: 0x10 */
  __IO uint32_t EGR;         /*!< TIM event generation register,            Address offset: 0x14 */
  __IO uint32_t CCMR1;       /*!< TIM capture/compare mode register 1,      Address offset: 0x18 */
  __IO uint32_t CCMR2;       /*!< TIM capture/compare mode register 2,      Address offset: 0x1C */
  __IO uint32_t CCER;        /*!< TIM capture/compare enable register,      Address offset: 0x20 */
  __IO uint32_t CNT;         /*!< TIM counter register,                     Address offset: 0x24 */
  __IO uint16_t PSC;         /*!< TIM prescaler,                            Address offset: 0x28 */
  uint16_t      RESERVED9;   /*!< Reserved, 0x2A                                                 */
  __IO uint32_t ARR;         /*!< TIM auto-reload register,                 Address offset: 0x2C */
  __IO uint16_t RCR;         /*!< TIM repetition counter register,          Address offset: 0x30 */
  uint16_t      RESERVED10;  /*!< Reserved, 0x32                                                 */
  __IO uint32_t CCR1;        /*!< TIM capture/compare register 1,           Address offset: 0x34 */
  __IO uint32_t CCR2;        /*!< TIM capture/compare register 2,           Address offset: 0x38 */
  __IO uint32_t CCR3;        /*!< TIM capture/compare register 3,           Address offset: 0x3C */
  __IO uint32_t CCR4;        /*!< TIM capture/compare register 4,           Address offset: 0x40 */
  __IO uint32_t BDTR;        /*!< TIM break and dead-time register,         Address offset: 0x44 */
  __IO uint16_t DCR;         /*!< TIM DMA control register,                 Address offset: 0x48 */
  uint16_t      RESERVED12;  /*!< Reserved, 0x4A                                                 */
  __IO uint16_t DMAR;        /*!< TIM DMA address for full transfer,        Address offset: 0x4C */
  uint16_t      RESERVED13;  /*!< Reserved, 0x4E                                                 */
  uint16_t      RESERVED14;  /*!< Reserved, 0x50                                                 */
  __IO uint32_t CCMR3;       /*!< TIM capture/compare mode register 3,      Address offset: 0x54 */
  __IO uint32_t CCR5;        /*!< TIM capture/compare register5,            Address offset: 0x58 */
  __IO uint32_t CCR6;        /*!< TIM capture/compare register6,            Address offset: 0x5C */
  __IO uint32_t OR2;         /*!< TIM option register 2                     Address offset: 0x60 */
  __IO uint32_t OR3;         /*!< TIM option register 3,                    Address offset: 0x64 */
  __IO uint32_t TISEL;       /*!< TIM Input Selection register,             Address offset: 0x68 */
} TIM_TypeDef;

/**
  * @brief LPTIMIMER
  */
typedef struct
{
  __IO uint32_t ISR;      /*!< LPTIM Interrupt and Status register,                Address offset: 0x00 */
  __IO uint32_t ICR;      /*!< LPTIM Interrupt Clear register,                     Address offset: 0x04 */
  __IO uint32_t IER;      /*!< LPTIM Interrupt Enable register,                    Address offset: 0x08 */
  __IO uint32_t CFGR;     /*!< LPTIM Configuration register,                       Address offset: 0x0C */
  __IO uint32_t CR;       /*!< LPTIM Control register,                             Address offset: 0x10 */
  __IO uint32_t CMP;      /*!< LPTIM Compare register,                             Address offset: 0x14 */
  __IO uint32_t ARR;      /*!< LPTIM Autoreload register,                          Address offset: 0x18 */
  __IO uint32_t CNT;      /*!< LPTIM Counter register,                             Address offset: 0x1C */
  uint16_t  RESERVED1;    /*!< Reserved, 0x20                                                 */
  __IO uint32_t CFGR2;     /*!< LPTIM Option register,                              Address offset: 0x24 */
} LPTIM_TypeDef;

/**
  * @brief Comparator
  */
typedef struct
{
  __IO uint32_t SR;        /*!< Comparator status register,                    Address offset: 0x00 */
 __IO uint32_t ICFR;      /*!< Comparator interrupt clear flag register,      Address offset: 0x04 */
	__IO uint32_t OR;        /*!< Comparator option register,                    Address offset: 0x08 */
} COMPOPT_TypeDef;

typedef struct
{  
	__IO uint32_t CFGR;      /*!< Comparator configuration register  ,           Address offset: 0x00 */
} COMP_TypeDef;

typedef struct
{
  __IO uint32_t CFGR;       /*!< COMP control and status register, used for bits common to several COMP instances, Address offset: 0x00 */
} COMP_Common_TypeDef;
/**
  * @brief Universal Synchronous Asynchronous Receiver Transmitter
  */

typedef struct
{
  __IO uint32_t CR1;    /*!< USART Control register 1,                 Address offset: 0x00 */
  __IO uint32_t CR2;    /*!< USART Control register 2,                 Address offset: 0x04 */
  __IO uint32_t CR3;    /*!< USART Control register 3,                 Address offset: 0x08 */
  __IO uint32_t BRR;    /*!< USART Baud rate register,                 Address offset: 0x0C */
  __IO uint16_t GTPR;   /*!< USART Guard time and prescaler register,  Address offset: 0x10 */
  uint16_t  RESERVED2;  /*!< Reserved, 0x12                                                 */
  __IO uint32_t RTOR;   /*!< USART Receiver Time Out register,         Address offset: 0x14 */
  __IO uint16_t RQR;    /*!< USART Request register,                   Address offset: 0x18 */
  uint16_t  RESERVED3;  /*!< Reserved, 0x1A                                                 */
  __IO uint32_t ISR;    /*!< USART Interrupt and status register,      Address offset: 0x1C */
  __IO uint32_t ICR;    /*!< USART Interrupt flag Clear register,      Address offset: 0x20 */
  __IO uint16_t RDR;    /*!< USART Receive Data register,              Address offset: 0x24 */
  uint16_t  RESERVED4;  /*!< Reserved, 0x26                                                 */
  __IO uint16_t TDR;    /*!< USART Transmit Data register,             Address offset: 0x28 */
  uint16_t  RESERVED5;  /*!< Reserved, 0x2A                                                 */
  __IO uint32_t PRESC;  /*!< USART clock Prescaler register,           Address offset: 0x2C */
} USART_TypeDef;

/**
  * @brief Single Wire Protocol Master Interface SPWMI
  */
typedef struct
{
  __IO uint32_t CR;          /*!< SWPMI Configuration/Control register,     Address offset: 0x00 */
  __IO uint32_t BRR;         /*!< SWPMI bitrate register,                   Address offset: 0x04 */
    uint32_t  RESERVED1;     /*!< Reserved, 0x08                                                 */
  __IO uint32_t ISR;         /*!< SWPMI Interrupt and Status register,      Address offset: 0x0C */
  __IO uint32_t ICR;         /*!< SWPMI Interrupt Flag Clear register,      Address offset: 0x10 */
  __IO uint32_t IER;         /*!< SWPMI Interrupt Enable register,          Address offset: 0x14 */
  __IO uint32_t RFL;         /*!< SWPMI Receive Frame Length register,      Address offset: 0x18 */
  __IO uint32_t TDR;         /*!< SWPMI Transmit data register,             Address offset: 0x1C */
  __IO uint32_t RDR;         /*!< SWPMI Receive data register,              Address offset: 0x20 */
  __IO uint32_t OR;          /*!< SWPMI Option register,                    Address offset: 0x24 */
} SWPMI_TypeDef;

/**
  * @brief Window WATCHDOG
  */

typedef struct
{
  __IO uint32_t CR;   /*!< WWDG Control register,       Address offset: 0x00 */
  __IO uint32_t CFR;  /*!< WWDG Configuration register, Address offset: 0x04 */
  __IO uint32_t SR;   /*!< WWDG Status register,        Address offset: 0x08 */
} WWDG_TypeDef;

/** 
  * @brief Crypto Processor
  */

typedef struct
{
  __IO uint32_t CR;         /*!< CRYP control register,                                    Address offset: 0x00 */
  __IO uint32_t SR;         /*!< CRYP status register,                                     Address offset: 0x04 */
  __IO uint32_t DR;         /*!< CRYP data input register,                                 Address offset: 0x08 */
  __IO uint32_t DOUT;       /*!< CRYP data output register,                                Address offset: 0x0C */
  __IO uint32_t DMACR;      /*!< CRYP DMA control register,                                Address offset: 0x10 */
  __IO uint32_t IMSCR;      /*!< CRYP interrupt mask set/clear register,                   Address offset: 0x14 */
  __IO uint32_t RISR;       /*!< CRYP raw interrupt status register,                       Address offset: 0x18 */
  __IO uint32_t MISR;       /*!< CRYP masked interrupt status register,                    Address offset: 0x1C */
  __IO uint32_t K0LR;       /*!< CRYP key left  register 0,                                Address offset: 0x20 */
  __IO uint32_t K0RR;       /*!< CRYP key right register 0,                                Address offset: 0x24 */
  __IO uint32_t K1LR;       /*!< CRYP key left  register 1,                                Address offset: 0x28 */
  __IO uint32_t K1RR;       /*!< CRYP key right register 1,                                Address offset: 0x2C */
  __IO uint32_t K2LR;       /*!< CRYP key left  register 2,                                Address offset: 0x30 */
  __IO uint32_t K2RR;       /*!< CRYP key right register 2,                                Address offset: 0x34 */
  __IO uint32_t K3LR;       /*!< CRYP key left  register 3,                                Address offset: 0x38 */
  __IO uint32_t K3RR;       /*!< CRYP key right register 3,                                Address offset: 0x3C */
  __IO uint32_t IV0LR;      /*!< CRYP initialization vector left-word  register 0,         Address offset: 0x40 */
  __IO uint32_t IV0RR;      /*!< CRYP initialization vector right-word register 0,         Address offset: 0x44 */
  __IO uint32_t IV1LR;      /*!< CRYP initialization vector left-word  register 1,         Address offset: 0x48 */
  __IO uint32_t IV1RR;      /*!< CRYP initialization vector right-word register 1,         Address offset: 0x4C */
  __IO uint32_t CSGCMCCM0R; /*!< CRYP GCM/GMAC or CCM/CMAC context swap register 0,        Address offset: 0x50 */
  __IO uint32_t CSGCMCCM1R; /*!< CRYP GCM/GMAC or CCM/CMAC context swap register 1,        Address offset: 0x54 */
  __IO uint32_t CSGCMCCM2R; /*!< CRYP GCM/GMAC or CCM/CMAC context swap register 2,        Address offset: 0x58 */
  __IO uint32_t CSGCMCCM3R; /*!< CRYP GCM/GMAC or CCM/CMAC context swap register 3,        Address offset: 0x5C */
  __IO uint32_t CSGCMCCM4R; /*!< CRYP GCM/GMAC or CCM/CMAC context swap register 4,        Address offset: 0x60 */
  __IO uint32_t CSGCMCCM5R; /*!< CRYP GCM/GMAC or CCM/CMAC context swap register 5,        Address offset: 0x64 */
  __IO uint32_t CSGCMCCM6R; /*!< CRYP GCM/GMAC or CCM/CMAC context swap register 6,        Address offset: 0x68 */
  __IO uint32_t CSGCMCCM7R; /*!< CRYP GCM/GMAC or CCM/CMAC context swap register 7,        Address offset: 0x6C */
  __IO uint32_t CSGCM0R;    /*!< CRYP GCM/GMAC context swap register 0,                    Address offset: 0x70 */
  __IO uint32_t CSGCM1R;    /*!< CRYP GCM/GMAC context swap register 1,                    Address offset: 0x74 */
  __IO uint32_t CSGCM2R;    /*!< CRYP GCM/GMAC context swap register 2,                    Address offset: 0x78 */
  __IO uint32_t CSGCM3R;    /*!< CRYP GCM/GMAC context swap register 3,                    Address offset: 0x7C */
  __IO uint32_t CSGCM4R;    /*!< CRYP GCM/GMAC context swap register 4,                    Address offset: 0x80 */
  __IO uint32_t CSGCM5R;    /*!< CRYP GCM/GMAC context swap register 5,                    Address offset: 0x84 */
  __IO uint32_t CSGCM6R;    /*!< CRYP GCM/GMAC context swap register 6,                    Address offset: 0x88 */
  __IO uint32_t CSGCM7R;    /*!< CRYP GCM/GMAC context swap register 7,                    Address offset: 0x8C */
} CRYP_TypeDef;

/** 
  * @brief HASH
  */
  
typedef struct 
{
  __IO uint32_t CR;               /*!< HASH control register,          Address offset: 0x00        */
  __IO uint32_t DIN;              /*!< HASH data input register,       Address offset: 0x04        */
  __IO uint32_t STR;              /*!< HASH start register,            Address offset: 0x08        */
  __IO uint32_t HR[5];            /*!< HASH digest registers,          Address offset: 0x0C-0x1C   */
  __IO uint32_t IMR;              /*!< HASH interrupt enable register, Address offset: 0x20        */
  __IO uint32_t SR;               /*!< HASH status register,           Address offset: 0x24        */
       uint32_t RESERVED[52];     /*!< Reserved, 0x28-0xF4                                         */
  __IO uint32_t CSR[54];          /*!< HASH context swap registers,    Address offset: 0x0F8-0x1CC */
} HASH_TypeDef;

/** 
  * @brief HASH_DIGEST
  */
  
typedef struct 
{
  __IO uint32_t HR[8];     /*!< HASH digest registers,          Address offset: 0x310-0x32C */ 
} HASH_DIGEST_TypeDef;

/** 
  * @brief High resolution Timer (HRTIM)
  */
/* HRTIM master registers definition */
typedef struct
{
  __IO uint32_t MCR;            /*!< HRTIM Master Timer control register,                     Address offset: 0x00 */
  __IO uint32_t MISR;           /*!< HRTIM Master Timer interrupt status register,            Address offset: 0x04 */
  __IO uint32_t MICR;           /*!< HRTIM Master Timer interupt clear register,              Address offset: 0x08 */
  __IO uint32_t MDIER;          /*!< HRTIM Master Timer DMA/interrupt enable register         Address offset: 0x0C */
  __IO uint32_t MCNTR;          /*!< HRTIM Master Timer counter register,                     Address offset: 0x10 */
  __IO uint32_t MPER;           /*!< HRTIM Master Timer period register,                      Address offset: 0x14 */
  __IO uint32_t MREP;           /*!< HRTIM Master Timer repetition register,                  Address offset: 0x18 */
  __IO uint32_t MCMP1R;         /*!< HRTIM Master Timer compare 1 register,                   Address offset: 0x1C */
  uint32_t      RESERVED0;     /*!< Reserved,                                                                0x20 */
  __IO uint32_t MCMP2R;         /*!< HRTIM Master Timer compare 2 register,                   Address offset: 0x24 */
  __IO uint32_t MCMP3R;         /*!< HRTIM Master Timer compare 3 register,                   Address offset: 0x28 */
  __IO uint32_t MCMP4R;         /*!< HRTIM Master Timer compare 4 register,                   Address offset: 0x2C */
  uint32_t      RESERVED1[20];  /*!< Reserved,                                                          0x30..0x7C */
}HRTIM_Master_TypeDef; 
 
/* HRTIM Timer A to E registers definition */
typedef struct
{
  __IO uint32_t TIMxCR;     /*!< HRTIM Timerx control register,                              Address offset: 0x00  */
  __IO uint32_t TIMxISR;    /*!< HRTIM Timerx interrupt status register,                     Address offset: 0x04  */
  __IO uint32_t TIMxICR;    /*!< HRTIM Timerx interrupt clear register,                      Address offset: 0x08  */
  __IO uint32_t TIMxDIER;   /*!< HRTIM Timerx DMA/interrupt enable register,                 Address offset: 0x0C  */
  __IO uint32_t CNTxR;      /*!< HRTIM Timerx counter register,                              Address offset: 0x10  */
  __IO uint32_t PERxR;      /*!< HRTIM Timerx period register,                               Address offset: 0x14  */
  __IO uint32_t REPxR;      /*!< HRTIM Timerx repetition register,                           Address offset: 0x18  */
  __IO uint32_t CMP1xR;     /*!< HRTIM Timerx compare 1 register,                            Address offset: 0x1C  */
  __IO uint32_t CMP1CxR;    /*!< HRTIM Timerx compare 1 compound register,                   Address offset: 0x20  */
  __IO uint32_t CMP2xR;     /*!< HRTIM Timerx compare 2 register,                            Address offset: 0x24  */
  __IO uint32_t CMP3xR;     /*!< HRTIM Timerx compare 3 register,                            Address offset: 0x28  */
  __IO uint32_t CMP4xR;     /*!< HRTIM Timerx compare 4 register,                            Address offset: 0x2C  */
  __IO uint32_t CPT1xR;     /*!< HRTIM Timerx capture 1 register,                            Address offset: 0x30  */
  __IO uint32_t CPT2xR;     /*!< HRTIM Timerx capture 2 register,                            Address offset: 0x34 */
  __IO uint32_t DTxR;       /*!< HRTIM Timerx dead time register,                            Address offset: 0x38 */
  __IO uint32_t SETx1R;     /*!< HRTIM Timerx output 1 set register,                         Address offset: 0x3C */
  __IO uint32_t RSTx1R;     /*!< HRTIM Timerx output 1 reset register,                       Address offset: 0x40 */
  __IO uint32_t SETx2R;     /*!< HRTIM Timerx output 2 set register,                         Address offset: 0x44 */
  __IO uint32_t RSTx2R;     /*!< HRTIM Timerx output 2 reset register,                       Address offset: 0x48 */
  __IO uint32_t EEFxR1;     /*!< HRTIM Timerx external event filtering 1 register,           Address offset: 0x4C */
  __IO uint32_t EEFxR2;     /*!< HRTIM Timerx external event filtering 2 register,           Address offset: 0x50 */
  __IO uint32_t RSTxR;      /*!< HRTIM Timerx Reset register,                                Address offset: 0x54 */
  __IO uint32_t CHPxR;      /*!< HRTIM Timerx Chopper register,                              Address offset: 0x58 */
  __IO uint32_t CPT1xCR;    /*!< HRTIM Timerx Capture 1 register,                            Address offset: 0x5C */
  __IO uint32_t CPT2xCR;    /*!< HRTIM Timerx Capture 2 register,                            Address offset: 0x60 */
  __IO uint32_t OUTxR;      /*!< HRTIM Timerx Output register,                               Address offset: 0x64 */
  __IO uint32_t FLTxR;      /*!< HRTIM Timerx Fault register,                                Address offset: 0x68 */
  uint32_t      RESERVED0[5];  /*!< Reserved,                                                              0x6C..0x7C */
}HRTIM_Timerx_TypeDef;

/* HRTIM common register definition */
typedef struct
{
  __IO uint32_t CR1;        /*!< HRTIM control register1,                                    Address offset: 0x00 */
  __IO uint32_t CR2;        /*!< HRTIM control register2,                                    Address offset: 0x04 */
  __IO uint32_t ISR;        /*!< HRTIM interrupt status register,                            Address offset: 0x08 */
  __IO uint32_t ICR;        /*!< HRTIM interrupt clear register,                             Address offset: 0x0C */
  __IO uint32_t IER;        /*!< HRTIM interrupt enable register,                            Address offset: 0x10 */
  __IO uint32_t OENR;       /*!< HRTIM Output enable register,                               Address offset: 0x14 */
  __IO uint32_t ODISR;      /*!< HRTIM Output disable register,                              Address offset: 0x18 */
  __IO uint32_t ODSR;       /*!< HRTIM Output disable status register,                       Address offset: 0x1C */
  __IO uint32_t BMCR;       /*!< HRTIM Burst mode control register,                          Address offset: 0x20 */
  __IO uint32_t BMTRGR;     /*!< HRTIM Busrt mode trigger register,                          Address offset: 0x24 */
  __IO uint32_t BMCMPR;     /*!< HRTIM Burst mode compare register,                          Address offset: 0x28 */
  __IO uint32_t BMPER;      /*!< HRTIM Burst mode period register,                           Address offset: 0x2C */
  __IO uint32_t EECR1;      /*!< HRTIM Timer external event control register1,               Address offset: 0x30 */
  __IO uint32_t EECR2;      /*!< HRTIM Timer external event control register2,               Address offset: 0x34 */
  __IO uint32_t EECR3;      /*!< HRTIM Timer external event control register3,               Address offset: 0x38 */
  __IO uint32_t ADC1R;      /*!< HRTIM ADC Trigger 1 register,                               Address offset: 0x3C */
  __IO uint32_t ADC2R;      /*!< HRTIM ADC Trigger 2 register,                               Address offset: 0x40 */
  __IO uint32_t ADC3R;      /*!< HRTIM ADC Trigger 3 register,                               Address offset: 0x44 */
  __IO uint32_t ADC4R;      /*!< HRTIM ADC Trigger 4 register,                               Address offset: 0x48 */
  __IO uint32_t DLLCR;      /*!< HRTIM DLL control register,                                 Address offset: 0x4C */
  __IO uint32_t FLTINR1;    /*!< HRTIM Fault input register1,                                Address offset: 0x50 */
  __IO uint32_t FLTINR2;    /*!< HRTIM Fault input register2,                                Address offset: 0x54 */
  __IO uint32_t BDMUPR;     /*!< HRTIM Burst DMA Master Timer update register,               Address offset: 0x58 */
  __IO uint32_t BDTAUPR;    /*!< HRTIM Burst DMA Timerx update register,                     Address offset: 0x5C */
  __IO uint32_t BDTBUPR;    /*!< HRTIM Burst DMA Timerx update register,                     Address offset: 0x60 */
  __IO uint32_t BDTCUPR;    /*!< HRTIM Burst DMA Timerx update register,                     Address offset: 0x64 */
  __IO uint32_t BDTDUPR;    /*!< HRTIM Burst DMA Timerx update register,                     Address offset: 0x68 */  
  __IO uint32_t BDTEUPR;    /*!< HRTIM Burst DMA Timerx update register,                     Address offset: 0x6C */  
  __IO uint32_t BDMADR;     /*!< HRTIM Burst DMA Master Data register,                       Address offset: 0x70 */
}HRTIM_Common_TypeDef;

/* HRTIM  register definition */
typedef struct {
  HRTIM_Master_TypeDef sMasterRegs;
  HRTIM_Timerx_TypeDef sTimerxRegs[5];
  uint32_t             RESERVED0[32];
  HRTIM_Common_TypeDef sCommonRegs;
}HRTIM_TypeDef;

/**
  * @brief RNG
  */

typedef struct
{
  __IO uint32_t CR;  /*!< RNG control register, Address offset: 0x00 */
  __IO uint32_t SR;  /*!< RNG status register,  Address offset: 0x04 */
  __IO uint32_t DR;  /*!< RNG data register,    Address offset: 0x08 */
} RNG_TypeDef;

/**
  * @brief MDIOS
  */

typedef struct
{
  __IO uint32_t CR;    
  __IO uint32_t WRFR; 
  __IO uint32_t CWRFR;
  __IO uint32_t RDFR; 
  __IO uint32_t CRDFR;   
  __IO uint32_t SR;   
  __IO uint32_t CLRFR;   	
  uint32_t RESERVED[57];
  __IO uint32_t DINR0;   
  __IO uint32_t DINR1;    
  __IO uint32_t DINR2;   
  __IO uint32_t DINR3;    
  __IO uint32_t DINR4;    
  __IO uint32_t DINR5;    
  __IO uint32_t DINR6; 
  __IO uint32_t DINR7;
  __IO uint32_t DINR8;
  __IO uint32_t DINR9;
  __IO uint32_t DINR10;
  __IO uint32_t DINR11;
  __IO uint32_t DINR12;
  __IO uint32_t DINR13;
  __IO uint32_t DINR14;
  __IO uint32_t DINR15;
  __IO uint32_t DINR16;
  __IO uint32_t DINR17;
  __IO uint32_t DINR18;
  __IO uint32_t DINR19;
  __IO uint32_t DINR20;
  __IO uint32_t DINR21;
  __IO uint32_t DINR22;
  __IO uint32_t DINR23;
  __IO uint32_t DINR24;
  __IO uint32_t DINR25;
  __IO uint32_t DINR26;
  __IO uint32_t DINR27;
  __IO uint32_t DINR28;
  __IO uint32_t DINR29;
  __IO uint32_t DINR30;
  __IO uint32_t DINR31;
  __IO uint32_t DOUTR0;   
  __IO uint32_t DOUTR1;   
  __IO uint32_t DOUTR2;    
  __IO uint32_t DOUTR3;    
  __IO uint32_t DOUTR4;   
  __IO uint32_t DOUTR5;    
  __IO uint32_t DOUTR6;    
  __IO uint32_t DOUTR7;
  __IO uint32_t DOUTR8;
  __IO uint32_t DOUTR9;
  __IO uint32_t DOUTR10;
  __IO uint32_t DOUTR11;
  __IO uint32_t DOUTR12;
  __IO uint32_t DOUTR13;
  __IO uint32_t DOUTR14;
  __IO uint32_t DOUTR15;
  __IO uint32_t DOUTR16;
  __IO uint32_t DOUTR17;
  __IO uint32_t DOUTR18;
  __IO uint32_t DOUTR19;
  __IO uint32_t DOUTR20;
  __IO uint32_t DOUTR21;
  __IO uint32_t DOUTR22;
  __IO uint32_t DOUTR23;
  __IO uint32_t DOUTR24;
  __IO uint32_t DOUTR25;
  __IO uint32_t DOUTR26;
  __IO uint32_t DOUTR27;
  __IO uint32_t DOUTR28;
  __IO uint32_t DOUTR29;
  __IO uint32_t DOUTR30;
  __IO uint32_t DOUTR31;
} MDIOS_TypeDef;


/** 
  * @brief USB_OTG_Core_Registers
  */
typedef struct
{
 __IO uint32_t GOTGCTL;               /*!< USB_OTG Control and Status Register          000h */
  __IO uint32_t GOTGINT;              /*!< USB_OTG Interrupt Register                   004h */
  __IO uint32_t GAHBCFG;              /*!< Core AHB Configuration Register              008h */
  __IO uint32_t GUSBCFG;              /*!< Core USB Configuration Register              00Ch */
  __IO uint32_t GRSTCTL;              /*!< Core Reset Register                          010h */
  __IO uint32_t GINTSTS;              /*!< Core Interrupt Register                      014h */
  __IO uint32_t GINTMSK;              /*!< Core Interrupt Mask Register                 018h */
  __IO uint32_t GRXSTSR;              /*!< Receive Sts Q Read Register                  01Ch */
  __IO uint32_t GRXSTSP;              /*!< Receive Sts Q Read & POP Register            020h */
  __IO uint32_t GRXFSIZ;              /*!< Receive FIFO Size Register                   024h */
  __IO uint32_t DIEPTXF0_HNPTXFSIZ;   /*!< EP0 / Non Periodic Tx FIFO Size Register     028h */
  __IO uint32_t HNPTXSTS;             /*!< Non Periodic Tx FIFO/Queue Sts reg           02Ch */
  uint32_t Reserved30[2];             /*!< Reserved                                     030h */
  __IO uint32_t GCCFG;                /*!< General Purpose IO Register                  038h */
  __IO uint32_t CID;                  /*!< User ID Register                             03Ch */
  uint32_t  Reserved5[3];             /*!< Reserved                                040h-048h */
  __IO uint32_t GHWCFG3;              /*!< User HW config3                              04Ch */
  uint32_t  Reserved6;                /*!< Reserved                                     050h */ 
  __IO uint32_t GLPMCFG;              /*!< LPM Register                                 054h */
  __IO uint32_t GPWRDN;               /*!< Power Down Register                          058h */
  __IO uint32_t GDFIFOCFG;            /*!< DFIFO Software Config Register               05Ch */
   __IO uint32_t GADPCTL;             /*!< ADP Timer, Control and Status Register       60Ch */
    uint32_t  Reserved43[39];         /*!< Reserved                                058h-0FFh */
  __IO uint32_t HPTXFSIZ;             /*!< Host Periodic Tx FIFO Size Reg               100h */
  __IO uint32_t DIEPTXF[0x0F];        /*!< dev Periodic Transmit FIFO */
} USB_OTG_GlobalTypeDef;


/** 
  * @brief USB_OTG_device_Registers
  */
typedef struct 
{
  __IO uint32_t DCFG;            /*!< dev Configuration Register   800h */
  __IO uint32_t DCTL;            /*!< dev Control Register         804h */
  __IO uint32_t DSTS;            /*!< dev Status Register (RO)     808h */
  uint32_t Reserved0C;           /*!< Reserved                     80Ch */
  __IO uint32_t DIEPMSK;         /*!< dev IN Endpoint Mask         810h */
  __IO uint32_t DOEPMSK;         /*!< dev OUT Endpoint Mask        814h */
  __IO uint32_t DAINT;           /*!< dev All Endpoints Itr Reg    818h */
  __IO uint32_t DAINTMSK;        /*!< dev All Endpoints Itr Mask   81Ch */
  uint32_t  Reserved20;          /*!< Reserved                     820h */
  uint32_t Reserved9;            /*!< Reserved                     824h */
  __IO uint32_t DVBUSDIS;        /*!< dev VBUS discharge Register  828h */
  __IO uint32_t DVBUSPULSE;      /*!< dev VBUS Pulse Register      82Ch */
  __IO uint32_t DTHRCTL;         /*!< dev threshold                830h */
  __IO uint32_t DIEPEMPMSK;      /*!< dev empty msk                834h */
  __IO uint32_t DEACHINT;        /*!< dedicated EP interrupt       838h */
  __IO uint32_t DEACHMSK;        /*!< dedicated EP msk             83Ch */  
  uint32_t Reserved40;           /*!< dedicated EP mask            840h */
  __IO uint32_t DINEP1MSK;       /*!< dedicated EP mask            844h */
  uint32_t  Reserved44[15];      /*!< Reserved                 844-87Ch */
  __IO uint32_t DOUTEP1MSK;      /*!< dedicated EP msk             884h */   
} USB_OTG_DeviceTypeDef;


/** 
  * @brief USB_OTG_IN_Endpoint-Specific_Register
  */
typedef struct 
{
  __IO uint32_t DIEPCTL;           /*!< dev IN Endpoint Control Reg    900h + (ep_num * 20h) + 00h */
  uint32_t Reserved04;             /*!< Reserved                       900h + (ep_num * 20h) + 04h */
  __IO uint32_t DIEPINT;           /*!< dev IN Endpoint Itr Reg        900h + (ep_num * 20h) + 08h */
  uint32_t Reserved0C;             /*!< Reserved                       900h + (ep_num * 20h) + 0Ch */
  __IO uint32_t DIEPTSIZ;          /*!< IN Endpoint Txfer Size         900h + (ep_num * 20h) + 10h */
  __IO uint32_t DIEPDMA;           /*!< IN Endpoint DMA Address Reg    900h + (ep_num * 20h) + 14h */
  __IO uint32_t DTXFSTS;           /*!< IN Endpoint Tx FIFO Status Reg 900h + (ep_num * 20h) + 18h */
  uint32_t Reserved18;             /*!< Reserved  900h+(ep_num*20h)+1Ch-900h+ (ep_num * 20h) + 1Ch */
} USB_OTG_INEndpointTypeDef;


/** 
  * @brief USB_OTG_OUT_Endpoint-Specific_Registers
  */
typedef struct 
{
  __IO uint32_t DOEPCTL;       /*!< dev OUT Endpoint Control Reg           B00h + (ep_num * 20h) + 00h */
  uint32_t Reserved04;         /*!< Reserved                               B00h + (ep_num * 20h) + 04h */
  __IO uint32_t DOEPINT;       /*!< dev OUT Endpoint Itr Reg               B00h + (ep_num * 20h) + 08h */
  uint32_t Reserved0C;         /*!< Reserved                               B00h + (ep_num * 20h) + 0Ch */
  __IO uint32_t DOEPTSIZ;      /*!< dev OUT Endpoint Txfer Size            B00h + (ep_num * 20h) + 10h */
  __IO uint32_t DOEPDMA;       /*!< dev OUT Endpoint DMA Address           B00h + (ep_num * 20h) + 14h */
  uint32_t Reserved18[2];      /*!< Reserved B00h + (ep_num * 20h) + 18h - B00h + (ep_num * 20h) + 1Ch */
} USB_OTG_OUTEndpointTypeDef;


/** 
  * @brief USB_OTG_Host_Mode_Register_Structures
  */
typedef struct 
{
  __IO uint32_t HCFG;             /*!< Host Configuration Register          400h */
  __IO uint32_t HFIR;             /*!< Host Frame Interval Register         404h */
  __IO uint32_t HFNUM;            /*!< Host Frame Nbr/Frame Remaining       408h */
  uint32_t Reserved40C;           /*!< Reserved                             40Ch */
  __IO uint32_t HPTXSTS;          /*!< Host Periodic Tx FIFO/ Queue Status  410h */
  __IO uint32_t HAINT;            /*!< Host All Channels Interrupt Register 414h */
  __IO uint32_t HAINTMSK;         /*!< Host All Channels Interrupt Mask     418h */
} USB_OTG_HostTypeDef;

/** 
  * @brief USB_OTG_Host_Channel_Specific_Registers
  */
typedef struct
{
  __IO uint32_t HCCHAR;           /*!< Host Channel Characteristics Register    500h */
  __IO uint32_t HCSPLT;           /*!< Host Channel Split Control Register      504h */
  __IO uint32_t HCINT;            /*!< Host Channel Interrupt Register          508h */
  __IO uint32_t HCINTMSK;         /*!< Host Channel Interrupt Mask Register     50Ch */
  __IO uint32_t HCTSIZ;           /*!< Host Channel Transfer Size Register      510h */
  __IO uint32_t HCDMA;            /*!< Host Channel DMA Address Register        514h */
  uint32_t Reserved[2];           /*!< Reserved                                      */
} USB_OTG_HostChannelTypeDef;
/**
  * @}
  */

/** @addtogroup Peripheral_memory_map
  * @{
  */
#define D1_ITCMRAM_BASE           ((uint32_t)0x00000000) /*!< Base address of : 64KB RAM reserved for CPU execution/instruction accessible over ITCM  */
#define D1_ITCMICP_BASE           ((uint32_t)0x00100000) /*!< Base address of : (up to 128KB) embedded Test FLASH memory accessible over ITCM         */
#define D1_DTCMRAM_BASE           ((uint32_t)0x20000000) /*!< Base address of : 128KB system data RAM accessible over DTCM                            */
#define D1_AXIFLASH_BASE          ((uint32_t)0x08000000) /*!< Base address of : (up to 2 MB) embedded FLASH memory accessible over AXI                */
#define D1_AXIICP_BASE            ((uint32_t)0x1FF00000) /*!< Base address of : (up to 128KB) embedded Test FLASH memory accessible over AXI          */
#define D1_AXISRAM_BASE           ((uint32_t)0x24000000) /*!< Base address of : (up to 512KB) system data RAM accessible over over AXI                */

#define D2_AXISRAM_BASE           ((uint32_t)0x10000000) /*!< Base address of : (up to 288KB) system data RAM accessible over over AXI                */
#define D2_AHBSRAM_BASE           ((uint32_t)0x30000000) /*!< Base address of : (up to 288KB) system data RAM accessible over over AXI->AHB Bridge    */

#define D3_BKPSRAM_BASE           ((uint32_t)0x38800000) /*!< Base address of : Backup SRAM(4 KB) over AXI->AHB Bridge                                */                                                  
#define D3_SRAM_BASE              ((uint32_t)0x38000000) /*!< Base address of : Backup SRAM(64 KB) over AXI->AHB Bridge                               */ 

#define PERIPH_BASE               ((uint32_t)0x40000000) /*!< Base address of : AHB/ABP Peripherals                                                   */
#define QSPI_BASE                 ((uint32_t)0x90000000) /*!< Base address of : QSPI memories  accessible over AXI                                    */

#define FLASH_BANK1_BASE          ((uint32_t)0x08000000) /*!< Base address of : Flash Bank1 accessible over AXI                                       */ 
#define FLASH_BANK2_BASE          ((uint32_t)0x08100000) /*!< Base address of : Flash Bank2  accessible over AXI                                      */ 



/*!< Peripheral memory map */
#define D2_APB1PERIPH_BASE        PERIPH_BASE
#define D2_APB2PERIPH_BASE       (PERIPH_BASE + 0x00010000)
#define D2_AHB1PERIPH_BASE       (PERIPH_BASE + 0x00020000)
#define D2_AHB2PERIPH_BASE       (PERIPH_BASE + 0x08020000)

#define D1_APB1PERIPH_BASE       (PERIPH_BASE + 0x10000000)
#define D1_AHB1PERIPH_BASE       (PERIPH_BASE + 0x12000000)

#define D3_APB1PERIPH_BASE       (PERIPH_BASE + 0x18000000)
#define D3_AHB1PERIPH_BASE       (PERIPH_BASE + 0x18020000)

/*!< Legacy Peripheral memory map */
#define APB1PERIPH_BASE        PERIPH_BASE
#define APB2PERIPH_BASE       (PERIPH_BASE + 0x00010000)
#define AHB1PERIPH_BASE       (PERIPH_BASE + 0x00020000)
#define AHB2PERIPH_BASE       (PERIPH_BASE + 0x08000000)

/*!< D1_AHB1PERIPH peripherals */

#define MDMA_BASE             (D1_AHB1PERIPH_BASE + 0x0000)
#define DMA2D_BASE            (D1_AHB1PERIPH_BASE + 0x1000)
#define JPGDEC_BASE           (D1_AHB1PERIPH_BASE + 0x3000)
#define FLASH_R_BASE          (D1_AHB1PERIPH_BASE + 0x2000)
#define FMC_R_BASE            (D1_AHB1PERIPH_BASE + 0x4000)
#define QSPI_R_BASE           (D1_AHB1PERIPH_BASE + 0x5000)
#define SDMMC1_BASE           (D1_AHB1PERIPH_BASE + 0x7000)

/*!< D2_AHB1PERIPH peripherals */

#define DMA1_BASE               (D2_AHB1PERIPH_BASE + 0x0000)
#define DMA2_BASE               (D2_AHB1PERIPH_BASE + 0x0400)
#define DMAMUX1_BASE            (D2_AHB1PERIPH_BASE + 0x0800)
#define ADC1_BASE               (D2_AHB1PERIPH_BASE + 0x2000)
#define ADC2_BASE               (D2_AHB1PERIPH_BASE + 0x2100)
#define ADC12_COMMON_BASE       (D2_AHB1PERIPH_BASE + 0x2300)
#define ADC3_COMMON_BASE        (D3_AHB1PERIPH_BASE + 0x6300)
#define ART_BASE                (D2_AHB1PERIPH_BASE + 0x4400)
#define ETH_BASE                (D2_AHB1PERIPH_BASE + 0x8000)
#define ETH_MAC_BASE            (ETH_BASE)

/*!< USB registers base address */
#define USB1_OTG_HS_PERIPH_BASE              ((uint32_t )0x40040000)
#define USB2_OTG_FS_PERIPH_BASE              ((uint32_t )0x40080000)
#define USB_OTG_GLOBAL_BASE                  ((uint32_t )0x000)
#define USB_OTG_DEVICE_BASE                  ((uint32_t )0x800)
#define USB_OTG_IN_ENDPOINT_BASE             ((uint32_t )0x900)
#define USB_OTG_OUT_ENDPOINT_BASE            ((uint32_t )0xB00)
#define USB_OTG_EP_REG_SIZE                  ((uint32_t )0x20)
#define USB_OTG_HOST_BASE                    ((uint32_t )0x400)
#define USB_OTG_HOST_PORT_BASE               ((uint32_t )0x440)
#define USB_OTG_HOST_CHANNEL_BASE            ((uint32_t )0x500)
#define USB_OTG_HOST_CHANNEL_SIZE            ((uint32_t )0x20)
#define USB_OTG_PCGCCTL_BASE                 ((uint32_t )0xE00)
#define USB_OTG_FIFO_BASE                    ((uint32_t )0x1000)
#define USB_OTG_FIFO_SIZE                    ((uint32_t )0x1000)

/*!< D2_AHB2PERIPH peripherals */

#define DCMI_BASE              (D2_AHB2PERIPH_BASE + 0x0000)
#define CRYP_BASE              (D2_AHB2PERIPH_BASE + 0x1000)
#define HASH_BASE              (D2_AHB2PERIPH_BASE + 0x1400)
#define HASH_DIGEST_BASE       (D2_AHB2PERIPH_BASE + 0x1710)
#define RNG_BASE               (D2_AHB2PERIPH_BASE + 0x1800)
#define SDMMC2_BASE            (D2_AHB2PERIPH_BASE + 0x2400)


/*!< D3_AHB1PERIPH peripherals */
#define GPIOA_BASE            (D3_AHB1PERIPH_BASE + 0x0000)
#define GPIOB_BASE            (D3_AHB1PERIPH_BASE + 0x0400)
#define GPIOC_BASE            (D3_AHB1PERIPH_BASE + 0x0800)
#define GPIOD_BASE            (D3_AHB1PERIPH_BASE + 0x0C00)
#define GPIOE_BASE            (D3_AHB1PERIPH_BASE + 0x1000)
#define GPIOF_BASE            (D3_AHB1PERIPH_BASE + 0x1400)
#define GPIOG_BASE            (D3_AHB1PERIPH_BASE + 0x1800)
#define GPIOH_BASE            (D3_AHB1PERIPH_BASE + 0x1C00)
#define GPIOI_BASE            (D3_AHB1PERIPH_BASE + 0x2000)
#define GPIOJ_BASE            (D3_AHB1PERIPH_BASE + 0x2400)
#define GPIOK_BASE            (D3_AHB1PERIPH_BASE + 0x2800)
#define RCC_BASE              (D3_AHB1PERIPH_BASE + 0x4400)
#define RCC_C1_BASE           (RCC_BASE + 0x130)
#define PWR_BASE              (D3_AHB1PERIPH_BASE + 0x4800)
#define CRC_BASE              (D3_AHB1PERIPH_BASE + 0x4C00)
#define BDMA_BASE             (D3_AHB1PERIPH_BASE + 0x5400)
#define DMAMUX2_BASE          (D3_AHB1PERIPH_BASE + 0x5800)
#define ADC3_BASE             (D3_AHB1PERIPH_BASE + 0x6000)
#define HSEM_BASE             (D3_AHB1PERIPH_BASE + 0x6400)

/*!< D1_APB1PERIPH peripherals */
#define LTDC_BASE             (D1_APB1PERIPH_BASE + 0x1000)
#define LTDC_Layer1_BASE      (LTDC_BASE + 0x84)
#define LTDC_Layer2_BASE      (LTDC_BASE + 0x104)
#define WWDG1_BASE            (D1_APB1PERIPH_BASE + 0x3000)

/*!< D2_APB1PERIPH peripherals */
#define TIM2_BASE             (D2_APB1PERIPH_BASE + 0x0000)
#define TIM3_BASE             (D2_APB1PERIPH_BASE + 0x0400)
#define TIM4_BASE             (D2_APB1PERIPH_BASE + 0x0800)
#define TIM5_BASE             (D2_APB1PERIPH_BASE + 0x0C00)
#define TIM6_BASE             (D2_APB1PERIPH_BASE + 0x1000)
#define TIM7_BASE             (D2_APB1PERIPH_BASE + 0x1400)
#define TIM12_BASE            (D2_APB1PERIPH_BASE + 0x1800)
#define TIM13_BASE            (D2_APB1PERIPH_BASE + 0x1C00)
#define TIM14_BASE            (D2_APB1PERIPH_BASE + 0x2000)
#define LPTIM1_BASE           (D2_APB1PERIPH_BASE + 0x2400)


#define SPI2_BASE             (D2_APB1PERIPH_BASE + 0x3800)
#define SPI3_BASE             (D2_APB1PERIPH_BASE + 0x3C00)
#define SPDIFRX_BASE          (D2_APB1PERIPH_BASE + 0x4000)
#define USART2_BASE           (D2_APB1PERIPH_BASE + 0x4400)
#define USART3_BASE           (D2_APB1PERIPH_BASE + 0x4800)
#define UART4_BASE            (D2_APB1PERIPH_BASE + 0x4C00)
#define UART5_BASE            (D2_APB1PERIPH_BASE + 0x5000)
#define I2C1_BASE             (D2_APB1PERIPH_BASE + 0x5400)
#define I2C2_BASE             (D2_APB1PERIPH_BASE + 0x5800)
#define I2C3_BASE             (D2_APB1PERIPH_BASE + 0x5C00)
#define CEC_BASE              (D2_APB1PERIPH_BASE + 0x6C00)
#define DAC1_BASE             (D2_APB1PERIPH_BASE + 0x7400)
#define UART7_BASE            (D2_APB1PERIPH_BASE + 0x7800)
#define UART8_BASE            (D2_APB1PERIPH_BASE + 0x7C00)
#define CRS_BASE              (D2_APB1PERIPH_BASE + 0x8400)
#define SWPMI1_BASE           (D2_APB1PERIPH_BASE + 0x8800)
#define OPAMP_BASE            (D2_APB1PERIPH_BASE + 0x9000)
#define OPAMP1_BASE           (D2_APB1PERIPH_BASE + 0x9000)
#define OPAMP2_BASE           (D2_APB1PERIPH_BASE + 0x9010)
#define MDIOS_BASE            (D2_APB1PERIPH_BASE + 0x9400)
#define TTFDCAN_BASE          (D2_APB1PERIPH_BASE + 0xA000)
#define FDCAN_BASE            (D2_APB1PERIPH_BASE + 0xA400)
#define CAN_Calibration_Unit_BASE (D2_APB1PERIPH_BASE + 0xA800)
#define SRAMCAN_BASE          (D2_APB1PERIPH_BASE + 0xAC00)

/*!< D2_APB2PERIPH peripherals */

#define TIM1_BASE             (D2_APB2PERIPH_BASE + 0x0000)
#define TIM8_BASE             (D2_APB2PERIPH_BASE + 0x0400)
#define USART1_BASE           (D2_APB2PERIPH_BASE + 0x1000)
#define USART6_BASE           (D2_APB2PERIPH_BASE + 0x1400)
#define SPI1_BASE             (D2_APB2PERIPH_BASE + 0x3000)
#define SPI4_BASE             (D2_APB2PERIPH_BASE + 0x3400)
#define TIM15_BASE            (D2_APB2PERIPH_BASE + 0x4000)
#define TIM16_BASE            (D2_APB2PERIPH_BASE + 0x4400)
#define TIM17_BASE            (D2_APB2PERIPH_BASE + 0x4800)
#define SPI5_BASE             (D2_APB2PERIPH_BASE + 0x5000)
#define SAI1_BASE             (D2_APB2PERIPH_BASE + 0x5800)
#define SAI1_Block_A_BASE     (SAI1_BASE + 0x004)
#define SAI1_Block_B_BASE     (SAI1_BASE + 0x024)
#define SAI2_BASE             (D2_APB2PERIPH_BASE + 0x5C00)
#define SAI2_Block_A_BASE     (SAI2_BASE + 0x004)
#define SAI2_Block_B_BASE     (SAI2_BASE + 0x024)
#define SAI3_BASE             (D2_APB2PERIPH_BASE + 0x6000)
#define SAI3_Block_A_BASE     (SAI3_BASE + 0x004)
#define SAI3_Block_B_BASE     (SAI3_BASE + 0x024)
#define DFSDM1_BASE           (D2_APB2PERIPH_BASE + 0x7000)
#define DFSDM1_Channel0_BASE  (DFSDM1_BASE + 0x00)
#define DFSDM1_Channel1_BASE  (DFSDM1_BASE + 0x20)
#define DFSDM1_Channel2_BASE  (DFSDM1_BASE + 0x40)
#define DFSDM1_Channel3_BASE  (DFSDM1_BASE + 0x60)
#define DFSDM1_Channel4_BASE  (DFSDM1_BASE + 0x80)
#define DFSDM1_Channel5_BASE  (DFSDM1_BASE + 0xA0)
#define DFSDM1_Channel6_BASE  (DFSDM1_BASE + 0xC0)
#define DFSDM1_Channel7_BASE  (DFSDM1_BASE + 0xE0)
#define DFSDM1_Filter0_BASE   (DFSDM1_BASE + 0x100)
#define DFSDM1_Filter1_BASE   (DFSDM1_BASE + 0x180)
#define DFSDM1_Filter2_BASE   (DFSDM1_BASE + 0x200)
#define DFSDM1_Filter3_BASE   (DFSDM1_BASE + 0x280)
#define HRTIM1_BASE           (D2_APB2PERIPH_BASE + 0x7400)
#define HRTIM1_TIMA_BASE      (HRTIM1_BASE + 0x00000080)
#define HRTIM1_TIMB_BASE      (HRTIM1_BASE + 0x00000100)
#define HRTIM1_TIMC_BASE      (HRTIM1_BASE + 0x00000180)
#define HRTIM1_TIMD_BASE      (HRTIM1_BASE + 0x00000200)
#define HRTIM1_TIME_BASE      (HRTIM1_BASE + 0x00000280)
#define HRTIM1_COMMON_BASE    (HRTIM1_BASE + 0x00000380)


/*!< D3_APB1PERIPH peripherals */
#define EXTI_BASE             (D3_APB1PERIPH_BASE + 0x0000)
#define EXTI_D1_BASE          (EXTI_BASE + 0x0080)
#define EXTI_D2_BASE          (EXTI_BASE + 0x00C0)
#define SYSCFG_BASE           (D3_APB1PERIPH_BASE + 0x0400)
#define LPUART1_BASE          (D3_APB1PERIPH_BASE + 0x0C00)
#define SPI6_BASE             (D3_APB1PERIPH_BASE + 0x1400)
#define I2C4_BASE             (D3_APB1PERIPH_BASE + 0x1C00)
#define LPTIM2_BASE           (D3_APB1PERIPH_BASE + 0x2400)
#define LPTIM3_BASE           (D3_APB1PERIPH_BASE + 0x2800)
#define LPTIM4_BASE           (D3_APB1PERIPH_BASE + 0x2C00)
#define LPTIM5_BASE           (D3_APB1PERIPH_BASE + 0x3000)
#define COMP12_BASE           (D3_APB1PERIPH_BASE + 0x3800)
#define COMP1_BASE            (COMP12_BASE + 0x0C)
#define COMP2_BASE            (COMP12_BASE + 0x10)
#define RTC_BASE              (D3_APB1PERIPH_BASE + 0x4000)
#define IWDG1_BASE            (D3_APB1PERIPH_BASE + 0x4800)


#define SAI4_BASE             (D3_APB1PERIPH_BASE + 0x5400)
#define SAI4_Block_A_BASE     (SAI4_BASE + 0x004)
#define SAI4_Block_B_BASE     (SAI4_BASE + 0x024)


#define BDMA_Channel0_BASE    (BDMA_BASE + 0x0008)
#define BDMA_Channel1_BASE    (BDMA_BASE + 0x001C)
#define BDMA_Channel2_BASE    (BDMA_BASE + 0x0030)
#define BDMA_Channel3_BASE    (BDMA_BASE + 0x0044)
#define BDMA_Channel4_BASE    (BDMA_BASE + 0x0058)
#define BDMA_Channel5_BASE    (BDMA_BASE + 0x006C)
#define BDMA_Channel6_BASE    (BDMA_BASE + 0x0080)
#define BDMA_Channel7_BASE    (BDMA_BASE + 0x0094)

#define DMAMUX2_Channel0_BASE    (DMAMUX2_BASE)
#define DMAMUX2_Channel1_BASE    (DMAMUX2_BASE + 0x0004)
#define DMAMUX2_Channel2_BASE    (DMAMUX2_BASE + 0x0008)
#define DMAMUX2_Channel3_BASE    (DMAMUX2_BASE + 0x000C)
#define DMAMUX2_Channel4_BASE    (DMAMUX2_BASE + 0x0010)
#define DMAMUX2_Channel5_BASE    (DMAMUX2_BASE + 0x0014)
#define DMAMUX2_Channel6_BASE    (DMAMUX2_BASE + 0x0018)
#define DMAMUX2_Channel7_BASE    (DMAMUX2_BASE + 0x001C)

#define DMAMUX2_RequestGenerator0_BASE  (DMAMUX2_BASE + 0x0100)
#define DMAMUX2_RequestGenerator1_BASE  (DMAMUX2_BASE + 0x0104)
#define DMAMUX2_RequestGenerator2_BASE  (DMAMUX2_BASE + 0x0108)
#define DMAMUX2_RequestGenerator3_BASE  (DMAMUX2_BASE + 0x010C)

#define DMAMUX2_ChannelStatus_BASE      (DMAMUX2_BASE + 0x0080)
#define DMAMUX2_RequestGenStatus_BASE   (DMAMUX2_BASE + 0x0140)

#define DMA1_Stream0_BASE     (DMA1_BASE + 0x010)
#define DMA1_Stream1_BASE     (DMA1_BASE + 0x028)
#define DMA1_Stream2_BASE     (DMA1_BASE + 0x040)
#define DMA1_Stream3_BASE     (DMA1_BASE + 0x058)
#define DMA1_Stream4_BASE     (DMA1_BASE + 0x070)
#define DMA1_Stream5_BASE     (DMA1_BASE + 0x088)
#define DMA1_Stream6_BASE     (DMA1_BASE + 0x0A0)
#define DMA1_Stream7_BASE     (DMA1_BASE + 0x0B8)

#define DMA2_Stream0_BASE     (DMA2_BASE + 0x010)
#define DMA2_Stream1_BASE     (DMA2_BASE + 0x028)
#define DMA2_Stream2_BASE     (DMA2_BASE + 0x040)
#define DMA2_Stream3_BASE     (DMA2_BASE + 0x058)
#define DMA2_Stream4_BASE     (DMA2_BASE + 0x070)
#define DMA2_Stream5_BASE     (DMA2_BASE + 0x088)
#define DMA2_Stream6_BASE     (DMA2_BASE + 0x0A0)
#define DMA2_Stream7_BASE     (DMA2_BASE + 0x0B8)

#define DMAMUX1_Channel0_BASE    (DMAMUX1_BASE)
#define DMAMUX1_Channel1_BASE    (DMAMUX1_BASE + 0x0004)
#define DMAMUX1_Channel2_BASE    (DMAMUX1_BASE + 0x0008)
#define DMAMUX1_Channel3_BASE    (DMAMUX1_BASE + 0x000C)
#define DMAMUX1_Channel4_BASE    (DMAMUX1_BASE + 0x0010)
#define DMAMUX1_Channel5_BASE    (DMAMUX1_BASE + 0x0014)
#define DMAMUX1_Channel6_BASE    (DMAMUX1_BASE + 0x0018)
#define DMAMUX1_Channel7_BASE    (DMAMUX1_BASE + 0x001C)
#define DMAMUX1_Channel8_BASE    (DMAMUX1_BASE + 0x0020)
#define DMAMUX1_Channel9_BASE    (DMAMUX1_BASE + 0x0024)
#define DMAMUX1_Channel10_BASE   (DMAMUX1_BASE + 0x0028)
#define DMAMUX1_Channel11_BASE   (DMAMUX1_BASE + 0x002C)
#define DMAMUX1_Channel12_BASE   (DMAMUX1_BASE + 0x0030)
#define DMAMUX1_Channel13_BASE   (DMAMUX1_BASE + 0x0034)
#define DMAMUX1_Channel14_BASE   (DMAMUX1_BASE + 0x0038)
#define DMAMUX1_Channel15_BASE   (DMAMUX1_BASE + 0x003C)

#define DMAMUX1_RequestGenerator0_BASE  (DMAMUX1_BASE + 0x0100)
#define DMAMUX1_RequestGenerator1_BASE  (DMAMUX1_BASE + 0x0104)
#define DMAMUX1_RequestGenerator2_BASE  (DMAMUX1_BASE + 0x0108)
#define DMAMUX1_RequestGenerator3_BASE  (DMAMUX1_BASE + 0x010C)

#define DMAMUX1_ChannelStatus_BASE      (DMAMUX1_BASE + 0x0080)
#define DMAMUX1_RequestGenStatus_BASE   (DMAMUX1_BASE + 0x0140) 



/*!< FMC Banks registers base  address */
#define FMC_Bank1_R_BASE      (FMC_R_BASE + 0x0000)
#define FMC_Bank1E_R_BASE     (FMC_R_BASE + 0x0104)
#define FMC_Bank2_R_BASE      (FMC_R_BASE + 0x0060)
#define FMC_Bank3_R_BASE      (FMC_R_BASE + 0x0080)
#define FMC_Bank5_6_R_BASE    (FMC_R_BASE + 0x0140)

/* Debug MCU registers base address */
#define DBGMCU_BASE           ((uint32_t )0x5C001000)

#define MDMA_Channel0_BASE    (MDMA_BASE + 0x00000040)
#define MDMA_Channel1_BASE    (MDMA_BASE + 0x00000080)
#define MDMA_Channel2_BASE    (MDMA_BASE + 0x000000C0)
#define MDMA_Channel3_BASE    (MDMA_BASE + 0x00000100)
#define MDMA_Channel4_BASE    (MDMA_BASE + 0x00000140)
#define MDMA_Channel5_BASE    (MDMA_BASE + 0x00000180)
#define MDMA_Channel6_BASE    (MDMA_BASE + 0x000001C0)
#define MDMA_Channel7_BASE    (MDMA_BASE + 0x00000200)
#define MDMA_Channel8_BASE    (MDMA_BASE + 0x00000240)
#define MDMA_Channel9_BASE    (MDMA_BASE + 0x00000280)
#define MDMA_Channel10_BASE   (MDMA_BASE + 0x000002C0)
#define MDMA_Channel11_BASE   (MDMA_BASE + 0x00000300)
#define MDMA_Channel12_BASE   (MDMA_BASE + 0x00000340)
#define MDMA_Channel13_BASE   (MDMA_BASE + 0x00000380)
#define MDMA_Channel14_BASE   (MDMA_BASE + 0x000003C0)
#define MDMA_Channel15_BASE   (MDMA_BASE + 0x00000400)
#define MDMA_Channel16_BASE   (MDMA_BASE + 0x00000440)

/**
  * @}
  */

/** @addtogroup Peripheral_declaration
  * @{
  */
#define TIM2                ((TIM_TypeDef *) TIM2_BASE)
#define TIM3                ((TIM_TypeDef *) TIM3_BASE)
#define TIM4                ((TIM_TypeDef *) TIM4_BASE)
#define TIM5                ((TIM_TypeDef *) TIM5_BASE)
#define TIM6                ((TIM_TypeDef *) TIM6_BASE)
#define TIM7                ((TIM_TypeDef *) TIM7_BASE)
#define TIM13               ((TIM_TypeDef *) TIM13_BASE)
#define TIM14               ((TIM_TypeDef *) TIM14_BASE)
#define LCD                 ((LCD_TypeDef *) LCD_BASE)
#define RTC                 ((RTC_TypeDef *) RTC_BASE)
#define WWDG1               ((WWDG_TypeDef *) WWDG1_BASE)


#define IWDG1               ((IWDG_TypeDef *) IWDG1_BASE)
#define SPI2                ((SPI_TypeDef *) SPI2_BASE)
#define SPI3                ((SPI_TypeDef *) SPI3_BASE)
#define SPI4                ((SPI_TypeDef *) SPI4_BASE)
#define SPI5                ((SPI_TypeDef *) SPI5_BASE)
#define SPI6                ((SPI_TypeDef *) SPI6_BASE)
#define USART2              ((USART_TypeDef *) USART2_BASE)
#define USART3              ((USART_TypeDef *) USART3_BASE)
#define USART6              ((USART_TypeDef *) USART6_BASE)
#define UART7               ((USART_TypeDef *) UART7_BASE)
#define UART8               ((USART_TypeDef *) UART8_BASE)
#define CRS                 ((CRS_TypeDef *) CRS_BASE)
#define UART4               ((USART_TypeDef *) UART4_BASE)
#define UART5               ((USART_TypeDef *) UART5_BASE)
#define I2C1                ((I2C_TypeDef *) I2C1_BASE)
#define I2C2                ((I2C_TypeDef *) I2C2_BASE)
#define I2C3                ((I2C_TypeDef *) I2C3_BASE)
#define I2C4                ((I2C_TypeDef *) I2C4_BASE)
#define FDCAN               ((FDCAN_TypeDef *) FDCAN_BASE)
#define TTFDCAN             ((TTFDCAN_TypeDef *) TTFDCAN_BASE)
#define CAN_Calibration_Unit ((CAN_Calibration_Unit_TypeDef *) CAN_Calibration_Unit_BASE)
#define CEC                 ((CEC_TypeDef *) CEC_BASE)
#define LPTIM1              ((LPTIM_TypeDef *) LPTIM1_BASE)
#define PWR                 ((PWR_TypeDef *) PWR_BASE)
#define DAC1                ((DAC_TypeDef *) DAC1_BASE)
#define LPUART1             ((USART_TypeDef *) LPUART1_BASE)
#define SWPMI1              ((SWPMI_TypeDef *) SWPMI1_BASE)
#define LPTIM2              ((LPTIM_TypeDef *) LPTIM2_BASE)
#define LPTIM3              ((LPTIM_TypeDef *) LPTIM3_BASE)
#define LPTIM4              ((LPTIM_TypeDef *) LPTIM4_BASE)
#define LPTIM5              ((LPTIM_TypeDef *) LPTIM5_BASE)
#define SYSCFG              ((SYSCFG_TypeDef *) SYSCFG_BASE)
#define COMP12              ((COMPOPT_TypeDef *) COMP12_BASE)
#define COMP1               ((COMP_TypeDef *) COMP1_BASE)
#define COMP2               ((COMP_TypeDef *) COMP2_BASE)
#define COMP12_COMMON       ((COMP_Common_TypeDef *) COMP2_BASE)
#define OPAMP               ((OPAMP_TypeDef *) OPAMP_BASE)
#define OPAMP1              ((OPAMP_TypeDef *) OPAMP1_BASE)
#define OPAMP2              ((OPAMP_TypeDef *) OPAMP2_BASE)


#define EXTI                ((EXTI_TypeDef *) EXTI_BASE)
#define EXTI_D1             ((EXTI_Core_TypeDef *) EXTI_D1_BASE)
#define EXTI_D2             ((EXTI_Core_TypeDef *) EXTI_D2_BASE)
#define SDMMC               ((SDMMC_TypeDef *) SDMMC_BASE)
#define TIM1                ((TIM_TypeDef *) TIM1_BASE)
#define SPI1                ((SPI_TypeDef *) SPI1_BASE)
#define TIM8                ((TIM_TypeDef *) TIM8_BASE)
#define USART1              ((USART_TypeDef *) USART1_BASE)
#define TIM12               ((TIM_TypeDef *) TIM12_BASE)
#define TIM15               ((TIM_TypeDef *) TIM15_BASE)
#define TIM16               ((TIM_TypeDef *) TIM16_BASE)
#define TIM17               ((TIM_TypeDef *) TIM17_BASE)
#define HRTIM1              ((HRTIM_TypeDef *) HRTIM1_BASE)
#define HRTIM1_TIMA         ((HRTIM_TIM_TypeDef *) HRTIM1_TIMA_BASE)
#define HRTIM1_TIMB         ((HRTIM_TIM_TypeDef *) HRTIM1_TIMB_BASE)
#define HRTIM1_TIMC         ((HRTIM_TIM_TypeDef *) HRTIM1_TIMC_BASE)
#define HRTIM1_TIMD         ((HRTIM_TIM_TypeDef *) HRTIM1_TIMD_BASE)
#define HRTIM1_TIME         ((HRTIM_TIM_TypeDef *) HRTIM1_TIME_BASE)
#define HRTIM1_COMMON       ((HRTIM_Common_TypeDef *) HRTIM1_COMMON_BASE)
#define SAI1                ((SAI_TypeDef *) SAI1_BASE)
#define SAI1_Block_A        ((SAI_Block_TypeDef *)SAI1_Block_A_BASE)
#define SAI1_Block_B        ((SAI_Block_TypeDef *)SAI1_Block_B_BASE)
#define SAI2                ((SAI_TypeDef *) SAI2_BASE)
#define SAI2_Block_A        ((SAI_Block_TypeDef *)SAI2_Block_A_BASE)
#define SAI2_Block_B        ((SAI_Block_TypeDef *)SAI2_Block_B_BASE)
#define SAI3                ((SAI_TypeDef *) SAI3_BASE)
#define SAI3_Block_A        ((SAI_Block_TypeDef *)SAI3_Block_A_BASE)
#define SAI3_Block_B        ((SAI_Block_TypeDef *)SAI3_Block_B_BASE)
#define SAI4                ((SAI_TypeDef *) SAI4_BASE)
#define SAI4_Block_A        ((SAI_Block_TypeDef *)SAI4_Block_A_BASE)
#define SAI4_Block_B        ((SAI_Block_TypeDef *)SAI4_Block_B_BASE)


#define SPDIFRX             ((SPDIFRX_TypeDef *) SPDIFRX_BASE) 
#define DFSDM1_Channel0     ((DFSDM_Channel_TypeDef *) DFSDM1_Channel0_BASE)
#define DFSDM1_Channel1     ((DFSDM_Channel_TypeDef *) DFSDM1_Channel1_BASE)
#define DFSDM1_Channel2     ((DFSDM_Channel_TypeDef *) DFSDM1_Channel2_BASE)
#define DFSDM1_Channel3     ((DFSDM_Channel_TypeDef *) DFSDM1_Channel3_BASE)
#define DFSDM1_Channel4     ((DFSDM_Channel_TypeDef *) DFSDM1_Channel4_BASE)
#define DFSDM1_Channel5     ((DFSDM_Channel_TypeDef *) DFSDM1_Channel5_BASE)
#define DFSDM1_Channel6     ((DFSDM_Channel_TypeDef *) DFSDM1_Channel6_BASE)
#define DFSDM1_Channel7     ((DFSDM_Channel_TypeDef *) DFSDM1_Channel7_BASE)
#define DFSDM1_Filter0      ((DFSDM_Filter_TypeDef *) DFSDM1_Filter0_BASE)
#define DFSDM1_Filter1      ((DFSDM_Filter_TypeDef *) DFSDM1_Filter1_BASE)
#define DFSDM1_Filter2      ((DFSDM_Filter_TypeDef *) DFSDM1_Filter2_BASE)
#define DFSDM1_Filter3      ((DFSDM_Filter_TypeDef *) DFSDM1_Filter3_BASE)
#define DMA2D               ((DMA2D_TypeDef *) DMA2D_BASE)
#define DCMI                ((DCMI_TypeDef *) DCMI_BASE)
#define RCC                 ((RCC_TypeDef *) RCC_BASE)
#define RCC_C1              ((RCC_Core_TypeDef *) RCC_C1_BASE)
#define FLASH               ((FLASH_TypeDef *) FLASH_R_BASE)
#define CRC                 ((CRC_TypeDef *) CRC_BASE)

#define GPIOA               ((GPIO_TypeDef *) GPIOA_BASE)
#define GPIOB               ((GPIO_TypeDef *) GPIOB_BASE)
#define GPIOC               ((GPIO_TypeDef *) GPIOC_BASE)
#define GPIOD               ((GPIO_TypeDef *) GPIOD_BASE)
#define GPIOE               ((GPIO_TypeDef *) GPIOE_BASE)
#define GPIOF               ((GPIO_TypeDef *) GPIOF_BASE)
#define GPIOG               ((GPIO_TypeDef *) GPIOG_BASE)
#define GPIOH               ((GPIO_TypeDef *) GPIOH_BASE)
#define GPIOI               ((GPIO_TypeDef *) GPIOI_BASE)
#define GPIOJ               ((GPIO_TypeDef *) GPIOJ_BASE)
#define GPIOK               ((GPIO_TypeDef *) GPIOK_BASE)

#define ADC1                ((ADC_TypeDef *) ADC1_BASE)
#define ADC2                ((ADC_TypeDef *) ADC2_BASE)
#define ADC3                ((ADC_TypeDef *) ADC3_BASE)
#define ADC12_COMMON        ((ADC_Common_TypeDef *) ADC12_COMMON_BASE)
#define ADC3_COMMON         ((ADC_Common_TypeDef *) ADC3_COMMON_BASE)
#define CRYP                ((CRYP_TypeDef *) CRYP_BASE)
#define HASH                ((HASH_TypeDef *) HASH_BASE)
#define HASH_DIGEST         ((HASH_DIGEST_TypeDef *) HASH_DIGEST_BASE)
#define RNG                 ((RNG_TypeDef *) RNG_BASE)
#define SDMMC2              ((SDMMC_TypeDef *) SDMMC2_BASE)

#define BDMA                 ((BDMA_TypeDef *) BDMA_BASE)
#define BDMA_Channel0        ((BDMA_Channel_TypeDef *) BDMA_Channel0_BASE)
#define BDMA_Channel1        ((BDMA_Channel_TypeDef *) BDMA_Channel1_BASE)
#define BDMA_Channel2        ((BDMA_Channel_TypeDef *) BDMA_Channel2_BASE)
#define BDMA_Channel3        ((BDMA_Channel_TypeDef *) BDMA_Channel3_BASE)
#define BDMA_Channel4        ((BDMA_Channel_TypeDef *) BDMA_Channel4_BASE)
#define BDMA_Channel5        ((BDMA_Channel_TypeDef *) BDMA_Channel5_BASE)
#define BDMA_Channel6        ((BDMA_Channel_TypeDef *) BDMA_Channel6_BASE)
#define BDMA_Channel7        ((BDMA_Channel_TypeDef *) BDMA_Channel7_BASE)

#define DMAMUX2_Channel0       ((DMAMUX_Channel_TypeDef *) DMAMUX2_Channel0_BASE)
#define DMAMUX2_Channel1       ((DMAMUX_Channel_TypeDef *) DMAMUX2_Channel1_BASE)
#define DMAMUX2_Channel2       ((DMAMUX_Channel_TypeDef *) DMAMUX2_Channel2_BASE)
#define DMAMUX2_Channel3       ((DMAMUX_Channel_TypeDef *) DMAMUX2_Channel3_BASE)
#define DMAMUX2_Channel4       ((DMAMUX_Channel_TypeDef *) DMAMUX2_Channel4_BASE)
#define DMAMUX2_Channel5       ((DMAMUX_Channel_TypeDef *) DMAMUX2_Channel5_BASE)
#define DMAMUX2_Channel6       ((DMAMUX_Channel_TypeDef *) DMAMUX2_Channel6_BASE)
#define DMAMUX2_Channel7       ((DMAMUX_Channel_TypeDef *) DMAMUX2_Channel7_BASE)


#define DMAMUX2_RequestGenerator0  ((DMAMUX_RequestGen_TypeDef *) DMAMUX2_RequestGenerator0_BASE)
#define DMAMUX2_RequestGenerator1  ((DMAMUX_RequestGen_TypeDef *) DMAMUX2_RequestGenerator1_BASE)
#define DMAMUX2_RequestGenerator2  ((DMAMUX_RequestGen_TypeDef *) DMAMUX2_RequestGenerator2_BASE)
#define DMAMUX2_RequestGenerator3  ((DMAMUX_RequestGen_TypeDef *) DMAMUX2_RequestGenerator3_BASE)

#define DMAMUX2_ChannelStatus      ((DMAMUX_ChannelStatus_TypeDef *) DMAMUX2_ChannelStatus_BASE)
#define DMAMUX2_RequestGenStatus   ((DMAMUX_RequestGenStatus_TypeDef *) DMAMUX2_RequestGenStatus_BASE)

#define DMA2                ((DMA_TypeDef *) DMA2_BASE)
#define DMA2_Stream0        ((DMA_Stream_TypeDef *) DMA2_Stream0_BASE)
#define DMA2_Stream1        ((DMA_Stream_TypeDef *) DMA2_Stream1_BASE)
#define DMA2_Stream2        ((DMA_Stream_TypeDef *) DMA2_Stream2_BASE)
#define DMA2_Stream3        ((DMA_Stream_TypeDef *) DMA2_Stream3_BASE)
#define DMA2_Stream4        ((DMA_Stream_TypeDef *) DMA2_Stream4_BASE)
#define DMA2_Stream5        ((DMA_Stream_TypeDef *) DMA2_Stream5_BASE)
#define DMA2_Stream6        ((DMA_Stream_TypeDef *) DMA2_Stream6_BASE)
#define DMA2_Stream7        ((DMA_Stream_TypeDef *) DMA2_Stream7_BASE)

#define DMA1                ((DMA_TypeDef *) DMA1_BASE)
#define DMA1_Stream0        ((DMA_Stream_TypeDef *) DMA1_Stream0_BASE)
#define DMA1_Stream1        ((DMA_Stream_TypeDef *) DMA1_Stream1_BASE)
#define DMA1_Stream2        ((DMA_Stream_TypeDef *) DMA1_Stream2_BASE)
#define DMA1_Stream3        ((DMA_Stream_TypeDef *) DMA1_Stream3_BASE)
#define DMA1_Stream4        ((DMA_Stream_TypeDef *) DMA1_Stream4_BASE)
#define DMA1_Stream5        ((DMA_Stream_TypeDef *) DMA1_Stream5_BASE)
#define DMA1_Stream6        ((DMA_Stream_TypeDef *) DMA1_Stream6_BASE)
#define DMA1_Stream7        ((DMA_Stream_TypeDef *) DMA1_Stream7_BASE)


#define DMAMUX1_Channel0     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel0_BASE)
#define DMAMUX1_Channel1     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel1_BASE)
#define DMAMUX1_Channel2     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel2_BASE)
#define DMAMUX1_Channel3     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel3_BASE)
#define DMAMUX1_Channel4     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel4_BASE)
#define DMAMUX1_Channel5     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel5_BASE)
#define DMAMUX1_Channel6     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel6_BASE)
#define DMAMUX1_Channel7     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel7_BASE)
#define DMAMUX1_Channel8     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel8_BASE)
#define DMAMUX1_Channel9     ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel9_BASE)
#define DMAMUX1_Channel10    ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel10_BASE)
#define DMAMUX1_Channel11    ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel11_BASE)
#define DMAMUX1_Channel12    ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel12_BASE)
#define DMAMUX1_Channel13    ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel13_BASE)
#define DMAMUX1_Channel14    ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel14_BASE)
#define DMAMUX1_Channel15    ((DMAMUX_Channel_TypeDef *) DMAMUX1_Channel15_BASE)

#define DMAMUX1_RequestGenerator0  ((DMAMUX_RequestGen_TypeDef *) DMAMUX1_RequestGenerator0_BASE)
#define DMAMUX1_RequestGenerator1  ((DMAMUX_RequestGen_TypeDef *) DMAMUX1_RequestGenerator1_BASE)
#define DMAMUX1_RequestGenerator2  ((DMAMUX_RequestGen_TypeDef *) DMAMUX1_RequestGenerator2_BASE)
#define DMAMUX1_RequestGenerator3  ((DMAMUX_RequestGen_TypeDef *) DMAMUX1_RequestGenerator3_BASE)

#define DMAMUX1_ChannelStatus      ((DMAMUX_ChannelStatus_TypeDef *)    DMAMUX1_ChannelStatus_BASE)
#define DMAMUX1_RequestGenStatus   ((DMAMUX_RequestGenStatus_TypeDef *) DMAMUX1_RequestGenStatus_BASE)


#define FMC_Bank1           ((FMC_Bank1_TypeDef *) FMC_Bank1_R_BASE)
#define FMC_Bank1E          ((FMC_Bank1E_TypeDef *) FMC_Bank1E_R_BASE)
#define FMC_Bank2           ((FMC_Bank2_TypeDef *) FMC_Bank2_R_BASE)
#define FMC_Bank3           ((FMC_Bank3_TypeDef *) FMC_Bank3_R_BASE)
#define FMC_Bank5_6         ((FMC_Bank5_6_TypeDef *) FMC_Bank5_6_R_BASE)

#define QUADSPI               ((QUADSPI_TypeDef *) QSPI_R_BASE)

#define SDMMC1                ((SDMMC_TypeDef *) SDMMC1_BASE)

#define DBGMCU              ((DBGMCU_TypeDef *) DBGMCU_BASE)

#define JPEG                ((JPEG_TypeDef *) JPGDEC_BASE)
#define HSEM                ((HSEM_TypeDef *) HSEM_BASE) 

#define LTDC                ((LTDC_TypeDef *)LTDC_BASE)
#define LTDC_Layer1         ((LTDC_Layer_TypeDef *)LTDC_Layer1_BASE)
#define LTDC_Layer2         ((LTDC_Layer_TypeDef *)LTDC_Layer2_BASE)
#define MDIOS               ((MDIOS_TypeDef *) MDIOS_BASE)

#define ETH                 ((ETH_TypeDef *)ETH_BASE)
#define MDMA                ((MDMA_TypeDef *)MDMA_BASE)
#define MDMA_Channel0       ((MDMA_Channel_TypeDef *)MDMA_Channel0_BASE)
#define MDMA_Channel1       ((MDMA_Channel_TypeDef *)MDMA_Channel1_BASE)
#define MDMA_Channel2       ((MDMA_Channel_TypeDef *)MDMA_Channel2_BASE)
#define MDMA_Channel3       ((MDMA_Channel_TypeDef *)MDMA_Channel3_BASE)
#define MDMA_Channel4       ((MDMA_Channel_TypeDef *)MDMA_Channel4_BASE)
#define MDMA_Channel5       ((MDMA_Channel_TypeDef *)MDMA_Channel5_BASE)
#define MDMA_Channel6       ((MDMA_Channel_TypeDef *)MDMA_Channel6_BASE)
#define MDMA_Channel7       ((MDMA_Channel_TypeDef *)MDMA_Channel7_BASE)
#define MDMA_Channel8       ((MDMA_Channel_TypeDef *)MDMA_Channel8_BASE)
#define MDMA_Channel9       ((MDMA_Channel_TypeDef *)MDMA_Channel9_BASE)
#define MDMA_Channel10      ((MDMA_Channel_TypeDef *)MDMA_Channel10_BASE)
#define MDMA_Channel11      ((MDMA_Channel_TypeDef *)MDMA_Channel11_BASE)
#define MDMA_Channel12      ((MDMA_Channel_TypeDef *)MDMA_Channel12_BASE)
#define MDMA_Channel13      ((MDMA_Channel_TypeDef *)MDMA_Channel13_BASE)
#define MDMA_Channel14      ((MDMA_Channel_TypeDef *)MDMA_Channel14_BASE)
#define MDMA_Channel15      ((MDMA_Channel_TypeDef *)MDMA_Channel15_BASE)
#define MDMA_Channel16      ((MDMA_Channel_TypeDef *)MDMA_Channel16_BASE)

#define USB1_OTG_HS         ((USB_OTG_GlobalTypeDef *) USB1_OTG_HS_PERIPH_BASE)
#define USB2_OTG_FS         ((USB_OTG_GlobalTypeDef *) USB2_OTG_FS_PERIPH_BASE)

/**
  * @}
  */

/** @addtogroup Exported_constants
  * @{
  */

  /** @addtogroup Peripheral_Registers_Bits_Definition
  * @{
  */

/******************************************************************************/
/*                         Peripheral Registers_Bits_Definition               */
/******************************************************************************/

/******************************************************************************/
/*                                                                            */
/*                        Analog to Digital Converter                         */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for ADC_ISR register  ********************/
#define ADC_ISR_ADRD          ((uint32_t)0x00000001)   /*!< ADC Ready (ADRDY) flag  */
#define ADC_ISR_EOSMP         ((uint32_t)0x00000002) /*!< ADC End of Sampling flag */
#define ADC_ISR_EOC           ((uint32_t)0x00000004) /*!< ADC End of Regular Conversion flag */
#define ADC_ISR_EOS           ((uint32_t)0x00000008) /*!< ADC End of Regular sequence of Conversions flag */
#define ADC_ISR_OVR           ((uint32_t)0x00000010) /*!< ADC overrun flag */
#define ADC_ISR_JEOC          ((uint32_t)0x00000020) /*!< ADC End of Injected Conversion flag */
#define ADC_ISR_JEOS          ((uint32_t)0x00000040) /*!< ADC End of Injected sequence of Conversions flag */
#define ADC_ISR_AWD1          ((uint32_t)0x00000080) /*!< ADC Analog watchdog 1 flag */
#define ADC_ISR_AWD2          ((uint32_t)0x00000100) /*!< ADC Analog watchdog 2 flag */
#define ADC_ISR_AWD3          ((uint32_t)0x00000200) /*!< ADC Analog watchdog 3 flag */
#define ADC_ISR_JQOVF         ((uint32_t)0x00000400) /*!< ADC Injected Context Queue Overflow flag */

/********************  Bit definition for ADC_IER register  ********************/
#define ADC_IER_RDY           ((uint32_t)0x00000001) /*!< ADC Ready (ADRDY) interrupt source */
#define ADC_IER_EOSMP         ((uint32_t)0x00000002) /*!< ADC End of Sampling interrupt source */
#define ADC_IER_EOC           ((uint32_t)0x00000004) /*!< ADC End of Regular Conversion interrupt source */
#define ADC_IER_EOS           ((uint32_t)0x00000008) /*!< ADC End of Regular sequence of Conversions interrupt source */
#define ADC_IER_OVR           ((uint32_t)0x00000010) /*!< ADC overrun interrupt source */
#define ADC_IER_JEOC          ((uint32_t)0x00000020) /*!< ADC End of Injected Conversion interrupt source */
#define ADC_IER_JEOS          ((uint32_t)0x00000040) /*!< ADC End of Injected sequence of Conversions interrupt source */
#define ADC_IER_AWD1          ((uint32_t)0x00000080) /*!< ADC Analog watchdog 1 interrupt source */
#define ADC_IER_AWD2          ((uint32_t)0x00000100) /*!< ADC Analog watchdog 2 interrupt source */
#define ADC_IER_AWD3          ((uint32_t)0x00000200) /*!< ADC Analog watchdog 3 interrupt source */
#define ADC_IER_JQOVF         ((uint32_t)0x00000400) /*!< ADC Injected Context Queue Overflow interrupt source */

/********************  Bit definition for ADC_CR register  ********************/
#define ADC_CR_ADEN          ((uint32_t)0x00000001) /*!< ADC Enable control */
#define ADC_CR_ADDIS         ((uint32_t)0x00000002) /*!< ADC Disable command */
#define ADC_CR_ADSTART       ((uint32_t)0x00000004) /*!< ADC Start of Regular conversion */
#define ADC_CR_JADSTART      ((uint32_t)0x00000008) /*!< ADC Start of injected conversion */
#define ADC_CR_ADSTP         ((uint32_t)0x00000010) /*!< ADC Stop of Regular conversion */
#define ADC_CR_JADSTP        ((uint32_t)0x00000020) /*!< ADC Boost Mode */
#define ADC_CR_BOOST         ((uint32_t)0x00000100) /*!< ADC Stop of injected conversion */
#define ADC_CR_ADCALLIN      ((uint32_t)0x00010000) /*!< ADC Linearity calibration */
#define ADC_CR_LINCALRDYW1   ((uint32_t)0x00400000) /*!< ADC Linearity calibration ready Word 1 */
#define ADC_CR_LINCALRDYW2   ((uint32_t)0x00800000) /*!< ADC Linearity calibration ready Word 2 */
#define ADC_CR_LINCALRDYW3   ((uint32_t)0x01000000) /*!< ADC Linearity calibration ready Word 3 */
#define ADC_CR_LINCALRDYW4   ((uint32_t)0x02000000) /*!< ADC Linearity calibration ready Word 4 */ 
#define ADC_CR_LINCALRDYW5   ((uint32_t)0x04000000) /*!< ADC Linearity calibration ready Word 5 */ 
#define ADC_CR_LINCALRDYW6   ((uint32_t)0x08000000) /*!< ADC Linearity calibration ready Word 6 */ 
#define ADC_CR_ADVREGEN      ((uint32_t)0x10000000) /*!< ADC Voltage regulator Enable */
#define ADC_CR_DEEPPWD       ((uint32_t)0x20000000) /*!< ADC Deep power down Enable */
#define ADC_CR_ADCALDIF      ((uint32_t)0x40000000) /*!< ADC Differential Mode for calibration */
#define ADC_CR_ADCAL         ((uint32_t)0x80000000) /*!< ADC Calibration */

/********************  Bit definition for ADC_CFGR register  ********************/
#define ADC_CFGR_DMNGT     ((uint32_t)0x00000003) /*!< ADC Data Management configuration */
#define ADC_CFGR_DMNGT_0   ((uint32_t)0x00000001) /*!< ADC Data Management configuration bit 0 */
#define ADC_CFGR_DMNGT_1   ((uint32_t)0x00000002) /*!< ADC Data Management configuration bit 1 */

#define ADC_CFGR_RES       ((uint32_t)0x0000001C) /*!< ADC Data resolution */
#define ADC_CFGR_RES_0     ((uint32_t)0x00000004) /*!< ADC RES bit 0 */
#define ADC_CFGR_RES_1     ((uint32_t)0x00000008) /*!< ADC RES bit 1 */
#define ADC_CFGR_RES_2     ((uint32_t)0x00000010) /*!< ADC RES bit 2 */

#define ADC_CFGR_ALIGN     ((uint32_t)0x00000020) /*!< ADC Data Alignement */

#define ADC_CFGR_EXTSEL    ((uint32_t)0x000003E0) /*!< ADC External trigger selection for regular group */
#define ADC_CFGR_EXTSEL_0 ((uint32_t)0x00000020) /*!< ADC EXTSEL bit 0 */
#define ADC_CFGR_EXTSEL_1 ((uint32_t)0x00000040) /*!< ADC EXTSEL bit 1 */
#define ADC_CFGR_EXTSEL_2 ((uint32_t)0x00000080) /*!< ADC EXTSEL bit 2 */
#define ADC_CFGR_EXTSEL_3 ((uint32_t)0x00000100) /*!< ADC EXTSEL bit 3 */
#define ADC_CFGR_EXTSEL_4 ((uint32_t)0x00000200) /*!< ADC EXTSEL bit 4 */

#define ADC_CFGR_EXTEN     ((uint32_t)0x00000C00) /*!< ADC External trigger enable and polarity selection for regular channels */
#define ADC_CFGR_EXTEN_0   ((uint32_t)0x00000400) /*!< ADC EXTEN bit 0 */
#define ADC_CFGR_EXTEN_1   ((uint32_t)0x00000800) /*!< ADC EXTEN bit 1 */

#define ADC_CFGR_OVRMOD    ((uint32_t)0x00001000) /*!< ADC overrun mode */
#define ADC_CFGR_CONT      ((uint32_t)0x00002000) /*!< ADC Single/continuous conversion mode for regular conversion */
#define ADC_CFGR_AUTDLY    ((uint32_t)0x00004000) /*!< ADC Delayed conversion mode */

#define ADC_CFGR_DISCEN    ((uint32_t)0x00010000) /*!< ADC Discontinuous mode for regular channels */

#define ADC_CFGR_DISCNUM   ((uint32_t)0x000E0000) /*!< ADC Discontinuous mode channel count */
#define ADC_CFGR_DISCNUM_0 ((uint32_t)0x00020000) /*!< ADC DISCNUM bit 0 */
#define ADC_CFGR_DISCNUM_1 ((uint32_t)0x00040000) /*!< ADC DISCNUM bit 1 */
#define ADC_CFGR_DISCNUM_2 ((uint32_t)0x00080000) /*!< ADC DISCNUM bit 2 */

#define ADC_CFGR_JDISCEN   ((uint32_t)0x00100000) /*!< ADC Discontinuous mode on injected channels */
#define ADC_CFGR_JQM       ((uint32_t)0x00200000) /*!< ADC JSQR Queue mode */
#define ADC_CFGR_AWD1SGL   ((uint32_t)0x00400000) /*!< Enable the watchdog 1 on a single channel or on all channels */
#define ADC_CFGR_AWD1EN    ((uint32_t)0x00800000) /*!< ADC Analog watchdog 1 enable on regular Channels */
#define ADC_CFGR_JAWD1EN   ((uint32_t)0x01000000) /*!< ADC Analog watchdog 1 enable on injected Channels */
#define ADC_CFGR_JAUTO     ((uint32_t)0x02000000) /*!< ADC Automatic injected group conversion */

#define ADC_CFGR_AWD1CH    ((uint32_t)0x7C000000) /*!< ADC Analog watchdog 1 Channel selection */
#define ADC_CFGR_AWD1CH_0  ((uint32_t)0x04000000) /*!< ADC AWD1CH bit 0 */
#define ADC_CFGR_AWD1CH_1  ((uint32_t)0x08000000) /*!< ADC AWD1CH bit 1  */
#define ADC_CFGR_AWD1CH_2  ((uint32_t)0x10000000) /*!< ADC AWD1CH bit 2  */
#define ADC_CFGR_AWD1CH_3  ((uint32_t)0x20000000) /*!< ADC AWD1CH bit 3  */
#define ADC_CFGR_AWD1CH_4  ((uint32_t)0x40000000) /*!< ADC AWD1CH bit 4  */

#define ADC_CFGR_JQDIS     ((uint32_t)0x80000000) /*!< ADC Injected queue disable */

/********************  Bit definition for ADC_CFGR2 register  ********************/
#define ADC_CFGR2_ROVSE    ((uint32_t)0x00000001) /*!< ADC Regular group oversampler enable */
#define ADC_CFGR2_JOVSE    ((uint32_t)0x00000002) /*!< ADC Injected group oversampler enable */

#define ADC_CFGR2_OVSR     ((uint32_t)0x0000001C) /*!< ADC Regular group oversampler enable TO Be removed after ADC driver update*/
#define ADC_CFGR2_OVSR_0   ((uint32_t)0x00000004) /*!< ADC OVSR bit 0 */
#define ADC_CFGR2_OVSR_1   ((uint32_t)0x00000008) /*!< ADC OVSR bit 1 */
#define ADC_CFGR2_OVSR_2   ((uint32_t)0x00000010) /*!< ADC OVSR bit 2 */

#define ADC_CFGR2_OVSS     ((uint32_t)0x000001E0) /*!< ADC Regular Oversampling shift */
#define ADC_CFGR2_OVSS_0   ((uint32_t)0x00000020) /*!< ADC OVSS bit 0 */
#define ADC_CFGR2_OVSS_1   ((uint32_t)0x00000040) /*!< ADC OVSS bit 1 */
#define ADC_CFGR2_OVSS_2   ((uint32_t)0x00000080) /*!< ADC OVSS bit 2 */
#define ADC_CFGR2_OVSS_3   ((uint32_t)0x00000100) /*!< ADC OVSS bit 3 */

#define ADC_CFGR2_TROVS   ((uint32_t)0x00000200) /*!< ADC Triggered regular Oversampling */
#define ADC_CFGR2_ROVSM   ((uint32_t)0x00000400) /*!< ADC Regular oversampling mode */

#define ADC_CFGR2_RSHIFT1 ((uint32_t)0x00000800) /*!< ADC Right-shift data after Offset 1 correction */
#define ADC_CFGR2_RSHIFT2 ((uint32_t)0x00001000) /*!< ADC Right-shift data after Offset 2 correction */
#define ADC_CFGR2_RSHIFT3 ((uint32_t)0x00002000) /*!< ADC Right-shift data after Offset 3 correction */
#define ADC_CFGR2_RSHIFT4 ((uint32_t)0x00004000) /*!< ADC Right-shift data after Offset 4 correction */

#define ADC_CFGR2_OSR     ((uint32_t)0x03FF0000) /*!< ADC oversampling Ratio */ 
#define ADC_CFGR2_OSR_0   ((uint32_t)0x00010000) /*!< ADC oversampling Ratio bit 0 */ 
#define ADC_CFGR2_OSR_1   ((uint32_t)0x00020000) /*!< ADC oversampling Ratio bit 1 */ 
#define ADC_CFGR2_OSR_2   ((uint32_t)0x00040000) /*!< ADC oversampling Ratio bit 2 */ 
#define ADC_CFGR2_OSR_3   ((uint32_t)0x00080000) /*!< ADC oversampling Ratio bit 3 */ 
#define ADC_CFGR2_OSR_4   ((uint32_t)0x00100000) /*!< ADC oversampling Ratio bit 4 */ 
#define ADC_CFGR2_OSR_5   ((uint32_t)0x00200000) /*!< ADC oversampling Ratio bit 5 */ 
#define ADC_CFGR2_OSR_6   ((uint32_t)0x00400000) /*!< ADC oversampling Ratio bit 6 */ 
#define ADC_CFGR2_OSR_7   ((uint32_t)0x00800000) /*!< ADC oversampling Ratio bit 7 */ 
#define ADC_CFGR2_OSR_8   ((uint32_t)0x01000000) /*!< ADC oversampling Ratio bit 8 */ 
#define ADC_CFGR2_OSR_9   ((uint32_t)0x02000000) /*!< ADC oversampling Ratio bit 9 */ 

#define ADC_CFGR2_LSHIFT     ((uint32_t)0xF0000000) /*!< ADC Left shift factor */ 
#define ADC_CFGR2_LSHIFT_0   ((uint32_t)0x10000000) /*!< ADC Left shift factor bit 0 */ 
#define ADC_CFGR2_LSHIFT_1   ((uint32_t)0x20000000) /*!< ADC Left shift factor bit 1 */ 
#define ADC_CFGR2_LSHIFT_2   ((uint32_t)0x40000000) /*!< ADC Left shift factor bit 2 */ 
#define ADC_CFGR2_LSHIFT_3   ((uint32_t)0x80000000) /*!< ADC Left shift factor bit 3 */ 

/********************  Bit definition for ADC_SMPR1 register  ********************/
#define ADC_SMPR1_SMP0     ((uint32_t)0x00000007) /*!< ADC Channel 0 Sampling time selection  */
#define ADC_SMPR1_SMP0_0   ((uint32_t)0x00000001) /*!< ADC SMP0 bit 0 */
#define ADC_SMPR1_SMP0_1   ((uint32_t)0x00000002) /*!< ADC SMP0 bit 1 */
#define ADC_SMPR1_SMP0_2   ((uint32_t)0x00000004) /*!< ADC SMP0 bit 2 */

#define ADC_SMPR1_SMP1     ((uint32_t)0x00000038) /*!< ADC Channel 1 Sampling time selection  */
#define ADC_SMPR1_SMP1_0   ((uint32_t)0x00000008) /*!< ADC SMP1 bit 0 */
#define ADC_SMPR1_SMP1_1   ((uint32_t)0x00000010) /*!< ADC SMP1 bit 1 */
#define ADC_SMPR1_SMP1_2   ((uint32_t)0x00000020) /*!< ADC SMP1 bit 2 */

#define ADC_SMPR1_SMP2     ((uint32_t)0x000001C0) /*!< ADC Channel 2 Sampling time selection  */
#define ADC_SMPR1_SMP2_0   ((uint32_t)0x00000040) /*!< ADC SMP2 bit 0 */
#define ADC_SMPR1_SMP2_1   ((uint32_t)0x00000080) /*!< ADC SMP2 bit 1 */
#define ADC_SMPR1_SMP2_2   ((uint32_t)0x00000100) /*!< ADC SMP2 bit 2 */

#define ADC_SMPR1_SMP3     ((uint32_t)0x00000E00) /*!< ADC Channel 3 Sampling time selection  */
#define ADC_SMPR1_SMP3_0   ((uint32_t)0x00000200) /*!< ADC SMP3 bit 0 */
#define ADC_SMPR1_SMP3_1   ((uint32_t)0x00000400) /*!< ADC SMP3 bit 1 */
#define ADC_SMPR1_SMP3_2   ((uint32_t)0x00000800) /*!< ADC SMP3 bit 2 */

#define ADC_SMPR1_SMP4     ((uint32_t)0x00007000) /*!< ADC Channel 4 Sampling time selection  */
#define ADC_SMPR1_SMP4_0   ((uint32_t)0x00001000) /*!< ADC SMP4 bit 0 */
#define ADC_SMPR1_SMP4_1   ((uint32_t)0x00002000) /*!< ADC SMP4 bit 1 */
#define ADC_SMPR1_SMP4_2   ((uint32_t)0x00004000) /*!< ADC SMP4 bit 2 */

#define ADC_SMPR1_SMP5     ((uint32_t)0x00038000) /*!< ADC Channel 5 Sampling time selection  */
#define ADC_SMPR1_SMP5_0   ((uint32_t)0x00008000) /*!< ADC SMP5 bit 0 */
#define ADC_SMPR1_SMP5_1   ((uint32_t)0x00010000) /*!< ADC SMP5 bit 1 */
#define ADC_SMPR1_SMP5_2   ((uint32_t)0x00020000) /*!< ADC SMP5 bit 2 */

#define ADC_SMPR1_SMP6     ((uint32_t)0x001C0000) /*!< ADC Channel 6 Sampling time selection  */
#define ADC_SMPR1_SMP6_0   ((uint32_t)0x00040000) /*!< ADC SMP6 bit 0 */
#define ADC_SMPR1_SMP6_1   ((uint32_t)0x00080000) /*!< ADC SMP6 bit 1 */
#define ADC_SMPR1_SMP6_2   ((uint32_t)0x00100000) /*!< ADC SMP6 bit 2 */

#define ADC_SMPR1_SMP7     ((uint32_t)0x00E00000) /*!< ADC Channel 7 Sampling time selection  */
#define ADC_SMPR1_SMP7_0   ((uint32_t)0x00200000) /*!< ADC SMP7 bit 0 */
#define ADC_SMPR1_SMP7_1   ((uint32_t)0x00400000) /*!< ADC SMP7 bit 1 */
#define ADC_SMPR1_SMP7_2   ((uint32_t)0x00800000) /*!< ADC SMP7 bit 2 */

#define ADC_SMPR1_SMP8     ((uint32_t)0x07000000) /*!< ADC Channel 8 Sampling time selection  */
#define ADC_SMPR1_SMP8_0   ((uint32_t)0x01000000) /*!< ADC SMP8 bit 0 */
#define ADC_SMPR1_SMP8_1   ((uint32_t)0x02000000) /*!< ADC SMP8 bit 1 */
#define ADC_SMPR1_SMP8_2   ((uint32_t)0x04000000) /*!< ADC SMP8 bit 2 */

#define ADC_SMPR1_SMP9     ((uint32_t)0x38000000) /*!< ADC Channel 9 Sampling time selection  */
#define ADC_SMPR1_SMP9_0   ((uint32_t)0x08000000) /*!< ADC SMP9 bit 0 */
#define ADC_SMPR1_SMP9_1   ((uint32_t)0x10000000) /*!< ADC SMP9 bit 1 */
#define ADC_SMPR1_SMP9_2   ((uint32_t)0x20000000) /*!< ADC SMP9 bit 2 */

/********************  Bit definition for ADC_SMPR2 register  ********************/
#define ADC_SMPR2_SMP10     ((uint32_t)0x00000007) /*!< ADC Channel 10 Sampling time selection  */
#define ADC_SMPR2_SMP10_0   ((uint32_t)0x00000001) /*!< ADC SMP10 bit 0 */
#define ADC_SMPR2_SMP10_1   ((uint32_t)0x00000002) /*!< ADC SMP10 bit 1 */
#define ADC_SMPR2_SMP10_2   ((uint32_t)0x00000004) /*!< ADC SMP10 bit 2 */

#define ADC_SMPR2_SMP11     ((uint32_t)0x00000038) /*!< ADC Channel 11 Sampling time selection  */
#define ADC_SMPR2_SMP11_0   ((uint32_t)0x00000008) /*!< ADC SMP11 bit 0 */
#define ADC_SMPR2_SMP11_1   ((uint32_t)0x00000010) /*!< ADC SMP11 bit 1 */
#define ADC_SMPR2_SMP11_2   ((uint32_t)0x00000020) /*!< ADC SMP11 bit 2 */

#define ADC_SMPR2_SMP12     ((uint32_t)0x000001C0) /*!< ADC Channel 12 Sampling time selection  */
#define ADC_SMPR2_SMP12_0   ((uint32_t)0x00000040) /*!< ADC SMP12 bit 0 */
#define ADC_SMPR2_SMP12_1   ((uint32_t)0x00000080) /*!< ADC SMP12 bit 1 */
#define ADC_SMPR2_SMP12_2   ((uint32_t)0x00000100) /*!< ADC SMP12 bit 2 */

#define ADC_SMPR2_SMP13     ((uint32_t)0x00000E00) /*!< ADC Channel 13 Sampling time selection  */
#define ADC_SMPR2_SMP13_0   ((uint32_t)0x00000200) /*!< ADC SMP13 bit 0 */
#define ADC_SMPR2_SMP13_1   ((uint32_t)0x00000400) /*!< ADC SMP13 bit 1 */
#define ADC_SMPR2_SMP13_2   ((uint32_t)0x00000800) /*!< ADC SMP13 bit 2 */

#define ADC_SMPR2_SMP14     ((uint32_t)0x00007000) /*!< ADC Channel 14 Sampling time selection  */
#define ADC_SMPR2_SMP14_0   ((uint32_t)0x00001000) /*!< ADC SMP14 bit 0 */
#define ADC_SMPR2_SMP14_1   ((uint32_t)0x00002000) /*!< ADC SMP14 bit 1 */
#define ADC_SMPR2_SMP14_2   ((uint32_t)0x00004000) /*!< ADC SMP14 bit 2 */

#define ADC_SMPR2_SMP15     ((uint32_t)0x00038000) /*!< ADC Channel 15 Sampling time selection  */
#define ADC_SMPR2_SMP15_0   ((uint32_t)0x00008000) /*!< ADC SMP15 bit 0 */
#define ADC_SMPR2_SMP15_1   ((uint32_t)0x00010000) /*!< ADC SMP15 bit 1 */
#define ADC_SMPR2_SMP15_2   ((uint32_t)0x00020000) /*!< ADC SMP15 bit 2 */

#define ADC_SMPR2_SMP16     ((uint32_t)0x001C0000) /*!< ADC Channel 16 Sampling time selection  */
#define ADC_SMPR2_SMP16_0   ((uint32_t)0x00040000) /*!< ADC SMP16 bit 0 */
#define ADC_SMPR2_SMP16_1   ((uint32_t)0x00080000) /*!< ADC SMP16 bit 1 */
#define ADC_SMPR2_SMP16_2   ((uint32_t)0x00100000) /*!< ADC SMP16 bit 2 */

#define ADC_SMPR2_SMP17     ((uint32_t)0x00E00000) /*!< ADC Channel 17 Sampling time selection  */
#define ADC_SMPR2_SMP17_0   ((uint32_t)0x00200000) /*!< ADC SMP17 bit 0 */
#define ADC_SMPR2_SMP17_1   ((uint32_t)0x00400000) /*!< ADC SMP17 bit 1 */
#define ADC_SMPR2_SMP17_2   ((uint32_t)0x00800000) /*!< ADC SMP17 bit 2 */

#define ADC_SMPR2_SMP18     ((uint32_t)0x07000000) /*!< ADC Channel 18 Sampling time selection  */
#define ADC_SMPR2_SMP18_0   ((uint32_t)0x01000000) /*!< ADC SMP18 bit 0 */
#define ADC_SMPR2_SMP18_1   ((uint32_t)0x02000000) /*!< ADC SMP18 bit 1 */
#define ADC_SMPR2_SMP18_2   ((uint32_t)0x04000000) /*!< ADC SMP18 bit 2 */

#define ADC_SMPR2_SMP19     ((uint32_t)0x38000000) /*!< ADC Channel 19 Sampling time selection  */
#define ADC_SMPR2_SMP19_0   ((uint32_t)0x08000000) /*!< ADC SMP19 bit 0 */
#define ADC_SMPR2_SMP19_1   ((uint32_t)0x10000000) /*!< ADC SMP19 bit 1 */
#define ADC_SMPR2_SMP19_2   ((uint32_t)0x20000000) /*!< ADC SMP19 bit 2 */

/********************  Bit definition for ADC_PCSEL register  ********************/
#define ADC_PCSEL_PCSEL         ((uint32_t)0x000FFFFF) /*!< ADC pre channel selection */
#define ADC_PCSEL_PCSEL_0       ((uint32_t)0x00000001) /*!< ADC LT1 bit 0 */
#define ADC_PCSEL_PCSEL_1       ((uint32_t)0x00000002) /*!< ADC LT1 bit 1 */
#define ADC_PCSEL_PCSEL_2       ((uint32_t)0x00000004) /*!< ADC LT1 bit 2 */
#define ADC_PCSEL_PCSEL_3       ((uint32_t)0x00000008) /*!< ADC LT1 bit 3 */
#define ADC_PCSEL_PCSEL_4       ((uint32_t)0x00000010) /*!< ADC LT1 bit 4 */
#define ADC_PCSEL_PCSEL_5       ((uint32_t)0x00000020) /*!< ADC LT1 bit 5 */
#define ADC_PCSEL_PCSEL_6       ((uint32_t)0x00000040) /*!< ADC LT1 bit 6 */
#define ADC_PCSEL_PCSEL_7       ((uint32_t)0x00000080) /*!< ADC LT1 bit 7 */
#define ADC_PCSEL_PCSEL_8       ((uint32_t)0x00000100) /*!< ADC LT1 bit 8 */
#define ADC_PCSEL_PCSEL_9       ((uint32_t)0x00000200) /*!< ADC LT1 bit 9 */
#define ADC_PCSEL_PCSEL_10      ((uint32_t)0x00000400) /*!< ADC LT1 bit 10 */
#define ADC_PCSEL_PCSEL_11      ((uint32_t)0x00000800) /*!< ADC LT1 bit 11 */
#define ADC_PCSEL_PCSEL_12      ((uint32_t)0x00001000) /*!< ADC LT1 bit 12 */
#define ADC_PCSEL_PCSEL_13      ((uint32_t)0x00002000) /*!< ADC LT1 bit 13 */
#define ADC_PCSEL_PCSEL_14      ((uint32_t)0x00004000) /*!< ADC LT1 bit 14 */
#define ADC_PCSEL_PCSEL_15      ((uint32_t)0x00008000) /*!< ADC LT1 bit 15 */
#define ADC_PCSEL_PCSEL_16      ((uint32_t)0x00010000) /*!< ADC LT1 bit 16 */
#define ADC_PCSEL_PCSEL_17      ((uint32_t)0x00020000) /*!< ADC LT1 bit 17 */
#define ADC_PCSEL_PCSEL_18      ((uint32_t)0x00040000) /*!< ADC LT1 bit 18 */
#define ADC_PCSEL_PCSEL_19      ((uint32_t)0x00080000) /*!< ADC LT1 bit 19 */

/********************  Bit definition for ADC_LTR1 register  ********************/
#define ADC_LTR1_LT1         ((uint32_t)0x03FFFFFF) /*!< ADC Analog watchdog 1 lower threshold */
#define ADC_LTR1_LT1_0       ((uint32_t)0x00000001) /*!< ADC LT1 bit 0 */
#define ADC_LTR1_LT1_1       ((uint32_t)0x00000002) /*!< ADC LT1 bit 1 */
#define ADC_LTR1_LT1_2       ((uint32_t)0x00000004) /*!< ADC LT1 bit 2 */
#define ADC_LTR1_LT1_3       ((uint32_t)0x00000008) /*!< ADC LT1 bit 3 */
#define ADC_LTR1_LT1_4       ((uint32_t)0x00000010) /*!< ADC LT1 bit 4 */
#define ADC_LTR1_LT1_5       ((uint32_t)0x00000020) /*!< ADC LT1 bit 5 */
#define ADC_LTR1_LT1_6       ((uint32_t)0x00000040) /*!< ADC LT1 bit 6 */
#define ADC_LTR1_LT1_7       ((uint32_t)0x00000080) /*!< ADC LT1 bit 7 */
#define ADC_LTR1_LT1_8       ((uint32_t)0x00000100) /*!< ADC LT1 bit 8 */
#define ADC_LTR1_LT1_9       ((uint32_t)0x00000200) /*!< ADC LT1 bit 9 */
#define ADC_LTR1_LT1_10      ((uint32_t)0x00000400) /*!< ADC LT1 bit 10 */
#define ADC_LTR1_LT1_11      ((uint32_t)0x00000800) /*!< ADC LT1 bit 11 */
#define ADC_LTR1_LT1_12      ((uint32_t)0x00001000) /*!< ADC LT1 bit 12 */
#define ADC_LTR1_LT1_13      ((uint32_t)0x00002000) /*!< ADC LT1 bit 13 */
#define ADC_LTR1_LT1_14      ((uint32_t)0x00004000) /*!< ADC LT1 bit 14 */
#define ADC_LTR1_LT1_15      ((uint32_t)0x00008000) /*!< ADC LT1 bit 15 */
#define ADC_LTR1_LT1_16      ((uint32_t)0x00010000) /*!< ADC LT1 bit 16 */
#define ADC_LTR1_LT1_17      ((uint32_t)0x00020000) /*!< ADC LT1 bit 17 */
#define ADC_LTR1_LT1_18      ((uint32_t)0x00040000) /*!< ADC LT1 bit 18 */
#define ADC_LTR1_LT1_19      ((uint32_t)0x00080000) /*!< ADC LT1 bit 19 */
#define ADC_LTR1_LT1_20      ((uint32_t)0x00100000) /*!< ADC LT1 bit 20 */
#define ADC_LTR1_LT1_21      ((uint32_t)0x00200000) /*!< ADC LT1 bit 21 */
#define ADC_LTR1_LT1_22      ((uint32_t)0x00400000) /*!< ADC LT1 bit 22 */
#define ADC_LTR1_LT1_23      ((uint32_t)0x00800000) /*!< ADC LT1 bit 23 */
#define ADC_LTR1_LT1_24      ((uint32_t)0x01000000) /*!< ADC LT1 bit 24 */
#define ADC_LTR1_LT1_25      ((uint32_t)0x02000000) /*!< ADC LT1 bit 25 */

/********************  Bit definition for ADC_HTR1 register  ********************/
#define ADC_HTR1_HT1         ((uint32_t) 0x03FFFFFF) /*!< ADC Analog watchdog 1 higher threshold */
#define ADC_HTR1_HT1_0       ((uint32_t)0x00000001) /*!< ADC HT1 bit 0 */
#define ADC_HTR1_HT1_1       ((uint32_t)0x00000002) /*!< ADC HT1 bit 1 */
#define ADC_HTR1_HT1_2       ((uint32_t)0x00000004) /*!< ADC HT1 bit 2 */
#define ADC_HTR1_HT1_3       ((uint32_t)0x00000008) /*!< ADC HT1 bit 3 */
#define ADC_HTR1_HT1_4       ((uint32_t)0x00000010) /*!< ADC HT1 bit 4 */
#define ADC_HTR1_HT1_5       ((uint32_t)0x00000020) /*!< ADC HT1 bit 5 */
#define ADC_HTR1_HT1_6       ((uint32_t)0x00000040) /*!< ADC HT1 bit 6 */
#define ADC_HTR1_HT1_7       ((uint32_t)0x00000080) /*!< ADC HT1 bit 7 */
#define ADC_HTR1_HT1_8       ((uint32_t)0x00000100) /*!< ADC HT1 bit 8 */
#define ADC_HTR1_HT1_9       ((uint32_t)0x00000200) /*!< ADC HT1 bit 9 */
#define ADC_HTR1_HT1_10      ((uint32_t)0x00000400) /*!< ADC HT1 bit 10 */
#define ADC_HTR1_HT1_11      ((uint32_t)0x00000800) /*!< ADC HT1 bit 11 */
#define ADC_HTR1_HT1_12      ((uint32_t)0x00001000) /*!< ADC HT1 bit 12 */
#define ADC_HTR1_HT1_13      ((uint32_t)0x00002000) /*!< ADC HT1 bit 13 */
#define ADC_HTR1_HT1_14      ((uint32_t)0x00004000) /*!< ADC HT1 bit 14 */
#define ADC_HTR1_HT1_15      ((uint32_t)0x00008000) /*!< ADC HT1 bit 15 */
#define ADC_HTR1_HT1_16      ((uint32_t)0x00010000) /*!< ADC HT1 bit 16 */
#define ADC_HTR1_HT1_17      ((uint32_t)0x00020000) /*!< ADC HT1 bit 17 */
#define ADC_HTR1_HT1_18      ((uint32_t)0x00040000) /*!< ADC HT1 bit 18 */
#define ADC_HTR1_HT1_19      ((uint32_t)0x00080000) /*!< ADC HT1 bit 19 */
#define ADC_HTR1_HT1_20      ((uint32_t)0x00100000) /*!< ADC HT1 bit 20 */
#define ADC_HTR1_HT1_21      ((uint32_t)0x00200000) /*!< ADC HT1 bit 21 */
#define ADC_HTR1_HT1_22      ((uint32_t)0x00400000) /*!< ADC HT1 bit 22 */
#define ADC_HTR1_HT1_23      ((uint32_t)0x00800000) /*!< ADC HT1 bit 23 */
#define ADC_HTR1_HT1_24      ((uint32_t)0x01000000) /*!< ADC HT1 bit 24 */
#define ADC_HTR1_HT1_25      ((uint32_t)0x02000000) /*!< ADC HT1 bit 25 */

/********************  Bit definition for ADC_LTR2 register  ********************/
#define ADC_LTR2_LT2         ((uint32_t) 0x03FFFFFF) /*!< ADC Analog watchdog 2 lower threshold */
#define ADC_LTR2_LT2_0       ((uint32_t)0x00000001) /*!< ADC LT2 bit 0 */
#define ADC_LTR2_LT2_1       ((uint32_t)0x00000002) /*!< ADC LT2 bit 1 */
#define ADC_LTR2_LT2_2       ((uint32_t)0x00000004) /*!< ADC LT2 bit 2 */
#define ADC_LTR2_LT2_3       ((uint32_t)0x00000008) /*!< ADC LT2 bit 3 */
#define ADC_LTR2_LT2_4       ((uint32_t)0x00000010) /*!< ADC LT2 bit 4 */
#define ADC_LTR2_LT2_5       ((uint32_t)0x00000020) /*!< ADC LT2 bit 5 */
#define ADC_LTR2_LT2_6       ((uint32_t)0x00000040) /*!< ADC LT2 bit 6 */
#define ADC_LTR2_LT2_7       ((uint32_t)0x00000080) /*!< ADC LT2 bit 7 */
#define ADC_LTR2_LT2_8       ((uint32_t)0x00000100) /*!< ADC LT2 bit 8 */
#define ADC_LTR2_LT2_9       ((uint32_t)0x00000200) /*!< ADC LT2 bit 9 */
#define ADC_LTR2_LT2_10      ((uint32_t)0x00000400) /*!< ADC LT2 bit 10 */
#define ADC_LTR2_LT2_11      ((uint32_t)0x00000800) /*!< ADC LT2 bit 11 */
#define ADC_LTR2_LT2_12      ((uint32_t)0x00001000) /*!< ADC LT2 bit 12 */
#define ADC_LTR2_LT2_13      ((uint32_t)0x00002000) /*!< ADC LT2 bit 13 */
#define ADC_LTR2_LT2_14      ((uint32_t)0x00004000) /*!< ADC LT2 bit 14 */
#define ADC_LTR2_LT2_15      ((uint32_t)0x00008000) /*!< ADC LT2 bit 15 */
#define ADC_LTR2_LT2_16      ((uint32_t)0x00010000) /*!< ADC LT2 bit 16 */
#define ADC_LTR2_LT2_17      ((uint32_t)0x00020000) /*!< ADC LT2 bit 17 */
#define ADC_LTR2_LT2_18      ((uint32_t)0x00040000) /*!< ADC LT2 bit 18 */
#define ADC_LTR2_LT2_19      ((uint32_t)0x00080000) /*!< ADC LT2 bit 19 */
#define ADC_LTR2_LT2_20      ((uint32_t)0x00100000) /*!< ADC LT2 bit 20 */
#define ADC_LTR2_LT2_21      ((uint32_t)0x00200000) /*!< ADC LT2 bit 21 */
#define ADC_LTR2_LT2_22      ((uint32_t)0x00400000) /*!< ADC LT2 bit 22 */
#define ADC_LTR2_LT2_23      ((uint32_t)0x00800000) /*!< ADC LT2 bit 23 */
#define ADC_LTR2_LT2_24      ((uint32_t)0x01000000) /*!< ADC LT2 bit 24 */
#define ADC_LTR2_LT2_25      ((uint32_t)0x02000000) /*!< ADC LT2 bit 25 */

/********************  Bit definition for ADC_HTR2 register  ********************/
#define ADC_HTR2_HT2         ((uint32_t) 0x03FFFFFF) /*!< ADC Analog watchdog 2 higher threshold */
#define ADC_HTR2_HT2_0       ((uint32_t)0x00000001) /*!< ADC HT2 bit 0 */
#define ADC_HTR2_HT2_1       ((uint32_t)0x00000002) /*!< ADC HT2 bit 1 */
#define ADC_HTR2_HT2_2       ((uint32_t)0x00000004) /*!< ADC HT2 bit 2 */
#define ADC_HTR2_HT2_3       ((uint32_t)0x00000008) /*!< ADC HT2 bit 3 */
#define ADC_HTR2_HT2_4       ((uint32_t)0x00000010) /*!< ADC HT2 bit 4 */
#define ADC_HTR2_HT2_5       ((uint32_t)0x00000020) /*!< ADC HT2 bit 5 */
#define ADC_HTR2_HT2_6       ((uint32_t)0x00000040) /*!< ADC HT2 bit 6 */
#define ADC_HTR2_HT2_7       ((uint32_t)0x00000080) /*!< ADC HT2 bit 7 */
#define ADC_HTR2_HT2_8       ((uint32_t)0x00000100) /*!< ADC HT2 bit 8 */
#define ADC_HTR2_HT2_9       ((uint32_t)0x00000200) /*!< ADC HT2 bit 9 */
#define ADC_HTR2_HT2_10      ((uint32_t)0x00000400) /*!< ADC HT2 bit 10 */
#define ADC_HTR2_HT2_11      ((uint32_t)0x00000800) /*!< ADC HT2 bit 11 */
#define ADC_HTR2_HT2_12      ((uint32_t)0x00001000) /*!< ADC HT2 bit 12 */
#define ADC_HTR2_HT2_13      ((uint32_t)0x00002000) /*!< ADC HT2 bit 13 */
#define ADC_HTR2_HT2_14      ((uint32_t)0x00004000) /*!< ADC HT2 bit 14 */
#define ADC_HTR2_HT2_15      ((uint32_t)0x00008000) /*!< ADC HT2 bit 15 */
#define ADC_HTR2_HT2_16      ((uint32_t)0x00010000) /*!< ADC HT2 bit 16 */
#define ADC_HTR2_HT2_17      ((uint32_t)0x00020000) /*!< ADC HT2 bit 17 */
#define ADC_HTR2_HT2_18      ((uint32_t)0x00040000) /*!< ADC HT2 bit 18 */
#define ADC_HTR2_HT2_19      ((uint32_t)0x00080000) /*!< ADC HT2 bit 19 */
#define ADC_HTR2_HT2_20      ((uint32_t)0x00100000) /*!< ADC HT2 bit 20 */
#define ADC_HTR2_HT2_21      ((uint32_t)0x00200000) /*!< ADC HT2 bit 21 */
#define ADC_HTR2_HT2_22      ((uint32_t)0x00400000) /*!< ADC HT2 bit 22 */
#define ADC_HTR2_HT2_23      ((uint32_t)0x00800000) /*!< ADC HT2 bit 23 */
#define ADC_HTR2_HT2_24      ((uint32_t)0x01000000) /*!< ADC HT2 bit 24 */
#define ADC_HTR2_HT2_25      ((uint32_t)0x020000000) /*!< ADC HT2 bit 25 */

/********************  Bit definition for ADC_LTR3 register  ********************/
#define ADC_LTR3_LT3         ((uint32_t) 0x03FFFFFF) /*!< ADC Analog watchdog 3 lower threshold */
#define ADC_LTR3_LT3_0       ((uint32_t)0x00000001) /*!< ADC LT3 bit 0 */
#define ADC_LTR3_LT3_1       ((uint32_t)0x00000002) /*!< ADC LT3 bit 1 */
#define ADC_LTR3_LT3_2       ((uint32_t)0x00000004) /*!< ADC LT3 bit 2 */
#define ADC_LTR3_LT3_3       ((uint32_t)0x00000008) /*!< ADC LT3 bit 3 */
#define ADC_LTR3_LT3_4       ((uint32_t)0x00000010) /*!< ADC LT3 bit 4 */
#define ADC_LTR3_LT3_5       ((uint32_t)0x00000020) /*!< ADC LT3 bit 5 */
#define ADC_LTR3_LT3_6       ((uint32_t)0x00000040) /*!< ADC LT3 bit 6 */
#define ADC_LTR3_LT3_7       ((uint32_t)0x00000080) /*!< ADC LT3 bit 7 */
#define ADC_LTR3_LT3_8       ((uint32_t)0x00000100) /*!< ADC LT3 bit 8 */
#define ADC_LTR3_LT3_9       ((uint32_t)0x00000200) /*!< ADC LT3 bit 9 */
#define ADC_LTR3_LT3_10      ((uint32_t)0x00000400) /*!< ADC LT3 bit 10 */
#define ADC_LTR3_LT3_11      ((uint32_t)0x00000800) /*!< ADC LT3 bit 11 */
#define ADC_LTR3_LT3_12      ((uint32_t)0x00001000) /*!< ADC LT3 bit 12 */
#define ADC_LTR3_LT3_13      ((uint32_t)0x00002000) /*!< ADC LT3 bit 13 */
#define ADC_LTR3_LT3_14      ((uint32_t)0x00004000) /*!< ADC LT3 bit 14 */
#define ADC_LTR3_LT3_15      ((uint32_t)0x00008000) /*!< ADC LT3 bit 15 */
#define ADC_LTR3_LT3_16      ((uint32_t)0x00010000) /*!< ADC LT3 bit 16 */
#define ADC_LTR3_LT3_17      ((uint32_t)0x00020000) /*!< ADC LT3 bit 17 */
#define ADC_LTR3_LT3_18      ((uint32_t)0x00040000) /*!< ADC LT3 bit 18 */
#define ADC_LTR3_LT3_19      ((uint32_t)0x00080000) /*!< ADC LT3 bit 19 */
#define ADC_LTR3_LT3_20      ((uint32_t)0x00100000) /*!< ADC LT3 bit 20 */
#define ADC_LTR3_LT3_21      ((uint32_t)0x00200000) /*!< ADC LT3 bit 21 */
#define ADC_LTR3_LT3_22      ((uint32_t)0x00400000) /*!< ADC LT3 bit 22 */
#define ADC_LTR3_LT3_23      ((uint32_t)0x00800000) /*!< ADC LT3 bit 23 */
#define ADC_LTR3_LT3_24      ((uint32_t)0x01000000) /*!< ADC LT3 bit 24*/
#define ADC_LTR3_LT3_25      ((uint32_t)0x02000000) /*!< ADC LT3 bit 25 */

/********************  Bit definition for ADC_HTR3 register  ********************/
#define ADC_HTR3_HT3         ((uint32_t) 0x03FFFFFF) /*!< ADC Analog watchdog 3 higher threshold */
#define ADC_HTR3_HT3_0       ((uint32_t)0x00000001) /*!< ADC HT3 bit 0 */
#define ADC_HTR3_HT3_1       ((uint32_t)0x00000002) /*!< ADC HT3 bit 1 */
#define ADC_HTR3_HT3_2       ((uint32_t)0x00000004) /*!< ADC HT3 bit 2 */
#define ADC_HTR3_HT3_3       ((uint32_t)0x00000008) /*!< ADC HT3 bit 3 */
#define ADC_HTR3_HT3_4       ((uint32_t)0x00000010) /*!< ADC HT3 bit 4 */
#define ADC_HTR3_HT3_5       ((uint32_t)0x00000020) /*!< ADC HT3 bit 5 */
#define ADC_HTR3_HT3_6       ((uint32_t)0x00000040) /*!< ADC HT3 bit 6 */
#define ADC_HTR3_HT3_7       ((uint32_t)0x00000080) /*!< ADC HT3 bit 7 */
#define ADC_HTR3_HT3_8       ((uint32_t)0x00000100) /*!< ADC HT3 bit 8 */
#define ADC_HTR3_HT3_9       ((uint32_t)0x00000200) /*!< ADC HT3 bit 9 */
#define ADC_HTR3_HT3_10      ((uint32_t)0x00000400) /*!< ADC HT3 bit 10 */
#define ADC_HTR3_HT3_11      ((uint32_t)0x00000800) /*!< ADC HT3 bit 11 */
#define ADC_HTR3_HT3_12      ((uint32_t)0x00001000) /*!< ADC HT3 bit 12 */
#define ADC_HTR3_HT3_13      ((uint32_t)0x00002000) /*!< ADC HT3 bit 13 */
#define ADC_HTR3_HT3_14      ((uint32_t)0x00004000) /*!< ADC HT3 bit 14 */
#define ADC_HTR3_HT3_15      ((uint32_t)0x00008000) /*!< ADC HT3 bit 15 */
#define ADC_HTR3_HT3_16      ((uint32_t)0x00010000) /*!< ADC HT3 bit 16 */
#define ADC_HTR3_HT3_17      ((uint32_t)0x00020000) /*!< ADC HT3 bit 17 */
#define ADC_HTR3_HT3_18      ((uint32_t)0x00040000) /*!< ADC HT3 bit 18 */
#define ADC_HTR3_HT3_19      ((uint32_t)0x00080000) /*!< ADC HT3 bit 19 */
#define ADC_HTR3_HT3_20      ((uint32_t)0x00100000) /*!< ADC HT3 bit 20 */
#define ADC_HTR3_HT3_21      ((uint32_t)0x00200000) /*!< ADC HT3 bit 21 */
#define ADC_HTR3_HT3_22      ((uint32_t)0x00400000) /*!< ADC HT3 bit 22 */
#define ADC_HTR3_HT3_23      ((uint32_t)0x00800000) /*!< ADC HT3 bit 23 */
#define ADC_HTR3_HT3_24      ((uint32_t)0x01000000) /*!< ADC HT3 bit 24 */
#define ADC_HTR3_HT3_25      ((uint32_t)0x02000000) /*!< ADC HT3 bit 25 */

/********************  Bit definition for ADC_SQR1 register  ********************/
#define ADC_SQR1_L          ((uint32_t)0x0000000F) /*!< ADC regular channel sequence lenght */
#define ADC_SQR1_L_0        ((uint32_t)0x00000001) /*!< ADC L bit 0 */
#define ADC_SQR1_L_1        ((uint32_t)0x00000002) /*!< ADC L bit 1 */
#define ADC_SQR1_L_2        ((uint32_t)0x00000004) /*!< ADC L bit 2 */
#define ADC_SQR1_L_3        ((uint32_t)0x00000008) /*!< ADC L bit 3 */

#define ADC_SQR1_SQ1        ((uint32_t)0x000007C0) /*!< ADC 1st conversion in regular sequence */
#define ADC_SQR1_SQ1_0      ((uint32_t)0x00000040) /*!< ADC SQ1 bit 0 */
#define ADC_SQR1_SQ1_1      ((uint32_t)0x00000080) /*!< ADC SQ1 bit 1 */
#define ADC_SQR1_SQ1_2      ((uint32_t)0x00000100) /*!< ADC SQ1 bit 2 */
#define ADC_SQR1_SQ1_3      ((uint32_t)0x00000200) /*!< ADC SQ1 bit 3 */
#define ADC_SQR1_SQ1_4      ((uint32_t)0x00000400) /*!< ADC SQ1 bit 4 */

#define ADC_SQR1_SQ2        ((uint32_t)0x0001F000) /*!< ADC 2nd conversion in regular sequence */
#define ADC_SQR1_SQ2_0      ((uint32_t)0x00001000) /*!< ADC SQ2 bit 0 */
#define ADC_SQR1_SQ2_1      ((uint32_t)0x00002000) /*!< ADC SQ2 bit 1 */
#define ADC_SQR1_SQ2_2      ((uint32_t)0x00004000) /*!< ADC SQ2 bit 2 */
#define ADC_SQR1_SQ2_3      ((uint32_t)0x00008000) /*!< ADC SQ2 bit 3 */
#define ADC_SQR1_SQ2_4      ((uint32_t)0x00010000) /*!< ADC SQ2 bit 4 */

#define ADC_SQR1_SQ3        ((uint32_t)0x007C0000) /*!< ADC 3rd conversion in regular sequence */
#define ADC_SQR1_SQ3_0      ((uint32_t)0x00040000) /*!< ADC SQ3 bit 0 */
#define ADC_SQR1_SQ3_1      ((uint32_t)0x00080000) /*!< ADC SQ3 bit 1 */
#define ADC_SQR1_SQ3_2      ((uint32_t)0x00100000) /*!< ADC SQ3 bit 2 */
#define ADC_SQR1_SQ3_3      ((uint32_t)0x00200000) /*!< ADC SQ3 bit 3 */
#define ADC_SQR1_SQ3_4      ((uint32_t)0x00400000) /*!< ADC SQ3 bit 4 */

#define ADC_SQR1_SQ4        ((uint32_t)0x1F000000) /*!< ADC 4th conversion in regular sequence */
#define ADC_SQR1_SQ4_0      ((uint32_t)0x01000000) /*!< ADC SQ4 bit 0 */
#define ADC_SQR1_SQ4_1      ((uint32_t)0x02000000) /*!< ADC SQ4 bit 1 */
#define ADC_SQR1_SQ4_2      ((uint32_t)0x04000000) /*!< ADC SQ4 bit 2 */
#define ADC_SQR1_SQ4_3      ((uint32_t)0x08000000) /*!< ADC SQ4 bit 3 */
#define ADC_SQR1_SQ4_4      ((uint32_t)0x10000000) /*!< ADC SQ4 bit 4 */

/********************  Bit definition for ADC_SQR2 register  ********************/
#define ADC_SQR2_SQ5        ((uint32_t)0x0000001F) /*!< ADC 5th conversion in regular sequence */
#define ADC_SQR2_SQ5_0      ((uint32_t)0x00000001) /*!< ADC SQ5 bit 0 */
#define ADC_SQR2_SQ5_1      ((uint32_t)0x00000002) /*!< ADC SQ5 bit 1 */
#define ADC_SQR2_SQ5_2      ((uint32_t)0x00000004) /*!< ADC SQ5 bit 2 */
#define ADC_SQR2_SQ5_3      ((uint32_t)0x00000008) /*!< ADC SQ5 bit 3 */
#define ADC_SQR2_SQ5_4      ((uint32_t)0x00000010) /*!< ADC SQ5 bit 4 */

#define ADC_SQR2_SQ6        ((uint32_t)0x000007C0) /*!< ADC 6th conversion in regular sequence */
#define ADC_SQR2_SQ6_0      ((uint32_t)0x00000040) /*!< ADC SQ6 bit 0 */
#define ADC_SQR2_SQ6_1      ((uint32_t)0x00000080) /*!< ADC SQ6 bit 1 */
#define ADC_SQR2_SQ6_2      ((uint32_t)0x00000100) /*!< ADC SQ6 bit 2 */
#define ADC_SQR2_SQ6_3      ((uint32_t)0x00000200) /*!< ADC SQ6 bit 3 */
#define ADC_SQR2_SQ6_4      ((uint32_t)0x00000400) /*!< ADC SQ6 bit 4 */

#define ADC_SQR2_SQ7        ((uint32_t)0x0001F000) /*!< ADC 7th conversion in regular sequence */
#define ADC_SQR2_SQ7_0      ((uint32_t)0x00001000) /*!< ADC SQ7 bit 0 */
#define ADC_SQR2_SQ7_1      ((uint32_t)0x00002000) /*!< ADC SQ7 bit 1 */
#define ADC_SQR2_SQ7_2      ((uint32_t)0x00004000) /*!< ADC SQ7 bit 2 */
#define ADC_SQR2_SQ7_3      ((uint32_t)0x00008000) /*!< ADC SQ7 bit 3 */
#define ADC_SQR2_SQ7_4      ((uint32_t)0x00010000) /*!< ADC SQ7 bit 4 */

#define ADC_SQR2_SQ8        ((uint32_t)0x007C0000) /*!< ADC 8th conversion in regular sequence */
#define ADC_SQR2_SQ8_0      ((uint32_t)0x00040000) /*!< ADC SQ8 bit 0 */
#define ADC_SQR2_SQ8_1      ((uint32_t)0x00080000) /*!< ADC SQ8 bit 1 */
#define ADC_SQR2_SQ8_2      ((uint32_t)0x00100000) /*!< ADC SQ8 bit 2 */
#define ADC_SQR2_SQ8_3      ((uint32_t)0x00200000) /*!< ADC SQ8 bit 3 */
#define ADC_SQR2_SQ8_4      ((uint32_t)0x00400000) /*!< ADC SQ8 bit 4 */

#define ADC_SQR2_SQ9        ((uint32_t)0x1F000000) /*!< ADC 9th conversion in regular sequence */
#define ADC_SQR2_SQ9_0      ((uint32_t)0x01000000) /*!< ADC SQ9 bit 0 */
#define ADC_SQR2_SQ9_1      ((uint32_t)0x02000000) /*!< ADC SQ9 bit 1 */
#define ADC_SQR2_SQ9_2      ((uint32_t)0x04000000) /*!< ADC SQ9 bit 2 */
#define ADC_SQR2_SQ9_3      ((uint32_t)0x08000000) /*!< ADC SQ9 bit 3 */
#define ADC_SQR2_SQ9_4      ((uint32_t)0x10000000) /*!< ADC SQ9 bit 4 */

/********************  Bit definition for ADC_SQR3 register  ********************/
#define ADC_SQR3_SQ10       ((uint32_t)0x0000001F) /*!< ADC 10th conversion in regular sequence */
#define ADC_SQR3_SQ10_0     ((uint32_t)0x00000001) /*!< ADC SQ10 bit 0 */
#define ADC_SQR3_SQ10_1     ((uint32_t)0x00000002) /*!< ADC SQ10 bit 1 */
#define ADC_SQR3_SQ10_2     ((uint32_t)0x00000004) /*!< ADC SQ10 bit 2 */
#define ADC_SQR3_SQ10_3     ((uint32_t)0x00000008) /*!< ADC SQ10 bit 3 */
#define ADC_SQR3_SQ10_4     ((uint32_t)0x00000010) /*!< ADC SQ10 bit 4 */

#define ADC_SQR3_SQ11       ((uint32_t)0x000007C0) /*!< ADC 11th conversion in regular sequence */
#define ADC_SQR3_SQ11_0     ((uint32_t)0x00000040) /*!< ADC SQ11 bit 0 */
#define ADC_SQR3_SQ11_1     ((uint32_t)0x00000080) /*!< ADC SQ11 bit 1 */
#define ADC_SQR3_SQ11_2     ((uint32_t)0x00000100) /*!< ADC SQ11 bit 2 */
#define ADC_SQR3_SQ11_3     ((uint32_t)0x00000200) /*!< ADC SQ11 bit 3 */
#define ADC_SQR3_SQ11_4     ((uint32_t)0x00000400) /*!< ADC SQ11 bit 4 */

#define ADC_SQR3_SQ12       ((uint32_t)0x0001F000) /*!< ADC 12th conversion in regular sequence */
#define ADC_SQR3_SQ12_0     ((uint32_t)0x00001000) /*!< ADC SQ12 bit 0 */
#define ADC_SQR3_SQ12_1     ((uint32_t)0x00002000) /*!< ADC SQ12 bit 1 */
#define ADC_SQR3_SQ12_2     ((uint32_t)0x00004000) /*!< ADC SQ12 bit 2 */
#define ADC_SQR3_SQ12_3     ((uint32_t)0x00008000) /*!< ADC SQ12 bit 3 */
#define ADC_SQR3_SQ12_4     ((uint32_t)0x00010000) /*!< ADC SQ12 bit 4 */

#define ADC_SQR3_SQ13       ((uint32_t)0x007C0000) /*!< ADC 13th conversion in regular sequence */
#define ADC_SQR3_SQ13_0     ((uint32_t)0x00040000) /*!< ADC SQ13 bit 0 */
#define ADC_SQR3_SQ13_1     ((uint32_t)0x00080000) /*!< ADC SQ13 bit 1 */
#define ADC_SQR3_SQ13_2     ((uint32_t)0x00100000) /*!< ADC SQ13 bit 2 */
#define ADC_SQR3_SQ13_3     ((uint32_t)0x00200000) /*!< ADC SQ13 bit 3 */
#define ADC_SQR3_SQ13_4     ((uint32_t)0x00400000) /*!< ADC SQ13 bit 4 */

#define ADC_SQR3_SQ14       ((uint32_t)0x1F000000) /*!< ADC 14th conversion in regular sequence */
#define ADC_SQR3_SQ14_0     ((uint32_t)0x01000000) /*!< ADC SQ14 bit 0 */
#define ADC_SQR3_SQ14_1     ((uint32_t)0x02000000) /*!< ADC SQ14 bit 1 */
#define ADC_SQR3_SQ14_2     ((uint32_t)0x04000000) /*!< ADC SQ14 bit 2 */
#define ADC_SQR3_SQ14_3     ((uint32_t)0x08000000) /*!< ADC SQ14 bit 3 */
#define ADC_SQR3_SQ14_4     ((uint32_t)0x10000000) /*!< ADC SQ14 bit 4 */

/********************  Bit definition for ADC_SQR4 register  ********************/
#define ADC_SQR4_SQ15       ((uint32_t)0x0000001F) /*!< ADC 15th conversion in regular sequence */
#define ADC_SQR4_SQ15_0     ((uint32_t)0x00000001) /*!< ADC SQ15 bit 0 */
#define ADC_SQR4_SQ15_1     ((uint32_t)0x00000002) /*!< ADC SQ15 bit 1 */
#define ADC_SQR4_SQ15_2     ((uint32_t)0x00000004) /*!< ADC SQ15 bit 2 */
#define ADC_SQR4_SQ15_3     ((uint32_t)0x00000008) /*!< ADC SQ15 bit 3 */
#define ADC_SQR4_SQ15_4     ((uint32_t)0x00000010) /*!< ADC SQ15 bit 4 */

#define ADC_SQR4_SQ16       ((uint32_t)0x000007C0) /*!< ADC 16th conversion in regular sequence */
#define ADC_SQR4_SQ16_0     ((uint32_t)0x00000040) /*!< ADC SQ16 bit 0 */
#define ADC_SQR4_SQ16_1     ((uint32_t)0x00000080) /*!< ADC SQ16 bit 1 */
#define ADC_SQR4_SQ16_2     ((uint32_t)0x00000100) /*!< ADC SQ16 bit 2 */
#define ADC_SQR4_SQ16_3     ((uint32_t)0x00000200) /*!< ADC SQ16 bit 3 */
#define ADC_SQR4_SQ16_4     ((uint32_t)0x00000400) /*!< ADC SQ16 bit 4 */
/********************  Bit definition for ADC_DR register  ********************/
#define ADC_DR_RDATA        ((uint32_t)0x0000FFFF) /*!< ADC regular Data converted */
#define ADC_DR_RDATA_0      ((uint32_t)0x00000001) /*!< ADC RDATA bit 0 */
#define ADC_DR_RDATA_1      ((uint32_t)0x00000002) /*!< ADC RDATA bit 1 */
#define ADC_DR_RDATA_2      ((uint32_t)0x00000004) /*!< ADC RDATA bit 2 */
#define ADC_DR_RDATA_3      ((uint32_t)0x00000008) /*!< ADC RDATA bit 3 */
#define ADC_DR_RDATA_4      ((uint32_t)0x00000010) /*!< ADC RDATA bit 4 */
#define ADC_DR_RDATA_5      ((uint32_t)0x00000020) /*!< ADC RDATA bit 5 */
#define ADC_DR_RDATA_6      ((uint32_t)0x00000040) /*!< ADC RDATA bit 6 */
#define ADC_DR_RDATA_7      ((uint32_t)0x00000080) /*!< ADC RDATA bit 7 */
#define ADC_DR_RDATA_8      ((uint32_t)0x00000100) /*!< ADC RDATA bit 8 */
#define ADC_DR_RDATA_9      ((uint32_t)0x00000200) /*!< ADC RDATA bit 9 */
#define ADC_DR_RDATA_10     ((uint32_t)0x00000400) /*!< ADC RDATA bit 10 */
#define ADC_DR_RDATA_11     ((uint32_t)0x00000800) /*!< ADC RDATA bit 11 */
#define ADC_DR_RDATA_12     ((uint32_t)0x00001000) /*!< ADC RDATA bit 12 */
#define ADC_DR_RDATA_13     ((uint32_t)0x00002000) /*!< ADC RDATA bit 13 */
#define ADC_DR_RDATA_14     ((uint32_t)0x00004000) /*!< ADC RDATA bit 14 */
#define ADC_DR_RDATA_15     ((uint32_t)0x00008000) /*!< ADC RDATA bit 15 */
#define ADC_DR_RDATA_16     ((uint32_t)0x00010000) /*!< ADC RDATA bit 16 */
#define ADC_DR_RDATA_17     ((uint32_t)0x00020000) /*!< ADC RDATA bit 17 */
#define ADC_DR_RDATA_18     ((uint32_t)0x00040000) /*!< ADC RDATA bit 18 */
#define ADC_DR_RDATA_19     ((uint32_t)0x00080000) /*!< ADC RDATA bit 19 */
#define ADC_DR_RDATA_20     ((uint32_t)0x00100000) /*!< ADC RDATA bit 20 */
#define ADC_DR_RDATA_21     ((uint32_t)0x00200000) /*!< ADC RDATA bit 21 */
#define ADC_DR_RDATA_22     ((uint32_t)0x00400000) /*!< ADC RDATA bit 22 */
#define ADC_DR_RDATA_23     ((uint32_t)0x00800000) /*!< ADC RDATA bit 23 */
#define ADC_DR_RDATA_24     ((uint32_t)0x01000000) /*!< ADC RDATA bit 24 */
#define ADC_DR_RDATA_25     ((uint32_t)0x02000000) /*!< ADC RDATA bit 25 */
#define ADC_DR_RDATA_26     ((uint32_t)0x04000000) /*!< ADC RDATA bit 26 */
#define ADC_DR_RDATA_27     ((uint32_t)0x08000000) /*!< ADC RDATA bit 27 */
#define ADC_DR_RDATA_28     ((uint32_t)0x10000000) /*!< ADC RDATA bit 28 */
#define ADC_DR_RDATA_29     ((uint32_t)0x20000000) /*!< ADC RDATA bit 29 */
#define ADC_DR_RDATA_30     ((uint32_t)0x40000000) /*!< ADC RDATA bit 30 */
#define ADC_DR_RDATA_31     ((uint32_t)0x80000000) /*!< ADC RDATA bit 31 */

/********************  Bit definition for ADC_JSQR register  ********************/
#define ADC_JSQR_JL         ((uint32_t)0x00000003) /*!< ADC injected channel sequence length */
#define ADC_JSQR_JL_0       ((uint32_t)0x00000001) /*!< ADC JL bit 0 */
#define ADC_JSQR_JL_1       ((uint32_t)0x00000002) /*!< ADC JL bit 1 */

#define ADC_JSQR_JEXTSEL    ((uint32_t)0x0000007C) /*!< ADC external trigger selection for injected group */
#define ADC_JSQR_JEXTSEL_0  ((uint32_t)0x00000004) /*!< ADC JEXTSEL bit 0 */
#define ADC_JSQR_JEXTSEL_1  ((uint32_t)0x00000008) /*!< ADC JEXTSEL bit 1 */
#define ADC_JSQR_JEXTSEL_2  ((uint32_t)0x00000010) /*!< ADC JEXTSEL bit 2 */
#define ADC_JSQR_JEXTSEL_3  ((uint32_t)0x00000020) /*!< ADC JEXTSEL bit 3 */
#define ADC_JSQR_JEXTSEL_4  ((uint32_t)0x00000040) /*!< ADC JEXTSEL bit 4 */

#define ADC_JSQR_JEXTEN     ((uint32_t)0x00000180) /*!< ADC external trigger enable and polarity selection for injected channels */
#define ADC_JSQR_JEXTEN_0   ((uint32_t)0x00000080) /*!< ADC JEXTEN bit 0 */
#define ADC_JSQR_JEXTEN_1   ((uint32_t)0x00000100) /*!< ADC JEXTEN bit 1 */

#define ADC_JSQR_JSQ1       ((uint32_t)0x00003E00) /*!< ADC 1st conversion in injected sequence */
#define ADC_JSQR_JSQ1_0     ((uint32_t)0x00000200) /*!< ADC JSQ1 bit 0 */
#define ADC_JSQR_JSQ1_1     ((uint32_t)0x00000400) /*!< ADC JSQ1 bit 1 */
#define ADC_JSQR_JSQ1_2     ((uint32_t)0x00000800) /*!< ADC JSQ1 bit 2 */
#define ADC_JSQR_JSQ1_3     ((uint32_t)0x00001000) /*!< ADC JSQ1 bit 3 */
#define ADC_JSQR_JSQ1_4     ((uint32_t)0x00002000) /*!< ADC JSQ1 bit 4 */

#define ADC_JSQR_JSQ2       ((uint32_t)0x000F8000) /*!< ADC 2nd conversion in injected sequence */
#define ADC_JSQR_JSQ2_0     ((uint32_t)0x00008000) /*!< ADC JSQ2 bit 0 */
#define ADC_JSQR_JSQ2_1     ((uint32_t)0x00010000) /*!< ADC JSQ2 bit 1 */
#define ADC_JSQR_JSQ2_2     ((uint32_t)0x00020000) /*!< ADC JSQ2 bit 2 */
#define ADC_JSQR_JSQ2_3     ((uint32_t)0x00040000) /*!< ADC JSQ2 bit 3 */
#define ADC_JSQR_JSQ2_4     ((uint32_t)0x00080000) /*!< ADC JSQ2 bit 4 */

#define ADC_JSQR_JSQ3       ((uint32_t)0x03E00000) /*!< ADC 3rd conversion in injected sequence */
#define ADC_JSQR_JSQ3_0     ((uint32_t)0x00200000) /*!< ADC JSQ3 bit 0 */
#define ADC_JSQR_JSQ3_1     ((uint32_t)0x00400000) /*!< ADC JSQ3 bit 1 */
#define ADC_JSQR_JSQ3_2     ((uint32_t)0x00800000) /*!< ADC JSQ3 bit 2 */
#define ADC_JSQR_JSQ3_3     ((uint32_t)0x01000000) /*!< ADC JSQ3 bit 3 */
#define ADC_JSQR_JSQ3_4     ((uint32_t)0x02000000) /*!< ADC JSQ3 bit 4 */

#define ADC_JSQR_JSQ4       ((uint32_t)0xF8000000) /*!< ADC 4th conversion in injected sequence */
#define ADC_JSQR_JSQ4_0     ((uint32_t)0x08000000) /*!< ADC JSQ4 bit 0 */
#define ADC_JSQR_JSQ4_1     ((uint32_t)0x10000000) /*!< ADC JSQ4 bit 1 */
#define ADC_JSQR_JSQ4_2     ((uint32_t)0x20000000) /*!< ADC JSQ4 bit 2 */
#define ADC_JSQR_JSQ4_3     ((uint32_t)0x40000000) /*!< ADC JSQ4 bit 3 */
#define ADC_JSQR_JSQ4_4     ((uint32_t)0x80000000) /*!< ADC JSQ4 bit 4 */

/********************  Bit definition for ADC_OFR1 register  ********************/
#define ADC_OFR1_OFFSET1    ((uint32_t)0x00000FFF) /*!< ADC data offset 1 for channel programmed into bits OFFSET1_CH[4:0] */
#define ADC_OFR1_OFFSET1_0  ((uint32_t)0x00000001) /*!< ADC OFFSET1 bit 0 */
#define ADC_OFR1_OFFSET1_1  ((uint32_t)0x00000002) /*!< ADC OFFSET1 bit 1 */
#define ADC_OFR1_OFFSET1_2  ((uint32_t)0x00000004) /*!< ADC OFFSET1 bit 2 */
#define ADC_OFR1_OFFSET1_3  ((uint32_t)0x00000008) /*!< ADC OFFSET1 bit 3 */
#define ADC_OFR1_OFFSET1_4  ((uint32_t)0x00000010) /*!< ADC OFFSET1 bit 4 */
#define ADC_OFR1_OFFSET1_5  ((uint32_t)0x00000020) /*!< ADC OFFSET1 bit 5 */
#define ADC_OFR1_OFFSET1_6  ((uint32_t)0x00000040) /*!< ADC OFFSET1 bit 6 */
#define ADC_OFR1_OFFSET1_7  ((uint32_t)0x00000080) /*!< ADC OFFSET1 bit 7 */
#define ADC_OFR1_OFFSET1_8  ((uint32_t)0x00000100) /*!< ADC OFFSET1 bit 8 */
#define ADC_OFR1_OFFSET1_9  ((uint32_t)0x00000200) /*!< ADC OFFSET1 bit 9 */
#define ADC_OFR1_OFFSET1_10 ((uint32_t)0x00000400) /*!< ADC OFFSET1 bit 10 */
#define ADC_OFR1_OFFSET1_11 ((uint32_t)0x00000800) /*!< ADC OFFSET1 bit 11 */
#define ADC_OFR1_OFFSET1_12 ((uint32_t)0x00001000) /*!< ADC OFFSET1 bit 12 */
#define ADC_OFR1_OFFSET1_13 ((uint32_t)0x00002000) /*!< ADC OFFSET1 bit 13 */
#define ADC_OFR1_OFFSET1_14 ((uint32_t)0x00004000) /*!< ADC OFFSET1 bit 14 */
#define ADC_OFR1_OFFSET1_15 ((uint32_t)0x00008000) /*!< ADC OFFSET1 bit 15 */
#define ADC_OFR1_OFFSET1_16 ((uint32_t)0x00010000) /*!< ADC OFFSET1 bit 16 */
#define ADC_OFR1_OFFSET1_17 ((uint32_t)0x00020000) /*!< ADC OFFSET1 bit 17 */
#define ADC_OFR1_OFFSET1_18 ((uint32_t)0x00040000) /*!< ADC OFFSET1 bit 18 */
#define ADC_OFR1_OFFSET1_19 ((uint32_t)0x00080000) /*!< ADC OFFSET1 bit 19 */
#define ADC_OFR1_OFFSET1_20 ((uint32_t)0x00100000) /*!< ADC OFFSET1 bit 20 */
#define ADC_OFR1_OFFSET1_21 ((uint32_t)0x00200000) /*!< ADC OFFSET1 bit 21 */
#define ADC_OFR1_OFFSET1_22 ((uint32_t)0x00400000) /*!< ADC OFFSET1 bit 22 */
#define ADC_OFR1_OFFSET1_23 ((uint32_t)0x00800000) /*!< ADC OFFSET1 bit 23 */
#define ADC_OFR1_OFFSET1_24 ((uint32_t)0x01000000) /*!< ADC OFFSET1 bit 24 */
#define ADC_OFR1_OFFSET1_25 ((uint32_t)0x02000000) /*!< ADC OFFSET1 bit 25 */

#define ADC_OFR1_OFFSET1_CH    ((uint32_t)0x7C000000) /*!< ADC Channel selection for the data offset 1 */
#define ADC_OFR1_OFFSET1_CH_0  ((uint32_t)0x04000000) /*!< ADC OFFSET1_CH bit 0 */
#define ADC_OFR1_OFFSET1_CH_1  ((uint32_t)0x08000000) /*!< ADC OFFSET1_CH bit 1 */
#define ADC_OFR1_OFFSET1_CH_2  ((uint32_t)0x10000000) /*!< ADC OFFSET1_CH bit 2 */
#define ADC_OFR1_OFFSET1_CH_3  ((uint32_t)0x20000000) /*!< ADC OFFSET1_CH bit 3 */
#define ADC_OFR1_OFFSET1_CH_4  ((uint32_t)0x40000000) /*!< ADC OFFSET1_CH bit 4 */

#define ADC_OFR1_SSATE         ((uint32_t)0x80000000) /*!< ADC Signed saturation Enable */

/********************  Bit definition for ADC_OFR2 register  ********************/
#define ADC_OFR2_OFFSET2    ((uint32_t)0x00000FFF) /*!< ADC data offset 2 for channel programmed into bits OFFSET2_CH[4:0] */
#define ADC_OFR2_OFFSET2_0  ((uint32_t)0x00000001) /*!< ADC OFFSET2 bit 0 */
#define ADC_OFR2_OFFSET2_1  ((uint32_t)0x00000002) /*!< ADC OFFSET2 bit 1 */
#define ADC_OFR2_OFFSET2_2  ((uint32_t)0x00000004) /*!< ADC OFFSET2 bit 2 */
#define ADC_OFR2_OFFSET2_3  ((uint32_t)0x00000008) /*!< ADC OFFSET2 bit 3 */
#define ADC_OFR2_OFFSET2_4  ((uint32_t)0x00000010) /*!< ADC OFFSET2 bit 4 */
#define ADC_OFR2_OFFSET2_5  ((uint32_t)0x00000020) /*!< ADC OFFSET2 bit 5 */
#define ADC_OFR2_OFFSET2_6  ((uint32_t)0x00000040) /*!< ADC OFFSET2 bit 6 */
#define ADC_OFR2_OFFSET2_7  ((uint32_t)0x00000080) /*!< ADC OFFSET2 bit 7 */
#define ADC_OFR2_OFFSET2_8  ((uint32_t)0x00000100) /*!< ADC OFFSET2 bit 8 */
#define ADC_OFR2_OFFSET2_9  ((uint32_t)0x00000200) /*!< ADC OFFSET2 bit 9 */
#define ADC_OFR2_OFFSET2_10 ((uint32_t)0x00000400) /*!< ADC OFFSET2 bit 10 */
#define ADC_OFR2_OFFSET2_11 ((uint32_t)0x00000800) /*!< ADC OFFSET2 bit 11 */
#define ADC_OFR2_OFFSET2_12 ((uint32_t)0x00001000) /*!< ADC OFFSET2 bit 12 */
#define ADC_OFR2_OFFSET2_13 ((uint32_t)0x00002000) /*!< ADC OFFSET2 bit 13 */
#define ADC_OFR2_OFFSET2_14 ((uint32_t)0x00004000) /*!< ADC OFFSET2 bit 14 */
#define ADC_OFR2_OFFSET2_15 ((uint32_t)0x00008000) /*!< ADC OFFSET2 bit 15 */
#define ADC_OFR2_OFFSET2_16 ((uint32_t)0x00010000) /*!< ADC OFFSET2 bit 16 */
#define ADC_OFR2_OFFSET2_17 ((uint32_t)0x00020000) /*!< ADC OFFSET2 bit 17 */
#define ADC_OFR2_OFFSET2_18 ((uint32_t)0x00040000) /*!< ADC OFFSET2 bit 18 */
#define ADC_OFR2_OFFSET2_19 ((uint32_t)0x00080000) /*!< ADC OFFSET2 bit 19 */
#define ADC_OFR2_OFFSET2_20 ((uint32_t)0x00100000) /*!< ADC OFFSET2 bit 20 */
#define ADC_OFR2_OFFSET2_21 ((uint32_t)0x00200000) /*!< ADC OFFSET2 bit 21 */
#define ADC_OFR2_OFFSET2_22 ((uint32_t)0x00400000) /*!< ADC OFFSET2 bit 22 */
#define ADC_OFR2_OFFSET2_23 ((uint32_t)0x00800000) /*!< ADC OFFSET2 bit 23 */
#define ADC_OFR2_OFFSET2_24 ((uint32_t)0x01000000) /*!< ADC OFFSET2 bit 24 */
#define ADC_OFR2_OFFSET2_25 ((uint32_t)0x02000000) /*!< ADC OFFSET2 bit 25 */

#define ADC_OFR2_OFFSET2_CH     ((uint32_t)0x7C000000) /*!< ADC Channel selection for the data offset 2 */
#define ADC_OFR2_OFFSET2_CH_0  ((uint32_t)0x04000000) /*!< ADC OFFSET2_CH bit 0 */
#define ADC_OFR2_OFFSET2_CH_1  ((uint32_t)0x08000000) /*!< ADC OFFSET2_CH bit 1 */
#define ADC_OFR2_OFFSET2_CH_2  ((uint32_t)0x10000000) /*!< ADC OFFSET2_CH bit 2 */
#define ADC_OFR2_OFFSET2_CH_3  ((uint32_t)0x20000000) /*!< ADC OFFSET2_CH bit 3 */
#define ADC_OFR2_OFFSET2_CH_4  ((uint32_t)0x40000000) /*!< ADC OFFSET2_CH bit 4 */

#define ADC_OFR2_SSATE         ((uint32_t)0x80000000) /*!< ADC Signed saturation Enable */

/********************  Bit definition for ADC_OFR3 register  ********************/
#define ADC_OFR3_OFFSET3    ((uint32_t)0x00000FFF) /*!< ADC data offset 3 for channel programmed into bits OFFSET3_CH[4:0] */
#define ADC_OFR3_OFFSET3_0  ((uint32_t)0x00000001) /*!< ADC OFFSET3 bit 0 */
#define ADC_OFR3_OFFSET3_1  ((uint32_t)0x00000002) /*!< ADC OFFSET3 bit 1 */
#define ADC_OFR3_OFFSET3_2  ((uint32_t)0x00000004) /*!< ADC OFFSET3 bit 2 */
#define ADC_OFR3_OFFSET3_3  ((uint32_t)0x00000008) /*!< ADC OFFSET3 bit 3 */
#define ADC_OFR3_OFFSET3_4  ((uint32_t)0x00000010) /*!< ADC OFFSET3 bit 4 */
#define ADC_OFR3_OFFSET3_5  ((uint32_t)0x00000020) /*!< ADC OFFSET3 bit 5 */
#define ADC_OFR3_OFFSET3_6  ((uint32_t)0x00000040) /*!< ADC OFFSET3 bit 6 */
#define ADC_OFR3_OFFSET3_7  ((uint32_t)0x00000080) /*!< ADC OFFSET3 bit 7 */
#define ADC_OFR3_OFFSET3_8  ((uint32_t)0x00000100) /*!< ADC OFFSET3 bit 8 */
#define ADC_OFR3_OFFSET3_9  ((uint32_t)0x00000200) /*!< ADC OFFSET3 bit 9 */
#define ADC_OFR3_OFFSET3_10 ((uint32_t)0x00000400) /*!< ADC OFFSET3 bit 10 */
#define ADC_OFR3_OFFSET3_11 ((uint32_t)0x00000800) /*!< ADC OFFSET3 bit 11 */
#define ADC_OFR3_OFFSET3_12 ((uint32_t)0x00001000) /*!< ADC OFFSET3 bit 12 */
#define ADC_OFR3_OFFSET3_13 ((uint32_t)0x00002000) /*!< ADC OFFSET3 bit 13 */
#define ADC_OFR3_OFFSET3_14 ((uint32_t)0x00004000) /*!< ADC OFFSET3 bit 14 */
#define ADC_OFR3_OFFSET3_15 ((uint32_t)0x00008000) /*!< ADC OFFSET3 bit 15 */
#define ADC_OFR3_OFFSET3_16 ((uint32_t)0x00010000) /*!< ADC OFFSET3 bit 16 */
#define ADC_OFR3_OFFSET3_17 ((uint32_t)0x00020000) /*!< ADC OFFSET3 bit 17 */
#define ADC_OFR3_OFFSET3_18 ((uint32_t)0x00040000) /*!< ADC OFFSET3 bit 18 */
#define ADC_OFR3_OFFSET3_19 ((uint32_t)0x00080000) /*!< ADC OFFSET3 bit 19 */
#define ADC_OFR3_OFFSET3_20 ((uint32_t)0x00100000) /*!< ADC OFFSET3 bit 20 */
#define ADC_OFR3_OFFSET3_21 ((uint32_t)0x00200000) /*!< ADC OFFSET3 bit 21 */
#define ADC_OFR3_OFFSET3_22 ((uint32_t)0x00400000) /*!< ADC OFFSET3 bit 22 */
#define ADC_OFR3_OFFSET3_23 ((uint32_t)0x00800000) /*!< ADC OFFSET3 bit 23 */
#define ADC_OFR3_OFFSET3_24 ((uint32_t)0x01000000) /*!< ADC OFFSET3 bit 24 */
#define ADC_OFR3_OFFSET3_25 ((uint32_t)0x02000000) /*!< ADC OFFSET3 bit 25 */

#define ADC_OFR3_OFFSET3_CH     ((uint32_t)0x7C000000) /*!< ADC Channel selection for the data offset 3 */
#define ADC_OFR3_OFFSET3_CH_0  ((uint32_t)0x04000000) /*!< ADC OFFSET3_CH bit 0 */
#define ADC_OFR3_OFFSET3_CH_1  ((uint32_t)0x08000000) /*!< ADC OFFSET3_CH bit 1 */
#define ADC_OFR3_OFFSET3_CH_2  ((uint32_t)0x10000000) /*!< ADC OFFSET3_CH bit 2 */
#define ADC_OFR3_OFFSET3_CH_3  ((uint32_t)0x20000000) /*!< ADC OFFSET3_CH bit 3 */
#define ADC_OFR3_OFFSET3_CH_4  ((uint32_t)0x40000000) /*!< ADC OFFSET3_CH bit 4 */

#define ADC_OFR3_SSATE         ((uint32_t)0x80000000) /*!< ADC Signed saturation Enable */

/********************  Bit definition for ADC_OFR4 register  ********************/
#define ADC_OFR4_OFFSET4    ((uint32_t)0x00000FFF) /*!< ADC data offset 4 for channel programmed into bits OFFSET4_CH[4:0] */
#define ADC_OFR4_OFFSET4_0  ((uint32_t)0x00000001) /*!< ADC OFFSET4 bit 0 */
#define ADC_OFR4_OFFSET4_1  ((uint32_t)0x00000002) /*!< ADC OFFSET4 bit 1 */
#define ADC_OFR4_OFFSET4_2  ((uint32_t)0x00000004) /*!< ADC OFFSET4 bit 2 */
#define ADC_OFR4_OFFSET4_3  ((uint32_t)0x00000008) /*!< ADC OFFSET4 bit 3 */
#define ADC_OFR4_OFFSET4_4  ((uint32_t)0x00000010) /*!< ADC OFFSET4 bit 4 */
#define ADC_OFR4_OFFSET4_5  ((uint32_t)0x00000020) /*!< ADC OFFSET4 bit 5 */
#define ADC_OFR4_OFFSET4_6  ((uint32_t)0x00000040) /*!< ADC OFFSET4 bit 6 */
#define ADC_OFR4_OFFSET4_7  ((uint32_t)0x00000080) /*!< ADC OFFSET4 bit 7 */
#define ADC_OFR4_OFFSET4_8  ((uint32_t)0x00000100) /*!< ADC OFFSET4 bit 8 */
#define ADC_OFR4_OFFSET4_9  ((uint32_t)0x00000200) /*!< ADC OFFSET4 bit 9 */
#define ADC_OFR4_OFFSET4_10 ((uint32_t)0x00000400) /*!< ADC OFFSET4 bit 10 */
#define ADC_OFR4_OFFSET4_11 ((uint32_t)0x00000800) /*!< ADC OFFSET4 bit 11 */
#define ADC_OFR4_OFFSET4_12 ((uint32_t)0x00001000) /*!< ADC OFFSET4 bit 12 */
#define ADC_OFR4_OFFSET4_13 ((uint32_t)0x00002000) /*!< ADC OFFSET4 bit 13 */
#define ADC_OFR4_OFFSET4_14 ((uint32_t)0x00004000) /*!< ADC OFFSET4 bit 14 */
#define ADC_OFR4_OFFSET4_15 ((uint32_t)0x00008000) /*!< ADC OFFSET4 bit 15 */
#define ADC_OFR4_OFFSET4_16 ((uint32_t)0x00010000) /*!< ADC OFFSET4 bit 16 */
#define ADC_OFR4_OFFSET4_17 ((uint32_t)0x00020000) /*!< ADC OFFSET4 bit 17 */
#define ADC_OFR4_OFFSET4_18 ((uint32_t)0x00040000) /*!< ADC OFFSET4 bit 18 */
#define ADC_OFR4_OFFSET4_19 ((uint32_t)0x00080000) /*!< ADC OFFSET4 bit 19 */
#define ADC_OFR4_OFFSET4_20 ((uint32_t)0x00100000) /*!< ADC OFFSET4 bit 20 */
#define ADC_OFR4_OFFSET4_21 ((uint32_t)0x00200000) /*!< ADC OFFSET4 bit 21 */
#define ADC_OFR4_OFFSET4_22 ((uint32_t)0x00400000) /*!< ADC OFFSET4 bit 22 */
#define ADC_OFR4_OFFSET4_23 ((uint32_t)0x00800000) /*!< ADC OFFSET4 bit 23 */
#define ADC_OFR4_OFFSET4_24 ((uint32_t)0x01000000) /*!< ADC OFFSET4 bit 24 */
#define ADC_OFR4_OFFSET4_25 ((uint32_t)0x02000000) /*!< ADC OFFSET4 bit 25 */

#define ADC_OFR4_OFFSET4_CH     ((uint32_t)0x7C000000) /*!< ADC Channel selection for the data offset 4 */
#define ADC_OFR4_OFFSET4_CH_0  ((uint32_t)0x04000000) /*!< ADC OFFSET4_CH bit 0 */
#define ADC_OFR4_OFFSET4_CH_1  ((uint32_t)0x08000000) /*!< ADC OFFSET4_CH bit 1 */
#define ADC_OFR4_OFFSET4_CH_2  ((uint32_t)0x10000000) /*!< ADC OFFSET4_CH bit 2 */
#define ADC_OFR4_OFFSET4_CH_3  ((uint32_t)0x20000000) /*!< ADC OFFSET4_CH bit 3 */
#define ADC_OFR4_OFFSET4_CH_4  ((uint32_t)0x40000000) /*!< ADC OFFSET4_CH bit 4 */

#define ADC_OFR4_SSATE         ((uint32_t)0x80000000) /*!< ADC Signed saturation Enable */

/********************  Bit definition for ADC_JDR1 register  ********************/
#define ADC_JDR1_JDATA      ((uint32_t)0x0000FFFF) /*!< ADC Injected DATA */
#define ADC_JDR1_JDATA_0    ((uint32_t)0x00000001) /*!< ADC JDATA bit 0 */
#define ADC_JDR1_JDATA_1    ((uint32_t)0x00000002) /*!< ADC JDATA bit 1 */
#define ADC_JDR1_JDATA_2    ((uint32_t)0x00000004) /*!< ADC JDATA bit 2 */
#define ADC_JDR1_JDATA_3    ((uint32_t)0x00000008) /*!< ADC JDATA bit 3 */
#define ADC_JDR1_JDATA_4    ((uint32_t)0x00000010) /*!< ADC JDATA bit 4 */
#define ADC_JDR1_JDATA_5    ((uint32_t)0x00000020) /*!< ADC JDATA bit 5 */
#define ADC_JDR1_JDATA_6    ((uint32_t)0x00000040) /*!< ADC JDATA bit 6 */
#define ADC_JDR1_JDATA_7    ((uint32_t)0x00000080) /*!< ADC JDATA bit 7 */
#define ADC_JDR1_JDATA_8    ((uint32_t)0x00000100) /*!< ADC JDATA bit 8 */
#define ADC_JDR1_JDATA_9    ((uint32_t)0x00000200) /*!< ADC JDATA bit 9 */
#define ADC_JDR1_JDATA_10   ((uint32_t)0x00000400) /*!< ADC JDATA bit 10 */
#define ADC_JDR1_JDATA_11   ((uint32_t)0x00000800) /*!< ADC JDATA bit 11 */
#define ADC_JDR1_JDATA_12   ((uint32_t)0x00001000) /*!< ADC JDATA bit 12 */
#define ADC_JDR1_JDATA_13   ((uint32_t)0x00002000) /*!< ADC JDATA bit 13 */
#define ADC_JDR1_JDATA_14   ((uint32_t)0x00004000) /*!< ADC JDATA bit 14 */
#define ADC_JDR1_JDATA_15   ((uint32_t)0x00008000) /*!< ADC JDATA bit 15 */
#define ADC_JDR1_JDATA_16   ((uint32_t)0x00010000) /*!< ADC JDATA bit 16 */
#define ADC_JDR1_JDATA_17   ((uint32_t)0x00020000) /*!< ADC JDATA bit 17 */
#define ADC_JDR1_JDATA_18   ((uint32_t)0x00040000) /*!< ADC JDATA bit 18 */
#define ADC_JDR1_JDATA_19   ((uint32_t)0x00080000) /*!< ADC JDATA bit 19 */
#define ADC_JDR1_JDATA_20   ((uint32_t)0x00100000) /*!< ADC JDATA bit 20 */
#define ADC_JDR1_JDATA_21   ((uint32_t)0x00200000) /*!< ADC JDATA bit 21 */
#define ADC_JDR1_JDATA_22   ((uint32_t)0x00400000) /*!< ADC JDATA bit 22 */
#define ADC_JDR1_JDATA_23   ((uint32_t)0x00800000) /*!< ADC JDATA bit 23 */
#define ADC_JDR1_JDATA_24   ((uint32_t)0x01000000) /*!< ADC JDATA bit 24 */
#define ADC_JDR1_JDATA_25   ((uint32_t)0x02000000) /*!< ADC JDATA bit 25 */
#define ADC_JDR1_JDATA_26   ((uint32_t)0x04000000) /*!< ADC JDATA bit 26 */
#define ADC_JDR1_JDATA_27   ((uint32_t)0x08000000) /*!< ADC JDATA bit 27 */
#define ADC_JDR1_JDATA_28   ((uint32_t)0x10000000) /*!< ADC JDATA bit 28 */
#define ADC_JDR1_JDATA_29   ((uint32_t)0x20000000) /*!< ADC JDATA bit 29 */
#define ADC_JDR1_JDATA_30   ((uint32_t)0x40000000) /*!< ADC JDATA bit 30 */
#define ADC_JDR1_JDATA_31   ((uint32_t)0x80000000) /*!< ADC JDATA bit 31 */

/********************  Bit definition for ADC_JDR2 register  ********************/
#define ADC_JDR2_JDATA      ((uint32_t)0x0000FFFF) /*!< ADC Injected DATA */
#define ADC_JDR2_JDATA_0    ((uint32_t)0x00000001) /*!< ADC JDATA bit 0 */
#define ADC_JDR2_JDATA_1    ((uint32_t)0x00000002) /*!< ADC JDATA bit 1 */
#define ADC_JDR2_JDATA_2    ((uint32_t)0x00000004) /*!< ADC JDATA bit 2 */
#define ADC_JDR2_JDATA_3    ((uint32_t)0x00000008) /*!< ADC JDATA bit 3 */
#define ADC_JDR2_JDATA_4    ((uint32_t)0x00000010) /*!< ADC JDATA bit 4 */
#define ADC_JDR2_JDATA_5    ((uint32_t)0x00000020) /*!< ADC JDATA bit 5 */
#define ADC_JDR2_JDATA_6    ((uint32_t)0x00000040) /*!< ADC JDATA bit 6 */
#define ADC_JDR2_JDATA_7    ((uint32_t)0x00000080) /*!< ADC JDATA bit 7 */
#define ADC_JDR2_JDATA_8    ((uint32_t)0x00000100) /*!< ADC JDATA bit 8 */
#define ADC_JDR2_JDATA_9    ((uint32_t)0x00000200) /*!< ADC JDATA bit 9 */
#define ADC_JDR2_JDATA_10   ((uint32_t)0x00000400) /*!< ADC JDATA bit 10 */
#define ADC_JDR2_JDATA_11   ((uint32_t)0x00000800) /*!< ADC JDATA bit 11 */
#define ADC_JDR2_JDATA_12   ((uint32_t)0x00001000) /*!< ADC JDATA bit 12 */
#define ADC_JDR2_JDATA_13   ((uint32_t)0x00002000) /*!< ADC JDATA bit 13 */
#define ADC_JDR2_JDATA_14   ((uint32_t)0x00004000) /*!< ADC JDATA bit 14 */
#define ADC_JDR2_JDATA_15   ((uint32_t)0x00008000) /*!< ADC JDATA bit 15 */
#define ADC_JDR2_JDATA_16   ((uint32_t)0x00010000) /*!< ADC JDATA bit 16 */
#define ADC_JDR2_JDATA_17   ((uint32_t)0x00020000) /*!< ADC JDATA bit 17 */
#define ADC_JDR2_JDATA_18   ((uint32_t)0x00040000) /*!< ADC JDATA bit 18 */
#define ADC_JDR2_JDATA_19   ((uint32_t)0x00080000) /*!< ADC JDATA bit 19 */
#define ADC_JDR2_JDATA_20   ((uint32_t)0x00100000) /*!< ADC JDATA bit 20 */
#define ADC_JDR2_JDATA_21   ((uint32_t)0x00200000) /*!< ADC JDATA bit 21 */
#define ADC_JDR2_JDATA_22   ((uint32_t)0x00400000) /*!< ADC JDATA bit 22 */
#define ADC_JDR2_JDATA_23   ((uint32_t)0x00800000) /*!< ADC JDATA bit 23 */
#define ADC_JDR2_JDATA_24   ((uint32_t)0x01000000) /*!< ADC JDATA bit 24 */
#define ADC_JDR2_JDATA_25   ((uint32_t)0x02000000) /*!< ADC JDATA bit 25 */
#define ADC_JDR2_JDATA_26   ((uint32_t)0x04000000) /*!< ADC JDATA bit 26 */
#define ADC_JDR2_JDATA_27   ((uint32_t)0x08000000) /*!< ADC JDATA bit 27 */
#define ADC_JDR2_JDATA_28   ((uint32_t)0x10000000) /*!< ADC JDATA bit 28 */
#define ADC_JDR2_JDATA_29   ((uint32_t)0x20000000) /*!< ADC JDATA bit 29 */
#define ADC_JDR2_JDATA_30   ((uint32_t)0x40000000) /*!< ADC JDATA bit 30 */
#define ADC_JDR2_JDATA_31   ((uint32_t)0x80000000) /*!< ADC JDATA bit 31 */

/********************  Bit definition for ADC_JDR3 register  ********************/
#define ADC_JDR3_JDATA      ((uint32_t)0x0000FFFF) /*!< ADC Injected DATA */
#define ADC_JDR3_JDATA_0    ((uint32_t)0x00000001) /*!< ADC JDATA bit 0 */
#define ADC_JDR3_JDATA_1    ((uint32_t)0x00000002) /*!< ADC JDATA bit 1 */
#define ADC_JDR3_JDATA_2    ((uint32_t)0x00000004) /*!< ADC JDATA bit 2 */
#define ADC_JDR3_JDATA_3    ((uint32_t)0x00000008) /*!< ADC JDATA bit 3 */
#define ADC_JDR3_JDATA_4    ((uint32_t)0x00000010) /*!< ADC JDATA bit 4 */
#define ADC_JDR3_JDATA_5    ((uint32_t)0x00000020) /*!< ADC JDATA bit 5 */
#define ADC_JDR3_JDATA_6    ((uint32_t)0x00000040) /*!< ADC JDATA bit 6 */
#define ADC_JDR3_JDATA_7    ((uint32_t)0x00000080) /*!< ADC JDATA bit 7 */
#define ADC_JDR3_JDATA_8    ((uint32_t)0x00000100) /*!< ADC JDATA bit 8 */
#define ADC_JDR3_JDATA_9    ((uint32_t)0x00000200) /*!< ADC JDATA bit 9 */
#define ADC_JDR3_JDATA_10   ((uint32_t)0x00000400) /*!< ADC JDATA bit 10 */
#define ADC_JDR3_JDATA_11   ((uint32_t)0x00000800) /*!< ADC JDATA bit 11 */
#define ADC_JDR3_JDATA_12   ((uint32_t)0x00001000) /*!< ADC JDATA bit 12 */
#define ADC_JDR3_JDATA_13   ((uint32_t)0x00002000) /*!< ADC JDATA bit 13 */
#define ADC_JDR3_JDATA_14   ((uint32_t)0x00004000) /*!< ADC JDATA bit 14 */
#define ADC_JDR3_JDATA_15   ((uint32_t)0x00008000) /*!< ADC JDATA bit 15 */
#define ADC_JDR3_JDATA_16   ((uint32_t)0x00010000) /*!< ADC JDATA bit 16 */
#define ADC_JDR3_JDATA_17   ((uint32_t)0x00020000) /*!< ADC JDATA bit 17 */
#define ADC_JDR3_JDATA_18   ((uint32_t)0x00040000) /*!< ADC JDATA bit 18 */
#define ADC_JDR3_JDATA_19   ((uint32_t)0x00080000) /*!< ADC JDATA bit 19 */
#define ADC_JDR3_JDATA_20   ((uint32_t)0x00100000) /*!< ADC JDATA bit 20 */
#define ADC_JDR3_JDATA_21   ((uint32_t)0x00200000) /*!< ADC JDATA bit 21 */
#define ADC_JDR3_JDATA_22   ((uint32_t)0x00400000) /*!< ADC JDATA bit 22 */
#define ADC_JDR3_JDATA_23   ((uint32_t)0x00800000) /*!< ADC JDATA bit 23 */
#define ADC_JDR3_JDATA_24   ((uint32_t)0x01000000) /*!< ADC JDATA bit 24 */
#define ADC_JDR3_JDATA_25   ((uint32_t)0x02000000) /*!< ADC JDATA bit 25 */
#define ADC_JDR3_JDATA_26   ((uint32_t)0x04000000) /*!< ADC JDATA bit 26 */
#define ADC_JDR3_JDATA_27   ((uint32_t)0x08000000) /*!< ADC JDATA bit 27 */
#define ADC_JDR3_JDATA_28   ((uint32_t)0x10000000) /*!< ADC JDATA bit 28 */
#define ADC_JDR3_JDATA_29   ((uint32_t)0x20000000) /*!< ADC JDATA bit 29 */
#define ADC_JDR3_JDATA_30   ((uint32_t)0x40000000) /*!< ADC JDATA bit 30 */
#define ADC_JDR3_JDATA_31   ((uint32_t)0x80000000) /*!< ADC JDATA bit 31 */

/********************  Bit definition for ADC_JDR4 register  ********************/
#define ADC_JDR4_JDATA      ((uint32_t)0x0000FFFF) /*!< ADC Injected DATA */
#define ADC_JDR4_JDATA_0    ((uint32_t)0x00000001) /*!< ADC JDATA bit 0 */
#define ADC_JDR4_JDATA_1    ((uint32_t)0x00000002) /*!< ADC JDATA bit 1 */
#define ADC_JDR4_JDATA_2    ((uint32_t)0x00000004) /*!< ADC JDATA bit 2 */
#define ADC_JDR4_JDATA_3    ((uint32_t)0x00000008) /*!< ADC JDATA bit 3 */
#define ADC_JDR4_JDATA_4    ((uint32_t)0x00000010) /*!< ADC JDATA bit 4 */
#define ADC_JDR4_JDATA_5    ((uint32_t)0x00000020) /*!< ADC JDATA bit 5 */
#define ADC_JDR4_JDATA_6    ((uint32_t)0x00000040) /*!< ADC JDATA bit 6 */
#define ADC_JDR4_JDATA_7    ((uint32_t)0x00000080) /*!< ADC JDATA bit 7 */
#define ADC_JDR4_JDATA_8    ((uint32_t)0x00000100) /*!< ADC JDATA bit 8 */
#define ADC_JDR4_JDATA_9    ((uint32_t)0x00000200) /*!< ADC JDATA bit 9 */
#define ADC_JDR4_JDATA_10   ((uint32_t)0x00000400) /*!< ADC JDATA bit 10 */
#define ADC_JDR4_JDATA_11   ((uint32_t)0x00000800) /*!< ADC JDATA bit 11 */
#define ADC_JDR4_JDATA_12   ((uint32_t)0x00001000) /*!< ADC JDATA bit 12 */
#define ADC_JDR4_JDATA_13   ((uint32_t)0x00002000) /*!< ADC JDATA bit 13 */
#define ADC_JDR4_JDATA_14   ((uint32_t)0x00004000) /*!< ADC JDATA bit 14 */
#define ADC_JDR4_JDATA_15   ((uint32_t)0x00008000) /*!< ADC JDATA bit 15 */
#define ADC_JDR4_JDATA_16   ((uint32_t)0x00010000) /*!< ADC JDATA bit 16 */
#define ADC_JDR4_JDATA_17   ((uint32_t)0x00020000) /*!< ADC JDATA bit 17 */
#define ADC_JDR4_JDATA_18   ((uint32_t)0x00040000) /*!< ADC JDATA bit 18 */
#define ADC_JDR4_JDATA_19   ((uint32_t)0x00080000) /*!< ADC JDATA bit 19 */
#define ADC_JDR4_JDATA_20   ((uint32_t)0x00100000) /*!< ADC JDATA bit 20 */
#define ADC_JDR4_JDATA_21   ((uint32_t)0x00200000) /*!< ADC JDATA bit 21 */
#define ADC_JDR4_JDATA_22   ((uint32_t)0x00400000) /*!< ADC JDATA bit 22 */
#define ADC_JDR4_JDATA_23   ((uint32_t)0x00800000) /*!< ADC JDATA bit 23 */
#define ADC_JDR4_JDATA_24   ((uint32_t)0x01000000) /*!< ADC JDATA bit 24 */
#define ADC_JDR4_JDATA_25   ((uint32_t)0x02000000) /*!< ADC JDATA bit 25 */
#define ADC_JDR4_JDATA_26   ((uint32_t)0x04000000) /*!< ADC JDATA bit 26 */
#define ADC_JDR4_JDATA_27   ((uint32_t)0x08000000) /*!< ADC JDATA bit 27 */
#define ADC_JDR4_JDATA_28   ((uint32_t)0x10000000) /*!< ADC JDATA bit 28 */
#define ADC_JDR4_JDATA_29   ((uint32_t)0x20000000) /*!< ADC JDATA bit 29 */
#define ADC_JDR4_JDATA_30   ((uint32_t)0x40000000) /*!< ADC JDATA bit 30 */
#define ADC_JDR4_JDATA_31   ((uint32_t)0x80000000) /*!< ADC JDATA bit 31 */

/********************  Bit definition for ADC_AWD2CR register  ********************/
#define ADC_AWD2CR_AWD2CH    ((uint32_t)0x000FFFFF) /*!< ADC Analog watchdog 2 channel selection */
#define ADC_AWD2CR_AWD2CH_0  ((uint32_t)0x00000001) /*!< ADC AWD2CH bit 0 */
#define ADC_AWD2CR_AWD2CH_1  ((uint32_t)0x00000002) /*!< ADC AWD2CH bit 1 */
#define ADC_AWD2CR_AWD2CH_2  ((uint32_t)0x00000004) /*!< ADC AWD2CH bit 2 */
#define ADC_AWD2CR_AWD2CH_3  ((uint32_t)0x00000008) /*!< ADC AWD2CH bit 3 */
#define ADC_AWD2CR_AWD2CH_4  ((uint32_t)0x00000010) /*!< ADC AWD2CH bit 4 */
#define ADC_AWD2CR_AWD2CH_5  ((uint32_t)0x00000020) /*!< ADC AWD2CH bit 5 */
#define ADC_AWD2CR_AWD2CH_6  ((uint32_t)0x00000040) /*!< ADC AWD2CH bit 6 */
#define ADC_AWD2CR_AWD2CH_7  ((uint32_t)0x00000080) /*!< ADC AWD2CH bit 7 */
#define ADC_AWD2CR_AWD2CH_8  ((uint32_t)0x00000100) /*!< ADC AWD2CH bit 8 */
#define ADC_AWD2CR_AWD2CH_9  ((uint32_t)0x00000200) /*!< ADC AWD2CH bit 9 */
#define ADC_AWD2CR_AWD2CH_10 ((uint32_t)0x00000400) /*!< ADC AWD2CH bit 10 */
#define ADC_AWD2CR_AWD2CH_11 ((uint32_t)0x00000800) /*!< ADC AWD2CH bit 11 */
#define ADC_AWD2CR_AWD2CH_12 ((uint32_t)0x00001000) /*!< ADC AWD2CH bit 12 */
#define ADC_AWD2CR_AWD2CH_13 ((uint32_t)0x00002000) /*!< ADC AWD2CH bit 13 */
#define ADC_AWD2CR_AWD2CH_14 ((uint32_t)0x00004000) /*!< ADC AWD2CH bit 14 */
#define ADC_AWD2CR_AWD2CH_15 ((uint32_t)0x00008000) /*!< ADC AWD2CH bit 15 */
#define ADC_AWD2CR_AWD2CH_16 ((uint32_t)0x00010000) /*!< ADC AWD2CH bit 16 */
#define ADC_AWD2CR_AWD2CH_17 ((uint32_t)0x00020000) /*!< ADC AWD2CH bit 17 */
#define ADC_AWD2CR_AWD2CH_18 ((uint32_t)0x00040000) /*!< ADC AWD2CH bit 18 */
#define ADC_AWD2CR_AWD2CH_19 ((uint32_t)0x00080000) /*!< ADC AWD2CH bit 19 */

/********************  Bit definition for ADC_AWD3CR register  ********************/
#define ADC_AWD3CR_AWD3CH    ((uint32_t)0x0007FFFF) /*!< ADC Analog watchdog 2 channel selection */
#define ADC_AWD3CR_AWD3CH_0  ((uint32_t)0x00000001) /*!< ADC AWD3CH bit 0 */
#define ADC_AWD3CR_AWD3CH_1  ((uint32_t)0x00000002) /*!< ADC AWD3CH bit 1 */
#define ADC_AWD3CR_AWD3CH_2  ((uint32_t)0x00000004) /*!< ADC AWD3CH bit 2 */
#define ADC_AWD3CR_AWD3CH_3  ((uint32_t)0x00000008) /*!< ADC AWD3CH bit 3 */
#define ADC_AWD3CR_AWD3CH_4  ((uint32_t)0x00000010) /*!< ADC AWD3CH bit 4 */
#define ADC_AWD3CR_AWD3CH_5  ((uint32_t)0x00000020) /*!< ADC AWD3CH bit 5 */
#define ADC_AWD3CR_AWD3CH_6  ((uint32_t)0x00000040) /*!< ADC AWD3CH bit 6 */
#define ADC_AWD3CR_AWD3CH_7  ((uint32_t)0x00000080) /*!< ADC AWD3CH bit 7 */
#define ADC_AWD3CR_AWD3CH_8  ((uint32_t)0x00000100) /*!< ADC AWD3CH bit 8 */
#define ADC_AWD3CR_AWD3CH_9  ((uint32_t)0x00000200) /*!< ADC AWD3CH bit 9 */
#define ADC_AWD3CR_AWD3CH_10 ((uint32_t)0x00000400) /*!< ADC AWD3CH bit 10 */
#define ADC_AWD3CR_AWD3CH_11 ((uint32_t)0x00000800) /*!< ADC AWD3CH bit 11 */
#define ADC_AWD3CR_AWD3CH_12 ((uint32_t)0x00001000) /*!< ADC AWD3CH bit 12 */
#define ADC_AWD3CR_AWD3CH_13 ((uint32_t)0x00002000) /*!< ADC AWD3CH bit 13 */
#define ADC_AWD3CR_AWD3CH_14 ((uint32_t)0x00004000) /*!< ADC AWD3CH bit 14 */
#define ADC_AWD3CR_AWD3CH_15 ((uint32_t)0x00008000) /*!< ADC AWD3CH bit 15 */
#define ADC_AWD3CR_AWD3CH_16 ((uint32_t)0x00010000) /*!< ADC AWD3CH bit 16 */
#define ADC_AWD3CR_AWD3CH_17 ((uint32_t)0x00020000) /*!< ADC AWD3CH bit 17 */
#define ADC_AWD3CR_AWD3CH_18 ((uint32_t)0x00040000) /*!< ADC AWD3CH bit 18 */
#define ADC_AWD3CR_AWD3CH_19 ((uint32_t)0x00080000) /*!< ADC AWD3CH bit 19 */

/********************  Bit definition for ADC_DIFSEL register  ********************/
#define ADC_DIFSEL_DIFSEL    ((uint32_t)0x000FFFFF) /*!< ADC differential modes for channels 1 to 18 */
#define ADC_DIFSEL_DIFSEL_0  ((uint32_t)0x00000001) /*!< ADC DIFSEL bit 0 */
#define ADC_DIFSEL_DIFSEL_1  ((uint32_t)0x00000002) /*!< ADC DIFSEL bit 1 */
#define ADC_DIFSEL_DIFSEL_2  ((uint32_t)0x00000004) /*!< ADC DIFSEL bit 2 */
#define ADC_DIFSEL_DIFSEL_3  ((uint32_t)0x00000008) /*!< ADC DIFSEL bit 3 */
#define ADC_DIFSEL_DIFSEL_4  ((uint32_t)0x00000010) /*!< ADC DIFSEL bit 4 */
#define ADC_DIFSEL_DIFSEL_5  ((uint32_t)0x00000020) /*!< ADC DIFSEL bit 5 */
#define ADC_DIFSEL_DIFSEL_6  ((uint32_t)0x00000040) /*!< ADC DIFSEL bit 6 */
#define ADC_DIFSEL_DIFSEL_7  ((uint32_t)0x00000080) /*!< ADC DIFSEL bit 7 */
#define ADC_DIFSEL_DIFSEL_8  ((uint32_t)0x00000100) /*!< ADC DIFSEL bit 8 */
#define ADC_DIFSEL_DIFSEL_9  ((uint32_t)0x00000200) /*!< ADC DIFSEL bit 9 */
#define ADC_DIFSEL_DIFSEL_10 ((uint32_t)0x00000400) /*!< ADC DIFSEL bit 10 */
#define ADC_DIFSEL_DIFSEL_11 ((uint32_t)0x00000800) /*!< ADC DIFSEL bit 11 */
#define ADC_DIFSEL_DIFSEL_12 ((uint32_t)0x00001000) /*!< ADC DIFSEL bit 12 */
#define ADC_DIFSEL_DIFSEL_13 ((uint32_t)0x00002000) /*!< ADC DIFSEL bit 13 */
#define ADC_DIFSEL_DIFSEL_14 ((uint32_t)0x00004000) /*!< ADC DIFSEL bit 14 */
#define ADC_DIFSEL_DIFSEL_15 ((uint32_t)0x00008000) /*!< ADC DIFSEL bit 15 */
#define ADC_DIFSEL_DIFSEL_16 ((uint32_t)0x00010000) /*!< ADC DIFSEL bit 16 */
#define ADC_DIFSEL_DIFSEL_17 ((uint32_t)0x00020000) /*!< ADC DIFSEL bit 17 */
#define ADC_DIFSEL_DIFSEL_18 ((uint32_t)0x00040000) /*!< ADC DIFSEL bit 18 */
#define ADC_DIFSEL_DIFSEL_19 ((uint32_t)0x00080000) /*!< ADC DIFSEL bit 19 */

/********************  Bit definition for ADC_CALFACT register  ********************/
#define ADC_CALFACT_CALFACT_S    ((uint32_t)0x000007FF) /*!< ADC calibration factors in single-ended mode */
#define ADC_CALFACT_CALFACT_S_0  ((uint32_t)0x00000001) /*!< ADC CALFACT_S bit 0 */
#define ADC_CALFACT_CALFACT_S_1  ((uint32_t)0x00000002) /*!< ADC CALFACT_S bit 1 */
#define ADC_CALFACT_CALFACT_S_2  ((uint32_t)0x00000004) /*!< ADC CALFACT_S bit 2 */
#define ADC_CALFACT_CALFACT_S_3  ((uint32_t)0x00000008) /*!< ADC CALFACT_S bit 3 */
#define ADC_CALFACT_CALFACT_S_4  ((uint32_t)0x00000010) /*!< ADC CALFACT_S bit 4 */
#define ADC_CALFACT_CALFACT_S_5  ((uint32_t)0x00000020) /*!< ADC CALFACT_S bit 5 */
#define ADC_CALFACT_CALFACT_S_6  ((uint32_t)0x00000040) /*!< ADC CALFACT_S bit 6 */
#define ADC_CALFACT_CALFACT_S_7  ((uint32_t)0x00000080) /*!< ADC CALFACT_S bit 7 */
#define ADC_CALFACT_CALFACT_S_8  ((uint32_t)0x00000100) /*!< ADC CALFACT_S bit 8 */
#define ADC_CALFACT_CALFACT_S_9  ((uint32_t)0x00000200) /*!< ADC CALFACT_S bit 9 */
#define ADC_CALFACT_CALFACT_S_10 ((uint32_t)0x00000400) /*!< ADC CALFACT_S bit 10 */
#define ADC_CALFACT_CALFACT_D    ((uint32_t)0x07FF0000) /*!< ADC calibration factors in differential mode */
#define ADC_CALFACT_CALFACT_D_0  ((uint32_t)0x00010000) /*!< ADC CALFACT_D bit 0 */
#define ADC_CALFACT_CALFACT_D_1  ((uint32_t)0x00020000) /*!< ADC CALFACT_D bit 1 */
#define ADC_CALFACT_CALFACT_D_2  ((uint32_t)0x00040000) /*!< ADC CALFACT_D bit 2 */
#define ADC_CALFACT_CALFACT_D_3  ((uint32_t)0x00080000) /*!< ADC CALFACT_D bit 3 */
#define ADC_CALFACT_CALFACT_D_4  ((uint32_t)0x00100000) /*!< ADC CALFACT_D bit 4 */
#define ADC_CALFACT_CALFACT_D_5  ((uint32_t)0x00200000) /*!< ADC CALFACT_D bit 5 */
#define ADC_CALFACT_CALFACT_D_6  ((uint32_t)0x00400000) /*!< ADC CALFACT_D bit 6 */
#define ADC_CALFACT_CALFACT_D_7  ((uint32_t)0x00800000) /*!< ADC CALFACT_D bit 7 */
#define ADC_CALFACT_CALFACT_D_8  ((uint32_t)0x01000000) /*!< ADC CALFACT_D bit 8 */
#define ADC_CALFACT_CALFACT_D_9  ((uint32_t)0x02000000) /*!< ADC CALFACT_D bit 9 */
#define ADC_CALFACT_CALFACT_D_10 ((uint32_t)0x04000000) /*!< ADC CALFACT_D bit 10 */

/********************  Bit definition for ADC_CALFACT2 register  ********************/
#define ADC_CALFACT2_LINCALFACT       ((uint32_t)0x3FFFFFFF) /*!< ADC Linearity calibration factors */
#define ADC_CALFACT2_LINCALFACT_0     ((uint32_t)0x00000001) /*!< ADC Linearity calibration factors  bit 0 */
#define ADC_CALFACT2_LINCALFACT_1     ((uint32_t)0x00000002) /*!< ADC Linearity calibration factors  bit 1 */
#define ADC_CALFACT2_LINCALFACT_2     ((uint32_t)0x00000004) /*!< ADC Linearity calibration factors  bit 2 */
#define ADC_CALFACT2_LINCALFACT_3     ((uint32_t)0x00000008) /*!< ADC Linearity calibration factors  bit 3 */
#define ADC_CALFACT2_LINCALFACT_4     ((uint32_t)0x00000010) /*!< ADC Linearity calibration factors  bit 4 */
#define ADC_CALFACT2_LINCALFACT_5     ((uint32_t)0x00000020) /*!< ADC Linearity calibration factors  bit 5 */
#define ADC_CALFACT2_LINCALFACT_6     ((uint32_t)0x00000040) /*!< ADC Linearity calibration factors  bit 6 */
#define ADC_CALFACT2_LINCALFACT_7     ((uint32_t)0x00000080) /*!< ADC Linearity calibration factors  bit 7 */
#define ADC_CALFACT2_LINCALFACT_8     ((uint32_t)0x00000100) /*!< ADC Linearity calibration factors  bit 8 */
#define ADC_CALFACT2_LINCALFACT_9     ((uint32_t)0x00000200) /*!< ADC Linearity calibration factors  bit 9 */
#define ADC_CALFACT2_LINCALFACT_10    ((uint32_t)0x00000400) /*!< ADC Linearity calibration factors  bit 10 */
#define ADC_CALFACT2_LINCALFACT_11    ((uint32_t)0x00000800) /*!< ADC Linearity calibration factors  bit 11 */
#define ADC_CALFACT2_LINCALFACT_12    ((uint32_t)0x00001000) /*!< ADC Linearity calibration factors  bit 12 */
#define ADC_CALFACT2_LINCALFACT_13    ((uint32_t)0x00002000) /*!< ADC Linearity calibration factors  bit 13 */
#define ADC_CALFACT2_LINCALFACT_14    ((uint32_t)0x00004000) /*!< ADC Linearity calibration factors  bit 14 */
#define ADC_CALFACT2_LINCALFACT_15    ((uint32_t)0x00008000) /*!< ADC Linearity calibration factors  bit 15 */
#define ADC_CALFACT2_LINCALFACT_16    ((uint32_t)0x00010000) /*!< ADC Linearity calibration factors  bit 16 */
#define ADC_CALFACT2_LINCALFACT_17    ((uint32_t)0x00020000) /*!< ADC Linearity calibration factors  bit 17 */
#define ADC_CALFACT2_LINCALFACT_18    ((uint32_t)0x00040000) /*!< ADC Linearity calibration factors  bit 18 */
#define ADC_CALFACT2_LINCALFACT_19    ((uint32_t)0x00080000) /*!< ADC Linearity calibration factors  bit 19 */
#define ADC_CALFACT2_LINCALFACT_20    ((uint32_t)0x00100000) /*!< ADC Linearity calibration factors  bit 20 */
#define ADC_CALFACT2_LINCALFACT_21    ((uint32_t)0x00200000) /*!< ADC Linearity calibration factors  bit 21 */
#define ADC_CALFACT2_LINCALFACT_22    ((uint32_t)0x00400000) /*!< ADC Linearity calibration factors  bit 22 */
#define ADC_CALFACT2_LINCALFACT_23    ((uint32_t)0x00800000) /*!< ADC Linearity calibration factors  bit 23 */
#define ADC_CALFACT2_LINCALFACT_24    ((uint32_t)0x01000000) /*!< ADC Linearity calibration factors  bit 24 */
#define ADC_CALFACT2_LINCALFACT_25    ((uint32_t)0x02000000) /*!< ADC Linearity calibration factors  bit 25 */
#define ADC_CALFACT2_LINCALFACT_26    ((uint32_t)0x04000000) /*!< ADC Linearity calibration factors  bit 26 */
#define ADC_CALFACT2_LINCALFACT_27    ((uint32_t)0x08000001) /*!< ADC Linearity calibration factors  bit 27 */
#define ADC_CALFACT2_LINCALFACT_28    ((uint32_t)0x10000000) /*!< ADC Linearity calibration factors  bit 28 */
#define ADC_CALFACT2_LINCALFACT_29    ((uint32_t)0x20000000) /*!< ADC Linearity calibration factors  bit 29 */

/*************************  ADC Common registers  *****************************/
/********************  Bit definition for ADC_CSR register  ********************/
#define ADC123_CSR_ADRDY_MST         ((uint32_t)0x00000001) /*!< Master ADC ready */
#define ADC123_CSR_ADRDY_EOSMP_MST   ((uint32_t)0x00000002) /*!< End of sampling phase flag of the master ADC */
#define ADC123_CSR_ADRDY_EOC_MST     ((uint32_t)0x00000004) /*!< End of regular conversion of the master ADC */
#define ADC123_CSR_ADRDY_EOS_MST     ((uint32_t)0x00000008) /*!< End of regular sequence flag of the master ADC */
#define ADC123_CSR_ADRDY_OVR_MST     ((uint32_t)0x00000010) /*!< Overrun flag of the master ADC */
#define ADC123_CSR_ADRDY_JEOC_MST    ((uint32_t)0x00000020) /*!< End of injected conversion of the master ADC */
#define ADC123_CSR_ADRDY_JEOS_MST    ((uint32_t)0x00000040) /*!< End of injected sequence flag of the master ADC */
#define ADC123_CSR_AWD1_MST          ((uint32_t)0x00000080) /*!< Analog watchdog 1 flag of the master ADC */
#define ADC123_CSR_AWD2_MST          ((uint32_t)0x00000100) /*!< Analog watchdog 2 flag of the master ADC */
#define ADC123_CSR_AWD3_MST          ((uint32_t)0x00000200) /*!< Analog watchdog 3 flag of the master ADC */
#define ADC123_CSR_JQOVF_MST         ((uint32_t)0x00000400) /*!< Injected context queue overflow flag of the master ADC */
#define ADC123_CSR_ADRDY_SLV         ((uint32_t)0x00010000) /*!< Slave ADC ready */
#define ADC123_CSR_ADRDY_EOSMP_SLV   ((uint32_t)0x00020000) /*!< End of sampling phase flag of the slave ADC */
#define ADC123_CSR_ADRDY_EOC_SLV     ((uint32_t)0x00040000) /*!< End of regular conversion of the slave ADC */
#define ADC123_CSR_ADRDY_EOS_SLV     ((uint32_t)0x00080000) /*!< End of regular sequence flag of the slave ADC */
#define ADC123_CSR_ADRDY_OVR_SLV     ((uint32_t)0x00100000) /*!< Overrun flag of the slave ADC */
#define ADC123_CSR_ADRDY_JEOC_SLV    ((uint32_t)0x00200000) /*!< End of injected conversion of the slave ADC */
#define ADC123_CSR_ADRDY_JEOS_SLV    ((uint32_t)0x00400000) /*!< End of injected sequence flag of the slave ADC */
#define ADC123_CSR_AWD1_SLV          ((uint32_t)0x00800000) /*!< Analog watchdog 1 flag of the slave ADC */
#define ADC123_CSR_AWD2_SLV          ((uint32_t)0x01000000) /*!< Analog watchdog 2 flag of the slave ADC */
#define ADC123_CSR_AWD3_SLV          ((uint32_t)0x02000000) /*!< Analog watchdog 3 flag of the slave ADC */
#define ADC123_CSR_JQOVF_SLV         ((uint32_t)0x04000000) /*!< Injected context queue overflow flag of the slave ADC */

/********************  Bit definition for ADC_CCR register  ********************/
#define ADC_CCR_DUAL             ((uint32_t)0x0000001F) /*!< Dual ADC mode selection */
#define ADC_CCR_DUAL_0           ((uint32_t)0x00000001) /*!< Dual bit 0 */
#define ADC_CCR_DUAL_1           ((uint32_t)0x00000002) /*!< Dual bit 1 */
#define ADC_CCR_DUAL_2           ((uint32_t)0x00000004) /*!< Dual bit 2 */
#define ADC_CCR_DUAL_3           ((uint32_t)0x00000008) /*!< Dual bit 3 */
#define ADC_CCR_DUAL_4           ((uint32_t)0x00000010) /*!< Dual bit 4 */

#define ADC_CCR_DELAY             ((uint32_t)0x00000F00) /*!< Delay between 2 sampling phases */
#define ADC_CCR_DELAY_0           ((uint32_t)0x00000100) /*!< DELAY bit 0 */
#define ADC_CCR_DELAY_1           ((uint32_t)0x00000200) /*!< DELAY bit 1 */
#define ADC_CCR_DELAY_2           ((uint32_t)0x00000400) /*!< DELAY bit 2 */
#define ADC_CCR_DELAY_3           ((uint32_t)0x00000800) /*!< DELAY bit 3 */


#define ADC_CCR_DMADF             ((uint32_t)0x0000C000) /*!< Dual ADC mode Data format */
#define ADC_CCR_DMADF_0           ((uint32_t)0x00004000) /*!< Dual ADC mode Data format Bit 0*/
#define ADC_CCR_DMADF_1           ((uint32_t)0x00008000) /*!< Dual ADC mode Data format Bit 1 */

#define ADC_CCR_CKMODE            ((uint32_t)0x00030000) /*!< ADC clock mode */
#define ADC_CCR_CKMODE_0          ((uint32_t)0x00010000) /*!< CKMODE bit 0 */
#define ADC_CCR_CKMODE_1          ((uint32_t)0x00020000) /*!< CKMODE bit 1 */

#define ADC_CCR_PRESC             ((uint32_t)0x003C0000) /*!< ADC prescaler */
#define ADC_CCR_PRESC_0           ((uint32_t)0x00040000) /*!< ADC prescaler bit 0 */
#define ADC_CCR_PRESC_1           ((uint32_t)0x00080000) /*!< ADC prescaler bit 1 */
#define ADC_CCR_PRESC_2           ((uint32_t)0x00100000) /*!< ADC prescaler bit 2 */
#define ADC_CCR_PRESC_3           ((uint32_t)0x00200000) /*!< ADC prescaler bit 3 */

#define ADC_CCR_VREFEN            ((uint32_t)0x00400000) /*!< VREFINT enable */
#define ADC_CCR_TSEN              ((uint32_t)0x00800000) /*!< Temperature sensor enable */
#define ADC_CCR_VBATEN            ((uint32_t)0x01000000) /*!< VBAT enable */

/********************  Bit definition for ADC_CDR register  ********************/
#define ADC123_CDR_RDATA_MST         ((uint32_t)0x0000FFFF) /*!< Regular Data of the master ADC */
#define ADC123_CDR_RDATA_MST_0       ((uint32_t)0x00000001) /*!< RDATA_MST bit 0 */
#define ADC123_CDR_RDATA_MST_1       ((uint32_t)0x00000002) /*!< RDATA_MST bit 1 */
#define ADC123_CDR_RDATA_MST_2       ((uint32_t)0x00000004) /*!< RDATA_MST bit 2 */
#define ADC123_CDR_RDATA_MST_3       ((uint32_t)0x00000008) /*!< RDATA_MST bit 3 */
#define ADC123_CDR_RDATA_MST_4       ((uint32_t)0x00000010) /*!< RDATA_MST bit 4 */
#define ADC123_CDR_RDATA_MST_5       ((uint32_t)0x00000020) /*!< RDATA_MST bit 5 */
#define ADC123_CDR_RDATA_MST_6       ((uint32_t)0x00000040) /*!< RDATA_MST bit 6 */
#define ADC123_CDR_RDATA_MST_7       ((uint32_t)0x00000080) /*!< RDATA_MST bit 7 */
#define ADC123_CDR_RDATA_MST_8       ((uint32_t)0x00000100) /*!< RDATA_MST bit 8 */
#define ADC123_CDR_RDATA_MST_9       ((uint32_t)0x00000200) /*!< RDATA_MST bit 9 */
#define ADC123_CDR_RDATA_MST_10      ((uint32_t)0x00000400) /*!< RDATA_MST bit 10 */
#define ADC123_CDR_RDATA_MST_11      ((uint32_t)0x00000800) /*!< RDATA_MST bit 11 */
#define ADC123_CDR_RDATA_MST_12      ((uint32_t)0x00001000) /*!< RDATA_MST bit 12 */
#define ADC123_CDR_RDATA_MST_13      ((uint32_t)0x00002000) /*!< RDATA_MST bit 13 */
#define ADC123_CDR_RDATA_MST_14      ((uint32_t)0x00004000) /*!< RDATA_MST bit 14 */
#define ADC123_CDR_RDATA_MST_15      ((uint32_t)0x00008000) /*!< RDATA_MST bit 15 */

#define ADC123_CDR_RDATA_SLV         ((uint32_t)0xFFFF0000) /*!< Regular Data of the master ADC */
#define ADC123_CDR_RDATA_SLV_0       ((uint32_t)0x00010000) /*!< RDATA_SLV bit 0 */
#define ADC123_CDR_RDATA_SLV_1       ((uint32_t)0x00020000) /*!< RDATA_SLV bit 1 */
#define ADC123_CDR_RDATA_SLV_2       ((uint32_t)0x00040000) /*!< RDATA_SLV bit 2 */
#define ADC123_CDR_RDATA_SLV_3       ((uint32_t)0x00080000) /*!< RDATA_SLV bit 3 */
#define ADC123_CDR_RDATA_SLV_4       ((uint32_t)0x00100000) /*!< RDATA_SLV bit 4 */
#define ADC123_CDR_RDATA_SLV_5       ((uint32_t)0x00200000) /*!< RDATA_SLV bit 5 */
#define ADC123_CDR_RDATA_SLV_6       ((uint32_t)0x00400000) /*!< RDATA_SLV bit 6 */
#define ADC123_CDR_RDATA_SLV_7       ((uint32_t)0x00800000) /*!< RDATA_SLV bit 7 */
#define ADC123_CDR_RDATA_SLV_8       ((uint32_t)0x01000000) /*!< RDATA_SLV bit 8 */
#define ADC123_CDR_RDATA_SLV_9       ((uint32_t)0x02000000) /*!< RDATA_SLV bit 9 */
#define ADC123_CDR_RDATA_SLV_10      ((uint32_t)0x04000000) /*!< RDATA_SLV bit 10 */
#define ADC123_CDR_RDATA_SLV_11      ((uint32_t)0x08000000) /*!< RDATA_SLV bit 11 */
#define ADC123_CDR_RDATA_SLV_12      ((uint32_t)0x10000000) /*!< RDATA_SLV bit 12 */
#define ADC123_CDR_RDATA_SLV_13      ((uint32_t)0x20000000) /*!< RDATA_SLV bit 13 */
#define ADC123_CDR_RDATA_SLV_14      ((uint32_t)0x40000000) /*!< RDATA_SLV bit 14 */
#define ADC123_CDR_RDATA_SLV_15      ((uint32_t)0x80000000) /*!< RDATA_SLV bit 15 */

/********************  Bit definition for ADC_CDR2 register  ********************/
#define ADC123_CDR2_RDATA_ALT         ((uint32_t)0xFFFFFFFF) /*!< Regular Data for dual Mode */
#define ADC123_CDR2_RDATA_ALT_0       ((uint32_t)0x00000001) /*!< RDATA_ALT bit 0 */
#define ADC123_CDR2_RDATA_ALT_1       ((uint32_t)0x00000002) /*!< RDATA_ALT bit 1 */
#define ADC123_CDR2_RDATA_ALT_2       ((uint32_t)0x00000004) /*!< RDATA_ALT bit 2 */
#define ADC123_CDR2_RDATA_ALT_3       ((uint32_t)0x00000008) /*!< RDATA_ALT bit 3 */
#define ADC123_CDR2_RDATA_ALT_4       ((uint32_t)0x00000010) /*!< RDATA_ALT bit 4 */
#define ADC123_CDR2_RDATA_ALT_5       ((uint32_t)0x00000020) /*!< RDATA_ALT bit 5 */
#define ADC123_CDR2_RDATA_ALT_6       ((uint32_t)0x00000040) /*!< RDATA_ALT bit 6 */
#define ADC123_CDR2_RDATA_ALT_7       ((uint32_t)0x00000080) /*!< RDATA_ALT bit 7 */
#define ADC123_CDR2_RDATA_ALT_8       ((uint32_t)0x00000100) /*!< RDATA_ALT bit 8 */
#define ADC123_CDR2_RDATA_ALT_9       ((uint32_t)0x00000200) /*!< RDATA_ALT bit 9 */
#define ADC123_CDR2_RDATA_ALT_10      ((uint32_t)0x00000400) /*!< RDATA_ALT bit 10 */
#define ADC123_CDR2_RDATA_ALT_11      ((uint32_t)0x00000800) /*!< RDATA_ALT bit 11 */
#define ADC123_CDR2_RDATA_ALT_12      ((uint32_t)0x00001000) /*!< RDATA_ALT bit 12 */
#define ADC123_CDR2_RDATA_ALT_13      ((uint32_t)0x00002000) /*!< RDATA_ALT bit 13 */
#define ADC123_CDR2_RDATA_ALT_14      ((uint32_t)0x00004000) /*!< RDATA_ALT bit 14 */
#define ADC123_CDR2_RDATA_ALT_15      ((uint32_t)0x00008000) /*!< RDATA_ALT bit 15 */
#define ADC123_CDR2_RDATA_ALT_16      ((uint32_t)0x00010000) /*!< RDATA_ALT bit 16 */
#define ADC123_CDR2_RDATA_ALT_17      ((uint32_t)0x00020000) /*!< RDATA_ALT bit 17 */
#define ADC123_CDR2_RDATA_ALT_18      ((uint32_t)0x00040000) /*!< RDATA_ALT bit 18 */
#define ADC123_CDR2_RDATA_ALT_19      ((uint32_t)0x00080000) /*!< RDATA_ALT bit 19 */
#define ADC123_CDR2_RDATA_ALT_20      ((uint32_t)0x00100000) /*!< RDATA_ALT bit 20 */
#define ADC123_CDR2_RDATA_ALT_21      ((uint32_t)0x00200000) /*!< RDATA_ALT bit 21 */
#define ADC123_CDR2_RDATA_ALT_22      ((uint32_t)0x00400000) /*!< RDATA_ALT bit 22 */
#define ADC123_CDR2_RDATA_ALT_23      ((uint32_t)0x00800000) /*!< RDATA_ALT bit 23 */
#define ADC123_CDR2_RDATA_ALT_24      ((uint32_t)0x01000000) /*!< RDATA_ALT bit 24 */
#define ADC123_CDR2_RDATA_ALT_25      ((uint32_t)0x02000000) /*!< RDATA_ALT bit 25 */
#define ADC123_CDR2_RDATA_ALT_26      ((uint32_t)0x04000000) /*!< RDATA_ALT bit 26 */
#define ADC123_CDR2_RDATA_ALT_27      ((uint32_t)0x08000000) /*!< RDATA_ALT bit 27 */
#define ADC123_CDR2_RDATA_ALT_28      ((uint32_t)0x10000000) /*!< RDATA_ALT bit 28 */
#define ADC123_CDR2_RDATA_ALT_29      ((uint32_t)0x20000000) /*!< RDATA_ALT bit 29 */
#define ADC123_CDR2_RDATA_ALT_30      ((uint32_t)0x40000000) /*!< RDATA_ALT bit 30 */
#define ADC123_CDR2_RDATA_ALT_31      ((uint32_t)0x80000000) /*!< RDATA_ALT bit 31 */

/******************************************************************************/
/*                                                                            */
/*                         Controller Area Network                            */
/*                                                                            */
/******************************************************************************/
/*!<CAN control and status registers */
/*******************  Bit definition for CAN_MCR register  ********************/
#define  CAN_MCR_INRQ                        ((uint16_t)0x0001)            /*!<Initialization Request */
#define  CAN_MCR_SLEEP                       ((uint16_t)0x0002)            /*!<Sleep Mode Request */
#define  CAN_MCR_TXFP                        ((uint16_t)0x0004)            /*!<Transmit FIFO Priority */
#define  CAN_MCR_RFLM                        ((uint16_t)0x0008)            /*!<Receive FIFO Locked Mode */
#define  CAN_MCR_NART                        ((uint16_t)0x0010)            /*!<No Automatic Retransmission */
#define  CAN_MCR_AWUM                        ((uint16_t)0x0020)            /*!<Automatic Wakeup Mode */
#define  CAN_MCR_ABOM                        ((uint16_t)0x0040)            /*!<Automatic Bus-Off Management */
#define  CAN_MCR_TTCM                        ((uint16_t)0x0080)            /*!<Time Triggered Communication Mode */
#define  CAN_MCR_RESET                       ((uint16_t)0x8000)            /*!<bxCAN software master reset */

/*******************  Bit definition for CAN_MSR register  ********************/
#define  CAN_MSR_INAK                        ((uint16_t)0x0001)            /*!<Initialization Acknowledge */
#define  CAN_MSR_SLAK                        ((uint16_t)0x0002)            /*!<Sleep Acknowledge */
#define  CAN_MSR_ERRI                        ((uint16_t)0x0004)            /*!<Error Interrupt */
#define  CAN_MSR_WKUI                        ((uint16_t)0x0008)            /*!<Wakeup Interrupt */
#define  CAN_MSR_SLAKI                       ((uint16_t)0x0010)            /*!<Sleep Acknowledge Interrupt */
#define  CAN_MSR_TXM                         ((uint16_t)0x0100)            /*!<Transmit Mode */
#define  CAN_MSR_RXM                         ((uint16_t)0x0200)            /*!<Receive Mode */
#define  CAN_MSR_SAMP                        ((uint16_t)0x0400)            /*!<Last Sample Point */
#define  CAN_MSR_RX                          ((uint16_t)0x0800)            /*!<CAN Rx Signal */

/*******************  Bit definition for CAN_TSR register  ********************/
#define  CAN_TSR_RQCP0                       ((uint32_t)0x00000001)        /*!<Request Completed Mailbox0 */
#define  CAN_TSR_TXOK0                       ((uint32_t)0x00000002)        /*!<Transmission OK of Mailbox0 */
#define  CAN_TSR_ALST0                       ((uint32_t)0x00000004)        /*!<Arbitration Lost for Mailbox0 */
#define  CAN_TSR_TERR0                       ((uint32_t)0x00000008)        /*!<Transmission Error of Mailbox0 */
#define  CAN_TSR_ABRQ0                       ((uint32_t)0x00000080)        /*!<Abort Request for Mailbox0 */
#define  CAN_TSR_RQCP1                       ((uint32_t)0x00000100)        /*!<Request Completed Mailbox1 */
#define  CAN_TSR_TXOK1                       ((uint32_t)0x00000200)        /*!<Transmission OK of Mailbox1 */
#define  CAN_TSR_ALST1                       ((uint32_t)0x00000400)        /*!<Arbitration Lost for Mailbox1 */
#define  CAN_TSR_TERR1                       ((uint32_t)0x00000800)        /*!<Transmission Error of Mailbox1 */
#define  CAN_TSR_ABRQ1                       ((uint32_t)0x00008000)        /*!<Abort Request for Mailbox 1 */
#define  CAN_TSR_RQCP2                       ((uint32_t)0x00010000)        /*!<Request Completed Mailbox2 */
#define  CAN_TSR_TXOK2                       ((uint32_t)0x00020000)        /*!<Transmission OK of Mailbox 2 */
#define  CAN_TSR_ALST2                       ((uint32_t)0x00040000)        /*!<Arbitration Lost for mailbox 2 */
#define  CAN_TSR_TERR2                       ((uint32_t)0x00080000)        /*!<Transmission Error of Mailbox 2 */
#define  CAN_TSR_ABRQ2                       ((uint32_t)0x00800000)        /*!<Abort Request for Mailbox 2 */
#define  CAN_TSR_CODE                        ((uint32_t)0x03000000)        /*!<Mailbox Code */

#define  CAN_TSR_TME                         ((uint32_t)0x1C000000)        /*!<TME[2:0] bits */
#define  CAN_TSR_TME0                        ((uint32_t)0x04000000)        /*!<Transmit Mailbox 0 Empty */
#define  CAN_TSR_TME1                        ((uint32_t)0x08000000)        /*!<Transmit Mailbox 1 Empty */
#define  CAN_TSR_TME2                        ((uint32_t)0x10000000)        /*!<Transmit Mailbox 2 Empty */

#define  CAN_TSR_LOW                         ((uint32_t)0xE0000000)        /*!<LOW[2:0] bits */
#define  CAN_TSR_LOW0                        ((uint32_t)0x20000000)        /*!<Lowest Priority Flag for Mailbox 0 */
#define  CAN_TSR_LOW1                        ((uint32_t)0x40000000)        /*!<Lowest Priority Flag for Mailbox 1 */
#define  CAN_TSR_LOW2                        ((uint32_t)0x80000000)        /*!<Lowest Priority Flag for Mailbox 2 */

/*******************  Bit definition for CAN_RF0R register  *******************/
#define  CAN_RF0R_FMP0                       ((uint8_t)0x03)               /*!<FIFO 0 Message Pending */
#define  CAN_RF0R_FULL0                      ((uint8_t)0x08)               /*!<FIFO 0 Full */
#define  CAN_RF0R_FOVR0                      ((uint8_t)0x10)               /*!<FIFO 0 Overrun */
#define  CAN_RF0R_RFOM0                      ((uint8_t)0x20)               /*!<Release FIFO 0 Output Mailbox */

/*******************  Bit definition for CAN_RF1R register  *******************/
#define  CAN_RF1R_FMP1                       ((uint8_t)0x03)               /*!<FIFO 1 Message Pending */
#define  CAN_RF1R_FULL1                      ((uint8_t)0x08)               /*!<FIFO 1 Full */
#define  CAN_RF1R_FOVR1                      ((uint8_t)0x10)               /*!<FIFO 1 Overrun */
#define  CAN_RF1R_RFOM1                      ((uint8_t)0x20)               /*!<Release FIFO 1 Output Mailbox */

/********************  Bit definition for CAN_IER register  *******************/
#define  CAN_IER_TMEIE                       ((uint32_t)0x00000001)        /*!<Transmit Mailbox Empty Interrupt Enable */
#define  CAN_IER_FMPIE0                      ((uint32_t)0x00000002)        /*!<FIFO Message Pending Interrupt Enable */
#define  CAN_IER_FFIE0                       ((uint32_t)0x00000004)        /*!<FIFO Full Interrupt Enable */
#define  CAN_IER_FOVIE0                      ((uint32_t)0x00000008)        /*!<FIFO Overrun Interrupt Enable */
#define  CAN_IER_FMPIE1                      ((uint32_t)0x00000010)        /*!<FIFO Message Pending Interrupt Enable */
#define  CAN_IER_FFIE1                       ((uint32_t)0x00000020)        /*!<FIFO Full Interrupt Enable */
#define  CAN_IER_FOVIE1                      ((uint32_t)0x00000040)        /*!<FIFO Overrun Interrupt Enable */
#define  CAN_IER_EWGIE                       ((uint32_t)0x00000100)        /*!<Error Warning Interrupt Enable */
#define  CAN_IER_EPVIE                       ((uint32_t)0x00000200)        /*!<Error Passive Interrupt Enable */
#define  CAN_IER_BOFIE                       ((uint32_t)0x00000400)        /*!<Bus-Off Interrupt Enable */
#define  CAN_IER_LECIE                       ((uint32_t)0x00000800)        /*!<Last Error Code Interrupt Enable */
#define  CAN_IER_ERRIE                       ((uint32_t)0x00008000)        /*!<Error Interrupt Enable */
#define  CAN_IER_WKUIE                       ((uint32_t)0x00010000)        /*!<Wakeup Interrupt Enable */
#define  CAN_IER_SLKIE                       ((uint32_t)0x00020000)        /*!<Sleep Interrupt Enable */

/********************  Bit definition for CAN_ESR register  *******************/
#define  CAN_ESR_EWGF                        ((uint32_t)0x00000001)        /*!<Error Warning Flag */
#define  CAN_ESR_EPVF                        ((uint32_t)0x00000002)        /*!<Error Passive Flag */
#define  CAN_ESR_BOFF                        ((uint32_t)0x00000004)        /*!<Bus-Off Flag */

#define  CAN_ESR_LEC                         ((uint32_t)0x00000070)        /*!<LEC[2:0] bits (Last Error Code) */
#define  CAN_ESR_LEC_0                       ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  CAN_ESR_LEC_1                       ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  CAN_ESR_LEC_2                       ((uint32_t)0x00000040)        /*!<Bit 2 */

#define  CAN_ESR_TEC                         ((uint32_t)0x00FF0000)        /*!<Least significant byte of the 9-bit Transmit Error Counter */
#define  CAN_ESR_REC                         ((uint32_t)0xFF000000)        /*!<Receive Error Counter */

/*******************  Bit definition for CAN_BTR register  ********************/
#define  CAN_BTR_BRP                         ((uint32_t)0x000003FF)        /*!<Baud Rate Prescaler */
#define  CAN_BTR_TS1                         ((uint32_t)0x000F0000)        /*!<Time Segment 1 */
#define  CAN_BTR_TS2                         ((uint32_t)0x00700000)        /*!<Time Segment 2 */
#define  CAN_BTR_SJW                         ((uint32_t)0x03000000)        /*!<Resynchronization Jump Width */
#define  CAN_BTR_LBKM                        ((uint32_t)0x40000000)        /*!<Loop Back Mode (Debug) */
#define  CAN_BTR_SILM                        ((uint32_t)0x80000000)        /*!<Silent Mode */

/*!<Mailbox registers */
/******************  Bit definition for CAN_TI0R register  ********************/
#define  CAN_TI0R_TXRQ                       ((uint32_t)0x00000001)        /*!<Transmit Mailbox Request */
#define  CAN_TI0R_RTR                        ((uint32_t)0x00000002)        /*!<Remote Transmission Request */
#define  CAN_TI0R_IDE                        ((uint32_t)0x00000004)        /*!<Identifier Extension */
#define  CAN_TI0R_EXID                       ((uint32_t)0x001FFFF8)        /*!<Extended Identifier */
#define  CAN_TI0R_STID                       ((uint32_t)0xFFE00000)        /*!<Standard Identifier or Extended Identifier */

/******************  Bit definition for CAN_TDT0R register  *******************/
#define  CAN_TDT0R_DLC                       ((uint32_t)0x0000000F)        /*!<Data Length Code */
#define  CAN_TDT0R_TGT                       ((uint32_t)0x00000100)        /*!<Transmit Global Time */
#define  CAN_TDT0R_TIME                      ((uint32_t)0xFFFF0000)        /*!<Message Time Stamp */

/******************  Bit definition for CAN_TDL0R register  *******************/
#define  CAN_TDL0R_DATA0                     ((uint32_t)0x000000FF)        /*!<Data byte 0 */
#define  CAN_TDL0R_DATA1                     ((uint32_t)0x0000FF00)        /*!<Data byte 1 */
#define  CAN_TDL0R_DATA2                     ((uint32_t)0x00FF0000)        /*!<Data byte 2 */
#define  CAN_TDL0R_DATA3                     ((uint32_t)0xFF000000)        /*!<Data byte 3 */

/******************  Bit definition for CAN_TDH0R register  *******************/
#define  CAN_TDH0R_DATA4                     ((uint32_t)0x000000FF)        /*!<Data byte 4 */
#define  CAN_TDH0R_DATA5                     ((uint32_t)0x0000FF00)        /*!<Data byte 5 */
#define  CAN_TDH0R_DATA6                     ((uint32_t)0x00FF0000)        /*!<Data byte 6 */
#define  CAN_TDH0R_DATA7                     ((uint32_t)0xFF000000)        /*!<Data byte 7 */

/*******************  Bit definition for CAN_TI1R register  *******************/
#define  CAN_TI1R_TXRQ                       ((uint32_t)0x00000001)        /*!<Transmit Mailbox Request */
#define  CAN_TI1R_RTR                        ((uint32_t)0x00000002)        /*!<Remote Transmission Request */
#define  CAN_TI1R_IDE                        ((uint32_t)0x00000004)        /*!<Identifier Extension */
#define  CAN_TI1R_EXID                       ((uint32_t)0x001FFFF8)        /*!<Extended Identifier */
#define  CAN_TI1R_STID                       ((uint32_t)0xFFE00000)        /*!<Standard Identifier or Extended Identifier */

/*******************  Bit definition for CAN_TDT1R register  ******************/
#define  CAN_TDT1R_DLC                       ((uint32_t)0x0000000F)        /*!<Data Length Code */
#define  CAN_TDT1R_TGT                       ((uint32_t)0x00000100)        /*!<Transmit Global Time */
#define  CAN_TDT1R_TIME                      ((uint32_t)0xFFFF0000)        /*!<Message Time Stamp */

/*******************  Bit definition for CAN_TDL1R register  ******************/
#define  CAN_TDL1R_DATA0                     ((uint32_t)0x000000FF)        /*!<Data byte 0 */
#define  CAN_TDL1R_DATA1                     ((uint32_t)0x0000FF00)        /*!<Data byte 1 */
#define  CAN_TDL1R_DATA2                     ((uint32_t)0x00FF0000)        /*!<Data byte 2 */
#define  CAN_TDL1R_DATA3                     ((uint32_t)0xFF000000)        /*!<Data byte 3 */

/*******************  Bit definition for CAN_TDH1R register  ******************/
#define  CAN_TDH1R_DATA4                     ((uint32_t)0x000000FF)        /*!<Data byte 4 */
#define  CAN_TDH1R_DATA5                     ((uint32_t)0x0000FF00)        /*!<Data byte 5 */
#define  CAN_TDH1R_DATA6                     ((uint32_t)0x00FF0000)        /*!<Data byte 6 */
#define  CAN_TDH1R_DATA7                     ((uint32_t)0xFF000000)        /*!<Data byte 7 */

/*******************  Bit definition for CAN_TI2R register  *******************/
#define  CAN_TI2R_TXRQ                       ((uint32_t)0x00000001)        /*!<Transmit Mailbox Request */
#define  CAN_TI2R_RTR                        ((uint32_t)0x00000002)        /*!<Remote Transmission Request */
#define  CAN_TI2R_IDE                        ((uint32_t)0x00000004)        /*!<Identifier Extension */
#define  CAN_TI2R_EXID                       ((uint32_t)0x001FFFF8)        /*!<Extended identifier */
#define  CAN_TI2R_STID                       ((uint32_t)0xFFE00000)        /*!<Standard Identifier or Extended Identifier */

/*******************  Bit definition for CAN_TDT2R register  ******************/
#define  CAN_TDT2R_DLC                       ((uint32_t)0x0000000F)        /*!<Data Length Code */
#define  CAN_TDT2R_TGT                       ((uint32_t)0x00000100)        /*!<Transmit Global Time */
#define  CAN_TDT2R_TIME                      ((uint32_t)0xFFFF0000)        /*!<Message Time Stamp */

/*******************  Bit definition for CAN_TDL2R register  ******************/
#define  CAN_TDL2R_DATA0                     ((uint32_t)0x000000FF)        /*!<Data byte 0 */
#define  CAN_TDL2R_DATA1                     ((uint32_t)0x0000FF00)        /*!<Data byte 1 */
#define  CAN_TDL2R_DATA2                     ((uint32_t)0x00FF0000)        /*!<Data byte 2 */
#define  CAN_TDL2R_DATA3                     ((uint32_t)0xFF000000)        /*!<Data byte 3 */

/*******************  Bit definition for CAN_TDH2R register  ******************/
#define  CAN_TDH2R_DATA4                     ((uint32_t)0x000000FF)        /*!<Data byte 4 */
#define  CAN_TDH2R_DATA5                     ((uint32_t)0x0000FF00)        /*!<Data byte 5 */
#define  CAN_TDH2R_DATA6                     ((uint32_t)0x00FF0000)        /*!<Data byte 6 */
#define  CAN_TDH2R_DATA7                     ((uint32_t)0xFF000000)        /*!<Data byte 7 */

/*******************  Bit definition for CAN_RI0R register  *******************/
#define  CAN_RI0R_RTR                        ((uint32_t)0x00000002)        /*!<Remote Transmission Request */
#define  CAN_RI0R_IDE                        ((uint32_t)0x00000004)        /*!<Identifier Extension */
#define  CAN_RI0R_EXID                       ((uint32_t)0x001FFFF8)        /*!<Extended Identifier */
#define  CAN_RI0R_STID                       ((uint32_t)0xFFE00000)        /*!<Standard Identifier or Extended Identifier */

/*******************  Bit definition for CAN_RDT0R register  ******************/
#define  CAN_RDT0R_DLC                       ((uint32_t)0x0000000F)        /*!<Data Length Code */
#define  CAN_RDT0R_FMI                       ((uint32_t)0x0000FF00)        /*!<Filter Match Index */
#define  CAN_RDT0R_TIME                      ((uint32_t)0xFFFF0000)        /*!<Message Time Stamp */

/*******************  Bit definition for CAN_RDL0R register  ******************/
#define  CAN_RDL0R_DATA0                     ((uint32_t)0x000000FF)        /*!<Data byte 0 */
#define  CAN_RDL0R_DATA1                     ((uint32_t)0x0000FF00)        /*!<Data byte 1 */
#define  CAN_RDL0R_DATA2                     ((uint32_t)0x00FF0000)        /*!<Data byte 2 */
#define  CAN_RDL0R_DATA3                     ((uint32_t)0xFF000000)        /*!<Data byte 3 */

/*******************  Bit definition for CAN_RDH0R register  ******************/
#define  CAN_RDH0R_DATA4                     ((uint32_t)0x000000FF)        /*!<Data byte 4 */
#define  CAN_RDH0R_DATA5                     ((uint32_t)0x0000FF00)        /*!<Data byte 5 */
#define  CAN_RDH0R_DATA6                     ((uint32_t)0x00FF0000)        /*!<Data byte 6 */
#define  CAN_RDH0R_DATA7                     ((uint32_t)0xFF000000)        /*!<Data byte 7 */

/*******************  Bit definition for CAN_RI1R register  *******************/
#define  CAN_RI1R_RTR                        ((uint32_t)0x00000002)        /*!<Remote Transmission Request */
#define  CAN_RI1R_IDE                        ((uint32_t)0x00000004)        /*!<Identifier Extension */
#define  CAN_RI1R_EXID                       ((uint32_t)0x001FFFF8)        /*!<Extended identifier */
#define  CAN_RI1R_STID                       ((uint32_t)0xFFE00000)        /*!<Standard Identifier or Extended Identifier */

/*******************  Bit definition for CAN_RDT1R register  ******************/
#define  CAN_RDT1R_DLC                       ((uint32_t)0x0000000F)        /*!<Data Length Code */
#define  CAN_RDT1R_FMI                       ((uint32_t)0x0000FF00)        /*!<Filter Match Index */
#define  CAN_RDT1R_TIME                      ((uint32_t)0xFFFF0000)        /*!<Message Time Stamp */

/*******************  Bit definition for CAN_RDL1R register  ******************/
#define  CAN_RDL1R_DATA0                     ((uint32_t)0x000000FF)        /*!<Data byte 0 */
#define  CAN_RDL1R_DATA1                     ((uint32_t)0x0000FF00)        /*!<Data byte 1 */
#define  CAN_RDL1R_DATA2                     ((uint32_t)0x00FF0000)        /*!<Data byte 2 */
#define  CAN_RDL1R_DATA3                     ((uint32_t)0xFF000000)        /*!<Data byte 3 */

/*******************  Bit definition for CAN_RDH1R register  ******************/
#define  CAN_RDH1R_DATA4                     ((uint32_t)0x000000FF)        /*!<Data byte 4 */
#define  CAN_RDH1R_DATA5                     ((uint32_t)0x0000FF00)        /*!<Data byte 5 */
#define  CAN_RDH1R_DATA6                     ((uint32_t)0x00FF0000)        /*!<Data byte 6 */
#define  CAN_RDH1R_DATA7                     ((uint32_t)0xFF000000)        /*!<Data byte 7 */

/*!<CAN filter registers */
/*******************  Bit definition for CAN_FMR register  ********************/
#define  CAN_FMR_FINIT                       ((uint8_t)0x01)               /*!<Filter Init Mode */

/*******************  Bit definition for CAN_FM1R register  *******************/
#define  CAN_FM1R_FBM                        ((uint16_t)0x3FFF)            /*!<Filter Mode */
#define  CAN_FM1R_FBM0                       ((uint16_t)0x0001)            /*!<Filter Init Mode bit 0 */
#define  CAN_FM1R_FBM1                       ((uint16_t)0x0002)            /*!<Filter Init Mode bit 1 */
#define  CAN_FM1R_FBM2                       ((uint16_t)0x0004)            /*!<Filter Init Mode bit 2 */
#define  CAN_FM1R_FBM3                       ((uint16_t)0x0008)            /*!<Filter Init Mode bit 3 */
#define  CAN_FM1R_FBM4                       ((uint16_t)0x0010)            /*!<Filter Init Mode bit 4 */
#define  CAN_FM1R_FBM5                       ((uint16_t)0x0020)            /*!<Filter Init Mode bit 5 */
#define  CAN_FM1R_FBM6                       ((uint16_t)0x0040)            /*!<Filter Init Mode bit 6 */
#define  CAN_FM1R_FBM7                       ((uint16_t)0x0080)            /*!<Filter Init Mode bit 7 */
#define  CAN_FM1R_FBM8                       ((uint16_t)0x0100)            /*!<Filter Init Mode bit 8 */
#define  CAN_FM1R_FBM9                       ((uint16_t)0x0200)            /*!<Filter Init Mode bit 9 */
#define  CAN_FM1R_FBM10                      ((uint16_t)0x0400)            /*!<Filter Init Mode bit 10 */
#define  CAN_FM1R_FBM11                      ((uint16_t)0x0800)            /*!<Filter Init Mode bit 11 */
#define  CAN_FM1R_FBM12                      ((uint16_t)0x1000)            /*!<Filter Init Mode bit 12 */
#define  CAN_FM1R_FBM13                      ((uint16_t)0x2000)            /*!<Filter Init Mode bit 13 */

/*******************  Bit definition for CAN_FS1R register  *******************/
#define  CAN_FS1R_FSC                        ((uint16_t)0x3FFF)            /*!<Filter Scale Configuration */
#define  CAN_FS1R_FSC0                       ((uint16_t)0x0001)            /*!<Filter Scale Configuration bit 0 */
#define  CAN_FS1R_FSC1                       ((uint16_t)0x0002)            /*!<Filter Scale Configuration bit 1 */
#define  CAN_FS1R_FSC2                       ((uint16_t)0x0004)            /*!<Filter Scale Configuration bit 2 */
#define  CAN_FS1R_FSC3                       ((uint16_t)0x0008)            /*!<Filter Scale Configuration bit 3 */
#define  CAN_FS1R_FSC4                       ((uint16_t)0x0010)            /*!<Filter Scale Configuration bit 4 */
#define  CAN_FS1R_FSC5                       ((uint16_t)0x0020)            /*!<Filter Scale Configuration bit 5 */
#define  CAN_FS1R_FSC6                       ((uint16_t)0x0040)            /*!<Filter Scale Configuration bit 6 */
#define  CAN_FS1R_FSC7                       ((uint16_t)0x0080)            /*!<Filter Scale Configuration bit 7 */
#define  CAN_FS1R_FSC8                       ((uint16_t)0x0100)            /*!<Filter Scale Configuration bit 8 */
#define  CAN_FS1R_FSC9                       ((uint16_t)0x0200)            /*!<Filter Scale Configuration bit 9 */
#define  CAN_FS1R_FSC10                      ((uint16_t)0x0400)            /*!<Filter Scale Configuration bit 10 */
#define  CAN_FS1R_FSC11                      ((uint16_t)0x0800)            /*!<Filter Scale Configuration bit 11 */
#define  CAN_FS1R_FSC12                      ((uint16_t)0x1000)            /*!<Filter Scale Configuration bit 12 */
#define  CAN_FS1R_FSC13                      ((uint16_t)0x2000)            /*!<Filter Scale Configuration bit 13 */

/******************  Bit definition for CAN_FFA1R register  *******************/
#define  CAN_FFA1R_FFA                       ((uint16_t)0x3FFF)            /*!<Filter FIFO Assignment */
#define  CAN_FFA1R_FFA0                      ((uint16_t)0x0001)            /*!<Filter FIFO Assignment for Filter 0 */
#define  CAN_FFA1R_FFA1                      ((uint16_t)0x0002)            /*!<Filter FIFO Assignment for Filter 1 */
#define  CAN_FFA1R_FFA2                      ((uint16_t)0x0004)            /*!<Filter FIFO Assignment for Filter 2 */
#define  CAN_FFA1R_FFA3                      ((uint16_t)0x0008)            /*!<Filter FIFO Assignment for Filter 3 */
#define  CAN_FFA1R_FFA4                      ((uint16_t)0x0010)            /*!<Filter FIFO Assignment for Filter 4 */
#define  CAN_FFA1R_FFA5                      ((uint16_t)0x0020)            /*!<Filter FIFO Assignment for Filter 5 */
#define  CAN_FFA1R_FFA6                      ((uint16_t)0x0040)            /*!<Filter FIFO Assignment for Filter 6 */
#define  CAN_FFA1R_FFA7                      ((uint16_t)0x0080)            /*!<Filter FIFO Assignment for Filter 7 */
#define  CAN_FFA1R_FFA8                      ((uint16_t)0x0100)            /*!<Filter FIFO Assignment for Filter 8 */
#define  CAN_FFA1R_FFA9                      ((uint16_t)0x0200)            /*!<Filter FIFO Assignment for Filter 9 */
#define  CAN_FFA1R_FFA10                     ((uint16_t)0x0400)            /*!<Filter FIFO Assignment for Filter 10 */
#define  CAN_FFA1R_FFA11                     ((uint16_t)0x0800)            /*!<Filter FIFO Assignment for Filter 11 */
#define  CAN_FFA1R_FFA12                     ((uint16_t)0x1000)            /*!<Filter FIFO Assignment for Filter 12 */
#define  CAN_FFA1R_FFA13                     ((uint16_t)0x2000)            /*!<Filter FIFO Assignment for Filter 13 */

/*******************  Bit definition for CAN_FA1R register  *******************/
#define  CAN_FA1R_FACT                       ((uint16_t)0x3FFF)            /*!<Filter Active */
#define  CAN_FA1R_FACT0                      ((uint16_t)0x0001)            /*!<Filter 0 Active */
#define  CAN_FA1R_FACT1                      ((uint16_t)0x0002)            /*!<Filter 1 Active */
#define  CAN_FA1R_FACT2                      ((uint16_t)0x0004)            /*!<Filter 2 Active */
#define  CAN_FA1R_FACT3                      ((uint16_t)0x0008)            /*!<Filter 3 Active */
#define  CAN_FA1R_FACT4                      ((uint16_t)0x0010)            /*!<Filter 4 Active */
#define  CAN_FA1R_FACT5                      ((uint16_t)0x0020)            /*!<Filter 5 Active */
#define  CAN_FA1R_FACT6                      ((uint16_t)0x0040)            /*!<Filter 6 Active */
#define  CAN_FA1R_FACT7                      ((uint16_t)0x0080)            /*!<Filter 7 Active */
#define  CAN_FA1R_FACT8                      ((uint16_t)0x0100)            /*!<Filter 8 Active */
#define  CAN_FA1R_FACT9                      ((uint16_t)0x0200)            /*!<Filter 9 Active */
#define  CAN_FA1R_FACT10                     ((uint16_t)0x0400)            /*!<Filter 10 Active */
#define  CAN_FA1R_FACT11                     ((uint16_t)0x0800)            /*!<Filter 11 Active */
#define  CAN_FA1R_FACT12                     ((uint16_t)0x1000)            /*!<Filter 12 Active */
#define  CAN_FA1R_FACT13                     ((uint16_t)0x2000)            /*!<Filter 13 Active */

/*******************  Bit definition for CAN_F0R1 register  *******************/
#define  CAN_F0R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F0R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F0R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F0R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F0R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F0R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F0R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F0R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F0R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F0R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F0R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F0R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F0R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F0R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F0R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F0R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F0R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F0R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F0R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F0R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F0R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F0R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F0R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F0R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F0R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F0R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F0R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F0R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F0R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F0R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F0R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F0R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F1R1 register  *******************/
#define  CAN_F1R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F1R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F1R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F1R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F1R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F1R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F1R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F1R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F1R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F1R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F1R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F1R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F1R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F1R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F1R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F1R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F1R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F1R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F1R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F1R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F1R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F1R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F1R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F1R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F1R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F1R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F1R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F1R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F1R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F1R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F1R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F1R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F2R1 register  *******************/
#define  CAN_F2R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F2R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F2R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F2R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F2R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F2R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F2R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F2R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F2R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F2R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F2R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F2R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F2R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F2R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F2R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F2R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F2R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F2R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F2R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F2R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F2R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F2R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F2R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F2R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F2R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F2R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F2R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F2R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F2R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F2R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F2R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F2R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F3R1 register  *******************/
#define  CAN_F3R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F3R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F3R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F3R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F3R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F3R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F3R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F3R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F3R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F3R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F3R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F3R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F3R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F3R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F3R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F3R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F3R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F3R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F3R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F3R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F3R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F3R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F3R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F3R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F3R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F3R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F3R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F3R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F3R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F3R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F3R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F3R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F4R1 register  *******************/
#define  CAN_F4R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F4R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F4R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F4R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F4R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F4R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F4R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F4R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F4R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F4R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F4R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F4R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F4R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F4R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F4R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F4R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F4R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F4R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F4R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F4R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F4R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F4R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F4R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F4R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F4R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F4R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F4R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F4R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F4R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F4R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F4R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F4R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F5R1 register  *******************/
#define  CAN_F5R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F5R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F5R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F5R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F5R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F5R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F5R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F5R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F5R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F5R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F5R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F5R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F5R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F5R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F5R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F5R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F5R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F5R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F5R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F5R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F5R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F5R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F5R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F5R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F5R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F5R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F5R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F5R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F5R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F5R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F5R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F5R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F6R1 register  *******************/
#define  CAN_F6R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F6R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F6R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F6R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F6R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F6R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F6R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F6R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F6R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F6R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F6R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F6R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F6R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F6R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F6R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F6R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F6R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F6R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F6R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F6R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F6R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F6R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F6R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F6R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F6R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F6R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F6R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F6R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F6R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F6R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F6R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F6R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F7R1 register  *******************/
#define  CAN_F7R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F7R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F7R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F7R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F7R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F7R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F7R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F7R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F7R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F7R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F7R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F7R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F7R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F7R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F7R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F7R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F7R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F7R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F7R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F7R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F7R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F7R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F7R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F7R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F7R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F7R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F7R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F7R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F7R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F7R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F7R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F7R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F8R1 register  *******************/
#define  CAN_F8R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F8R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F8R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F8R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F8R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F8R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F8R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F8R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F8R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F8R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F8R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F8R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F8R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F8R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F8R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F8R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F8R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F8R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F8R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F8R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F8R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F8R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F8R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F8R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F8R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F8R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F8R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F8R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F8R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F8R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F8R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F8R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F9R1 register  *******************/
#define  CAN_F9R1_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F9R1_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F9R1_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F9R1_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F9R1_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F9R1_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F9R1_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F9R1_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F9R1_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F9R1_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F9R1_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F9R1_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F9R1_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F9R1_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F9R1_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F9R1_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F9R1_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F9R1_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F9R1_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F9R1_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F9R1_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F9R1_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F9R1_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F9R1_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F9R1_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F9R1_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F9R1_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F9R1_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F9R1_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F9R1_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F9R1_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F9R1_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F10R1 register  ******************/
#define  CAN_F10R1_FB0                       ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F10R1_FB1                       ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F10R1_FB2                       ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F10R1_FB3                       ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F10R1_FB4                       ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F10R1_FB5                       ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F10R1_FB6                       ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F10R1_FB7                       ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F10R1_FB8                       ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F10R1_FB9                       ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F10R1_FB10                      ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F10R1_FB11                      ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F10R1_FB12                      ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F10R1_FB13                      ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F10R1_FB14                      ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F10R1_FB15                      ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F10R1_FB16                      ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F10R1_FB17                      ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F10R1_FB18                      ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F10R1_FB19                      ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F10R1_FB20                      ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F10R1_FB21                      ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F10R1_FB22                      ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F10R1_FB23                      ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F10R1_FB24                      ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F10R1_FB25                      ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F10R1_FB26                      ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F10R1_FB27                      ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F10R1_FB28                      ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F10R1_FB29                      ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F10R1_FB30                      ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F10R1_FB31                      ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F11R1 register  ******************/
#define  CAN_F11R1_FB0                       ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F11R1_FB1                       ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F11R1_FB2                       ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F11R1_FB3                       ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F11R1_FB4                       ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F11R1_FB5                       ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F11R1_FB6                       ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F11R1_FB7                       ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F11R1_FB8                       ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F11R1_FB9                       ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F11R1_FB10                      ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F11R1_FB11                      ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F11R1_FB12                      ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F11R1_FB13                      ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F11R1_FB14                      ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F11R1_FB15                      ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F11R1_FB16                      ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F11R1_FB17                      ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F11R1_FB18                      ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F11R1_FB19                      ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F11R1_FB20                      ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F11R1_FB21                      ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F11R1_FB22                      ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F11R1_FB23                      ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F11R1_FB24                      ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F11R1_FB25                      ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F11R1_FB26                      ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F11R1_FB27                      ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F11R1_FB28                      ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F11R1_FB29                      ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F11R1_FB30                      ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F11R1_FB31                      ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F12R1 register  ******************/
#define  CAN_F12R1_FB0                       ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F12R1_FB1                       ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F12R1_FB2                       ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F12R1_FB3                       ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F12R1_FB4                       ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F12R1_FB5                       ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F12R1_FB6                       ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F12R1_FB7                       ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F12R1_FB8                       ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F12R1_FB9                       ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F12R1_FB10                      ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F12R1_FB11                      ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F12R1_FB12                      ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F12R1_FB13                      ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F12R1_FB14                      ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F12R1_FB15                      ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F12R1_FB16                      ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F12R1_FB17                      ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F12R1_FB18                      ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F12R1_FB19                      ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F12R1_FB20                      ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F12R1_FB21                      ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F12R1_FB22                      ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F12R1_FB23                      ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F12R1_FB24                      ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F12R1_FB25                      ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F12R1_FB26                      ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F12R1_FB27                      ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F12R1_FB28                      ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F12R1_FB29                      ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F12R1_FB30                      ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F12R1_FB31                      ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F13R1 register  ******************/
#define  CAN_F13R1_FB0                       ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F13R1_FB1                       ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F13R1_FB2                       ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F13R1_FB3                       ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F13R1_FB4                       ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F13R1_FB5                       ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F13R1_FB6                       ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F13R1_FB7                       ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F13R1_FB8                       ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F13R1_FB9                       ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F13R1_FB10                      ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F13R1_FB11                      ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F13R1_FB12                      ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F13R1_FB13                      ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F13R1_FB14                      ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F13R1_FB15                      ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F13R1_FB16                      ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F13R1_FB17                      ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F13R1_FB18                      ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F13R1_FB19                      ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F13R1_FB20                      ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F13R1_FB21                      ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F13R1_FB22                      ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F13R1_FB23                      ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F13R1_FB24                      ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F13R1_FB25                      ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F13R1_FB26                      ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F13R1_FB27                      ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F13R1_FB28                      ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F13R1_FB29                      ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F13R1_FB30                      ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F13R1_FB31                      ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F0R2 register  *******************/
#define  CAN_F0R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F0R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F0R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F0R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F0R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F0R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F0R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F0R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F0R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F0R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F0R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F0R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F0R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F0R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F0R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F0R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F0R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F0R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F0R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F0R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F0R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F0R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F0R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F0R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F0R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F0R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F0R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F0R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F0R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F0R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F0R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F0R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F1R2 register  *******************/
#define  CAN_F1R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F1R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F1R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F1R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F1R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F1R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F1R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F1R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F1R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F1R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F1R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F1R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F1R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F1R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F1R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F1R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F1R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F1R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F1R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F1R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F1R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F1R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F1R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F1R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F1R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F1R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F1R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F1R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F1R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F1R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F1R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F1R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F2R2 register  *******************/
#define  CAN_F2R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F2R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F2R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F2R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F2R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F2R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F2R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F2R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F2R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F2R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F2R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F2R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F2R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F2R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F2R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F2R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F2R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F2R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F2R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F2R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F2R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F2R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F2R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F2R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F2R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F2R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F2R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F2R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F2R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F2R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F2R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F2R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F3R2 register  *******************/
#define  CAN_F3R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F3R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F3R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F3R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F3R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F3R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F3R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F3R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F3R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F3R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F3R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F3R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F3R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F3R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F3R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F3R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F3R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F3R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F3R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F3R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F3R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F3R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F3R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F3R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F3R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F3R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F3R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F3R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F3R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F3R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F3R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F3R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F4R2 register  *******************/
#define  CAN_F4R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F4R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F4R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F4R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F4R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F4R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F4R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F4R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F4R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F4R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F4R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F4R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F4R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F4R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F4R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F4R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F4R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F4R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F4R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F4R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F4R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F4R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F4R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F4R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F4R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F4R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F4R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F4R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F4R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F4R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F4R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F4R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F5R2 register  *******************/
#define  CAN_F5R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F5R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F5R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F5R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F5R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F5R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F5R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F5R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F5R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F5R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F5R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F5R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F5R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F5R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F5R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F5R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F5R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F5R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F5R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F5R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F5R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F5R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F5R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F5R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F5R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F5R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F5R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F5R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F5R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F5R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F5R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F5R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F6R2 register  *******************/
#define  CAN_F6R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F6R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F6R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F6R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F6R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F6R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F6R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F6R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F6R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F6R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F6R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F6R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F6R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F6R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F6R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F6R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F6R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F6R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F6R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F6R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F6R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F6R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F6R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F6R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F6R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F6R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F6R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F6R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F6R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F6R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F6R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F6R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F7R2 register  *******************/
#define  CAN_F7R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F7R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F7R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F7R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F7R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F7R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F7R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F7R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F7R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F7R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F7R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F7R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F7R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F7R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F7R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F7R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F7R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F7R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F7R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F7R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F7R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F7R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F7R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F7R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F7R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F7R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F7R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F7R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F7R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F7R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F7R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F7R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F8R2 register  *******************/
#define  CAN_F8R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F8R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F8R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F8R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F8R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F8R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F8R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F8R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F8R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F8R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F8R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F8R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F8R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F8R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F8R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F8R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F8R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F8R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F8R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F8R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F8R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F8R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F8R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F8R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F8R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F8R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F8R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F8R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F8R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F8R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F8R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F8R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F9R2 register  *******************/
#define  CAN_F9R2_FB0                        ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F9R2_FB1                        ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F9R2_FB2                        ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F9R2_FB3                        ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F9R2_FB4                        ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F9R2_FB5                        ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F9R2_FB6                        ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F9R2_FB7                        ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F9R2_FB8                        ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F9R2_FB9                        ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F9R2_FB10                       ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F9R2_FB11                       ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F9R2_FB12                       ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F9R2_FB13                       ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F9R2_FB14                       ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F9R2_FB15                       ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F9R2_FB16                       ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F9R2_FB17                       ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F9R2_FB18                       ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F9R2_FB19                       ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F9R2_FB20                       ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F9R2_FB21                       ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F9R2_FB22                       ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F9R2_FB23                       ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F9R2_FB24                       ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F9R2_FB25                       ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F9R2_FB26                       ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F9R2_FB27                       ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F9R2_FB28                       ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F9R2_FB29                       ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F9R2_FB30                       ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F9R2_FB31                       ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F10R2 register  ******************/
#define  CAN_F10R2_FB0                       ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F10R2_FB1                       ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F10R2_FB2                       ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F10R2_FB3                       ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F10R2_FB4                       ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F10R2_FB5                       ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F10R2_FB6                       ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F10R2_FB7                       ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F10R2_FB8                       ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F10R2_FB9                       ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F10R2_FB10                      ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F10R2_FB11                      ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F10R2_FB12                      ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F10R2_FB13                      ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F10R2_FB14                      ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F10R2_FB15                      ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F10R2_FB16                      ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F10R2_FB17                      ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F10R2_FB18                      ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F10R2_FB19                      ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F10R2_FB20                      ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F10R2_FB21                      ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F10R2_FB22                      ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F10R2_FB23                      ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F10R2_FB24                      ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F10R2_FB25                      ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F10R2_FB26                      ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F10R2_FB27                      ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F10R2_FB28                      ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F10R2_FB29                      ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F10R2_FB30                      ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F10R2_FB31                      ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F11R2 register  ******************/
#define  CAN_F11R2_FB0                       ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F11R2_FB1                       ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F11R2_FB2                       ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F11R2_FB3                       ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F11R2_FB4                       ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F11R2_FB5                       ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F11R2_FB6                       ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F11R2_FB7                       ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F11R2_FB8                       ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F11R2_FB9                       ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F11R2_FB10                      ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F11R2_FB11                      ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F11R2_FB12                      ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F11R2_FB13                      ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F11R2_FB14                      ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F11R2_FB15                      ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F11R2_FB16                      ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F11R2_FB17                      ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F11R2_FB18                      ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F11R2_FB19                      ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F11R2_FB20                      ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F11R2_FB21                      ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F11R2_FB22                      ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F11R2_FB23                      ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F11R2_FB24                      ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F11R2_FB25                      ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F11R2_FB26                      ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F11R2_FB27                      ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F11R2_FB28                      ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F11R2_FB29                      ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F11R2_FB30                      ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F11R2_FB31                      ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F12R2 register  ******************/
#define  CAN_F12R2_FB0                       ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F12R2_FB1                       ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F12R2_FB2                       ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F12R2_FB3                       ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F12R2_FB4                       ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F12R2_FB5                       ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F12R2_FB6                       ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F12R2_FB7                       ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F12R2_FB8                       ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F12R2_FB9                       ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F12R2_FB10                      ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F12R2_FB11                      ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F12R2_FB12                      ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F12R2_FB13                      ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F12R2_FB14                      ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F12R2_FB15                      ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F12R2_FB16                      ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F12R2_FB17                      ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F12R2_FB18                      ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F12R2_FB19                      ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F12R2_FB20                      ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F12R2_FB21                      ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F12R2_FB22                      ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F12R2_FB23                      ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F12R2_FB24                      ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F12R2_FB25                      ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F12R2_FB26                      ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F12R2_FB27                      ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F12R2_FB28                      ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F12R2_FB29                      ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F12R2_FB30                      ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F12R2_FB31                      ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/*******************  Bit definition for CAN_F13R2 register  ******************/
#define  CAN_F13R2_FB0                       ((uint32_t)0x00000001)        /*!<Filter bit 0 */
#define  CAN_F13R2_FB1                       ((uint32_t)0x00000002)        /*!<Filter bit 1 */
#define  CAN_F13R2_FB2                       ((uint32_t)0x00000004)        /*!<Filter bit 2 */
#define  CAN_F13R2_FB3                       ((uint32_t)0x00000008)        /*!<Filter bit 3 */
#define  CAN_F13R2_FB4                       ((uint32_t)0x00000010)        /*!<Filter bit 4 */
#define  CAN_F13R2_FB5                       ((uint32_t)0x00000020)        /*!<Filter bit 5 */
#define  CAN_F13R2_FB6                       ((uint32_t)0x00000040)        /*!<Filter bit 6 */
#define  CAN_F13R2_FB7                       ((uint32_t)0x00000080)        /*!<Filter bit 7 */
#define  CAN_F13R2_FB8                       ((uint32_t)0x00000100)        /*!<Filter bit 8 */
#define  CAN_F13R2_FB9                       ((uint32_t)0x00000200)        /*!<Filter bit 9 */
#define  CAN_F13R2_FB10                      ((uint32_t)0x00000400)        /*!<Filter bit 10 */
#define  CAN_F13R2_FB11                      ((uint32_t)0x00000800)        /*!<Filter bit 11 */
#define  CAN_F13R2_FB12                      ((uint32_t)0x00001000)        /*!<Filter bit 12 */
#define  CAN_F13R2_FB13                      ((uint32_t)0x00002000)        /*!<Filter bit 13 */
#define  CAN_F13R2_FB14                      ((uint32_t)0x00004000)        /*!<Filter bit 14 */
#define  CAN_F13R2_FB15                      ((uint32_t)0x00008000)        /*!<Filter bit 15 */
#define  CAN_F13R2_FB16                      ((uint32_t)0x00010000)        /*!<Filter bit 16 */
#define  CAN_F13R2_FB17                      ((uint32_t)0x00020000)        /*!<Filter bit 17 */
#define  CAN_F13R2_FB18                      ((uint32_t)0x00040000)        /*!<Filter bit 18 */
#define  CAN_F13R2_FB19                      ((uint32_t)0x00080000)        /*!<Filter bit 19 */
#define  CAN_F13R2_FB20                      ((uint32_t)0x00100000)        /*!<Filter bit 20 */
#define  CAN_F13R2_FB21                      ((uint32_t)0x00200000)        /*!<Filter bit 21 */
#define  CAN_F13R2_FB22                      ((uint32_t)0x00400000)        /*!<Filter bit 22 */
#define  CAN_F13R2_FB23                      ((uint32_t)0x00800000)        /*!<Filter bit 23 */
#define  CAN_F13R2_FB24                      ((uint32_t)0x01000000)        /*!<Filter bit 24 */
#define  CAN_F13R2_FB25                      ((uint32_t)0x02000000)        /*!<Filter bit 25 */
#define  CAN_F13R2_FB26                      ((uint32_t)0x04000000)        /*!<Filter bit 26 */
#define  CAN_F13R2_FB27                      ((uint32_t)0x08000000)        /*!<Filter bit 27 */
#define  CAN_F13R2_FB28                      ((uint32_t)0x10000000)        /*!<Filter bit 28 */
#define  CAN_F13R2_FB29                      ((uint32_t)0x20000000)        /*!<Filter bit 29 */
#define  CAN_F13R2_FB30                      ((uint32_t)0x40000000)        /*!<Filter bit 30 */
#define  CAN_F13R2_FB31                      ((uint32_t)0x80000000)        /*!<Filter bit 31 */

/******************************************************************************/
/*                                                                            */
/*                          HDMI-CEC (CEC)                                    */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for CEC_CR register  *********************/
#define  CEC_CR_CECEN                        ((uint32_t)0x00000001)       /*!< CEC Enable                                */
#define  CEC_CR_TXSOM                        ((uint32_t)0x00000002)       /*!< CEC Tx Start Of Message                   */
#define  CEC_CR_TXEOM                        ((uint32_t)0x00000004)       /*!< CEC Tx End Of Message                     */

/*******************  Bit definition for CEC_CFGR register  *******************/
#define  CEC_CFGR_SFT                        ((uint32_t)0x00000007)       /*!< CEC Signal Free Time                      */
#define  CEC_CFGR_RXTOL                      ((uint32_t)0x00000008)       /*!< CEC Tolerance                             */
#define  CEC_CFGR_BRESTP                     ((uint32_t)0x00000010)       /*!< CEC Rx Stop                               */
#define  CEC_CFGR_BREGEN                     ((uint32_t)0x00000020)       /*!< CEC Bit Rising Error generation           */
#define  CEC_CFGR_LBPEGEN                    ((uint32_t)0x00000040)       /*!< CEC Long Bit Period Error generation      */
#define  CEC_CFGR_SFTOPT                     ((uint32_t)0x00000100)       /*!< CEC Signal Free Time optional             */
#define  CEC_CFGR_BRDNOGEN                   ((uint32_t)0x00000080)       /*!< CEC Broadcast No error generation         */
#define  CEC_CFGR_OAR                        ((uint32_t)0x7FFF0000)       /*!< CEC Own Address                           */
#define  CEC_CFGR_LSTN                       ((uint32_t)0x80000000)       /*!< CEC Listen mode                           */

/*******************  Bit definition for CEC_TXDR register  *******************/
#define  CEC_TXDR_TXD                        ((uint32_t)0x000000FF)       /*!< CEC Tx Data                               */

/*******************  Bit definition for CEC_RXDR register  *******************/
#define  CEC_TXDR_RXD                        ((uint32_t)0x000000FF)       /*!< CEC Rx Data                               */

/*******************  Bit definition for CEC_ISR register  ********************/
#define  CEC_ISR_RXBR                        ((uint32_t)0x00000001)       /*!< CEC Rx-Byte Received                      */
#define  CEC_ISR_RXEND                       ((uint32_t)0x00000002)       /*!< CEC End Of Reception                      */
#define  CEC_ISR_RXOVR                       ((uint32_t)0x00000004)       /*!< CEC Rx-Overrun                            */
#define  CEC_ISR_BRE                         ((uint32_t)0x00000008)       /*!< CEC Rx Bit Rising Error                   */
#define  CEC_ISR_SBPE                        ((uint32_t)0x00000010)       /*!< CEC Rx Short Bit period Error             */
#define  CEC_ISR_LBPE                        ((uint32_t)0x00000020)       /*!< CEC Rx Long Bit period Error              */
#define  CEC_ISR_RXACKE                      ((uint32_t)0x00000040)       /*!< CEC Rx Missing Acknowledge                */
#define  CEC_ISR_ARBLST                      ((uint32_t)0x00000080)       /*!< CEC Arbitration Lost                      */
#define  CEC_ISR_TXBR                        ((uint32_t)0x00000100)       /*!< CEC Tx Byte Request                       */
#define  CEC_ISR_TXEND                       ((uint32_t)0x00000200)       /*!< CEC End of Transmission                   */
#define  CEC_ISR_TXUDR                       ((uint32_t)0x00000400)       /*!< CEC Tx-Buffer Underrun                    */
#define  CEC_ISR_TXERR                       ((uint32_t)0x00000800)       /*!< CEC Tx-Error                              */
#define  CEC_ISR_TXACKE                      ((uint32_t)0x00001000)       /*!< CEC Tx Missing Acknowledge                */

/*******************  Bit definition for CEC_IER register  ********************/
#define  CEC_IER_RXBRIE                      ((uint32_t)0x00000001)       /*!< CEC Rx-Byte Received IT Enable            */
#define  CEC_IER_RXENDIE                     ((uint32_t)0x00000002)       /*!< CEC End Of Reception IT Enable            */
#define  CEC_IER_RXOVRIE                     ((uint32_t)0x00000004)       /*!< CEC Rx-Overrun IT Enable                  */
#define  CEC_IER_BREIE                       ((uint32_t)0x00000008)       /*!< CEC Rx Bit Rising Error IT Enable         */
#define  CEC_IER_SBPEIE                      ((uint32_t)0x00000010)       /*!< CEC Rx Short Bit period Error IT Enable   */
#define  CEC_IER_LBPEIE                      ((uint32_t)0x00000020)       /*!< CEC Rx Long Bit period Error IT Enable    */
#define  CEC_IER_RXACKEIE                    ((uint32_t)0x00000040)       /*!< CEC Rx Missing Acknowledge IT Enable      */
#define  CEC_IER_ARBLSTIE                    ((uint32_t)0x00000080)       /*!< CEC Arbitration Lost IT Enable            */
#define  CEC_IER_TXBRIE                      ((uint32_t)0x00000100)       /*!< CEC Tx Byte Request  IT Enable            */
#define  CEC_IER_TXENDIE                     ((uint32_t)0x00000200)       /*!< CEC End of Transmission IT Enable         */
#define  CEC_IER_TXUDRIE                     ((uint32_t)0x00000400)       /*!< CEC Tx-Buffer Underrun IT Enable          */
#define  CEC_IER_TXERRIE                     ((uint32_t)0x00000800)       /*!< CEC Tx-Error IT Enable                    */
#define  CEC_IER_TXACKEIE                    ((uint32_t)0x00001000)       /*!< CEC Tx Missing Acknowledge IT Enable      */

/******************************************************************************/
/*                                                                            */
/*                          CRC calculation unit                              */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for CRC_DR register  *********************/
#define  CRC_DR_DR                           ((uint32_t)0xFFFFFFFF) /*!< Data register bits */

/*******************  Bit definition for CRC_IDR register  ********************/
#define  CRC_IDR_IDR                         ((uint32_t)0xFFFFFFFF) /*!< General-purpose 32-bit data register bits */

/********************  Bit definition for CRC_CR register  ********************/
#define  CRC_CR_RESET                        ((uint32_t)0x00000001) /*!< RESET the CRC computation unit bit */
#define  CRC_CR_POLYSIZE                     ((uint32_t)0x00000018) /*!< Polynomial size bits */
#define  CRC_CR_POLYSIZE_0                   ((uint32_t)0x00000008) /*!< Polynomial size bit 0 */
#define  CRC_CR_POLYSIZE_1                   ((uint32_t)0x00000010) /*!< Polynomial size bit 1 */
#define  CRC_CR_REV_IN                       ((uint32_t)0x00000060) /*!< REV_IN Reverse Input Data bits */
#define  CRC_CR_REV_IN_0                     ((uint32_t)0x00000020) /*!< Bit 0 */
#define  CRC_CR_REV_IN_1                     ((uint32_t)0x00000040) /*!< Bit 1 */
#define  CRC_CR_REV_OUT                      ((uint32_t)0x00000080) /*!< REV_OUT Reverse Output Data bits */

/*******************  Bit definition for CRC_INIT register  *******************/
#define  CRC_INIT_INIT                       ((uint32_t)0xFFFFFFFF) /*!< Initial CRC value bits */

/*******************  Bit definition for CRC_POL register  ********************/
#define  CRC_POL_POL                         ((uint32_t)0xFFFFFFFF) /*!< Coefficients of the polynomial */

/******************************************************************************/
/*                                                                            */
/*                          CRS Clock Recovery System                         */
/******************************************************************************/

/*******************  Bit definition for CRS_CR register  *********************/
#define  CRS_CR_SYNCOKIE                     ((uint32_t)0x00000001U) /*!< SYNC event OK interrupt enable */
#define  CRS_CR_SYNCWARNIE                   ((uint32_t)0x00000002U) /*!< SYNC warning interrupt enable */
#define  CRS_CR_ERRIE                        ((uint32_t)0x00000004U) /*!< SYNC error or trimming error interrupt enable */
#define  CRS_CR_ESYNCIE                      ((uint32_t)0x00000008U) /*!< Expected SYNC interrupt enable */
#define  CRS_CR_CEN                          ((uint32_t)0x00000020U) /*!< Frequency error counter enable */
#define  CRS_CR_AUTOTRIMEN                   ((uint32_t)0x00000040U) /*!< Automatic trimming enable */
#define  CRS_CR_SWSYNC                       ((uint32_t)0x00000080U) /*!< Generate software SYNC event */
#define  CRS_CR_TRIM                         ((uint32_t)0x00003F00U) /*!< HSI48 oscillator smooth trimming */

/*******************  Bit definition for CRS_CFGR register  *********************/
#define  CRS_CFGR_RELOAD                     ((uint32_t)0x0000FFFFU) /*!< Counter reload value */
#define  CRS_CFGR_FELIM                      ((uint32_t)0x00FF0000U) /*!< Frequency error limit */

#define  CRS_CFGR_SYNCDIV                    ((uint32_t)0x07000000U) /*!< SYNC divider */
#define  CRS_CFGR_SYNCDIV_0                  ((uint32_t)0x01000000U) /*!< SYNC divider bit 0 */
#define  CRS_CFGR_SYNCDIV_1                  ((uint32_t)0x02000000U) /*!< SYNC divider bit 1 */
#define  CRS_CFGR_SYNCDIV_2                  ((uint32_t)0x04000000U) /*!< SYNC divider bit 2 */

#define  CRS_CFGR_SYNCSRC                    ((uint32_t)0x30000000U) /*!< SYNC signal source selection */
#define  CRS_CFGR_SYNCSRC_0                  ((uint32_t)0x10000000U) /*!< SYNC signal source selection bit 0 */
#define  CRS_CFGR_SYNCSRC_1                  ((uint32_t)0x20000000U) /*!< SYNC signal source selection bit 1 */

#define  CRS_CFGR_SYNCPOL                    ((uint32_t)0x80000000U) /*!< SYNC polarity selection */
  
/*******************  Bit definition for CRS_ISR register  *********************/
#define  CRS_ISR_SYNCOKF                     ((uint32_t)0x00000001U) /*!< SYNC event OK flag */
#define  CRS_ISR_SYNCWARNF                   ((uint32_t)0x00000002U) /*!< SYNC warning flag */
#define  CRS_ISR_ERRF                        ((uint32_t)0x00000004U) /*!< Error flag */
#define  CRS_ISR_ESYNCF                      ((uint32_t)0x00000008U) /*!< Expected SYNC flag */
#define  CRS_ISR_SYNCERR                     ((uint32_t)0x00000100U) /*!< SYNC error */
#define  CRS_ISR_SYNCMISS                    ((uint32_t)0x00000200U) /*!< SYNC missed */
#define  CRS_ISR_TRIMOVF                     ((uint32_t)0x00000400U) /*!< Trimming overflow or underflow */
#define  CRS_ISR_FEDIR                       ((uint32_t)0x00008000U) /*!< Frequency error direction */
#define  CRS_ISR_FECAP                       ((uint32_t)0xFFFF0000U) /*!< Frequency error capture */

/*******************  Bit definition for CRS_ICR register  *********************/
#define  CRS_ICR_SYNCOKC                     ((uint32_t)0x00000001U) /*!< SYNC event OK clear flag */
#define  CRS_ICR_SYNCWARNC                   ((uint32_t)0x00000002U) /*!< SYNC warning clear flag */
#define  CRS_ICR_ERRC                        ((uint32_t)0x00000004U) /*!< Error clear flag */
#define  CRS_ICR_ESYNCC                      ((uint32_t)0x00000008U) /*!< Expected SYNC clear flag */

/******************************************************************************/
/*                                                                            */
/*                            Crypto Processor                                */
/*                                                                            */
/******************************************************************************/
/******************* Bits definition for CRYP_CR register  ********************/
#define CRYP_CR_ALGODIR                      ((uint32_t)0x00000004)

#define CRYP_CR_ALGOMODE                     ((uint32_t)0x00080038)
#define CRYP_CR_ALGOMODE_0                   ((uint32_t)0x00000008)
#define CRYP_CR_ALGOMODE_1                   ((uint32_t)0x00000010)
#define CRYP_CR_ALGOMODE_2                   ((uint32_t)0x00000020)
#define CRYP_CR_ALGOMODE_TDES_ECB            ((uint32_t)0x00000000)
#define CRYP_CR_ALGOMODE_TDES_CBC            ((uint32_t)0x00000008)
#define CRYP_CR_ALGOMODE_DES_ECB             ((uint32_t)0x00000010)
#define CRYP_CR_ALGOMODE_DES_CBC             ((uint32_t)0x00000018)
#define CRYP_CR_ALGOMODE_AES_ECB             ((uint32_t)0x00000020)
#define CRYP_CR_ALGOMODE_AES_CBC             ((uint32_t)0x00000028)
#define CRYP_CR_ALGOMODE_AES_CTR             ((uint32_t)0x00000030)
#define CRYP_CR_ALGOMODE_AES_KEY             ((uint32_t)0x00000038)

#define CRYP_CR_DATATYPE                     ((uint32_t)0x000000C0)
#define CRYP_CR_DATATYPE_0                   ((uint32_t)0x00000040)
#define CRYP_CR_DATATYPE_1                   ((uint32_t)0x00000080)
#define CRYP_CR_KEYSIZE                      ((uint32_t)0x00000300)
#define CRYP_CR_KEYSIZE_0                    ((uint32_t)0x00000100)
#define CRYP_CR_KEYSIZE_1                    ((uint32_t)0x00000200)
#define CRYP_CR_FFLUSH                       ((uint32_t)0x00004000)
#define CRYP_CR_CRYPEN                       ((uint32_t)0x00008000)

#define CRYP_CR_GCM_CCMPH                    ((uint32_t)0x00030000)
#define CRYP_CR_GCM_CCMPH_0                  ((uint32_t)0x00010000)
#define CRYP_CR_GCM_CCMPH_1                  ((uint32_t)0x00020000)
#define CRYP_CR_ALGOMODE_3                   ((uint32_t)0x00080000) 

/****************** Bits definition for CRYP_SR register  *********************/
#define CRYP_SR_IFEM                         ((uint32_t)0x00000001)
#define CRYP_SR_IFNF                         ((uint32_t)0x00000002)
#define CRYP_SR_OFNE                         ((uint32_t)0x00000004)
#define CRYP_SR_OFFU                         ((uint32_t)0x00000008)
#define CRYP_SR_BUSY                         ((uint32_t)0x00000010)
/****************** Bits definition for CRYP_DMACR register  ******************/
#define CRYP_DMACR_DIEN                      ((uint32_t)0x00000001)
#define CRYP_DMACR_DOEN                      ((uint32_t)0x00000002)
/*****************  Bits definition for CRYP_IMSCR register  ******************/
#define CRYP_IMSCR_INIM                      ((uint32_t)0x00000001)
#define CRYP_IMSCR_OUTIM                     ((uint32_t)0x00000002)
/****************** Bits definition for CRYP_RISR register  *******************/
#define CRYP_RISR_OUTRIS                     ((uint32_t)0x00000001)
#define CRYP_RISR_INRIS                      ((uint32_t)0x00000002)
/****************** Bits definition for CRYP_MISR register  *******************/
#define CRYP_MISR_INMIS                      ((uint32_t)0x00000001)
#define CRYP_MISR_OUTMIS                     ((uint32_t)0x00000002)

/******************************************************************************/
/*                                                                            */
/*                      Digital to Analog Converter                           */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for DAC_CR register  ********************/
#define  DAC_CR_EN1                          ((uint32_t)0x00000001)        /*!<DAC channel1 enable */
#define  DAC_CR_TEN1                         ((uint32_t)0x00000002)        /*!<DAC channel1 Trigger enable */

#define  DAC_CR_TSEL1                        ((uint32_t)0x0000003C)        /*!<TSEL1[2:0] (DAC channel1 Trigger selection) */
#define  DAC_CR_TSEL1_0                      ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  DAC_CR_TSEL1_1                      ((uint32_t)0x00000008)        /*!<Bit 1 */
#define  DAC_CR_TSEL1_2                      ((uint32_t)0x00000010)        /*!<Bit 2 */
#define  DAC_CR_TSEL1_3                      ((uint32_t)0x00000020)        /*!<Bit 2 */


#define  DAC_CR_WAVE1                        ((uint32_t)0x000000C0)        /*!<WAVE1[1:0] (DAC channel1 noise/triangle wave generation enable) */
#define  DAC_CR_WAVE1_0                      ((uint32_t)0x00000040)        /*!<Bit 0 */
#define  DAC_CR_WAVE1_1                      ((uint32_t)0x00000080)        /*!<Bit 1 */

#define  DAC_CR_MAMP1                        ((uint32_t)0x00000F00)        /*!<MAMP1[3:0] (DAC channel1 Mask/Amplitude selector) */
#define  DAC_CR_MAMP1_0                      ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  DAC_CR_MAMP1_1                      ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  DAC_CR_MAMP1_2                      ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  DAC_CR_MAMP1_3                      ((uint32_t)0x00000800)        /*!<Bit 3 */

#define  DAC_CR_DMAEN1                       ((uint32_t)0x00001000)        /*!<DAC channel1 DMA enable */
#define  DAC_CR_DMAUDRIE1                    ((uint32_t)0x00002000)        /*!<DAC channel 1 DMA underrun interrupt enable  >*/
#define  DAC_CR_CEN1                         ((uint32_t)0x00004000)        /*!<DAC channel 1 calibration enable >*/

#define  DAC_CR_EN2                          ((uint32_t)0x00010000)        /*!<DAC channel2 enable */
#define  DAC_CR_TEN2                         ((uint32_t)0x00020000)        /*!<DAC channel2 Trigger enable */

#define  DAC_CR_TSEL2                        ((uint32_t)0x003C0000)        /*!<TSEL2[2:0] (DAC channel2 Trigger selection) */
#define  DAC_CR_TSEL2_0                      ((uint32_t)0x00040000)        /*!<Bit 0 */
#define  DAC_CR_TSEL2_1                      ((uint32_t)0x00080000)        /*!<Bit 1 */
#define  DAC_CR_TSEL2_2                      ((uint32_t)0x00100000)        /*!<Bit 2 */
#define  DAC_CR_TSEL2_3                      ((uint32_t)0x00200000)        /*!<Bit 2 */


#define  DAC_CR_WAVE2                        ((uint32_t)0x00C00000)        /*!<WAVE2[1:0] (DAC channel2 noise/triangle wave generation enable) */
#define  DAC_CR_WAVE2_0                      ((uint32_t)0x00400000)        /*!<Bit 0 */
#define  DAC_CR_WAVE2_1                      ((uint32_t)0x00800000)        /*!<Bit 1 */

#define  DAC_CR_MAMP2                        ((uint32_t)0x0F000000)        /*!<MAMP2[3:0] (DAC channel2 Mask/Amplitude selector) */
#define  DAC_CR_MAMP2_0                      ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  DAC_CR_MAMP2_1                      ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  DAC_CR_MAMP2_2                      ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  DAC_CR_MAMP2_3                      ((uint32_t)0x08000000)        /*!<Bit 3 */

#define  DAC_CR_DMAEN2                       ((uint32_t)0x10000000)        /*!<DAC channel2 DMA enabled */
#define  DAC_CR_DMAUDRIE2                    ((uint32_t)0x20000000)        /*!<DAC channel2 DMA underrun interrupt enable  >*/
#define  DAC_CR_CEN2                         ((uint32_t)0x40000000)        /*!<DAC channel2 calibration enable >*/

/*****************  Bit definition for DAC_SWTRIGR register  ******************/
#define  DAC_SWTRIGR_SWTRIG1                 ((uint8_t)0x01)               /*!<DAC channel1 software trigger */
#define  DAC_SWTRIGR_SWTRIG2                 ((uint8_t)0x02)               /*!<DAC channel2 software trigger */

/*****************  Bit definition for DAC_DHR12R1 register  ******************/
#define  DAC_DHR12R1_DACC1DHR                ((uint16_t)0x0FFF)            /*!<DAC channel1 12-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12L1 register  ******************/
#define  DAC_DHR12L1_DACC1DHR                ((uint16_t)0xFFF0)            /*!<DAC channel1 12-bit Left aligned data */

/******************  Bit definition for DAC_DHR8R1 register  ******************/
#define  DAC_DHR8R1_DACC1DHR                 ((uint8_t)0xFF)               /*!<DAC channel1 8-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12R2 register  ******************/
#define  DAC_DHR12R2_DACC2DHR                ((uint16_t)0x0FFF)            /*!<DAC channel2 12-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12L2 register  ******************/
#define  DAC_DHR12L2_DACC2DHR                ((uint16_t)0xFFF0)            /*!<DAC channel2 12-bit Left aligned data */

/******************  Bit definition for DAC_DHR8R2 register  ******************/
#define  DAC_DHR8R2_DACC2DHR                 ((uint8_t)0xFF)               /*!<DAC channel2 8-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12RD register  ******************/
#define  DAC_DHR12RD_DACC1DHR                ((uint32_t)0x00000FFF)        /*!<DAC channel1 12-bit Right aligned data */
#define  DAC_DHR12RD_DACC2DHR                ((uint32_t)0x0FFF0000)        /*!<DAC channel2 12-bit Right aligned data */

/*****************  Bit definition for DAC_DHR12LD register  ******************/
#define  DAC_DHR12LD_DACC1DHR                ((uint32_t)0x0000FFF0)        /*!<DAC channel1 12-bit Left aligned data */
#define  DAC_DHR12LD_DACC2DHR                ((uint32_t)0xFFF00000)        /*!<DAC channel2 12-bit Left aligned data */

/******************  Bit definition for DAC_DHR8RD register  ******************/
#define  DAC_DHR8RD_DACC1DHR                 ((uint16_t)0x00FF)            /*!<DAC channel1 8-bit Right aligned data */
#define  DAC_DHR8RD_DACC2DHR                 ((uint16_t)0xFF00)            /*!<DAC channel2 8-bit Right aligned data */

/*******************  Bit definition for DAC_DOR1 register  *******************/
#define  DAC_DOR1_DACC1DOR                   ((uint16_t)0x0FFF)            /*!<DAC channel1 data output */

/*******************  Bit definition for DAC_DOR2 register  *******************/
#define  DAC_DOR2_DACC2DOR                   ((uint16_t)0x0FFF)            /*!<DAC channel2 data output */

/********************  Bit definition for DAC_SR register  ********************/
#define  DAC_SR_DMAUDR1                      ((uint32_t)0x00002000)        /*!<DAC channel1 DMA underrun flag */
#define  DAC_SR_CAL_FLAG1                    ((uint32_t)0x00004000)        /*!<DAC channel1 calibration offset status */
#define  DAC_SR_BWST1                        ((uint32_t)0x20008000)        /*!<DAC channel1 busy writing sample time flag */

#define  DAC_SR_DMAUDR2                      ((uint32_t)0x20000000)        /*!<DAC channel2 DMA underrun flag */
#define  DAC_SR_CAL_FLAG2                    ((uint32_t)0x40000000)        /*!<DAC channel2 calibration offset status */
#define  DAC_SR_BWST2                        ((uint32_t)0x80000000)        /*!<DAC channel2 busy writing sample time flag */

/*******************  Bit definition for DAC_CCR register  ********************/
#define  DAC_CCR_OTRIM1                      ((uint32_t)0x0000001F)        /*!<DAC channel1 offset trimming value */
#define  DAC_CCR_OTRIM2                      ((uint32_t)0x001F0000)        /*!<DAC channel2 offset trimming value */

/*******************  Bit definition for DAC_MCR register  *******************/
#define  DAC_MCR_MODE1                        ((uint32_t)0x00000007)        /*!<MODE1[2:0] (DAC channel1 mode) */
#define  DAC_MCR_MODE1_0                      ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  DAC_MCR_MODE1_1                      ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  DAC_MCR_MODE1_2                      ((uint32_t)0x00000004)        /*!<Bit 2 */

#define  DAC_MCR_MODE2                        ((uint32_t)0x00070000)        /*!<MODE2[2:0] (DAC channel2 mode) */
#define  DAC_MCR_MODE2_0                      ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  DAC_MCR_MODE2_1                      ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  DAC_MCR_MODE2_2                      ((uint32_t)0x00040000)        /*!<Bit 2 */

/******************  Bit definition for DAC_SHSR1 register  ******************/
#define  DAC_SHSR1_TSAMPLE1                   ((uint32_t)0x000003FF)        /*!<DAC channel1 sample time */

/******************  Bit definition for DAC_SHSR2 register  ******************/
#define  DAC_SHSR1_TSAMPLE2                   ((uint32_t)0x000003FF)        /*!<DAC channel2 sample time */

/******************  Bit definition for DAC_SHHR register  ******************/
#define  DAC_SHHR_THOLD1                      ((uint32_t)0x000003FF)        /*!<DAC channel1 hold time */
#define  DAC_SHHR_THOLD2                      ((uint32_t)0x03FF0000)        /*!<DAC channel2 hold time */

/******************  Bit definition for DAC_SHRR register  ******************/
#define  DAC_SHRR_TREFRESH1                   ((uint32_t)0x000000FF)        /*!<DAC channel1 refresh time */
#define  DAC_SHRR_TREFRESH2                   ((uint32_t)0x00FF0000)        /*!<DAC channel2 refresh time */

/******************************************************************************/
/*                                                                            */
/*                                 Debug MCU                                  */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/*                                                                            */
/*                                    DCMI                                    */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for DCMI_CR register  ******************/
#define DCMI_CR_CAPTURE                      ((uint32_t)0x00000001)
#define DCMI_CR_CM                           ((uint32_t)0x00000002)
#define DCMI_CR_CROP                         ((uint32_t)0x00000004)
#define DCMI_CR_JPEG                         ((uint32_t)0x00000008)
#define DCMI_CR_ESS                          ((uint32_t)0x00000010)
#define DCMI_CR_PCKPOL                       ((uint32_t)0x00000020)
#define DCMI_CR_HSPOL                        ((uint32_t)0x00000040)
#define DCMI_CR_VSPOL                        ((uint32_t)0x00000080)
#define DCMI_CR_FCRC_0                       ((uint32_t)0x00000100)
#define DCMI_CR_FCRC_1                       ((uint32_t)0x00000200)
#define DCMI_CR_EDM_0                        ((uint32_t)0x00000400)
#define DCMI_CR_EDM_1                        ((uint32_t)0x00000800)
#define DCMI_CR_CRE                          ((uint32_t)0x00001000)
#define DCMI_CR_OUTEN                        ((uint32_t)0x00002000)
#define DCMI_CR_ENABLE                       ((uint32_t)0x00004000)
#define DCMI_CR_BSM                          ((uint32_t)0x00030000)
#define DCMI_CR_BSM_0                        ((uint32_t)0x00010000)
#define DCMI_CR_BSM_1                        ((uint32_t)0x00020000)
#define DCMI_CR_OEBS                         ((uint32_t)0x00040000)
#define DCMI_CR_LSM                          ((uint32_t)0x00080000)
#define DCMI_CR_OELS                         ((uint32_t)0x00100000)

/********************  Bits definition for DCMI_SR register  ******************/
#define DCMI_SR_HSYNC                        ((uint32_t)0x00000001)
#define DCMI_SR_VSYNC                        ((uint32_t)0x00000002)
#define DCMI_SR_FNE                          ((uint32_t)0x00000004)

/********************  Bits definition for DCMI_RISR register  ****************/
#define DCMI_RISR_FRAME_RIS                  ((uint32_t)0x00000001)
#define DCMI_RISR_OVF_RIS                    ((uint32_t)0x00000002)
#define DCMI_RISR_ERR_RIS                    ((uint32_t)0x00000004)
#define DCMI_RISR_VSYNC_RIS                  ((uint32_t)0x00000008)
#define DCMI_RISR_LINE_RIS                   ((uint32_t)0x00000010)

/********************  Bits definition for DCMI_IER register  *****************/
#define DCMI_IER_FRAME_IE                    ((uint32_t)0x00000001)
#define DCMI_IER_OVF_IE                      ((uint32_t)0x00000002)
#define DCMI_IER_ERR_IE                      ((uint32_t)0x00000004)
#define DCMI_IER_VSYNC_IE                    ((uint32_t)0x00000008)
#define DCMI_IER_LINE_IE                     ((uint32_t)0x00000010)

/********************  Bits definition for DCMI_MISR register  ****************/
#define DCMI_MISR_FRAME_MIS                  ((uint32_t)0x00000001)
#define DCMI_MISR_OVF_MIS                    ((uint32_t)0x00000002)
#define DCMI_MISR_ERR_MIS                    ((uint32_t)0x00000004)
#define DCMI_MISR_VSYNC_MIS                  ((uint32_t)0x00000008)
#define DCMI_MISR_LINE_MIS                   ((uint32_t)0x00000010)

/********************  Bits definition for DCMI_ICR register  *****************/
#define DCMI_ICR_FRAME_ISC                   ((uint32_t)0x00000001)
#define DCMI_ICR_OVF_ISC                     ((uint32_t)0x00000002)
#define DCMI_ICR_ERR_ISC                     ((uint32_t)0x00000004)
#define DCMI_ICR_VSYNC_ISC                   ((uint32_t)0x00000008)
#define DCMI_ICR_LINE_ISC                    ((uint32_t)0x00000010)

/******************************************************************************/
/*                                                                            */
/*                 Digital Filter for Sigma Delta Modulators                  */
/*                                                                            */
/******************************************************************************/

/****************   DFSDM channel configuration registers  ********************/

/***************  Bit definition for DFSDM_CHCFGR1 register  ******************/
#define  DFSDM_CHCFGR1_DFSDMEN                ((uint32_t)0x80000000)            /*!< Global enable for DFSDM interface */
#define  DFSDM_CHCFGR1_CKOUTSRC               ((uint32_t)0x40000000)            /*!< Output serial clock source selection */
#define  DFSDM_CHCFGR1_CKOUTDIV               ((uint32_t)0x00FF0000)            /*!< CKOUTDIV[7:0] output serial clock divider */
#define  DFSDM_CHCFGR1_DATPACK                ((uint32_t)0x0000C000)            /*!< DATPACK[1:0] Data packing mode */
#define  DFSDM_CHCFGR1_DATPACK_1              ((uint32_t)0x00008000)            /*!< Data packing mode, Bit 1 */
#define  DFSDM_CHCFGR1_DATPACK_0              ((uint32_t)0x00004000)            /*!< Data packing mode, Bit 0 */
#define  DFSDM_CHCFGR1_DATMPX                 ((uint32_t)0x00003000)            /*!< DATMPX[1:0] Input data multiplexer for channel y */
#define  DFSDM_CHCFGR1_DATMPX_1               ((uint32_t)0x00002000)            /*!< Input data multiplexer for channel y, Bit 1 */
#define  DFSDM_CHCFGR1_DATMPX_0               ((uint32_t)0x00001000)            /*!< Input data multiplexer for channel y, Bit 0 */
#define  DFSDM_CHCFGR1_CHINSEL                ((uint32_t)0x00000100)            /*!< Serial inputs selection for channel y */
#define  DFSDM_CHCFGR1_CHEN                   ((uint32_t)0x00000080)            /*!< Channel y enable */
#define  DFSDM_CHCFGR1_CKABEN                 ((uint32_t)0x00000040)            /*!< Clock absence detector enable on channel y */
#define  DFSDM_CHCFGR1_SCDEN                  ((uint32_t)0x00000020)            /*!< Short circuit detector enable on channel y */
#define  DFSDM_CHCFGR1_SPICKSEL               ((uint32_t)0x0000000C)            /*!< SPICKSEL[1:0] SPI clock select for channel y */
#define  DFSDM_CHCFGR1_SPICKSEL_1             ((uint32_t)0x00000008)            /*!< SPI clock select for channel y, Bit 1 */
#define  DFSDM_CHCFGR1_SPICKSEL_0             ((uint32_t)0x00000004)            /*!< SPI clock select for channel y, Bit 0 */
#define  DFSDM_CHCFGR1_SITP                   ((uint32_t)0x00000003)            /*!< SITP[1:0] Serial interface type for channel y */
#define  DFSDM_CHCFGR1_SITP_1                 ((uint32_t)0x00000002)            /*!< Serial interface type for channel y, Bit 1 */
#define  DFSDM_CHCFGR1_SITP_0                 ((uint32_t)0x00000001)            /*!< Serial interface type for channel y, Bit 0 */

/***************  Bit definition for DFSDM_CHCFGR2 register  ******************/
#define  DFSDM_CHCFGR2_OFFSET                 ((uint32_t)0xFFFFFF00)            /*!< OFFSET[23:0] 24-bit calibration offset for channel y */
#define  DFSDM_CHCFGR2_DTRBS                  ((uint32_t)0x000000F8)            /*!< DTRBS[4:0] Data right bit-shift for channel y */

/******************  Bit definition for DFSDM_AWSCDR register *****************/
#define  DFSDM_AWSCDR_AWFORD                  ((uint32_t)0x00C00000)            /*!< AWFORD[1:0] Analog watchdog Sinc filter order on channel y */
#define  DFSDM_AWSCDR_AWFORD_1                ((uint32_t)0x00800000)            /*!< Analog watchdog Sinc filter order on channel y, Bit 1 */
#define  DFSDM_AWSCDR_AWFORD_0                ((uint32_t)0x00400000)            /*!< Analog watchdog Sinc filter order on channel y, Bit 0 */
#define  DFSDM_AWSCDR_AWFOSR                  ((uint32_t)0x001F0000)            /*!< AWFOSR[4:0] Analog watchdog filter oversampling ratio on channel y */
#define  DFSDM_AWSCDR_BKSCD                   ((uint32_t)0x0000F000)            /*!< BKSCD[3:0] Break signal assignment for short circuit detector on channel y */
#define  DFSDM_AWSCDR_SCDT                    ((uint32_t)0x000000FF)            /*!< SCDT[7:0] Short circuit detector threshold for channel y */

/****************  Bit definition for DFSDM_CHWDATR register *******************/
#define  DFSDM_AWSCDR_WDATA                   ((uint32_t)0x0000FFFF)            /*!< WDATA[15:0] Input channel y watchdog data */

/****************  Bit definition for DFSDM_CHDATINR register *****************/
#define  DFSDM_AWSCDR_INDAT0                   ((uint32_t)0x0000FFFF)            /*!< INDAT0[31:16] Input data for channel y or channel (y+1) */
#define  DFSDM_AWSCDR_INDAT1                   ((uint32_t)0xFFFF0000)            /*!< INDAT0[15:0] Input data for channel y */

/************************   DFSDM module registers  ****************************/

/********************  Bit definition for DFSDM_CR1 register *******************/
#define  DFSDM_CR1_AWFSEL                     ((uint32_t)0x40000000)            /*!< Analog watchdog fast mode select */
#define  DFSDM_CR1_FAST                       ((uint32_t)0x20000000)            /*!< Fast conversion mode selection */
#define  DFSDM_CR1_RCH                        ((uint32_t)0x07000000)            /*!< RCH[2:0] Regular channel selection */
#define  DFSDM_CR1_RDMAEN                     ((uint32_t)0x00200000)            /*!< DMA channel enabled to read data for the regular conversion */
#define  DFSDM_CR1_RSYNC                      ((uint32_t)0x00080000)            /*!< Launch regular conversion synchronously with DFSDMx */
#define  DFSDM_CR1_RCONT                      ((uint32_t)0x00040000)            /*!< Continuous mode selection for regular conversions */
#define  DFSDM_CR1_RSWSTART                   ((uint32_t)0x00020000)            /*!< Software start of a conversion on the regular channel */
#define  DFSDM_CR1_JEXTEN                     ((uint32_t)0x00006000)            /*!< JEXTEN[1:0] Trigger enable and trigger edge selection for injected conversions */
#define  DFSDM_CR1_JEXTEN_1                   ((uint32_t)0x00004000)            /*!< Trigger enable and trigger edge selection for injected conversions, Bit 1 */
#define  DFSDM_CR1_JEXTEN_0                   ((uint32_t)0x00002000)            /*!< Trigger enable and trigger edge selection for injected conversions, Bit 0 */
#define  DFSDM_CR1_JEXTSEL                    ((uint32_t)0x00000700)            /*!< JEXTSEL[2:0]Trigger signal selection for launching injected conversions */
#define  DFSDM_CR1_JEXTSEL_2                  ((uint32_t)0x00000400)            /*!< Trigger signal selection for launching injected conversions, Bit 2 */
#define  DFSDM_CR1_JEXTSEL_1                  ((uint32_t)0x00000200)            /*!< Trigger signal selection for launching injected conversions, Bit 1 */
#define  DFSDM_CR1_JEXTSEL_0                  ((uint32_t)0x00000100)            /*!< Trigger signal selection for launching injected conversions, Bit 0 */
#define  DFSDM_CR1_JEXTSEL_3                  ((uint32_t)0x00000800)            /*!< Trigger signal selection for launching injected conversions, Bit 0 */
#define  DFSDM_CR1_JEXTSEL_4                  ((uint32_t)0x00001000)            /*!< Trigger signal selection for launching injected conversions, Bit 0 */

#define  DFSDM_CR1_JDMAEN                     ((uint32_t)0x00000020)            /*!< DMA channel enabled to read data for the injected channel group */
#define  DFSDM_CR1_JSCAN                      ((uint32_t)0x00000010)            /*!< Scanning conversion in continuous mode selection for injected conversions */
#define  DFSDM_CR1_JSYNC                      ((uint32_t)0x00000008)            /*!< Launch an injected conversion synchronously with DFSDMx JSWSTART trigger  */
#define  DFSDM_CR1_JSWSTART                   ((uint32_t)0x00000002)            /*!< Start the conversion of the injected group of channels */
#define  DFSDM_CR1_DFEN                       ((uint32_t)0x00000001)            /*!< DFSDM enable */

/********************  Bit definition for DFSDM_CR2 register *******************/
#define  DFSDM_CR2_AWDCH                      ((uint32_t)0x00FF0000)            /*!< AWDCH[7:0] Analog watchdog channel selection */
#define  DFSDM_CR2_EXCH                       ((uint32_t)0x0000FF00)            /*!< EXCH[7:0] Extreme detector channel selection */
#define  DFSDM_CR2_CKABIE                     ((uint32_t)0x00000040)            /*!< Clock absence interrupt enable */
#define  DFSDM_CR2_SCDIE                      ((uint32_t)0x00000020)            /*!< Short circuit detector interrupt enable */
#define  DFSDM_CR2_AWDIE                      ((uint32_t)0x00000010)            /*!< Analog watchdog interrupt enable */
#define  DFSDM_CR2_ROVRIE                     ((uint32_t)0x00000008)            /*!< Regular data overrun interrupt enable */
#define  DFSDM_CR2_JOVRIE                     ((uint32_t)0x00000004)            /*!< Injected data overrun interrupt enable */
#define  DFSDM_CR2_REOCIE                     ((uint32_t)0x00000002)            /*!< Regular end of conversion interrupt enable */
#define  DFSDM_CR2_JEOCIE                     ((uint32_t)0x00000001)            /*!< Injected end of conversion interrupt enable */

/********************  Bit definition for DFSDM_ISR register *******************/
#define  DFSDM_ISR_SCDF                       ((uint32_t)0xFF000000)            /*!< SCDF[7:0] Short circuit detector flag */
#define  DFSDM_ISR_CKABF                      ((uint32_t)0x00FF0000)            /*!< CKABF[7:0] Clock absence flag */
#define  DFSDM_ISR_RCIP                       ((uint32_t)0x00004000)            /*!< Regular conversion in progress status */
#define  DFSDM_ISR_JCIP                       ((uint32_t)0x00002000)            /*!< Injected conversion in progress status */
#define  DFSDM_ISR_AWDF                       ((uint32_t)0x00000010)            /*!< Analog watchdog */
#define  DFSDM_ISR_ROVRF                      ((uint32_t)0x00000008)            /*!< Regular conversion overrun flag */
#define  DFSDM_ISR_JOVRF                      ((uint32_t)0x00000004)            /*!< Injected conversion overrun flag */
#define  DFSDM_ISR_REOCF                      ((uint32_t)0x00000002)            /*!< End of regular conversion flag */
#define  DFSDM_ISR_JEOCF                      ((uint32_t)0x00000001)            /*!< End of injected conversion flag */

/********************  Bit definition for DFSDM_ICR register *******************/
#define  DFSDM_ICR_CLRSCSDF                   ((uint32_t)0xFF000000)            /*!< CLRSCSDF[7:0] Clear the short circuit detector flag */
#define  DFSDM_ICR_CLRCKABF                   ((uint32_t)0x00FF0000)            /*!< CLRCKABF[7:0] Clear the clock absence flag */
#define  DFSDM_ICR_CLRROVRF                   ((uint32_t)0x00000008)            /*!< Clear the regular conversion overrun flag */
#define  DFSDM_ICR_CLRJOVRF                   ((uint32_t)0x00000004)            /*!< Clear the injected conversion overrun flag */

/*******************  Bit definition for DFSDM_JCHGR register ******************/
#define  DFSDM_JCHGR_JCHG                     ((uint32_t)0x000000FF)            /*!< JCHG[7:0] Injected channel group selection */

/********************  Bit definition for DFSDM_FCR register *******************/
#define  DFSDM_FCR_FORD                       ((uint32_t)0xE0000000)            /*!< FORD[2:0] Sinc filter order */
#define  DFSDM_FCR_FORD_2                     ((uint32_t)0x80000000)            /*!< Sinc filter order, Bit 2 */
#define  DFSDM_FCR_FORD_1                     ((uint32_t)0x40000000)            /*!< Sinc filter order, Bit 1 */
#define  DFSDM_FCR_FORD_0                     ((uint32_t)0x20000000)            /*!< Sinc filter order, Bit 0 */
#define  DFSDM_FCR_FOSR                       ((uint32_t)0x03FF0000)            /*!< FOSR[9:0] Sinc filter oversampling ratio (decimation rate) */
#define  DFSDM_FCR_IOSR                       ((uint32_t)0x000000FF)            /*!< IOSR[7:0] Integrator oversampling ratio (averaging length) */

/******************  Bit definition for DFSDM_JDATAR register *****************/
#define  DFSDM_JDATAR_JDATA                   ((uint32_t)0xFFFFFF00)            /*!< JDATA[23:0] Injected group conversion data */
#define  DFSDM_JDATAR_JDATACH                 ((uint32_t)0x00000007)            /*!< JDATACH[2:0] Injected channel most recently converted */

/******************  Bit definition for DFSDM_RDATAR register *****************/
#define  DFSDM_RDATAR_RDATA                   ((uint32_t)0xFFFFFF00)            /*!< RDATA[23:0] Regular channel conversion data */
#define  DFSDM_RDATAR_RPEND                   ((uint32_t)0x00000010)            /*!< RPEND Regular channel pending data */
#define  DFSDM_RDATAR_RDATACH                 ((uint32_t)0x00000007)            /*!< RDATACH[2:0] Regular channel most recently converted */

/******************  Bit definition for DFSDM_AWHTR register ******************/
#define  DFSDM_AWHTR_AWHT                    ((uint32_t)0xFFFFFF00)             /*!< AWHT[23:0] Analog watchdog high threshold */
#define  DFSDM_AWHTR_BKAWH                   ((uint32_t)0x0000000F)             /*!< BKAWH[3:0] Break signal assignment to analog watchdog high threshold event */

/******************  Bit definition for DFSDM_AWLTR register ******************/
#define  DFSDM_AWLTR_AWLT                    ((uint32_t)0xFFFFFF00)             /*!< AWHT[23:0] Analog watchdog low threshold */
#define  DFSDM_AWLTR_BKAWL                   ((uint32_t)0x0000000F)             /*!< BKAWL[3:0] Break signal assignment to analog watchdog low threshold event */

/******************  Bit definition for DFSDM_AWSR register ******************/
#define  DFSDM_AWSR_AWHTF                    ((uint32_t)0x0000FF00)             /*!< AWHTF[15:8] Analog watchdog high threshold error on given channels */
#define  DFSDM_AWSR_AWLTF                    ((uint32_t)0x000000FF)             /*!< AWLTF[7:0] Analog watchdog low threshold error on given channels */

/******************  Bit definition for DFSDM_AWCFR) register *****************/
#define  DFSDM_AWCFR_CLRAWHTF                ((uint32_t)0x0000FF00)             /*!< CLRAWHTF[15:8] Clear the Analog watchdog high threshold flag */
#define  DFSDM_AWCFR_CLRAWLTF                ((uint32_t)0x000000FF)             /*!< CLRAWLTF[7:0] Clear the Analog watchdog low threshold flag */

/******************  Bit definition for DFSDM_EXMAX register ******************/
#define  DFSDM_EXMAX_EXMAX                   ((uint32_t)0xFFFFFF00)             /*!< EXMAX[23:0] Extreme detector maximum value */
#define  DFSDM_EXMAX_EXMAXCH                 ((uint32_t)0x00000007)             /*!< EXMAXCH[2:0] Extreme detector maximum data channel */

/******************  Bit definition for DFSDM_EXMIN register ******************/
#define  DFSDM_EXMIN_EXMIN                   ((uint32_t)0xFFFFFF00)             /*!< EXMIN[23:0] Extreme detector minimum value */
#define  DFSDM_EXMIN_EXMINCH                 ((uint32_t)0x00000007)             /*!< EXMINCH[2:0] Extreme detector minimum data channel */

/******************  Bit definition for DFSDM_EXMIN register ******************/
#define  DFSDM_CNVTIMR_CNVCNT                ((uint32_t)0xFFFFFFF0)             /*!< CNVCNT[27:0]: 28-bit timer counting conversion time */

/******************************************************************************/
/*                                                                            */
/*                           BDMA Controller                                  */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for BDMA_ISR register  ********************/
#define  BDMA_ISR_GIF0                        ((uint32_t)0x00000001)        /*!< Channel 0 Global interrupt flag */
#define  BDMA_ISR_TCIF0                       ((uint32_t)0x00000002)        /*!< Channel 0 Transfer Complete flag */
#define  BDMA_ISR_HTIF0                       ((uint32_t)0x00000004)        /*!< Channel 0 Half Transfer flag */
#define  BDMA_ISR_TEIF0                       ((uint32_t)0x00000008)        /*!< Channel 0 Transfer Error flag */
#define  BDMA_ISR_GIF1                        ((uint32_t)0x00000010)        /*!< Channel 1 Global interrupt flag */
#define  BDMA_ISR_TCIF1                       ((uint32_t)0x00000020)        /*!< Channel 1 Transfer Complete flag */
#define  BDMA_ISR_HTIF1                       ((uint32_t)0x00000040)        /*!< Channel 1 Half Transfer flag */
#define  BDMA_ISR_TEIF1                       ((uint32_t)0x00000080)        /*!< Channel 1 Transfer Error flag */
#define  BDMA_ISR_GIF2                        ((uint32_t)0x00000100)        /*!< Channel 2 Global interrupt flag */
#define  BDMA_ISR_TCIF2                       ((uint32_t)0x00000200)        /*!< Channel 2 Transfer Complete flag */
#define  BDMA_ISR_HTIF2                       ((uint32_t)0x00000400)        /*!< Channel 2 Half Transfer flag */
#define  BDMA_ISR_TEIF2                       ((uint32_t)0x00000800)        /*!< Channel 2 Transfer Error flag */
#define  BDMA_ISR_GIF3                        ((uint32_t)0x00001000)        /*!< Channel 3 Global interrupt flag */
#define  BDMA_ISR_TCIF3                       ((uint32_t)0x00002000)        /*!< Channel 3 Transfer Complete flag */
#define  BDMA_ISR_HTIF3                       ((uint32_t)0x00004000)        /*!< Channel 3 Half Transfer flag */
#define  BDMA_ISR_TEIF3                       ((uint32_t)0x00008000)        /*!< Channel 3 Transfer Error flag */
#define  BDMA_ISR_GIF4                        ((uint32_t)0x00010000)        /*!< Channel 4 Global interrupt flag */
#define  BDMA_ISR_TCIF4                       ((uint32_t)0x00020000)        /*!< Channel 4 Transfer Complete flag */
#define  BDMA_ISR_HTIF4                       ((uint32_t)0x00040000)        /*!< Channel 4 Half Transfer flag */
#define  BDMA_ISR_TEIF4                       ((uint32_t)0x00080000)        /*!< Channel 4 Transfer Error flag */
#define  BDMA_ISR_GIF5                        ((uint32_t)0x00100000)        /*!< Channel 5 Global interrupt flag */
#define  BDMA_ISR_TCIF5                       ((uint32_t)0x00200000)        /*!< Channel 5 Transfer Complete flag */
#define  BDMA_ISR_HTIF5                       ((uint32_t)0x00400000)        /*!< Channel 5 Half Transfer flag */
#define  BDMA_ISR_TEIF5                       ((uint32_t)0x00800000)        /*!< Channel 5 Transfer Error flag */
#define  BDMA_ISR_GIF6                        ((uint32_t)0x01000000)        /*!< Channel 6 Global interrupt flag */
#define  BDMA_ISR_TCIF6                       ((uint32_t)0x02000000)        /*!< Channel 6 Transfer Complete flag */
#define  BDMA_ISR_HTIF6                       ((uint32_t)0x04000000)        /*!< Channel 6 Half Transfer flag */
#define  BDMA_ISR_TEIF6                       ((uint32_t)0x08000000)        /*!< Channel 6 Transfer Error flag */
#define  BDMA_ISR_GIF7                        ((uint32_t)0x10000000)        /*!< Channel 7 Global interrupt flag */
#define  BDMA_ISR_TCIF7                       ((uint32_t)0x20000000)        /*!< Channel 7 Transfer Complete flag */
#define  BDMA_ISR_HTIF7                       ((uint32_t)0x40000000)        /*!< Channel 7 Half Transfer flag */
#define  BDMA_ISR_TEIF7                       ((uint32_t)0x80000000)        /*!< Channel 7 Transfer Error flag */

/*******************  Bit definition for BDMA_IFCR register  *******************/
#define  BDMA_IFCR_CGIF0                      ((uint32_t)0x00000001)        /*!< Channel 0 Global interrupt clearr */
#define  BDMA_IFCR_CTCIF0                     ((uint32_t)0x00000002)        /*!< Channel 0 Transfer Complete clear */
#define  BDMA_IFCR_CHTIF0                     ((uint32_t)0x00000004)        /*!< Channel 0 Half Transfer clear */
#define  BDMA_IFCR_CTEIF0                     ((uint32_t)0x00000008)        /*!< Channel 0 Transfer Error clear */
#define  BDMA_IFCR_CGIF1                      ((uint32_t)0x00000010)        /*!< Channel 1 Global interrupt clear */
#define  BDMA_IFCR_CTCIF1                     ((uint32_t)0x00000020)        /*!< Channel 1 Transfer Complete clear */
#define  BDMA_IFCR_CHTIF1                     ((uint32_t)0x00000040)        /*!< Channel 1 Half Transfer clear */
#define  BDMA_IFCR_CTEIF1                     ((uint32_t)0x00000080)        /*!< Channel 1 Transfer Error clear */
#define  BDMA_IFCR_CGIF2                      ((uint32_t)0x00000100)        /*!< Channel 2 Global interrupt clear */
#define  BDMA_IFCR_CTCIF2                     ((uint32_t)0x00000200)        /*!< Channel 2 Transfer Complete clear */
#define  BDMA_IFCR_CHTIF2                     ((uint32_t)0x00000400)        /*!< Channel 2 Half Transfer clear */
#define  BDMA_IFCR_CTEIF2                     ((uint32_t)0x00000800)        /*!< Channel 2 Transfer Error clear */
#define  BDMA_IFCR_CGIF3                      ((uint32_t)0x00001000)        /*!< Channel 3 Global interrupt clear */
#define  BDMA_IFCR_CTCIF3                     ((uint32_t)0x00002000)        /*!< Channel 3 Transfer Complete clear */
#define  BDMA_IFCR_CHTIF3                     ((uint32_t)0x00004000)        /*!< Channel 3 Half Transfer clear */
#define  BDMA_IFCR_CTEIF3                     ((uint32_t)0x00008000)        /*!< Channel 3 Transfer Error clear */
#define  BDMA_IFCR_CGIF4                      ((uint32_t)0x00010000)        /*!< Channel 4 Global interrupt clear */
#define  BDMA_IFCR_CTCIF4                     ((uint32_t)0x00020000)        /*!< Channel 4 Transfer Complete clear */
#define  BDMA_IFCR_CHTIF4                     ((uint32_t)0x00040000)        /*!< Channel 4 Half Transfer clear */
#define  BDMA_IFCR_CTEIF4                     ((uint32_t)0x00080000)        /*!< Channel 4 Transfer Error clear */
#define  BDMA_IFCR_CGIF5                      ((uint32_t)0x00100000)        /*!< Channel 5 Global interrupt clear */
#define  BDMA_IFCR_CTCIF5                     ((uint32_t)0x00200000)        /*!< Channel 5 Transfer Complete clear */
#define  BDMA_IFCR_CHTIF5                     ((uint32_t)0x00400000)        /*!< Channel 5 Half Transfer clear */
#define  BDMA_IFCR_CTEIF5                     ((uint32_t)0x00800000)        /*!< Channel 5 Transfer Error clear */
#define  BDMA_IFCR_CGIF6                      ((uint32_t)0x01000000)        /*!< Channel 6 Global interrupt clear */
#define  BDMA_IFCR_CTCIF6                     ((uint32_t)0x02000000)        /*!< Channel 6 Transfer Complete clear */
#define  BDMA_IFCR_CHTIF6                     ((uint32_t)0x04000000)        /*!< Channel 6 Half Transfer clear */
#define  BDMA_IFCR_CTEIF6                     ((uint32_t)0x08000000)        /*!< Channel 6 Transfer Error clear */
#define  BDMA_IFCR_CGIF7                      ((uint32_t)0x10000000)        /*!< Channel 7 Global interrupt clear */
#define  BDMA_IFCR_CTCIF7                     ((uint32_t)0x20000000)        /*!< Channel 7 Transfer Complete clear */
#define  BDMA_IFCR_CHTIF7                     ((uint32_t)0x40000000)        /*!< Channel 7 Half Transfer clear */
#define  BDMA_IFCR_CTEIF7                     ((uint32_t)0x80000000)        /*!< Channel 7 Transfer Error clear */

/*******************  Bit definition for BDMA_CCR register  ********************/
#define  BDMA_CCR_EN                          ((uint32_t)0x00000001)        /*!< Channel enable                      */
#define  BDMA_CCR_TCIE                        ((uint32_t)0x00000002)        /*!< Transfer complete interrupt enable  */
#define  BDMA_CCR_HTIE                        ((uint32_t)0x00000004)        /*!< Half Transfer interrupt enable      */
#define  BDMA_CCR_TEIE                        ((uint32_t)0x00000008)        /*!< Transfer error interrupt enable     */
#define  BDMA_CCR_DIR                         ((uint32_t)0x00000010)        /*!< Data transfer direction             */
#define  BDMA_CCR_CIRC                        ((uint32_t)0x00000020)        /*!< Circular mode                       */
#define  BDMA_CCR_PINC                        ((uint32_t)0x00000040)        /*!< Peripheral increment mode           */
#define  BDMA_CCR_MINC                        ((uint32_t)0x00000080)        /*!< Memory increment mode               */

#define  BDMA_CCR_PSIZE                       ((uint32_t)0x00000300)        /*!< PSIZE[1:0] bits (Peripheral size)   */
#define  BDMA_CCR_PSIZE_0                     ((uint32_t)0x00000100)        /*!< Bit 0                               */
#define  BDMA_CCR_PSIZE_1                     ((uint32_t)0x00000200)        /*!< Bit 1                               */

#define  BDMA_CCR_MSIZE                       ((uint32_t)0x00000C00)        /*!< MSIZE[1:0] bits (Memory size)       */
#define  BDMA_CCR_MSIZE_0                     ((uint32_t)0x00000400)        /*!< Bit 0                               */
#define  BDMA_CCR_MSIZE_1                     ((uint32_t)0x00000800)        /*!< Bit 1                               */

#define  BDMA_CCR_PL                          ((uint32_t)0x00003000)        /*!< PL[1:0] bits(Channel Priority level)*/
#define  BDMA_CCR_PL_0                        ((uint32_t)0x00001000)        /*!< Bit 0                               */
#define  BDMA_CCR_PL_1                        ((uint32_t)0x00002000)        /*!< Bit 1                               */

#define  BDMA_CCR_MEM2MEM                     ((uint32_t)0x00004000)        /*!< Memory to memory mode               */

/******************  Bit definition for BDMA_CNDTR register  *******************/
#define  BDMA_CNDTR_NDT                       ((uint32_t)0x0000FFFF)        /*!< Number of data to Transfer          */

/******************  Bit definition for BDMA_CPAR register  ********************/
#define  BDMA_CPAR_PA                         ((uint32_t)0xFFFFFFFF)        /*!< Peripheral Address                  */

/******************  Bit definition for BDMA_CMAR register  ********************/
#define  BDMA_CMAR_MA                         ((uint32_t)0xFFFFFFFF)        /*!< Memory Address                      */

/******************************************************************************/
/*                                                                            */
/*                Ethernet MAC Registers bits definitions                     */
/*                                                                            */
/******************************************************************************/
/* Bit definition for Ethernet MAC Configuration Register register */
#define ETH_MACCR_ARP              ((uint32_t)0x80000000)  /* ARP Offload Enable */
#define ETH_MACCR_SARC             ((uint32_t)0x70000000)  /* Source Address Insertion or Replacement Control */
#define ETH_MACCR_SARC_MTIATI      ((uint32_t)0x00000000)  /* The mti_sa_ctrl_i and ati_sa_ctrl_i input signals control the SA field generation. */
#define ETH_MACCR_SARC_INSADDR0    ((uint32_t)0x20000000)  /* Insert MAC Address0 in the SA field of all transmitted packets. */
#define ETH_MACCR_SARC_INSADDR1    ((uint32_t)0x60000000)  /* Insert MAC Address1 in the SA field of all transmitted packets. */
#define ETH_MACCR_SARC_REPADDR0    ((uint32_t)0x30000000)  /* Replace MAC Address0 in the SA field of all transmitted packets. */
#define ETH_MACCR_SARC_REPADDR1    ((uint32_t)0x70000000)  /* Replace MAC Address1 in the SA field of all transmitted packets. */
#define ETH_MACCR_IPC              ((uint32_t)0x08000000)  /* Checksum Offload */
#define ETH_MACCR_IPG              ((uint32_t)0x07000000)  /* Inter-Packet Gap */
#define ETH_MACCR_IPG_96BIT        ((uint32_t)0x00000000)  /* Minimum IFG between Packets during transmission is 96Bit */
#define ETH_MACCR_IPG_88BIT        ((uint32_t)0x01000000)  /* Minimum IFG between Packets during transmission is 88Bit */
#define ETH_MACCR_IPG_80BIT        ((uint32_t)0x02000000)  /* Minimum IFG between Packets during transmission is 80Bit */
#define ETH_MACCR_IPG_72BIT        ((uint32_t)0x03000000)  /* Minimum IFG between Packets during transmission is 72Bit */
#define ETH_MACCR_IPG_64BIT        ((uint32_t)0x04000000)  /* Minimum IFG between Packets during transmission is 64Bit */        
#define ETH_MACCR_IPG_56BIT        ((uint32_t)0x05000000)  /* Minimum IFG between Packets during transmission is 56Bit */
#define ETH_MACCR_IPG_48BIT        ((uint32_t)0x06000000)  /* Minimum IFG between Packets during transmission is 48Bit */
#define ETH_MACCR_IPG_40BIT        ((uint32_t)0x07000000)  /* Minimum IFG between Packets during transmission is 40Bit */ 
#define ETH_MACCR_GPSLCE           ((uint32_t)0x00800000)  /* Giant Packet Size Limit Control Enable */
#define ETH_MACCR_S2KP             ((uint32_t)0x00400000)  /* IEEE 802.3as Support for 2K Packets */
#define ETH_MACCR_CST              ((uint32_t)0x00200000)  /* CRC stripping for Type packets */
#define ETH_MACCR_ACS              ((uint32_t)0x00100000)  /* Automatic Pad or CRC Stripping */
#define ETH_MACCR_WD               ((uint32_t)0x00080000)  /* Watchdog disable */
#define ETH_MACCR_JD               ((uint32_t)0x00020000)  /* Jabber disable */
#define ETH_MACCR_JE               ((uint32_t)0x00010000)  /* Jumbo Packet Enable */
#define ETH_MACCR_FES              ((uint32_t)0x00004000)  /* Fast ethernet speed */
#define ETH_MACCR_DM               ((uint32_t)0x00002000)  /* Duplex mode */
#define ETH_MACCR_LM               ((uint32_t)0x00001000)  /* loopback mode */
#define ETH_MACCR_ECRSFD           ((uint32_t)0x00000800)  /* Enable Carrier Sense Before Transmission in Full-Duplex Mode */
#define ETH_MACCR_RO               ((uint32_t)0x00000400)  /* Disable Receive own  */
#define ETH_MACCR_DCRS             ((uint32_t)0x00000200)  /* Disable Carrier Sense During Transmission */
#define ETH_MACCR_RD               ((uint32_t)0x00000100)  /* Disable Retry */
#define ETH_MACCR_BL               ((uint32_t)0x00000060)  /* Back-off limit mask */
#define ETH_MACCR_BL_10            ((uint32_t)0x00000000)  /* k = min (n, 10) */
#define ETH_MACCR_BL_8             ((uint32_t)0x00000020)  /* k = min (n, 8) */
#define ETH_MACCR_BL_4             ((uint32_t)0x00000040)  /* k = min (n, 4) */
#define ETH_MACCR_BL_1             ((uint32_t)0x00000060)  /* k = min (n, 1) */ 
#define ETH_MACCR_DC               ((uint32_t)0x00000010)  /* Defferal check */
#define ETH_MACCR_PRELEN           ((uint32_t)0x0000000C)  /* Preamble Length for Transmit packets */
#define ETH_MACCR_PRELEN_7         ((uint32_t)0x00000000)  /* 7 bytes of preamble */
#define ETH_MACCR_PRELEN_5         ((uint32_t)0x00000004)  /* 5 bytes of preamble */
#define ETH_MACCR_PRELEN_3         ((uint32_t)0x00000008)  /* 3 bytes of preamble */
#define ETH_MACCR_TE               ((uint32_t)0x00000002)  /* Transmitter enable */
#define ETH_MACCR_RE               ((uint32_t)0x00000001)  /* Receiver enable */

/* Bit definition for Ethernet MAC Extended Configuration Register register */
#define ETH_MACECR_EIPG            ((uint32_t)0x3E000000)  /* Extended Inter-Packet Gap */
#define ETH_MACECR_EIPGEN          ((uint32_t)0x01000000)  /* Extended Inter-Packet Gap Enable */
#define ETH_MACECR_USP             ((uint32_t)0x00040000)  /* Unicast Slow Protocol Packet Detect */
#define ETH_MACECR_SPEN            ((uint32_t)0x00020000)  /* Slow Protocol Detection Enable */
#define ETH_MACECR_DCRCC           ((uint32_t)0x00010000)  /* Disable CRC Checking for Received Packets */
#define ETH_MACECR_GPSL            ((uint32_t)0x00003FFF)  /* Giant Packet Size Limit */

/* Bit definition for Ethernet MAC Packet Filter Register */
#define ETH_MACPFR_RA                          ((uint32_t)0x80000000)  /* Receive all */ 
#define ETH_MACPFR_DNTU                        ((uint32_t)0x00200000)  /* Drop Non-TCP/UDP over IP Packets */ 
#define ETH_MACPFR_IPFE                        ((uint32_t)0x00100000)  /* Layer 3 and Layer 4 Filter Enable */ 
#define ETH_MACPFR_VTFE                        ((uint32_t)0x00010000)  /* VLAN Tag Filter Enable */ 
#define ETH_MACPFR_HPF                         ((uint32_t)0x00000400)  /* Hash or perfect filter */ 
#define ETH_MACPFR_SAF                         ((uint32_t)0x00000200)  /* Source address filter enable */ 
#define ETH_MACPFR_SAIF                        ((uint32_t)0x00000100)  /* SA inverse filtering */ 
#define ETH_MACPFR_PCF                         ((uint32_t)0x000000C0)  /* Pass control frames: 4 cases */
#define ETH_MACPFR_PCF_BLOCKALL                ((uint32_t)0x00000000)  /* MAC filters all control frames from reaching the application */
#define ETH_MACPFR_PCF_FORWARDALLEXCEPTPA      ((uint32_t)0x00000040)  /* MAC forwards all control frames except Pause packets to application even if they fail the Address Filter */
#define ETH_MACPFR_PCF_FORWARDALL              ((uint32_t)0x00000080)  /* MAC forwards all control frames to application even if they fail the Address Filter */
#define ETH_MACPFR_PCF_FORWARDPASSEDADDRFILTER ((uint32_t)0x000000C0)  /* MAC forwards control frames that pass the Address Filter. */ 
#define ETH_MACPFR_DBF                         ((uint32_t)0x00000020)  /* Disable Broadcast Packets */ 
#define ETH_MACPFR_PM                          ((uint32_t)0x00000010)  /* Pass all mutlicast */ 
#define ETH_MACPFR_DAIF                        ((uint32_t)0x00000008)  /* DA Inverse filtering */ 
#define ETH_MACPFR_HMC                         ((uint32_t)0x00000004)  /* Hash multicast */ 
#define ETH_MACPFR_HUC                         ((uint32_t)0x00000002)  /* Hash unicast */
#define ETH_MACPFR_PR                          ((uint32_t)0x00000001)  /* Promiscuous mode */

/* Bit definition for Ethernet MAC Watchdog Timeout Register */
#define ETH_MACWTR_PWE             ((uint32_t)0x00000100)  /* Programmable Watchdog Enable */
#define ETH_MACWTR_WTO             ((uint32_t)0x0000000F)  /* Watchdog Timeout */
#define ETH_MACWTR_WTO_2KB         ((uint32_t)0x00000000)  /* Maximum received packet length 2KB*/
#define ETH_MACWTR_WTO_3KB         ((uint32_t)0x00000001)  /* Maximum received packet length 3KB */
#define ETH_MACWTR_WTO_4KB         ((uint32_t)0x00000002)  /* Maximum received packet length 4KB */
#define ETH_MACWTR_WTO_5KB         ((uint32_t)0x00000003)  /* Maximum received packet length 5KB */
#define ETH_MACWTR_WTO_6KB         ((uint32_t)0x00000004)  /* Maximum received packet length 6KB */
#define ETH_MACWTR_WTO_7KB         ((uint32_t)0x00000005)  /* Maximum received packet length 7KB */
#define ETH_MACWTR_WTO_8KB         ((uint32_t)0x00000006)  /* Maximum received packet length 8KB */
#define ETH_MACWTR_WTO_9KB         ((uint32_t)0x00000007)  /* Maximum received packet length 9KB */
#define ETH_MACWTR_WTO_10KB        ((uint32_t)0x00000008)  /* Maximum received packet length 10KB */
#define ETH_MACWTR_WTO_11KB        ((uint32_t)0x00000009)  /* Maximum received packet length 11KB */
#define ETH_MACWTR_WTO_12KB        ((uint32_t)0x0000000A)  /* Maximum received packet length 12KB */
#define ETH_MACWTR_WTO_13KB        ((uint32_t)0x0000000B)  /* Maximum received packet length 13KB */
#define ETH_MACWTR_WTO_14KB        ((uint32_t)0x0000000C)  /* Maximum received packet length 14KB */
#define ETH_MACWTR_WTO_15KB        ((uint32_t)0x0000000D)  /* Maximum received packet length 15KB */
#define ETH_MACWTR_WTO_16KB        ((uint32_t)0x0000000E)  /* Maximum received packet length 16KB */
	
/* Bit definition for Ethernet MAC Hash Table High Register */
#define ETH_MACHTHR_HTH            ((uint32_t)0xFFFFFFFF)  /* Hash table high */

/* Bit definition for Ethernet MAC Hash Table Low Register */
#define ETH_MACHTLR_HTL            ((uint32_t)0xFFFFFFFF)  /* Hash table low */

/* Bit definition for Ethernet MAC VLAN Tag Register */
#define ETH_MACVTR_EIVLRXS            ((uint32_t)0x80000000)  /* Enable Inner VLAN Tag in Rx Status */
#define ETH_MACVTR_EIVLS              ((uint32_t)0x30000000)  /* Enable Inner VLAN Tag Stripping on Receive */
#define ETH_MACVTR_EIVLS_DONOTSTRIP   ((uint32_t)0x00000000)  /* Do not strip */
#define ETH_MACVTR_EIVLS_STRIPIFPASS  ((uint32_t)0x10000000)  /* Strip if VLAN filter passes */
#define ETH_MACVTR_EIVLS_STRIPIFFAILS ((uint32_t)0x20000000)  /* Strip if VLAN filter fails */
#define ETH_MACVTR_EIVLS_ALWAYSSTRIP  ((uint32_t)0x30000000)  /* Always strip */
#define ETH_MACVTR_ERIVLT             ((uint32_t)0x08000000)  /* Enable Inner VLAN Tag */
#define ETH_MACVTR_EDVLP              ((uint32_t)0x04000000)  /* Enable Double VLAN Processing */
#define ETH_MACVTR_VTHM               ((uint32_t)0x02000000)  /* VLAN Tag Hash Table Match Enable */
#define ETH_MACVTR_EVLRXS             ((uint32_t)0x01000000)  /* Enable VLAN Tag in Rx status */
#define ETH_MACVTR_EVLS               ((uint32_t)0x00600000)  /* Enable VLAN Tag Stripping on Receive */
#define ETH_MACVTR_EVLS_DONOTSTRIP    ((uint32_t)0x00000000)  /* Do not strip */
#define ETH_MACVTR_EVLS_STRIPIFPASS   ((uint32_t)0x00200000)  /* Strip if VLAN filter passes */
#define ETH_MACVTR_EVLS_STRIPIFFAILS  ((uint32_t)0x00400000)  /* Strip if VLAN filter fails */
#define ETH_MACVTR_EVLS_ALWAYSSTRIP   ((uint32_t)0x00600000)  /* Always strip */
#define ETH_MACVTR_DOVLTC             ((uint32_t)0x00100000)  /* Disable VLAN Type Check */
#define ETH_MACVTR_ERSVLM             ((uint32_t)0x00080000)  /* Enable Receive S-VLAN Match */
#define ETH_MACVTR_ESVL               ((uint32_t)0x00040000)  /* Enable S-VLAN */
#define ETH_MACVTR_VTIM               ((uint32_t)0x00020000)  /* VLAN Tag Inverse Match Enable */
#define ETH_MACVTR_ETV                ((uint32_t)0x00010000)  /* Enable 12-Bit VLAN Tag Comparison */
#define ETH_MACVTR_VL                 ((uint32_t)0x0000FFFF)  /* VLAN Tag Identifier for Receive Packets */
#define ETH_MACVTR_VL_UP              ((uint32_t)0x0000E000)  /* User Priority */
#define ETH_MACVTR_VL_CFIDEI          ((uint32_t)0x00001000)  /* Canonical Format Indicator or Drop Eligible Indicator */
#define ETH_MACVTR_VL_VID             ((uint32_t)0x00000FFF)  /* VLAN Identifier field of VLAN tag */

/* Bit definition for Ethernet MAC VLAN Hash Table Register */
#define ETH_MACVHTR_VLHT              ((uint32_t)0x0000FFFF)  /* VLAN Hash Table */

/* Bit definition for Ethernet MAC VLAN Incl Register */
#define ETH_MACVIR_VLTI                  ((uint32_t)0x00100000)  /* VLAN Tag Input */
#define ETH_MACVIR_CSVL                  ((uint32_t)0x00080000)  /* C-VLAN or S-VLAN */
#define ETH_MACVIR_VLP                   ((uint32_t)0x00040000)  /* VLAN Priority Control */
#define ETH_MACVIR_VLC                   ((uint32_t)0x00030000)  /* VLAN Tag Control in Transmit Packets */
#define ETH_MACVIR_VLC_NOVLANTAG         ((uint32_t)0x00000000)  /* No VLAN tag deletion, insertion, or replacement */
#define ETH_MACVIR_VLC_VLANTAGDELETE     ((uint32_t)0x00010000)  /* VLAN tag deletion */
#define ETH_MACVIR_VLC_VLANTAGINSERT     ((uint32_t)0x00020000)  /* VLAN tag insertion */
#define ETH_MACVIR_VLC_VLANTAGREPLACE    ((uint32_t)0x00030000)  /* VLAN tag replacement */
#define ETH_MACVIR_VLT                   ((uint32_t)0x000FFFF)   /* VLAN Tag for Transmit Packets */
#define ETH_MACVIR_VLT_UP                ((uint32_t)0x0000E000)  /* User Priority */
#define ETH_MACVIR_VLT_CFIDEI            ((uint32_t)0x00001000)  /* Canonical Format Indicator or Drop Eligible Indicator */
#define ETH_MACVIR_VLT_VID               ((uint32_t)0x00000FFF)  /* VLAN Identifier field of VLAN tag */

/* Bit definition for Ethernet MAC Inner_VLAN Incl Register */
#define ETH_MACIVIR_VLTI                 ((uint32_t)0x00100000)  /* VLAN Tag Input */
#define ETH_MACIVIR_CSVL                 ((uint32_t)0x00080000)  /* C-VLAN or S-VLAN */
#define ETH_MACIVIR_VLP                  ((uint32_t)0x00040000)  /* VLAN Priority Control */
#define ETH_MACIVIR_VLC                  ((uint32_t)0x00030000)  /* VLAN Tag Control in Transmit Packets */
#define ETH_MACIVIR_VLC_NOVLANTAG        ((uint32_t)0x00000000)  /* No VLAN tag deletion, insertion, or replacement */
#define ETH_MACIVIR_VLC_VLANTAGDELETE    ((uint32_t)0x00010000)  /* VLAN tag deletion */
#define ETH_MACIVIR_VLC_VLANTAGINSERT    ((uint32_t)0x00020000)  /* VLAN tag insertion */
#define ETH_MACIVIR_VLC_VLANTAGREPLACE   ((uint32_t)0x00030000)  /* VLAN tag replacement */
#define ETH_MACIVIR_VLT                  ((uint32_t)0x000FFFF)   /* VLAN Tag for Transmit Packets */
#define ETH_MACIVIR_VLT_UP               ((uint32_t)0x0000E000)  /* User Priority */
#define ETH_MACIVIR_VLT_CFIDEI           ((uint32_t)0x00001000)  /* Canonical Format Indicator or Drop Eligible Indicator */
#define ETH_MACIVIR_VLT_VID              ((uint32_t)0x00000FFF)  /* VLAN Identifier field of VLAN tag */

/* Bit definition for Ethernet MAC Tx Flow Ctrl Register */
#define ETH_MACTFCR_PT                   ((uint32_t)0xFFFF0000)  /* Pause Time */
#define ETH_MACTFCR_DZPQ                 ((uint32_t)0x00000080)  /* Disable Zero-Quanta Pause */
#define ETH_MACTFCR_PLT                  ((uint32_t)0x00000070)  /* Pause Low Threshold */
#define ETH_MACTFCR_PLT_MINUS4           ((uint32_t)0x00000000)  /* Pause time minus 4 slot times */
#define ETH_MACTFCR_PLT_MINUS28          ((uint32_t)0x00000010)  /* Pause time minus 28 slot times */
#define ETH_MACTFCR_PLT_MINUS36          ((uint32_t)0x00000020)  /* Pause time minus 36 slot times */
#define ETH_MACTFCR_PLT_MINUS144         ((uint32_t)0x00000030)  /* Pause time minus 144 slot times */
#define ETH_MACTFCR_PLT_MINUS256         ((uint32_t)0x00000040)  /* Pause time minus 256 slot times */
#define ETH_MACTFCR_PLT_MINUS512         ((uint32_t)0x00000050)  /* Pause time minus 512 slot times */
#define ETH_MACTFCR_TFE                  ((uint32_t)0x00000002)  /* Transmit Flow Control Enable */
#define ETH_MACTFCR_FCB                  ((uint32_t)0x00000001)  /* Flow Control Busy or Backpressure Activate */

/* Bit definition for Ethernet MAC Rx Flow Ctrl Register */
#define ETH_MACRFCR_UP                   ((uint32_t)0x00000002)  /* Unicast Pause Packet Detect */
#define ETH_MACRFCR_RFE                  ((uint32_t)0x00000001)  /* Receive Flow Control Enable */

/* Bit definition for Ethernet MAC Interrupt Status Register */
#define ETH_MACISR_RXSTSIS               ((uint32_t)0x00004000)  /* Receive Status Interrupt */
#define ETH_MACISR_TXSTSIS               ((uint32_t)0x00002000)  /* Transmit Status Interrupt */
#define ETH_MACISR_TSIS                  ((uint32_t)0x00001000)  /* Timestamp Interrupt Status */
#define ETH_MACISR_MMCTXIS               ((uint32_t)0x00000400)  /* MMC Transmit Interrupt Status */
#define ETH_MACISR_MMCRXIS               ((uint32_t)0x00000200)  /* MMC Receive Interrupt Status */
#define ETH_MACISR_MMCIS                 ((uint32_t)0x00000100)  /* MMC Interrupt Status */
#define ETH_MACISR_LPIIS                 ((uint32_t)0x00000020)  /* LPI Interrupt Status */
#define ETH_MACISR_PMTIS                 ((uint32_t)0x00000010)  /* PMT Interrupt Status */
#define ETH_MACISR_PHYIS                 ((uint32_t)0x00000008)  /* PHY Interrupt */

/* Bit definition for Ethernet MAC Interrupt Enable Register */
#define ETH_MACIER_RXSTSIE               ((uint32_t)0x00004000)  /* Receive Status Interrupt Enable */
#define ETH_MACIER_TXSTSIE               ((uint32_t)0x00002000)  /* Transmit Status Interrupt Enable */
#define ETH_MACIER_TSIE                  ((uint32_t)0x00001000)  /* Timestamp Interrupt Enable */
#define ETH_MACIER_LPIIE                 ((uint32_t)0x00000020)  /* LPI Interrupt Enable */
#define ETH_MACIER_PMTIE                 ((uint32_t)0x00000010)  /* PMT Interrupt Enable */
#define ETH_MACIER_PHYIE                 ((uint32_t)0x00000008)  /* PHY Interrupt Enable */

/* Bit definition for Ethernet MAC Rx Tx Status Register */
#define ETH_MACRTSR_RWT                  ((uint32_t)0x00000100)  /* Receive Watchdog Timeout */
#define ETH_MACRTSR_EXCOL                ((uint32_t)0x00000020)  /* Excessive Collisions */
#define ETH_MACRTSR_LCOL                 ((uint32_t)0x00000010)  /* Late Collision */
#define ETH_MACRTSR_EXDEF                ((uint32_t)0x00000008)  /* Excessive Deferral */
#define ETH_MACRTSR_LCARR                ((uint32_t)0x00000004)  /* Loss of Carrier */
#define ETH_MACRTSR_NCARR                ((uint32_t)0x00000002)  /* No Carrier */
#define ETH_MACRTSR_TJT                  ((uint32_t)0x00000001)  /* Transmit Jabber Timeout */

/* Bit definition for Ethernet MAC PMT Control Status Register */
#define ETH_MACPCSR_RWKFILTRST           ((uint32_t)0x80000000)  /* Remote Wake-Up Packet Filter Register Pointer Reset */
#define ETH_MACPCSR_RWKPTR               ((uint32_t)0x1F000000)  /* Remote Wake-up FIFO Pointer */
#define ETH_MACPCSR_RWKPFE               ((uint32_t)0x00000400)  /* Remote Wake-up Packet Forwarding Enable */
#define ETH_MACPCSR_GLBLUCAST            ((uint32_t)0x00000200)  /* Global Unicast */
#define ETH_MACPCSR_RWKPRCVD             ((uint32_t)0x00000040)  /* Remote Wake-Up Packet Received */
#define ETH_MACPCSR_MGKPRCVD             ((uint32_t)0x00000020)  /* Magic Packet Received */
#define ETH_MACPCSR_RWKPKTEN             ((uint32_t)0x00000004)  /* Remote Wake-Up Packet Enable */
#define ETH_MACPCSR_MGKPKTEN             ((uint32_t)0x00000002)  /* Magic Packet Enable */
#define ETH_MACPCSR_PWRDWN               ((uint32_t)0x00000001)  /* Power Down */

/* Bit definition for Ethernet MAC Remote Wake-Up Packet Filter Register */ 
#define ETH_MACRWUPFR_D                  ((uint32_t)0xFFFFFFFF)  /* Wake-up Packet filter register data */

/* Bit definition for Ethernet MAC LPI Control Status Register */ 
#define ETH_MACLPICSR_LPITCSE            ((uint32_t)0x00200000)  /* LPI Tx Clock Stop Enable */
#define ETH_MACLPICSR_LPITE              ((uint32_t)0x00100000)  /* LPI Timer Enable */
#define ETH_MACLPICSR_LPITXA             ((uint32_t)0x00080000)  /* LPI Tx Automate */
#define ETH_MACLPICSR_PLS                ((uint32_t)0x00020000)  /* PHY Link Status */
#define ETH_MACLPICSR_LPIEN              ((uint32_t)0x00010000)  /* LPI Enable */
#define ETH_MACLPICSR_RLPIST             ((uint32_t)0x00000200)  /* Receive LPI State */
#define ETH_MACLPICSR_TLPIST             ((uint32_t)0x00000100)  /* Transmit LPI State */
#define ETH_MACLPICSR_RLPIEX             ((uint32_t)0x00000008)  /* Receive LPI Exit */
#define ETH_MACLPICSR_RLPIEN             ((uint32_t)0x00000004)  /* Receive LPI Entry */
#define ETH_MACLPICSR_TLPIEX             ((uint32_t)0x00000002)  /* Transmit LPI Exit */
#define ETH_MACLPICSR_TLPIEN             ((uint32_t)0x00000001)  /* Transmit LPI Entry */

/* Bit definition for Ethernet MAC LPI Timers Control Register */ 
#define ETH_MACLPITCR_LST                ((uint32_t)0x03FF0000)  /* LPI LS TIMER */
#define ETH_MACLPITCR_TWT                ((uint32_t)0x0000FFFF)  /* LPI TW TIMER */

/* Bit definition for Ethernet MAC LPI Entry Timer Register */ 
#define ETH_MACLPIETR_LPIET              ((uint32_t)0x000FFFFF)  /* LPI Entry Timer */

/* Bit definition for Ethernet MAC 1US Tic Counter Register */ 
#define ETH_MAC1USTCR_TIC1USCNTR         ((uint32_t)0x00000FFF)  /* 1US TIC Counter */

/* Bit definition for Ethernet MAC Version Register */ 
#define ETH_MACVR_USERVER                ((uint32_t)0x0000FF00)  /* User-defined Version */
#define ETH_MACVR_SNPSVER                ((uint32_t)0x000000FF)  /* Synopsys-defined Version */

/* Bit definition for Ethernet MAC Debug Register */ 
#define ETH_MACDR_TFCSTS                 ((uint32_t)0x00060000)  /* MAC Transmit Packet Controller Status */
#define ETH_MACDR_TFCSTS_IDLE            ((uint32_t)0x00000000)  /* Idle state */
#define ETH_MACDR_TFCSTS_WAIT            ((uint32_t)0x00020000)  /* Waiting for status of the previous packet, IPG or backoff period to be over */
#define ETH_MACDR_TFCSTS_GENERATEPCP     ((uint32_t)0x00040000)  /* Generating and transmitting a Pause control packet */
#define ETH_MACDR_TFCSTS_TRASFERIP       ((uint32_t)0x00060000)  /* Transferring input packet for transmission */
#define ETH_MACDR_TPESTS                 ((uint32_t)0x00010000)  /* MAC Receive Packet Controller FIFO Status */
#define ETH_MACDR_RFCFCSTS               ((uint32_t)0x00000006)  /* MAC MII Transmit Protocol Engine Status */
#define ETH_MACDR_RPESTS                 ((uint32_t)0x00000001)  /* MAC MII Receive Protocol Engine Status */

/* Bit definition for Ethernet MAC HW Feature0 Register */
#define ETH_MACHWF0R_ACTPHYSEL           ((uint32_t)0x70000000)  /* Active PHY Selected */ 
#define ETH_MACHWF0R_ACTPHYSEL_MII       ((uint32_t)0x00000000) /* MII */
#define ETH_MACHWF0R_ACTPHYSEL_RMII      ((uint32_t)0x40000000) /* RMII */
#define ETH_MACHWF0R_ACTPHYSEL_REVMII    ((uint32_t)0x70000000) /* RevMII */
#define ETH_MACHWF0R_SAVLANINS           ((uint32_t)0x08000000)  /* Source Address or VLAN Insertion Enable */ 
#define ETH_MACHWF0R_TSSTSSEL            ((uint32_t)0x06000000)  /* Timestamp System Time Source */ 
#define ETH_MACHWF0R_TSSTSSEL_INTERNAL   ((uint32_t)0x02000000)  /* Timestamp System Time Source: Internal */ 
#define ETH_MACHWF0R_TSSTSSEL_EXTERNAL   ((uint32_t)0x04000000)  /* Timestamp System Time Source: External */ 
#define ETH_MACHWF0R_TSSTSSEL_BOTH       ((uint32_t)0x06000000)  /* Timestamp System Time Source: Internal & External */ 
#define ETH_MACHWF0R_MACADR64SEL         ((uint32_t)0x01000000)  /* MAC Addresses 64127 Selected */ 
#define ETH_MACHWF0R_MACADR32SEL         ((uint32_t)0x00800000)  /* MAC Addresses 3263 Selected */ 
#define ETH_MACHWF0R_ADDMACADRSEL        ((uint32_t)0x007C0000)  /* MAC Addresses 1 31 Selected */ 
#define ETH_MACHWF0R_RXCOESEL            ((uint32_t)0x00010000)  /* Receive Checksum Offload Enabled */ 
#define ETH_MACHWF0R_TXCOESEL            ((uint32_t)0x00004000)  /* Transmit Checksum Offload Enabled */ 
#define ETH_MACHWF0R_EEESEL              ((uint32_t)0x00002000)  /* Energy Efficient Ethernet Enabled */ 
#define ETH_MACHWF0R_TSSEL               ((uint32_t)0x00001000)  /* IEEE 1588-2008 Timestamp Enabled */ 
#define ETH_MACHWF0R_ARPOFFSEL           ((uint32_t)0x00000200)  /* ARP Offload Enabled */ 
#define ETH_MACHWF0R_MMCSEL              ((uint32_t)0x00000100)  /* RMON Module Enable */ 
#define ETH_MACHWF0R_MGKSEL              ((uint32_t)0x00000080)  /* PMT Magic Packet Enable */ 
#define ETH_MACHWF0R_RWKSEL              ((uint32_t)0x00000040)  /* PMT Remote Wake-up Packet Enable */ 
#define ETH_MACHWF0R_SMASEL              ((uint32_t)0x00000020)  /* SMA (MDIO) Interface */ 
#define ETH_MACHWF0R_VLHASH              ((uint32_t)0x00000010)   /* VLAN Hash Filter Selected */
#define ETH_MACHWF0R_PCSSEL              ((uint32_t)0x00000008)   /* PCS Registers (TBI, SGMII, or RTBI PHY interface) */
#define ETH_MACHWF0R_HDSEL               ((uint32_t)0x00000004)   /* Half-duplex Support */ 
#define ETH_MACHWF0R_GMIISEL             ((uint32_t)0x00000002)   /* 1000 Mbps Support */
#define ETH_MACHWF0R_MIISEL              ((uint32_t)0x00000001)   /* 10 or 100 Mbps Support */

/* Bit definition for Ethernet MAC HW Feature1 Register */ 
#define ETH_MACHWF1R_L3L4FNUM            ((uint32_t)0x78000000)  /* Total number of L3 or L4 Filters */
#define ETH_MACHWF1R_HASHTBLSZ           ((uint32_t)0x03000000)  /* Hash Table Size */
#define ETH_MACHWF1R_AVSEL               ((uint32_t)0x00100000)  /* AV Feature Enabled */
#define ETH_MACHWF1R_DBGMEMA             ((uint32_t)0x00080000)  /* Debug Memory Interface Enabled */
#define ETH_MACHWF1R_TSOEN               ((uint32_t)0x00040000)  /* TCP Segmentation Offload Enable */
#define ETH_MACHWF1R_SPHEN               ((uint32_t)0x00020000)  /* Split Header Feature Enable */
#define ETH_MACHWF1R_DCBEN               ((uint32_t)0x00010000)  /* DCB Feature Enable */
#define ETH_MACHWF1R_ADDR64              ((uint32_t)0x0000C000)  /* Address Width */
#define ETH_MACHWF1R_ADDR64_32           ((uint32_t)0x00000000)  /* Address Width: 32 */
#define ETH_MACHWF1R_ADDR64_40           ((uint32_t)0x00004000)  /* Address Width: 40 */
#define ETH_MACHWF1R_ADDR64_48           ((uint32_t)0x00008000)  /* Address Width: 48 */
#define ETH_MACHWF1R_ADVTHWORD           ((uint32_t)0x00002000)  /* IEEE 1588 High Word Register Enable */
#define ETH_MACHWF1R_PTOEN               ((uint32_t)0x00001000)  /* PTP Offload Enable */
#define ETH_MACHWF1R_OSTEN               ((uint32_t)0x00000800)  /* One-Step Timestamping Enable */
#define ETH_MACHWF1R_TXFIFOSIZE          ((uint32_t)0x000007C0)  /* MTL Transmit FIFO Size */
#define ETH_MACHWF1R_RXFIFOSIZE          ((uint32_t)0x0000001F)  /* MTL Receive FIFO Size */

/* Bit definition for Ethernet MAC HW Feature2 Register */
#define ETH_MACHWF2R_AUXSNAPNUM          ((uint32_t)0x70000000)  /* Number of Auxiliary Snapshot Inputs */
#define ETH_MACHWF2R_PPSOUTNUM           ((uint32_t)0x07000000)  /*  Number of PPS Outputs */
#define ETH_MACHWF2R_TXCHCNT             ((uint32_t)0x003C0000)  /* Number of DMA Transmit Channels */
#define ETH_MACHWF2R_RXCHCNT             ((uint32_t)0x0000E000)  /* Number of DMA Receive Channels */
#define ETH_MACHWF2R_TXQCNT              ((uint32_t)0x000003C0)  /* Number of MTL Transmit Queues */
#define ETH_MACHWF2R_RXQCNT              ((uint32_t)0x0000000F)  /* Number of MTL Receive Queues */

/* Bit definition for Ethernet MAC MDIO Address Register */
#define ETH_MACMDIOAR_PSE                ((uint32_t)0x08000000)  /* Preamble Suppression Enable */
#define ETH_MACMDIOAR_BTB                ((uint32_t)0x04000000)  /* Back to Back transactions */
#define ETH_MACMDIOAR_PA                 ((uint32_t)0x03E00000)  /* Physical Layer Address */
#define ETH_MACMDIOAR_RDA                ((uint32_t)0x001F0000)  /* Register/Device Address */
#define ETH_MACMDIOAR_NTC                ((uint32_t)0x00007000)  /* Number of Trailing Clocks */
#define ETH_MACMDIOAR_CR                 ((uint32_t)0x00000F00)  /* CSR Clock Range */
#define ETH_MACMDIOAR_CR_DIV42           ((uint32_t)0x00000000)  /* CSR clock/42 */
#define ETH_MACMDIOAR_CR_DIV62           ((uint32_t)0x00000100)  /* CSR clock/62 */
#define ETH_MACMDIOAR_CR_DIV16           ((uint32_t)0x00000200)  /* CSR clock/16 */
#define ETH_MACMDIOAR_CR_DIV26           ((uint32_t)0x00000300)  /* CSR clock/26 */
#define ETH_MACMDIOAR_CR_DIV102          ((uint32_t)0x00000400)  /* CSR clock/102 */
#define ETH_MACMDIOAR_CR_DIV124          ((uint32_t)0x00000500)  /* CSR clock/124 */
#define ETH_MACMDIOAR_CR_DIV4AR          ((uint32_t)0x00000800)  /* CSR clock/4: MDC clock above range specified in IEEE */
#define ETH_MACMDIOAR_CR_DIV6AR          ((uint32_t)0x00000900)  /* CSR clock/6: MDC clock above range specified in IEEE */
#define ETH_MACMDIOAR_CR_DIV8AR          ((uint32_t)0x00000A00)  /* CSR clock/8: MDC clock above range specified in IEEE */
#define ETH_MACMDIOAR_CR_DIV10AR         ((uint32_t)0x00000B00)  /* CSR clock/10: MDC clock above range specified in IEEE */
#define ETH_MACMDIOAR_CR_DIV12AR         ((uint32_t)0x00000C00)  /* CSR clock/12: MDC clock above range specified in IEEE */
#define ETH_MACMDIOAR_CR_DIV14AR         ((uint32_t)0x00000D00)  /* CSR clock/14: MDC clock above range specified in IEEE */
#define ETH_MACMDIOAR_CR_DIV16AR         ((uint32_t)0x00000E00)  /* CSR clock/16: MDC clock above range specified in IEEE */
#define ETH_MACMDIOAR_CR_DIV18AR         ((uint32_t)0x00000F00)  /* CSR clock/18: MDC clock above range specified in IEEE */
#define ETH_MACMDIOAR_SKAP               ((uint32_t)0x00000010)  /* Skip Address Packet */
#define ETH_MACMDIOAR_MOC                ((uint32_t)0x0000000C)  /* MII Operation Command */
#define ETH_MACMDIOAR_MOC_WR             ((uint32_t)0x00000004)  /* Write */
#define ETH_MACMDIOAR_MOC_PRDIA          ((uint32_t)0x00000008)  /* Post Read Increment Address for Clause 45 PHY */
#define ETH_MACMDIOAR_MOC_RD             ((uint32_t)0x0000000C)  /* Read */
#define ETH_MACMDIOAR_C45E               ((uint32_t)0x00000002)  /* Clause 45 PHY Enable */
#define ETH_MACMDIOAR_MB                 ((uint32_t)0x00000001)  /* MII Busy */

/* Bit definition for Ethernet MAC MDIO Data Register */
#define ETH_MACMDIODR_RA                 ((uint32_t)0xFFFF0000)  /* Register Address */
#define ETH_MACMDIODR_MD                 ((uint32_t)0x0000FFFF)  /* MII Data */

/* Bit definition for Ethernet MAC Address0 High Register */
#define ETH_MACA0HR_MACA0H               ((uint32_t)0x0000FFFF)  /* MAC address0 high */

/* Bit definition for Ethernet MAC Address0 Low Register */
#define ETH_MACA0LR_MACA0L               ((uint32_t)0xFFFFFFFF)  /* MAC address0 low */

/* Bit definition for Ethernet MAC Address1 High Register */
#define ETH_MACA1HR_AE                   ((uint32_t)0x80000000)  /* Address enable */
#define ETH_MACA1HR_SA                   ((uint32_t)0x40000000)  /* Source address */
#define ETH_MACA1HR_MBC                  ((uint32_t)0x3F000000)  /* Mask byte control: bits to mask for comparison of the MAC Address bytes */
#define ETH_MACA1HR_MBC_HBITS15_8        ((uint32_t)0x20000000)  /* Mask MAC Address high reg bits [15:8] */
#define ETH_MACA1HR_MBC_HBITS7_0         ((uint32_t)0x10000000)  /* Mask MAC Address high reg bits [7:0] */
#define ETH_MACA1HR_MBC_LBITS31_24       ((uint32_t)0x08000000)  /* Mask MAC Address low reg bits [31:24] */
#define ETH_MACA1HR_MBC_LBITS23_16       ((uint32_t)0x04000000)  /* Mask MAC Address low reg bits [23:16] */
#define ETH_MACA1HR_MBC_LBITS15_8        ((uint32_t)0x02000000)  /* Mask MAC Address low reg bits [15:8] */
#define ETH_MACA1HR_MBC_LBITS7_0         ((uint32_t)0x01000000)  /* Mask MAC Address low reg bits [7:0] */ 
#define ETH_MACA1HR_MACA1H               ((uint32_t)0x0000FFFF)  /* MAC address1 high */

/* Bit definition for Ethernet MAC Address1 Low Register */
#define ETH_MACA1LR_MACA1L               ((uint32_t)0xFFFFFFFF)  /* MAC address1 low */

/* Bit definition for Ethernet MAC Address2 High Register */
#define ETH_MACA2HR_AE                   ((uint32_t)0x80000000)  /* Address enable */
#define ETH_MACA2HR_SA                   ((uint32_t)0x40000000)  /* Source address */
#define ETH_MACA2HR_MBC                  ((uint32_t)0x3F000000)  /* Mask byte control */
#define ETH_MACA2HR_MBC_HBITS15_8        ((uint32_t)0x20000000)  /* Mask MAC Address high reg bits [15:8] */
#define ETH_MACA2HR_MBC_HBITS7_0         ((uint32_t)0x10000000)  /* Mask MAC Address high reg bits [7:0] */
#define ETH_MACA2HR_MBC_LBITS31_24       ((uint32_t)0x08000000)  /* Mask MAC Address low reg bits [31:24] */
#define ETH_MACA2HR_MBC_LBITS23_16       ((uint32_t)0x04000000)  /* Mask MAC Address low reg bits [23:16] */
#define ETH_MACA2HR_MBC_LBITS15_8        ((uint32_t)0x02000000)  /* Mask MAC Address low reg bits [15:8] */
#define ETH_MACA2HR_MBC_LBITS7_0         ((uint32_t)0x01000000)  /* Mask MAC Address low reg bits [70] */
#define ETH_MACA2HR_MACA2H               ((uint32_t)0x0000FFFF)  /* MAC address1 high */

/* Bit definition for Ethernet MAC Address2 Low Register */
#define ETH_MACA2LR_MACA2L               ((uint32_t)0xFFFFFFFF)  /* MAC address2 low */

/* Bit definition for Ethernet MAC Address3 High Register */
#define ETH_MACA3HR_AE                   ((uint32_t)0x80000000)  /* Address enable */
#define ETH_MACA3HR_SA                   ((uint32_t)0x40000000)  /* Source address */
#define ETH_MACA3HR_MBC                  ((uint32_t)0x3F000000)  /* Mask byte control */
#define ETH_MACA3HR_MBC_HBITS15_8        ((uint32_t)0x20000000)  /* Mask MAC Address high reg bits [15:8] */
#define ETH_MACA3HR_MBC_HBITS7_0         ((uint32_t)0x10000000)  /* Mask MAC Address high reg bits [7:0] */
#define ETH_MACA3HR_MBC_LBITS31_24       ((uint32_t)0x08000000)  /* Mask MAC Address low reg bits [31:24] */
#define ETH_MACA3HR_MBC_LBITS23_16       ((uint32_t)0x04000000)  /* Mask MAC Address low reg bits [23:16] */
#define ETH_MACA3HR_MBC_LBITS15_8        ((uint32_t)0x02000000)  /* Mask MAC Address low reg bits [15:8] */
#define ETH_MACA3HR_MBC_LBITS7_0         ((uint32_t)0x01000000)  /* Mask MAC Address low reg bits [70] */
#define ETH_MACA3HR_MACA3H               ((uint32_t)0x0000FFFF)  /* MAC address3 high */

/* Bit definition for Ethernet MAC Address3 Low Register */
#define ETH_MACA3LR_MACA3L               ((uint32_t)0xFFFFFFFF)  /* MAC address3 low */

/* Bit definition for Ethernet MAC L3 L4 Control Register */
#define ETH_MACL3L4CR_L4DPIM             ((uint32_t)0x00200000)  /* Layer 4 Destination Port Inverse Match Enable */
#define ETH_MACL3L4CR_L4DPM              ((uint32_t)0x00100000)  /* Layer 4 Destination Port Match Enable */
#define ETH_MACL3L4CR_L4SPIM             ((uint32_t)0x00080000)  /* Layer 4 Source Port Inverse Match Enable */
#define ETH_MACL3L4CR_L4SPM              ((uint32_t)0x00040000)  /* Layer 4 Source Port Match Enable */
#define ETH_MACL3L4CR_L4PEN              ((uint32_t)0x00010000)  /* Layer 4 Protocol Enable */
#define ETH_MACL3L4CR_L3HDBM             ((uint32_t)0x0000F800)  /* Layer 3 IP DA Higher Bits Match */
#define ETH_MACL3L4CR_L3HSBM             ((uint32_t)0x000007C0)  /* Layer 3 IP SA Higher Bits Match */
#define ETH_MACL3L4CR_L3DAIM             ((uint32_t)0x00000020)  /* Layer 3 IP DA Inverse Match Enable */
#define ETH_MACL3L4CR_L3DAM              ((uint32_t)0x00000010)  /* Layer 3 IP DA Match Enable */
#define ETH_MACL3L4CR_L3SAIM             ((uint32_t)0x00000008)  /* Layer 3 IP SA Inverse Match Enable */
#define ETH_MACL3L4CR_L3SAM              ((uint32_t)0x00000004)  /* Layer 3 IP SA Match Enable*/
#define ETH_MACL3L4CR_L3PEN              ((uint32_t)0x00000001)  /* Layer 3 Protocol Enable */

/* Bit definition for Ethernet MAC L4 Address Register */
#define ETH_MACL4AR_L4DP                 ((uint32_t)0xFFFF0000)  /* Layer 4 Destination Port Number Field */
#define ETH_MACL4AR_L4SP                 ((uint32_t)0x0000FFFF)  /* Layer 4 Source Port Number Field */

/* Bit definition for Ethernet MAC L3 Address0 Register */
#define ETH_MACL3A0R_L3A0                ((uint32_t)0xFFFFFFFF)  /* Layer 3 Address 0 Field */

/* Bit definition for Ethernet MAC L4 Address1 Register */
#define ETH_MACL3A1R_L3A1                ((uint32_t)0xFFFFFFFF)  /* Layer 3 Address 1 Field */

/* Bit definition for Ethernet MAC L4 Address2 Register */
#define ETH_MACL3A2R_L3A2                ((uint32_t)0xFFFFFFFF)  /* Layer 3 Address 2 Field */

/* Bit definition for Ethernet MAC L4 Address3 Register */
#define ETH_MACL3A3R_L3A3                ((uint32_t)0xFFFFFFFF)  /* Layer 3 Address 3 Field */

/* Bit definition for Ethernet MTL Operation Mode Register */
#define ETH_MTLOMR_CNTCLR                ((uint32_t)0x00000200)  /* Counters Reset */
#define ETH_MTLOMR_CNTPRST               ((uint32_t)0x00000100)  /* Counters Preset */
#define ETH_MTLOMR_DTXSTS                ((uint32_t)0x00000002)  /* Drop Transmit Status */

/* Bit definition for Ethernet MTL Interrupt Status Register */
#define ETH_MTLISR_MACIS                 ((uint32_t)0x00010000)  /* MAC Interrupt Status */
#define ETH_MTLISR_QIS                   ((uint32_t)0x00000001)  /* Queue Interrupt status */

/* Bit definition for Ethernet MTL Tx Queue Operation Mode Register */
#define ETH_MTLTQOMR_TTC                 ((uint32_t)0x00000070)  /* Transmit Threshold Control */
#define ETH_MTLTQOMR_TTC_32BITS          ((uint32_t)0x00000000)  /* 32 bits Threshold */
#define ETH_MTLTQOMR_TTC_64BITS          ((uint32_t)0x00000010)  /* 64  bits Threshold */
#define ETH_MTLTQOMR_TTC_96BITS          ((uint32_t)0x00000020)  /* 96 bits Threshold */
#define ETH_MTLTQOMR_TTC_128BITS         ((uint32_t)0x00000030)  /* 128 bits Threshold */
#define ETH_MTLTQOMR_TTC_192BITS         ((uint32_t)0x00000040)  /* 192 bits Threshold */
#define ETH_MTLTQOMR_TTC_256BITS         ((uint32_t)0x00000050)  /* 256 bits Threshold */
#define ETH_MTLTQOMR_TTC_384BITS         ((uint32_t)0x00000060)  /* 384 bits Threshold */
#define ETH_MTLTQOMR_TTC_512BITS         ((uint32_t)0x00000070)  /* 512 bits Threshold */
#define ETH_MTLTQOMR_TSF                 ((uint32_t)0x00000002)  /* Transmit Store and Forward */
#define ETH_MTLTQOMR_FTQ                 ((uint32_t)0x00000001)  /* Flush Transmit Queue */

/* Bit definition for Ethernet MTL Tx Queue Underflow Register */
#define ETH_MTLTQUR_UFCNTOVF             ((uint32_t)0x00000800)  /* Overflow Bit for Underflow Packet Counter */
#define ETH_MTLTQUR_UFPKTCNT             ((uint32_t)0x000007FF)  /* Underflow Packet Counter */

/* Bit definition for Ethernet MTL Tx Queue Debug Register */
#define ETH_MTLTQDR_STXSTSF              ((uint32_t)0x00700000)  /* Number of Status Words in the Tx Status FIFO of Queue */
#define ETH_MTLTQDR_PTXQ                 ((uint32_t)0x00070000)  /* Number of Packets in the Transmit Queue */
#define ETH_MTLTQDR_TXSTSFSTS            ((uint32_t)0x00000020)  /* MTL Tx Status FIFO Full Status */
#define ETH_MTLTQDR_TXQSTS               ((uint32_t)0x00000010)  /* MTL Tx Queue Not Empty Status */
#define ETH_MTLTQDR_TWCSTS               ((uint32_t)0x00000008)  /* MTL Tx Queue Write Controller Status */
#define ETH_MTLTQDR_TRCSTS               ((uint32_t)0x00000006)  /* MTL Tx Queue Read Controller Status */
#define ETH_MTLTQDR_TXQSTS_IDLE          ((uint32_t)0x00000000)  /* Idle state */
#define ETH_MTLTQDR_TXQSTS_READ          ((uint32_t)0x00000002)  /* Read state (transferring data to the MAC transmitter) */
#define ETH_MTLTQDR_TXQSTS_WAITING       ((uint32_t)0x00000004)  /* Waiting for pending Tx Status from the MAC transmitter */
#define ETH_MTLTQDR_TXQSTS_FLUSHING      ((uint32_t)0x00000006)  /* Flushing the Tx queue because of the Packet Abort request from the MAC */   
#define ETH_MTLTQDR_TXQPAUSED            ((uint32_t)0x00000001)  /* Transmit Queue in Pause */

/* Bit definition for Ethernet MTL Queue Interrupt Control Status Register */
#define ETH_MTLQICSR_RXOIE               ((uint32_t)0x01000000)  /* Receive Queue Overflow Interrupt Enable */
#define ETH_MTLQICSR_RXOVFIS             ((uint32_t)0x00010000)  /* Receive Queue Overflow Interrupt Status */
#define ETH_MTLQICSR_TXUIE               ((uint32_t)0x00000100)  /* Transmit Queue Underflow Interrupt Enable */
#define ETH_MTLQICSR_TXUNFIS             ((uint32_t)0x00000001)  /* Transmit Queue Underflow Interrupt Status */

/* Bit definition for Ethernet MTL Rx Queue Operation Mode Register */
#define ETH_MTLRQOMR_DISTCPEF            ((uint32_t)0x00000040)  /* Disable Dropping of TCP/IP Checksum Error Packets */
#define ETH_MTLRQOMR_RSF                 ((uint32_t)0x00000020)  /* Receive Queue Store and Forward */
#define ETH_MTLRQOMR_FEP                 ((uint32_t)0x00000010)  /* Forward Error Packets */
#define ETH_MTLRQOMR_FUP                 ((uint32_t)0x00000008)  /* Forward Undersized Good Packets */
#define ETH_MTLRQOMR_RTC                 ((uint32_t)0x00000003)  /* Receive Queue Threshold Control */
#define ETH_MTLRQOMR_RTC_64BITS          ((uint32_t)0x00000000)  /* 64 bits Threshold */
#define ETH_MTLRQOMR_RTC_32BITS          ((uint32_t)0x00000001)  /* 32 bits Threshold */
#define ETH_MTLRQOMR_RTC_96BITS          ((uint32_t)0x00000002)  /* 96 bits Threshold */
#define ETH_MTLRQOMR_RTC_128BITS         ((uint32_t)0x00000003)  /* 128 bits Threshold */

/* Bit definition for Ethernet MTL Rx Queue Missed Packet Overflow Cnt Register */
#define ETH_MTLRQMPOCR_MISCNTOVF         ((uint32_t)0x08000000)  /* Missed Packet Counter Overflow Bit */
#define ETH_MTLRQMPOCR_MISPKTCNT         ((uint32_t)0x07FF0000)  /* Missed Packet Counter */
#define ETH_MTLRQMPOCR_OVFCNTOVF         ((uint32_t)0x00000800)  /* Overflow Counter Overflow Bit */
#define ETH_MTLRQMPOCR_OVFPKTCNT         ((uint32_t)0x000007FF)  /* Overflow Packet Counter */

/* Bit definition for Ethernet MTL Rx Queue Debug Register */
#define ETH_MTLRQDR_PRXQ                  ((uint32_t)0x3FFF0000)  /* Number of Packets in Receive Queue */
#define ETH_MTLRQDR_RXQSTS                ((uint32_t)0x00000030)  /* MTL Rx Queue Fill-Level Status */
#define ETH_MTLRQDR_RXQSTS_EMPTY          ((uint32_t)0x00000000)  /* Rx Queue empty */
#define ETH_MTLRQDR_RXQSTS_BELOWTHRESHOLD ((uint32_t)0x00000010)  /* Rx Queue fill-level below flow-control deactivate threshold */
#define ETH_MTLRQDR_RXQSTS_ABOVETHRESHOLD ((uint32_t)0x00000020)  /* Rx Queue fill-level above flow-control activate threshold */
#define ETH_MTLRQDR_RXQSTS_FULL           ((uint32_t)0x00000030)  /* Rx Queue full */
#define ETH_MTLRQDR_RRCSTS                ((uint32_t)0x00000006)  /* MTL Rx Queue Read Controller State */
#define ETH_MTLRQDR_RRCSTS_IDLE           ((uint32_t)0x00000000)  /* Idle state */
#define ETH_MTLRQDR_RRCSTS_READINGDATA    ((uint32_t)0x00000002)  /* Reading packet data */
#define ETH_MTLRQDR_RRCSTS_READINGSTATUS  ((uint32_t)0x00000004)  /* Reading packet status (or timestamp) */
#define ETH_MTLRQDR_RRCSTS_FLUSHING       ((uint32_t)0x00000006)  /* Flushing the packet data and status */
#define ETH_MTLRQDR_RWCSTS                ((uint32_t)0x00000001)  /* MTL Rx Queue Write Controller Active Status */

/* Bit definition for Ethernet MTL Rx Queue Control Register */
#define ETH_MTLRQCR_RQPA                 ((uint32_t)0x00000008)  /* Receive Queue Packet Arbitration */
#define ETH_MTLRQCR_RQW                  ((uint32_t)0x00000007)  /* Receive Queue Weight */

/* Bit definition for Ethernet DMA Mode Register */
#define ETH_DMAMR_INTM                   ((uint32_t)0x00030000)  /* This field defines the interrupt mode */
#define ETH_DMAMR_INTM_0                 ((uint32_t)0x00000000)  /* Interrupt mode 0 */
#define ETH_DMAMR_INTM_1                 ((uint32_t)0x00010000)  /* Interrupt mode 1 */
#define ETH_DMAMR_INTM_2                 ((uint32_t)0x00020000)  /* Interrupt mode 2 */
#define ETH_DMAMR_PR                     ((uint32_t)0x00007000)  /* Priority Ratio */
#define ETH_DMAMR_PR_1_1                 ((uint32_t)0x00000000)  /* The priority ratio is 1:1 */
#define ETH_DMAMR_PR_2_1                 ((uint32_t)0x00001000)  /* The priority ratio is 2:1 */
#define ETH_DMAMR_PR_3_1                 ((uint32_t)0x00002000)  /* The priority ratio is 3:1 */
#define ETH_DMAMR_PR_4_1                 ((uint32_t)0x00003000)  /* The priority ratio is 4:1 */
#define ETH_DMAMR_PR_5_1                 ((uint32_t)0x00004000)  /* The priority ratio is 5:1 */
#define ETH_DMAMR_PR_6_1                 ((uint32_t)0x00005000)  /* The priority ratio is 6:1 */
#define ETH_DMAMR_PR_7_1                 ((uint32_t)0x00006000)  /* The priority ratio is 7:1 */
#define ETH_DMAMR_PR_8_1                 ((uint32_t)0x00007000)  /* The priority ratio is 8:1 */
#define ETH_DMAMR_TXPR                   ((uint32_t)0x00000800)  /* Transmit Priority */
#define ETH_DMAMR_DA                     ((uint32_t)0x00000002)  /* DMA Tx or Rx Arbitration Scheme */
#define ETH_DMAMR_SWR                    ((uint32_t)0x00000001)  /* Software Reset */

/* Bit definition for Ethernet DMA SysBus Mode Register */
#define ETH_DMASBMR_RB                   ((uint32_t)0x00008000)  /* Rebuild INCRx Burst */
#define ETH_DMASBMR_MB                   ((uint32_t)0x00004000)  /* Mixed Burst */
#define ETH_DMASBMR_AAL                  ((uint32_t)0x00001000)  /* Address-Aligned Beats */
#define ETH_DMASBMR_FB                   ((uint32_t)0x00000001)  /* Fixed Burst Length */

/* Bit definition for Ethernet DMA Interrupt Status Register */
#define ETH_DMAISR_MACIS                 ((uint32_t)0x00020000)  /* MAC Interrupt Status */
#define ETH_DMAISR_MTLIS                 ((uint32_t)0x00010000)  /* MAC Interrupt Status */
#define ETH_DMAISR_DMACIS                ((uint32_t)0x00000001)  /* DMA Channel Interrupt Status */

/* Bit definition for Ethernet DMA Debug Status Register */
#define ETH_DMADSR_TPS                   ((uint32_t)0x0000F000)  /* DMA Channel Transmit Process State */
#define ETH_DMADSR_TPS_STOPPED           ((uint32_t)0x00000000)  /* Stopped (Reset or Stop Transmit Command issued) */
#define ETH_DMADSR_TPS_FETCHING          ((uint32_t)0x00001000)  /* Running (Fetching Tx Transfer Descriptor) */
#define ETH_DMADSR_TPS_WAITING           ((uint32_t)0x00002000)  /* Running (Waiting for status) */
#define ETH_DMADSR_TPS_READING           ((uint32_t)0x00003000)  /* Running (Reading Data from system memory buffer and queuing it to the Tx buffer (Tx FIFO)) */
#define ETH_DMADSR_TPS_TIMESTAMP_WR      ((uint32_t)0x00004000)  /* Timestamp write state */
#define ETH_DMADSR_TPS_SUSPENDED         ((uint32_t)0x00006000)  /* Suspended (Tx Descriptor Unavailable or Tx Buffer Underflow) */
#define ETH_DMADSR_TPS_CLOSING           ((uint32_t)0x00007000)  /* Running (Closing Tx Descriptor) */
#define ETH_DMADSR_RPS                   ((uint32_t)0x00000F00)  /* DMA Channel Receive Process State */
#define ETH_DMADSR_RPS_STOPPED           ((uint32_t)0x00000000)  /* Stopped (Reset or Stop Receive Command issued) */
#define ETH_DMADSR_RPS_FETCHING          ((uint32_t)0x00001000)  /* Running (Fetching Rx Transfer Descriptor) */
#define ETH_DMADSR_RPS_WAITING           ((uint32_t)0x00003000)  /* Running (Waiting for status) */
#define ETH_DMADSR_RPS_SUSPENDED         ((uint32_t)0x00004000)  /* Suspended (Rx Descriptor Unavailable) */
#define ETH_DMADSR_RPS_CLOSING           ((uint32_t)0x00005000)  /* Running (Closing the Rx Descriptor) */
#define ETH_DMADSR_RPS_TIMESTAMP_WR      ((uint32_t)0x00006000)  /* Timestamp write state */
#define ETH_DMADSR_RPS_TRANSFERRING      ((uint32_t)0x00007000)  /* Running (Transferring the received packet data from the Rx buffer to the system memory) */
  
/* Bit definition for Ethernet DMA Channel Control Register */
#define ETH_DMACCR_DSL                   ((uint32_t)0x001C0000)  /* Descriptor Skip Length */
#define ETH_DMACCR_DSL_0BIT              ((uint32_t)0x00000000)
#define ETH_DMACCR_DSL_32BIT             ((uint32_t)0x00040000)
#define ETH_DMACCR_DSL_64BIT             ((uint32_t)0x00080000)
#define ETH_DMACCR_DSL_128BIT            ((uint32_t)0x00100000)
#define ETH_DMACCR_8PBL                  ((uint32_t)0x00010000)  /* 8xPBL mode */
#define ETH_DMACCR_MSS                   ((uint32_t)0x00003FFF)  /* Maximum Segment Size */

/* Bit definition for Ethernet DMA Channel Tx Control Register */
#define ETH_DMACTCR_TPBL                 ((uint32_t)0x003F0000)  /* Transmit Programmable Burst Length */
#define ETH_DMACTCR_TPBL_1PBL            ((uint32_t)0x00010000)  /* Transmit Programmable Burst Length 1 */
#define ETH_DMACTCR_TPBL_2PBL            ((uint32_t)0x00020000)  /* Transmit Programmable Burst Length 2 */
#define ETH_DMACTCR_TPBL_4PBL            ((uint32_t)0x00040000)  /* Transmit Programmable Burst Length 4 */
#define ETH_DMACTCR_TPBL_8PBL            ((uint32_t)0x00080000)  /* Transmit Programmable Burst Length 8 */
#define ETH_DMACTCR_TPBL_16PBL           ((uint32_t)0x00100000)  /* Transmit Programmable Burst Length 16 */
#define ETH_DMACTCR_TPBL_32PBL           ((uint32_t)0x00200000)  /* Transmit Programmable Burst Length 32 */
#define ETH_DMACTCR_TSE                  ((uint32_t)0x00001000)  /* TCP Segmentation Enabled */
#define ETH_DMACTCR_OSP                  ((uint32_t)0x00000010)  /* Operate on Second Packet */
#define ETH_DMACTCR_ST                   ((uint32_t)0x00000001)  /* Start or Stop Transmission Command */

/* Bit definition for Ethernet DMA Channel Rx Control Register */
#define ETH_DMACRCR_RPF                  ((uint32_t)0x80000000)  /* Rx Packet Flush */
#define ETH_DMACRCR_RPBL                 ((uint32_t)0x003F0000)  /* Receive Programmable Burst Length */
#define ETH_DMACRCR_RPBL_1PBL            ((uint32_t)0x00010000)  /* Receive Programmable Burst Length 1 */
#define ETH_DMACRCR_RPBL_2PBL            ((uint32_t)0x00020000)  /* Receive Programmable Burst Length 2 */
#define ETH_DMACRCR_RPBL_4PBL            ((uint32_t)0x00040000)  /* Receive Programmable Burst Length 4 */
#define ETH_DMACRCR_RPBL_8PBL            ((uint32_t)0x00080000)  /* Receive Programmable Burst Length 8 */
#define ETH_DMACRCR_RPBL_16PBL           ((uint32_t)0x00100000)  /* Receive Programmable Burst Length 16 */
#define ETH_DMACRCR_RPBL_32PBL           ((uint32_t)0x00200000)  /* Receive Programmable Burst Length 32 */
#define ETH_DMACRCR_RBSZ                 ((uint32_t)0x00007FFE)  /* Receive Buffer size */
#define ETH_DMACRCR_SR                   ((uint32_t)0x00000001)  /* Start or Stop Receive */

/* Bit definition for Ethernet DMA CH Tx Desc List Address Register */
#define ETH_DMACTDLAR_TDESLA             ((uint32_t)0xFFFFFFFC)  /* Start of Transmit List */

/* Bit definition for Ethernet DMA CH Rx Desc List Address Register */
#define ETH_DMACRDLAR_RDESLA             ((uint32_t)0xFFFFFFFC)  /* Start of Receive List */

/* Bit definition for Ethernet DMA CH Tx Desc Tail Pointer Register */
#define ETH_DMACTDTPR_TDT                ((uint32_t)0xFFFFFFFC)  /* Transmit Descriptor Tail Pointer */

/* Bit definition for Ethernet DMA CH Rx Desc Tail Pointer Register */
#define ETH_DMACRDTPR_RDT                ((uint32_t)0xFFFFFFFC)  /* Receive Descriptor Tail Pointer */

/* Bit definition for Ethernet DMA CH Tx Desc Ring Length Register */
#define ETH_DMACTDRLR_TDRL               ((uint32_t)0x000003FF)  /* Transmit Descriptor Ring Length */

/* Bit definition for Ethernet DMA CH Rx Desc Ring Length Register */
#define ETH_DMACRDRLR_RDRL               ((uint32_t)0x000003FF)  /* Receive Descriptor Ring Length */

/* Bit definition for Ethernet DMA Channel Interrupt Enable Register */
#define ETH_DMACIER_NIE                  ((uint32_t)0x00008000)  /* Normal Interrupt Summary Enable */
#define ETH_DMACIER_AIE                  ((uint32_t)0x00004000)  /* Abnormal Interrupt Summary Enable */
#define ETH_DMACIER_CDEE                 ((uint32_t)0x00002000)  /* Context Descriptor Error Enable */
#define ETH_DMACIER_FBEE                 ((uint32_t)0x00001000)  /* Fatal Bus Error Enable */
#define ETH_DMACIER_ERIE                 ((uint32_t)0x00000800)  /* Early Receive Interrupt Enable */
#define ETH_DMACIER_ETIE                 ((uint32_t)0x00000400)  /* Early Transmit Interrupt Enable */
#define ETH_DMACIER_RWTE                 ((uint32_t)0x00000200)  /* Receive Watchdog Timeout Enable */
#define ETH_DMACIER_RSE                  ((uint32_t)0x00000100)  /* Receive Stopped Enable */
#define ETH_DMACIER_RBUE                 ((uint32_t)0x00000080)  /* Receive Buffer Unavailable Enable */
#define ETH_DMACIER_RIE                  ((uint32_t)0x00000040)  /* Receive Interrupt Enable */
#define ETH_DMACIER_TBUE                 ((uint32_t)0x00000004)  /* Transmit Buffer Unavailable Enable */
#define ETH_DMACIER_TXSE                 ((uint32_t)0x00000002)  /* Transmit Stopped Enable */
#define ETH_DMACIER_TIE                  ((uint32_t)0x00000001)  /* Transmit Interrupt Enable */

/* Bit definition for Ethernet DMA Channel Rx Interrupt Watchdog Timer Register */
#define ETH_DMACRIWTR_RWT                ((uint32_t)0x000000FF)  /* Receive Interrupt Watchdog Timer Count */

/* Bit definition for Ethernet DMA Channel Current App Tx Desc Register */
#define ETH_DMACCATDR_CURTDESAPTR        ((uint32_t)0xFFFFFFFF)  /* Application Transmit Descriptor Address Pointer */

/* Bit definition for Ethernet DMA Channel Current App Rx Desc Register */
#define ETH_DMACCARDR_CURRDESAPTR        ((uint32_t)0xFFFFFFFF)  /* Application Receive Descriptor Address Pointer */

/* Bit definition for Ethernet DMA Channel Current App Tx Buffer Register */
#define ETH_DMACCATBR_CURTBUFAPTR        ((uint32_t)0xFFFFFFFF)  /* Application Transmit Buffer Address Pointer */

/* Bit definition for Ethernet DMA Channel Current App Rx Buffer Register */
#define ETH_DMACCARBR_CURRBUFAPTR        ((uint32_t)0xFFFFFFFF)  /* Application Receive Buffer Address Pointer */

/* Bit definition for Ethernet DMA Channel Status Register */
#define ETH_DMACSR_REB                   ((uint32_t)0x00380000)  /* Rx DMA Error Bits */
#define ETH_DMACSR_TEB                   ((uint32_t)0x00070000)  /* Tx DMA Error Bits */
#define ETH_DMACSR_NIS                   ((uint32_t)0x00008000)  /* Normal Interrupt Summary */
#define ETH_DMACSR_AIS                   ((uint32_t)0x00004000)  /* Abnormal Interrupt Summary */
#define ETH_DMACSR_CDE                   ((uint32_t)0x00002000)  /* Context Descriptor Error */
#define ETH_DMACSR_FBE                   ((uint32_t)0x00001000)  /* Fatal Bus Error */
#define ETH_DMACSR_ERI                   ((uint32_t)0x00000800)  /* Early Receive Interrupt */
#define ETH_DMACSR_ETI                   ((uint32_t)0x00000400)  /* Early Transmit Interrupt */
#define ETH_DMACSR_RWT                   ((uint32_t)0x00000200)  /* Receive Watchdog Timeout */
#define ETH_DMACSR_RPS                   ((uint32_t)0x00000100)  /* Receive Process Stopped */
#define ETH_DMACSR_RBU                   ((uint32_t)0x00000080)  /* Receive Buffer Unavailable */
#define ETH_DMACSR_RI                    ((uint32_t)0x00000040)  /* Receive Interrupt */
#define ETH_DMACSR_TBU                   ((uint32_t)0x00000004)  /* Transmit Buffer Unavailable */
#define ETH_DMACSR_TPS                   ((uint32_t)0x00000002)  /* Transmit Process Stopped */
#define ETH_DMACSR_TI                    ((uint32_t)0x00000001)  /* Transmit Interrupt */

/* Bit definition for Ethernet DMA Channel missed frame count register */
#define ETH_DMACMFCR_MFCO                ((uint32_t)0x00008000)  /* Overflow status of the MFC Counter */
#define ETH_DMACMFCR_MFC                 ((uint32_t)0x000007FF)  /* The number of packet counters dropped by the DMA */

/******************************************************************************/
/*                                                                            */
/*                             DMA Controller                                 */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for DMA_SxCR register  *****************/ 
#define DMA_SxCR_MBURST                      ((uint32_t)0x01800000)
#define DMA_SxCR_MBURST_0                    ((uint32_t)0x00800000)
#define DMA_SxCR_MBURST_1                    ((uint32_t)0x01000000)
#define DMA_SxCR_PBURST                      ((uint32_t)0x00600000)
#define DMA_SxCR_PBURST_0                    ((uint32_t)0x00200000)
#define DMA_SxCR_PBURST_1                    ((uint32_t)0x00400000)
#define DMA_SxCR_ACK                         ((uint32_t)0x00100000)
#define DMA_SxCR_CT                          ((uint32_t)0x00080000)  
#define DMA_SxCR_DBM                         ((uint32_t)0x00040000)
#define DMA_SxCR_PL                          ((uint32_t)0x00030000)
#define DMA_SxCR_PL_0                        ((uint32_t)0x00010000)
#define DMA_SxCR_PL_1                        ((uint32_t)0x00020000)
#define DMA_SxCR_PINCOS                      ((uint32_t)0x00008000)
#define DMA_SxCR_MSIZE                       ((uint32_t)0x00006000)
#define DMA_SxCR_MSIZE_0                     ((uint32_t)0x00002000)
#define DMA_SxCR_MSIZE_1                     ((uint32_t)0x00004000)
#define DMA_SxCR_PSIZE                       ((uint32_t)0x00001800)
#define DMA_SxCR_PSIZE_0                     ((uint32_t)0x00000800)
#define DMA_SxCR_PSIZE_1                     ((uint32_t)0x00001000)
#define DMA_SxCR_MINC                        ((uint32_t)0x00000400)
#define DMA_SxCR_PINC                        ((uint32_t)0x00000200)
#define DMA_SxCR_CIRC                        ((uint32_t)0x00000100)
#define DMA_SxCR_DIR                         ((uint32_t)0x000000C0)
#define DMA_SxCR_DIR_0                       ((uint32_t)0x00000040)
#define DMA_SxCR_DIR_1                       ((uint32_t)0x00000080)
#define DMA_SxCR_PFCTRL                      ((uint32_t)0x00000020)
#define DMA_SxCR_TCIE                        ((uint32_t)0x00000010)
#define DMA_SxCR_HTIE                        ((uint32_t)0x00000008)
#define DMA_SxCR_TEIE                        ((uint32_t)0x00000004)
#define DMA_SxCR_DMEIE                       ((uint32_t)0x00000002)
#define DMA_SxCR_EN                          ((uint32_t)0x00000001)

/********************  Bits definition for DMA_SxCNDTR register  **************/
#define DMA_SxNDT                            ((uint32_t)0x0000FFFF)
#define DMA_SxNDT_0                          ((uint32_t)0x00000001)
#define DMA_SxNDT_1                          ((uint32_t)0x00000002)
#define DMA_SxNDT_2                          ((uint32_t)0x00000004)
#define DMA_SxNDT_3                          ((uint32_t)0x00000008)
#define DMA_SxNDT_4                          ((uint32_t)0x00000010)
#define DMA_SxNDT_5                          ((uint32_t)0x00000020)
#define DMA_SxNDT_6                          ((uint32_t)0x00000040)
#define DMA_SxNDT_7                          ((uint32_t)0x00000080)
#define DMA_SxNDT_8                          ((uint32_t)0x00000100)
#define DMA_SxNDT_9                          ((uint32_t)0x00000200)
#define DMA_SxNDT_10                         ((uint32_t)0x00000400)
#define DMA_SxNDT_11                         ((uint32_t)0x00000800)
#define DMA_SxNDT_12                         ((uint32_t)0x00001000)
#define DMA_SxNDT_13                         ((uint32_t)0x00002000)
#define DMA_SxNDT_14                         ((uint32_t)0x00004000)
#define DMA_SxNDT_15                         ((uint32_t)0x00008000)

/********************  Bits definition for DMA_SxFCR register  ****************/ 
#define DMA_SxFCR_FEIE                       ((uint32_t)0x00000080)
#define DMA_SxFCR_FS                         ((uint32_t)0x00000038)
#define DMA_SxFCR_FS_0                       ((uint32_t)0x00000008)
#define DMA_SxFCR_FS_1                       ((uint32_t)0x00000010)
#define DMA_SxFCR_FS_2                       ((uint32_t)0x00000020)
#define DMA_SxFCR_DMDIS                      ((uint32_t)0x00000004)
#define DMA_SxFCR_FTH                        ((uint32_t)0x00000003)
#define DMA_SxFCR_FTH_0                      ((uint32_t)0x00000001)
#define DMA_SxFCR_FTH_1                      ((uint32_t)0x00000002)

/********************  Bits definition for DMA_LISR register  *****************/ 
#define DMA_LISR_TCIF3                       ((uint32_t)0x08000000)
#define DMA_LISR_HTIF3                       ((uint32_t)0x04000000)
#define DMA_LISR_TEIF3                       ((uint32_t)0x02000000)
#define DMA_LISR_DMEIF3                      ((uint32_t)0x01000000)
#define DMA_LISR_FEIF3                       ((uint32_t)0x00400000)
#define DMA_LISR_TCIF2                       ((uint32_t)0x00200000)
#define DMA_LISR_HTIF2                       ((uint32_t)0x00100000)
#define DMA_LISR_TEIF2                       ((uint32_t)0x00080000)
#define DMA_LISR_DMEIF2                      ((uint32_t)0x00040000)
#define DMA_LISR_FEIF2                       ((uint32_t)0x00010000)
#define DMA_LISR_TCIF1                       ((uint32_t)0x00000800)
#define DMA_LISR_HTIF1                       ((uint32_t)0x00000400)
#define DMA_LISR_TEIF1                       ((uint32_t)0x00000200)
#define DMA_LISR_DMEIF1                      ((uint32_t)0x00000100)
#define DMA_LISR_FEIF1                       ((uint32_t)0x00000040)
#define DMA_LISR_TCIF0                       ((uint32_t)0x00000020)
#define DMA_LISR_HTIF0                       ((uint32_t)0x00000010)
#define DMA_LISR_TEIF0                       ((uint32_t)0x00000008)
#define DMA_LISR_DMEIF0                      ((uint32_t)0x00000004)
#define DMA_LISR_FEIF0                       ((uint32_t)0x00000001)

/********************  Bits definition for DMA_HISR register  *****************/ 
#define DMA_HISR_TCIF7                       ((uint32_t)0x08000000)
#define DMA_HISR_HTIF7                       ((uint32_t)0x04000000)
#define DMA_HISR_TEIF7                       ((uint32_t)0x02000000)
#define DMA_HISR_DMEIF7                      ((uint32_t)0x01000000)
#define DMA_HISR_FEIF7                       ((uint32_t)0x00400000)
#define DMA_HISR_TCIF6                       ((uint32_t)0x00200000)
#define DMA_HISR_HTIF6                       ((uint32_t)0x00100000)
#define DMA_HISR_TEIF6                       ((uint32_t)0x00080000)
#define DMA_HISR_DMEIF6                      ((uint32_t)0x00040000)
#define DMA_HISR_FEIF6                       ((uint32_t)0x00010000)
#define DMA_HISR_TCIF5                       ((uint32_t)0x00000800)
#define DMA_HISR_HTIF5                       ((uint32_t)0x00000400)
#define DMA_HISR_TEIF5                       ((uint32_t)0x00000200)
#define DMA_HISR_DMEIF5                      ((uint32_t)0x00000100)
#define DMA_HISR_FEIF5                       ((uint32_t)0x00000040)
#define DMA_HISR_TCIF4                       ((uint32_t)0x00000020)
#define DMA_HISR_HTIF4                       ((uint32_t)0x00000010)
#define DMA_HISR_TEIF4                       ((uint32_t)0x00000008)
#define DMA_HISR_DMEIF4                      ((uint32_t)0x00000004)
#define DMA_HISR_FEIF4                       ((uint32_t)0x00000001)

/********************  Bits definition for DMA_LIFCR register  ****************/ 
#define DMA_LIFCR_CTCIF3                     ((uint32_t)0x08000000)
#define DMA_LIFCR_CHTIF3                     ((uint32_t)0x04000000)
#define DMA_LIFCR_CTEIF3                     ((uint32_t)0x02000000)
#define DMA_LIFCR_CDMEIF3                    ((uint32_t)0x01000000)
#define DMA_LIFCR_CFEIF3                     ((uint32_t)0x00400000)
#define DMA_LIFCR_CTCIF2                     ((uint32_t)0x00200000)
#define DMA_LIFCR_CHTIF2                     ((uint32_t)0x00100000)
#define DMA_LIFCR_CTEIF2                     ((uint32_t)0x00080000)
#define DMA_LIFCR_CDMEIF2                    ((uint32_t)0x00040000)
#define DMA_LIFCR_CFEIF2                     ((uint32_t)0x00010000)
#define DMA_LIFCR_CTCIF1                     ((uint32_t)0x00000800)
#define DMA_LIFCR_CHTIF1                     ((uint32_t)0x00000400)
#define DMA_LIFCR_CTEIF1                     ((uint32_t)0x00000200)
#define DMA_LIFCR_CDMEIF1                    ((uint32_t)0x00000100)
#define DMA_LIFCR_CFEIF1                     ((uint32_t)0x00000040)
#define DMA_LIFCR_CTCIF0                     ((uint32_t)0x00000020)
#define DMA_LIFCR_CHTIF0                     ((uint32_t)0x00000010)
#define DMA_LIFCR_CTEIF0                     ((uint32_t)0x00000008)
#define DMA_LIFCR_CDMEIF0                    ((uint32_t)0x00000004)
#define DMA_LIFCR_CFEIF0                     ((uint32_t)0x00000001)

/********************  Bits definition for DMA_HIFCR  register  ****************/ 
#define DMA_HIFCR_CTCIF7                     ((uint32_t)0x08000000)
#define DMA_HIFCR_CHTIF7                     ((uint32_t)0x04000000)
#define DMA_HIFCR_CTEIF7                     ((uint32_t)0x02000000)
#define DMA_HIFCR_CDMEIF7                    ((uint32_t)0x01000000)
#define DMA_HIFCR_CFEIF7                     ((uint32_t)0x00400000)
#define DMA_HIFCR_CTCIF6                     ((uint32_t)0x00200000)
#define DMA_HIFCR_CHTIF6                     ((uint32_t)0x00100000)
#define DMA_HIFCR_CTEIF6                     ((uint32_t)0x00080000)
#define DMA_HIFCR_CDMEIF6                    ((uint32_t)0x00040000)
#define DMA_HIFCR_CFEIF6                     ((uint32_t)0x00010000)
#define DMA_HIFCR_CTCIF5                     ((uint32_t)0x00000800)
#define DMA_HIFCR_CHTIF5                     ((uint32_t)0x00000400)
#define DMA_HIFCR_CTEIF5                     ((uint32_t)0x00000200)
#define DMA_HIFCR_CDMEIF5                    ((uint32_t)0x00000100)
#define DMA_HIFCR_CFEIF5                     ((uint32_t)0x00000040)
#define DMA_HIFCR_CTCIF4                     ((uint32_t)0x00000020)
#define DMA_HIFCR_CHTIF4                     ((uint32_t)0x00000010)
#define DMA_HIFCR_CTEIF4                     ((uint32_t)0x00000008)
#define DMA_HIFCR_CDMEIF4                    ((uint32_t)0x00000004)
#define DMA_HIFCR_CFEIF4                     ((uint32_t)0x00000001)

/******************************************************************************/
/*                                                                            */
/*                             DMAMUX Controller                              */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for DMAMUX_CxCR register  **************/
#define DMAMUX_CxCR_DMAREQ_ID                 ((uint32_t)0x000000FF)
#define DMAMUX_CxCR_DMAREQ_ID_0               ((uint32_t)0x00000001)
#define DMAMUX_CxCR_DMAREQ_ID_1               ((uint32_t)0x00000002)
#define DMAMUX_CxCR_DMAREQ_ID_2               ((uint32_t)0x00000004)
#define DMAMUX_CxCR_DMAREQ_ID_3               ((uint32_t)0x00000008)
#define DMAMUX_CxCR_DMAREQ_ID_4               ((uint32_t)0x00000010)
#define DMAMUX_CxCR_DMAREQ_ID_5               ((uint32_t)0x00000020)
#define DMAMUX_CxCR_DMAREQ_ID_6               ((uint32_t)0x00000040)
#define DMAMUX_CxCR_DMAREQ_ID_7               ((uint32_t)0x00000080)
#define DMAMUX_CxCR_SOIE                      ((uint32_t)0x00000100)
#define DMAMUX_CxCR_EGE                       ((uint32_t)0x00000200)
#define DMAMUX_CxCR_SE                        ((uint32_t)0x00010000)
#define DMAMUX_CxCR_SPOL                      ((uint32_t)0x00060000)
#define DMAMUX_CxCR_SPOL_0                    ((uint32_t)0x00020000)
#define DMAMUX_CxCR_SPOL_1                    ((uint32_t)0x00040000)
#define DMAMUX_CxCR_NBREQ                     ((uint32_t)0x00F80000)
#define DMAMUX_CxCR_NBREQ_0                   ((uint32_t)0x00080000)
#define DMAMUX_CxCR_NBREQ_1                   ((uint32_t)0x00100000)
#define DMAMUX_CxCR_NBREQ_2                   ((uint32_t)0x00200000)
#define DMAMUX_CxCR_NBREQ_3                   ((uint32_t)0x00400000)
#define DMAMUX_CxCR_NBREQ_4                   ((uint32_t)0x00800000)
#define DMAMUX_CxCR_SYNC_ID                   ((uint32_t)0x1F000000)
#define DMAMUX_CxCR_SYNC_ID_0                 ((uint32_t)0x01000000)
#define DMAMUX_CxCR_SYNC_ID_1                 ((uint32_t)0x02000000)
#define DMAMUX_CxCR_SYNC_ID_2                 ((uint32_t)0x04000000)
#define DMAMUX_CxCR_SYNC_ID_3                 ((uint32_t)0x08000000)
#define DMAMUX_CxCR_SYNC_ID_4                 ((uint32_t)0x10000000)

/********************  Bits definition for DMAMUX_CSR register  **************/
#define DMAMUX_CSR_SOF0                       ((uint32_t)0x00000001)
#define DMAMUX_CSR_SOF1                       ((uint32_t)0x00000002)
#define DMAMUX_CSR_SOF2                       ((uint32_t)0x00000004)
#define DMAMUX_CSR_SOF3                       ((uint32_t)0x00000008)
#define DMAMUX_CSR_SOF4                       ((uint32_t)0x00000010)
#define DMAMUX_CSR_SOF5                       ((uint32_t)0x00000020)
#define DMAMUX_CSR_SOF6                       ((uint32_t)0x00000040)
#define DMAMUX_CSR_SOF7                       ((uint32_t)0x00000080)
#define DMAMUX_CSR_SOF8                       ((uint32_t)0x00000100)
#define DMAMUX_CSR_SOF9                       ((uint32_t)0x00000200)
#define DMAMUX_CSR_SOF10                      ((uint32_t)0x00000400)
#define DMAMUX_CSR_SOF11                      ((uint32_t)0x00000800)
#define DMAMUX_CSR_SOF12                      ((uint32_t)0x00001000)
#define DMAMUX_CSR_SOF13                      ((uint32_t)0x00002000)
#define DMAMUX_CSR_SOF14                      ((uint32_t)0x00004000)
#define DMAMUX_CSR_SOF15                      ((uint32_t)0x00008000)

/********************  Bits definition for DMAMUX_CFR register  **************/
#define DMAMUX_CFR_CSOF0                      ((uint32_t)0x00000001)
#define DMAMUX_CFR_CSOF1                      ((uint32_t)0x00000002)
#define DMAMUX_CFR_CSOF2                      ((uint32_t)0x00000004)
#define DMAMUX_CFR_CSOF3                      ((uint32_t)0x00000008)
#define DMAMUX_CFR_CSOF4                      ((uint32_t)0x00000010)
#define DMAMUX_CFR_CSOF5                      ((uint32_t)0x00000020)
#define DMAMUX_CFR_CSOF6                      ((uint32_t)0x00000040)
#define DMAMUX_CFR_CSOF7                      ((uint32_t)0x00000080)
#define DMAMUX_CFR_CSOF8                      ((uint32_t)0x00000100)
#define DMAMUX_CFR_CSOF9                      ((uint32_t)0x00000200)
#define DMAMUX_CFR_CSOF10                     ((uint32_t)0x00000400)
#define DMAMUX_CFR_CSOF11                     ((uint32_t)0x00000800)
#define DMAMUX_CFR_CSOF12                     ((uint32_t)0x00001000)
#define DMAMUX_CFR_CSOF13                     ((uint32_t)0x00002000)
#define DMAMUX_CFR_CSOF14                     ((uint32_t)0x00004000)
#define DMAMUX_CFR_CSOF15                     ((uint32_t)0x00008000)

/********************  Bits definition for DMAMUX_RGxCR register  ************/
#define DMAMUX_RGxCR_SIG_ID                   ((uint32_t)0x0000001F)
#define DMAMUX_RGxCR_SIG_ID_0                 ((uint32_t)0x00000001)
#define DMAMUX_RGxCR_SIG_ID_1                 ((uint32_t)0x00000002)
#define DMAMUX_RGxCR_SIG_ID_2                 ((uint32_t)0x00000004)
#define DMAMUX_RGxCR_SIG_ID_3                 ((uint32_t)0x00000008)
#define DMAMUX_RGxCR_SIG_ID_4                 ((uint32_t)0x00000010)
#define DMAMUX_RGxCR_OIE                      ((uint32_t)0x00000100)
#define DMAMUX_RGxCR_GE                       ((uint32_t)0x00010000)
#define DMAMUX_RGxCR_GPOL                     ((uint32_t)0x00060000)
#define DMAMUX_RGxCR_GPOL_0                   ((uint32_t)0x00020000)
#define DMAMUX_RGxCR_GPOL_1                   ((uint32_t)0x00040000)
#define DMAMUX_RGxCR_NBREQ                    ((uint32_t)0x00F80000)
#define DMAMUX_RGxCR_NBREQ_0                  ((uint32_t)0x00080000)
#define DMAMUX_RGxCR_NBREQ_1                  ((uint32_t)0x00100000)
#define DMAMUX_RGxCR_NBREQ_2                  ((uint32_t)0x00200000)
#define DMAMUX_RGxCR_NBREQ_3                  ((uint32_t)0x00400000)
#define DMAMUX_RGxCR_NBREQ_4                  ((uint32_t)0x00800000)

/********************  Bits definition for DMAMUX_RGSR register  **************/
#define DMAMUX_RGSR_OF0                       ((uint32_t)0x00000001)
#define DMAMUX_RGSR_OF1                       ((uint32_t)0x00000002)
#define DMAMUX_RGSR_OF2                       ((uint32_t)0x00000004)
#define DMAMUX_RGSR_OF3                       ((uint32_t)0x00000008)

/********************  Bits definition for DMAMUX_RGCFR register  **************/
#define DMAMUX_RGCFR_COF0                     ((uint32_t)0x00000001)
#define DMAMUX_RGCFR_COF1                     ((uint32_t)0x00000002)
#define DMAMUX_RGCFR_COF2                     ((uint32_t)0x00000004)
#define DMAMUX_RGCFR_COF3                     ((uint32_t)0x00000008)

/******************************************************************************/
/*                                                                            */
/*                         AHB Master DMA2D Controller (DMA2D)                */
/*                                                                            */
/******************************************************************************/

/********************  Bit definition for DMA2D_CR register  ******************/

#define DMA2D_CR_START                     ((uint32_t)0x00000001U)               /*!< Start transfer                          */
#define DMA2D_CR_SUSP                      ((uint32_t)0x00000002U)               /*!< Suspend transfer                        */
#define DMA2D_CR_ABORT                     ((uint32_t)0x00000004U)               /*!< Abort transfer                          */
#define DMA2D_CR_TEIE                      ((uint32_t)0x00000100U)               /*!< Transfer Error Interrupt Enable         */
#define DMA2D_CR_TCIE                      ((uint32_t)0x00000200U)               /*!< Transfer Complete Interrupt Enable      */
#define DMA2D_CR_TWIE                      ((uint32_t)0x00000400U)               /*!< Transfer Watermark Interrupt Enable     */
#define DMA2D_CR_CAEIE                     ((uint32_t)0x00000800U)               /*!< CLUT Access Error Interrupt Enable      */
#define DMA2D_CR_CTCIE                     ((uint32_t)0x00001000U)               /*!< CLUT Transfer Complete Interrupt Enable */
#define DMA2D_CR_CEIE                      ((uint32_t)0x00002000U)               /*!< Configuration Error Interrupt Enable    */
#define DMA2D_CR_MODE                      ((uint32_t)0x00030000U)               /*!< DMA2D Mode[1:0]                         */
#define DMA2D_CR_MODE_0                    ((uint32_t)0x00010000U)               /*!< DMA2D Mode bit 0                        */
#define DMA2D_CR_MODE_1                    ((uint32_t)0x00020000U)               /*!< DMA2D Mode bit 1                        */

/********************  Bit definition for DMA2D_ISR register  *****************/

#define DMA2D_ISR_TEIF                     ((uint32_t)0x00000001U)               /*!< Transfer Error Interrupt Flag         */
#define DMA2D_ISR_TCIF                     ((uint32_t)0x00000002U)               /*!< Transfer Complete Interrupt Flag      */
#define DMA2D_ISR_TWIF                     ((uint32_t)0x00000004U)               /*!< Transfer Watermark Interrupt Flag     */
#define DMA2D_ISR_CAEIF                    ((uint32_t)0x00000008U)               /*!< CLUT Access Error Interrupt Flag      */
#define DMA2D_ISR_CTCIF                    ((uint32_t)0x00000010U)               /*!< CLUT Transfer Complete Interrupt Flag */
#define DMA2D_ISR_CEIF                     ((uint32_t)0x00000020U)               /*!< Configuration Error Interrupt Flag    */

/********************  Bit definition for DMA2D_IFCR register  ****************/

#define DMA2D_IFCR_CTEIF                   ((uint32_t)0x00000001U)               /*!< Clears Transfer Error Interrupt Flag         */
#define DMA2D_IFCR_CTCIF                   ((uint32_t)0x00000002U)               /*!< Clears Transfer Complete Interrupt Flag      */
#define DMA2D_IFCR_CTWIF                   ((uint32_t)0x00000004U)               /*!< Clears Transfer Watermark Interrupt Flag     */
#define DMA2D_IFCR_CAECIF                  ((uint32_t)0x00000008U)               /*!< Clears CLUT Access Error Interrupt Flag      */
#define DMA2D_IFCR_CCTCIF                  ((uint32_t)0x00000010U)               /*!< Clears CLUT Transfer Complete Interrupt Flag */
#define DMA2D_IFCR_CCEIF                   ((uint32_t)0x00000020U)               /*!< Clears Configuration Error Interrupt Flag    */

/********************  Bit definition for DMA2D_FGMAR register  ***************/

#define DMA2D_FGMAR_MA                     ((uint32_t)0xFFFFFFFFU)               /*!< Memory Address */

/********************  Bit definition for DMA2D_FGOR register  ****************/

#define DMA2D_FGOR_LO                      ((uint32_t)0x00003FFFU)               /*!< Line Offset */

/********************  Bit definition for DMA2D_BGMAR register  ***************/

#define DMA2D_BGMAR_MA                     ((uint32_t)0xFFFFFFFFU)               /*!< Memory Address */

/********************  Bit definition for DMA2D_BGOR register  ****************/

#define DMA2D_BGOR_LO                      ((uint32_t)0x00003FFFU)               /*!< Line Offset */

/********************  Bit definition for DMA2D_FGPFCCR register  *************/

#define DMA2D_FGPFCCR_CM                   ((uint32_t)0x0000000FU)               /*!< Input color mode CM[3:0] */
#define DMA2D_FGPFCCR_CM_0                 ((uint32_t)0x00000001U)               /*!< Input color mode CM bit 0 */
#define DMA2D_FGPFCCR_CM_1                 ((uint32_t)0x00000002U)               /*!< Input color mode CM bit 1 */
#define DMA2D_FGPFCCR_CM_2                 ((uint32_t)0x00000004U)               /*!< Input color mode CM bit 2 */
#define DMA2D_FGPFCCR_CM_3                 ((uint32_t)0x00000008U)               /*!< Input color mode CM bit 3 */
#define DMA2D_FGPFCCR_CCM                  ((uint32_t)0x00000010U)               /*!< CLUT Color mode */
#define DMA2D_FGPFCCR_START                ((uint32_t)0x00000020U)               /*!< Start */
#define DMA2D_FGPFCCR_CS                   ((uint32_t)0x0000FF00U)               /*!< CLUT size */
#define DMA2D_FGPFCCR_AM                   ((uint32_t)0x00030000U)               /*!< Alpha mode AM[1:0] */
#define DMA2D_FGPFCCR_AM_0                 ((uint32_t)0x00010000U)               /*!< Alpha mode AM bit 0 */
#define DMA2D_FGPFCCR_AM_1                 ((uint32_t)0x00020000U)               /*!< Alpha mode AM bit 1 */
#define DMA2D_FGPFCCR_CSS                  ((uint32_t)0x000C0000U)               /* !< Chroma Sub-Sampling */
#define DMA2D_FGPFCCR_CSS_0                ((uint32_t)0x00040000U)               /* !< Chroma Sub-Sampling bit 0 */ 
#define DMA2D_FGPFCCR_CSS_1                ((uint32_t)0x00080000U)               /* !< Chroma Sub-Sampling bit 1 */
#define DMA2D_FGPFCCR_AI                   ((uint32_t)0x00100000U)               /*!< Foreground Input Alpha Inverted */
#define DMA2D_FGPFCCR_RBS                  ((uint32_t)0x00200000U)               /*!< Foreground Input Red Blue Swap */
#define DMA2D_FGPFCCR_ALPHA                ((uint32_t)0xFF000000U)               /*!< Alpha value */

/********************  Bit definition for DMA2D_FGCOLR register  **************/

#define DMA2D_FGCOLR_BLUE                  ((uint32_t)0x000000FFU)               /*!< Blue Value */
#define DMA2D_FGCOLR_GREEN                 ((uint32_t)0x0000FF00U)               /*!< Green Value */
#define DMA2D_FGCOLR_RED                   ((uint32_t)0x00FF0000U)               /*!< Red Value */   

/********************  Bit definition for DMA2D_BGPFCCR register  *************/

#define DMA2D_BGPFCCR_CM                   ((uint32_t)0x0000000FU)               /*!< Input color mode CM[3:0] */
#define DMA2D_BGPFCCR_CM_0                 ((uint32_t)0x00000001U)               /*!< Input color mode CM bit 0 */
#define DMA2D_BGPFCCR_CM_1                 ((uint32_t)0x00000002U)               /*!< Input color mode CM bit 1 */
#define DMA2D_BGPFCCR_CM_2                 ((uint32_t)0x00000004U)               /*!< Input color mode CM bit 2 */
#define DMA2D_FGPFCCR_CM_3                 ((uint32_t)0x00000008U)               /*!< Input color mode CM bit 3 */
#define DMA2D_BGPFCCR_CCM                  ((uint32_t)0x00000010U)               /*!< CLUT Color mode */
#define DMA2D_BGPFCCR_START                ((uint32_t)0x00000020U)               /*!< Start */
#define DMA2D_BGPFCCR_CS                   ((uint32_t)0x0000FF00U)               /*!< CLUT size */
#define DMA2D_BGPFCCR_AM                   ((uint32_t)0x00030000U)               /*!< Alpha mode AM[1:0] */
#define DMA2D_BGPFCCR_AM_0                 ((uint32_t)0x00010000U)               /*!< Alpha mode AM bit 0 */
#define DMA2D_BGPFCCR_AM_1                 ((uint32_t)0x00020000U)               /*!< Alpha mode AM bit 1 */
#define DMA2D_BGPFCCR_AI                   ((uint32_t)0x00100000U)               /*!< background Input Alpha Inverted */
#define DMA2D_BGPFCCR_RBS                  ((uint32_t)0x00200000U)               /*!< Background Input Red Blue Swap */
#define DMA2D_BGPFCCR_ALPHA                ((uint32_t)0xFF000000U)               /*!< background Input Alpha value */

/********************  Bit definition for DMA2D_BGCOLR register  **************/

#define DMA2D_BGCOLR_BLUE                  ((uint32_t)0x000000FFU)               /*!< Blue Value */
#define DMA2D_BGCOLR_GREEN                 ((uint32_t)0x0000FF00U)               /*!< Green Value */
#define DMA2D_BGCOLR_RED                   ((uint32_t)0x00FF0000U)               /*!< Red Value */

/********************  Bit definition for DMA2D_FGCMAR register  **************/

#define DMA2D_FGCMAR_MA                    ((uint32_t)0xFFFFFFFFU)               /*!< Memory Address */

/********************  Bit definition for DMA2D_BGCMAR register  **************/

#define DMA2D_BGCMAR_MA                    ((uint32_t)0xFFFFFFFFU)               /*!< Memory Address */

/********************  Bit definition for DMA2D_OPFCCR register  **************/

#define DMA2D_OPFCCR_CM                    ((uint32_t)0x00000007U)               /*!< Color mode CM[2:0] */
#define DMA2D_OPFCCR_CM_0                  ((uint32_t)0x00000001U)               /*!< Color mode CM bit 0 */
#define DMA2D_OPFCCR_CM_1                  ((uint32_t)0x00000002U)               /*!< Color mode CM bit 1 */
#define DMA2D_OPFCCR_CM_2                  ((uint32_t)0x00000004U)               /*!< Color mode CM bit 2 */
#define DMA2D_OPFCCR_AI                    ((uint32_t)0x00100000U)               /*!< Output Alpha Inverted */
#define DMA2D_OPFCCR_RBS                   ((uint32_t)0x00200000U)               /*!< Output Red Blue Swap */

/********************  Bit definition for DMA2D_OCOLR register  ***************/

/*!<Mode_ARGB8888/RGB888 */

#define DMA2D_OCOLR_BLUE_1                 ((uint32_t)0x000000FFU)               /*!< BLUE Value */
#define DMA2D_OCOLR_GREEN_1                ((uint32_t)0x0000FF00U)               /*!< GREEN Value  */
#define DMA2D_OCOLR_RED_1                  ((uint32_t)0x00FF0000U)               /*!< Red Value */
#define DMA2D_OCOLR_ALPHA_1                ((uint32_t)0xFF000000U)               /*!< Alpha Channel Value */

/*!<Mode_RGB565 */
#define DMA2D_OCOLR_BLUE_2                 ((uint32_t)0x0000001FU)               /*!< BLUE Value */
#define DMA2D_OCOLR_GREEN_2                ((uint32_t)0x000007E0U)               /*!< GREEN Value  */
#define DMA2D_OCOLR_RED_2                  ((uint32_t)0x0000F800U)               /*!< Red Value */

/*!<Mode_ARGB1555 */
#define DMA2D_OCOLR_BLUE_3                 ((uint32_t)0x0000001FU)               /*!< BLUE Value */
#define DMA2D_OCOLR_GREEN_3                ((uint32_t)0x000003E0U)               /*!< GREEN Value  */
#define DMA2D_OCOLR_RED_3                  ((uint32_t)0x00007C00U)               /*!< Red Value */
#define DMA2D_OCOLR_ALPHA_3                ((uint32_t)0x00008000U)               /*!< Alpha Channel Value */

/*!<Mode_ARGB4444 */
#define DMA2D_OCOLR_BLUE_4                 ((uint32_t)0x0000000FU)               /*!< BLUE Value */
#define DMA2D_OCOLR_GREEN_4                ((uint32_t)0x000000F0U)               /*!< GREEN Value  */
#define DMA2D_OCOLR_RED_4                  ((uint32_t)0x00000F00U)               /*!< Red Value */
#define DMA2D_OCOLR_ALPHA_4                ((uint32_t)0x0000F000U)               /*!< Alpha Channel Value */

/********************  Bit definition for DMA2D_OMAR register  ****************/

#define DMA2D_OMAR_MA                      ((uint32_t)0xFFFFFFFFU)               /*!< Memory Address */

/********************  Bit definition for DMA2D_OOR register  *****************/

#define DMA2D_OOR_LO                       ((uint32_t)0x00003FFFU)               /*!< Line Offset */

/********************  Bit definition for DMA2D_NLR register  *****************/

#define DMA2D_NLR_NL                       ((uint32_t)0x0000FFFFU)               /*!< Number of Lines */
#define DMA2D_NLR_PL                       ((uint32_t)0x3FFF0000U)               /*!< Pixel per Lines */

/********************  Bit definition for DMA2D_LWR register  *****************/

#define DMA2D_LWR_LW                       ((uint32_t)0x0000FFFFU)               /*!< Line Watermark */

/********************  Bit definition for DMA2D_AMTCR register  ***************/

#define DMA2D_AMTCR_EN                     ((uint32_t)0x00000001U)               /*!< Enable */
#define DMA2D_AMTCR_DT                     ((uint32_t)0x0000FF00U)               /*!< Dead Time */


/********************  Bit definition for DMA2D_FGCLUT register  **************/
                                                                     
/********************  Bit definition for DMA2D_BGCLUT register  **************/
/******************************************************************************/
/*                                                                            */
/*                    External Interrupt/Event Controller                     */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for EXTI_IMR1 register  *******************/
#define  EXTI_IMR1_IM0                        ((uint32_t)0x00000001)        /*!< Interrupt Mask on line 0 */
#define  EXTI_IMR1_IM1                        ((uint32_t)0x00000002)        /*!< Interrupt Mask on line 1 */
#define  EXTI_IMR1_IM2                        ((uint32_t)0x00000004)        /*!< Interrupt Mask on line 2 */
#define  EXTI_IMR1_IM3                        ((uint32_t)0x00000008)        /*!< Interrupt Mask on line 3 */
#define  EXTI_IMR1_IM4                        ((uint32_t)0x00000010)        /*!< Interrupt Mask on line 4 */
#define  EXTI_IMR1_IM5                        ((uint32_t)0x00000020)        /*!< Interrupt Mask on line 5 */
#define  EXTI_IMR1_IM6                        ((uint32_t)0x00000040)        /*!< Interrupt Mask on line 6 */
#define  EXTI_IMR1_IM7                        ((uint32_t)0x00000080)        /*!< Interrupt Mask on line 7 */
#define  EXTI_IMR1_IM8                        ((uint32_t)0x00000100)        /*!< Interrupt Mask on line 8 */
#define  EXTI_IMR1_IM9                        ((uint32_t)0x00000200)        /*!< Interrupt Mask on line 9 */
#define  EXTI_IMR1_IM10                       ((uint32_t)0x00000400)        /*!< Interrupt Mask on line 10 */
#define  EXTI_IMR1_IM11                       ((uint32_t)0x00000800)        /*!< Interrupt Mask on line 11 */
#define  EXTI_IMR1_IM12                       ((uint32_t)0x00001000)        /*!< Interrupt Mask on line 12 */
#define  EXTI_IMR1_IM13                       ((uint32_t)0x00002000)        /*!< Interrupt Mask on line 13 */
#define  EXTI_IMR1_IM14                       ((uint32_t)0x00004000)        /*!< Interrupt Mask on line 14 */
#define  EXTI_IMR1_IM15                       ((uint32_t)0x00008000)        /*!< Interrupt Mask on line 15 */
#define  EXTI_IMR1_IM16                       ((uint32_t)0x00010000)        /*!< Interrupt Mask on line 16 */
#define  EXTI_IMR1_IM17                       ((uint32_t)0x00020000)        /*!< Interrupt Mask on line 17 */
#define  EXTI_IMR1_IM18                       ((uint32_t)0x00040000)        /*!< Interrupt Mask on line 18 */
#define  EXTI_IMR1_IM19                       ((uint32_t)0x00080000)        /*!< Interrupt Mask on line 19 */
#define  EXTI_IMR1_IM20                       ((uint32_t)0x00100000)        /*!< Interrupt Mask on line 20 */
#define  EXTI_IMR1_IM21                       ((uint32_t)0x00200000)        /*!< Interrupt Mask on line 21 */
#define  EXTI_IMR1_IM22                       ((uint32_t)0x00400000)        /*!< Interrupt Mask on line 22 */
#define  EXTI_IMR1_IM23                       ((uint32_t)0x00800000)        /*!< Interrupt Mask on line 23 */
#define  EXTI_IMR1_IM24                       ((uint32_t)0x01000000)        /*!< Interrupt Mask on line 24 */
#define  EXTI_IMR1_IM25                       ((uint32_t)0x02000000)        /*!< Interrupt Mask on line 25 */
#define  EXTI_IMR1_IM26                       ((uint32_t)0x04000000)        /*!< Interrupt Mask on line 26 */
#define  EXTI_IMR1_IM27                       ((uint32_t)0x08000000)        /*!< Interrupt Mask on line 27 */
#define  EXTI_IMR1_IM28                       ((uint32_t)0x10000000)        /*!< Interrupt Mask on line 28 */
#define  EXTI_IMR1_IM29                       ((uint32_t)0x20000000)        /*!< Interrupt Mask on line 29 */
#define  EXTI_IMR1_IM30                       ((uint32_t)0x40000000)        /*!< Interrupt Mask on line 30 */
#define  EXTI_IMR1_IM31                       ((uint32_t)0x80000000)        /*!< Interrupt Mask on line 31 */
/*******************  Bit definition for EXTI_IMR2 register  *******************/
#define  EXTI_IMR2_IM32                       ((uint32_t)0x00000001)        /*!< Interrupt Mask on line 32 */
#define  EXTI_IMR2_IM33                       ((uint32_t)0x00000002)        /*!< Interrupt Mask on line 33 */
#define  EXTI_IMR2_IM34                       ((uint32_t)0x00000004)        /*!< Interrupt Mask on line 34 */
#define  EXTI_IMR2_IM35                       ((uint32_t)0x00000008)        /*!< Interrupt Mask on line 35 */
#define  EXTI_IMR2_IM36                       ((uint32_t)0x00000010)        /*!< Interrupt Mask on line 36 */
#define  EXTI_IMR2_IM37                       ((uint32_t)0x00000020)        /*!< Interrupt Mask on line 37 */
#define  EXTI_IMR2_IM38                       ((uint32_t)0x00000040)        /*!< Interrupt Mask on line 38 */
#define  EXTI_IMR2_IM39                       ((uint32_t)0x00000080)        /*!< Interrupt Mask on line 39 */
#define  EXTI_IMR2_IM40                       ((uint32_t)0x00000100)        /*!< Interrupt Mask on line 40 */
#define  EXTI_IMR2_IM41                       ((uint32_t)0x00000200)        /*!< Interrupt Mask on line 41 */
#define  EXTI_IMR2_IM42                       ((uint32_t)0x00000400)        /*!< Interrupt Mask on line 42 */
#define  EXTI_IMR2_IM43                       ((uint32_t)0x00000800)        /*!< Interrupt Mask on line 43 */
#define  EXTI_IMR2_IM44                       ((uint32_t)0x00001000)        /*!< Interrupt Mask on line 44 */
#define  EXTI_IMR2_IM45                       ((uint32_t)0x00002000)        /*!< Interrupt Mask on line 45 */
#define  EXTI_IMR2_IM46                       ((uint32_t)0x00004000)        /*!< Interrupt Mask on line 46 */
#define  EXTI_IMR2_IM47                       ((uint32_t)0x00008000)        /*!< Interrupt Mask on line 47 */
#define  EXTI_IMR2_IM48                       ((uint32_t)0x00010000)        /*!< Interrupt Mask on line 48 */
#define  EXTI_IMR2_IM49                       ((uint32_t)0x00020000)        /*!< Interrupt Mask on line 49 */
#define  EXTI_IMR2_IM50                       ((uint32_t)0x00040000)        /*!< Interrupt Mask on line 50 */
#define  EXTI_IMR2_IM51                       ((uint32_t)0x00080000)        /*!< Interrupt Mask on line 51 */
#define  EXTI_IMR2_IM52                       ((uint32_t)0x00100000)        /*!< Interrupt Mask on line 52 */
#define  EXTI_IMR2_IM53                       ((uint32_t)0x00200000)        /*!< Interrupt Mask on line 53 */
#define  EXTI_IMR2_IM54                       ((uint32_t)0x00400000)        /*!< Interrupt Mask on line 54 */
#define  EXTI_IMR2_IM55                       ((uint32_t)0x00800000)        /*!< Interrupt Mask on line 55 */
#define  EXTI_IMR2_IM56                       ((uint32_t)0x01000000)        /*!< Interrupt Mask on line 56 */
#define  EXTI_IMR2_IM57                       ((uint32_t)0x02000000)        /*!< Interrupt Mask on line 57 */
#define  EXTI_IMR2_IM58                       ((uint32_t)0x04000000)        /*!< Interrupt Mask on line 58 */
#define  EXTI_IMR2_IM59                       ((uint32_t)0x08000000)        /*!< Interrupt Mask on line 59 */
#define  EXTI_IMR2_IM60                       ((uint32_t)0x10000000)        /*!< Interrupt Mask on line 60 */
#define  EXTI_IMR2_IM61                       ((uint32_t)0x20000000)        /*!< Interrupt Mask on line 61 */
#define  EXTI_IMR2_IM62                       ((uint32_t)0x40000000)        /*!< Interrupt Mask on line 62 */
#define  EXTI_IMR2_IM63                       ((uint32_t)0x80000000)        /*!< Interrupt Mask on line 63 */
/*******************  Bit definition for EXTI_IMR3 register  *******************/
#define  EXTI_IMR3_IM64                       ((uint32_t)0x00000001)        /*!< Interrupt Mask on line 64 */
#define  EXTI_IMR3_IM65                       ((uint32_t)0x00000002)        /*!< Interrupt Mask on line 65 */
#define  EXTI_IMR3_IM66                       ((uint32_t)0x00000004)        /*!< Interrupt Mask on line 66 */
#define  EXTI_IMR3_IM67                       ((uint32_t)0x00000008)        /*!< Interrupt Mask on line 67 */
#define  EXTI_IMR3_IM68                       ((uint32_t)0x00000010)        /*!< Interrupt Mask on line 68 */
#define  EXTI_IMR3_IM69                       ((uint32_t)0x00000020)        /*!< Interrupt Mask on line 69 */
#define  EXTI_IMR3_IM70                       ((uint32_t)0x00000040)        /*!< Interrupt Mask on line 70 */
#define  EXTI_IMR3_IM71                       ((uint32_t)0x00000080)        /*!< Interrupt Mask on line 71 */
#define  EXTI_IMR3_IM72                       ((uint32_t)0x00000100)        /*!< Interrupt Mask on line 72 */
#define  EXTI_IMR3_IM73                       ((uint32_t)0x00000200)        /*!< Interrupt Mask on line 73 */
#define  EXTI_IMR3_IM74                       ((uint32_t)0x00000400)        /*!< Interrupt Mask on line 74 */
#define  EXTI_IMR3_IM75                       ((uint32_t)0x00000800)        /*!< Interrupt Mask on line 75 */
#define  EXTI_IMR3_IM76                       ((uint32_t)0x00001000)        /*!< Interrupt Mask on line 76 */
#define  EXTI_IMR3_IM77                       ((uint32_t)0x00002000)        /*!< Interrupt Mask on line 77 */
#define  EXTI_IMR3_IM78                       ((uint32_t)0x00004000)        /*!< Interrupt Mask on line 78 */
#define  EXTI_IMR3_IM79                       ((uint32_t)0x00008000)        /*!< Interrupt Mask on line 79 */
#define  EXTI_IMR3_IM80                       ((uint32_t)0x00010000)        /*!< Interrupt Mask on line 80 */
#define  EXTI_IMR3_IM81                       ((uint32_t)0x00020000)        /*!< Interrupt Mask on line 81 */
#define  EXTI_IMR3_IM82                       ((uint32_t)0x00040000)        /*!< Interrupt Mask on line 82 */
#define  EXTI_IMR3_IM84                       ((uint32_t)0x00100000)        /*!< Interrupt Mask on line 84 */
#define  EXTI_IMR3_IM85                       ((uint32_t)0x00200000)        /*!< Interrupt Mask on line 85 */
#define  EXTI_IMR3_IM86                       ((uint32_t)0x00400000)        /*!< Interrupt Mask on line 86 */
#define  EXTI_IMR3_IM87                       ((uint32_t)0x00800000)        /*!< Interrupt Mask on line 87 */
#define  EXTI_IMR3_IM88                       ((uint32_t)0x01000000)        /*!< Interrupt Mask on line 88 */
/*******************  Bit definition for EXTI_EMR1 register  *******************/
#define  EXTI_EMR1_EM0                        ((uint32_t)0x00000001)        /*!< Event Mask on line 0 */
#define  EXTI_EMR1_EM1                        ((uint32_t)0x00000002)        /*!< Event Mask on line 1 */
#define  EXTI_EMR1_EM2                        ((uint32_t)0x00000004)        /*!< Event Mask on line 2 */
#define  EXTI_EMR1_EM3                        ((uint32_t)0x00000008)        /*!< Event Mask on line 3 */
#define  EXTI_EMR1_EM4                        ((uint32_t)0x00000010)        /*!< Event Mask on line 4 */
#define  EXTI_EMR1_EM5                        ((uint32_t)0x00000020)        /*!< Event Mask on line 5 */
#define  EXTI_EMR1_EM6                        ((uint32_t)0x00000040)        /*!< Event Mask on line 6 */
#define  EXTI_EMR1_EM7                        ((uint32_t)0x00000080)        /*!< Event Mask on line 7 */
#define  EXTI_EMR1_EM8                        ((uint32_t)0x00000100)        /*!< Event Mask on line 8 */
#define  EXTI_EMR1_EM9                        ((uint32_t)0x00000200)        /*!< Event Mask on line 9 */
#define  EXTI_EMR1_EM10                       ((uint32_t)0x00000400)        /*!< Event Mask on line 10 */
#define  EXTI_EMR1_EM11                       ((uint32_t)0x00000800)        /*!< Event Mask on line 11 */
#define  EXTI_EMR1_EM12                       ((uint32_t)0x00001000)        /*!< Event Mask on line 12 */
#define  EXTI_EMR1_EM13                       ((uint32_t)0x00002000)        /*!< Event Mask on line 13 */
#define  EXTI_EMR1_EM14                       ((uint32_t)0x00004000)        /*!< Event Mask on line 14 */
#define  EXTI_EMR1_EM15                       ((uint32_t)0x00008000)        /*!< Event Mask on line 15 */
#define  EXTI_EMR1_EM16                       ((uint32_t)0x00010000)        /*!< Event Mask on line 16 */
#define  EXTI_EMR1_EM17                       ((uint32_t)0x00020000)        /*!< Event Mask on line 17 */
#define  EXTI_EMR1_EM18                       ((uint32_t)0x00040000)        /*!< Event Mask on line 18 */
#define  EXTI_EMR1_EM20                       ((uint32_t)0x00100000)        /*!< Event Mask on line 20 */
#define  EXTI_EMR1_EM21                       ((uint32_t)0x00200000)        /*!< Event Mask on line 21 */
#define  EXTI_EMR1_EM22                       ((uint32_t)0x00400000)        /*!< Event Mask on line 22 */
#define  EXTI_EMR1_EM23                       ((uint32_t)0x00800000)        /*!< Event Mask on line 23 */
#define  EXTI_EMR1_EM24                       ((uint32_t)0x01000000)        /*!< Event Mask on line 24 */
#define  EXTI_EMR1_EM25                       ((uint32_t)0x02000000)        /*!< Event Mask on line 25 */
#define  EXTI_EMR1_EM26                       ((uint32_t)0x04000000)        /*!< Event Mask on line 26 */
#define  EXTI_EMR1_EM27                       ((uint32_t)0x08000000)        /*!< Event Mask on line 27 */
#define  EXTI_EMR1_EM28                       ((uint32_t)0x10000000)        /*!< Event Mask on line 28 */
#define  EXTI_EMR1_EM29                       ((uint32_t)0x20000000)        /*!< Event Mask on line 29 */
#define  EXTI_EMR1_EM30                       ((uint32_t)0x40000000)        /*!< Event Mask on line 30 */
#define  EXTI_EMR1_EM31                       ((uint32_t)0x80000000)        /*!< Event Mask on line 31 */
/*******************  Bit definition for EXTI_EMR2 register  *******************/
#define  EXTI_EMR2_EM32                       ((uint32_t)0x00000001)        /*!< Event Mask on line 32*/
#define  EXTI_EMR2_EM33                       ((uint32_t)0x00000002)        /*!< Event Mask on line 33*/
#define  EXTI_EMR2_EM34                       ((uint32_t)0x00000004)        /*!< Event Mask on line 34*/
#define  EXTI_EMR2_EM35                       ((uint32_t)0x00000008)        /*!< Event Mask on line 35*/
#define  EXTI_EMR2_EM36                       ((uint32_t)0x00000010)        /*!< Event Mask on line 36*/
#define  EXTI_EMR2_EM37                       ((uint32_t)0x00000020)        /*!< Event Mask on line 37*/
#define  EXTI_EMR2_EM38                       ((uint32_t)0x00000040)        /*!< Event Mask on line 38*/
#define  EXTI_EMR2_EM39                       ((uint32_t)0x00000080)        /*!< Event Mask on line 39*/
#define  EXTI_EMR2_EM40                       ((uint32_t)0x00000100)        /*!< Event Mask on line 40*/
#define  EXTI_EMR2_EM41                       ((uint32_t)0x00000200)        /*!< Event Mask on line 41*/
#define  EXTI_EMR2_EM42                       ((uint32_t)0x00000400)        /*!< Event Mask on line 42 */
#define  EXTI_EMR2_EM43                       ((uint32_t)0x00000800)        /*!< Event Mask on line 43 */
#define  EXTI_EMR2_EM44                       ((uint32_t)0x00001000)        /*!< Event Mask on line 44 */
#define  EXTI_EMR2_EM45                       ((uint32_t)0x00002000)        /*!< Event Mask on line 45 */
#define  EXTI_EMR2_EM46                       ((uint32_t)0x00004000)        /*!< Event Mask on line 46 */
#define  EXTI_EMR2_EM47                       ((uint32_t)0x00008000)        /*!< Event Mask on line 47 */
#define  EXTI_EMR2_EM48                       ((uint32_t)0x00010000)        /*!< Event Mask on line 48 */
#define  EXTI_EMR2_EM49                       ((uint32_t)0x00020000)        /*!< Event Mask on line 49 */
#define  EXTI_EMR2_EM50                       ((uint32_t)0x00040000)        /*!< Event Mask on line 50 */
#define  EXTI_EMR2_EM51                       ((uint32_t)0x00080000)        /*!< Event Mask on line 51 */
#define  EXTI_EMR2_EM52                       ((uint32_t)0x00100000)        /*!< Event Mask on line 52 */
#define  EXTI_EMR2_EM53                       ((uint32_t)0x00200000)        /*!< Event Mask on line 53 */
#define  EXTI_EMR2_EM54                       ((uint32_t)0x00400000)        /*!< Event Mask on line 54 */
#define  EXTI_EMR2_EM55                       ((uint32_t)0x00800000)        /*!< Event Mask on line 55 */
#define  EXTI_EMR2_EM56                       ((uint32_t)0x01000000)        /*!< Event Mask on line 56 */
#define  EXTI_EMR2_EM57                       ((uint32_t)0x02000000)        /*!< Event Mask on line 57 */
#define  EXTI_EMR2_EM58                       ((uint32_t)0x04000000)        /*!< Event Mask on line 58 */
#define  EXTI_EMR2_EM59                       ((uint32_t)0x08000000)        /*!< Event Mask on line 59 */
#define  EXTI_EMR2_EM60                       ((uint32_t)0x10000000)        /*!< Event Mask on line 60 */
#define  EXTI_EMR2_EM61                       ((uint32_t)0x20000000)        /*!< Event Mask on line 61 */
#define  EXTI_EMR2_EM62                       ((uint32_t)0x40000000)        /*!< Event Mask on line 62 */
#define  EXTI_EMR2_EM63                       ((uint32_t)0x80000000)        /*!< Event Mask on line 63 */
/*******************  Bit definition for EXTI_EMR3 register  *******************/
#define  EXTI_EMR3_EM64                       ((uint32_t)0x00000001)        /*!< Event Mask on line 64*/
#define  EXTI_EMR3_EM65                       ((uint32_t)0x00000002)        /*!< Event Mask on line 65*/
#define  EXTI_EMR3_EM66                       ((uint32_t)0x00000004)        /*!< Event Mask on line 66*/
#define  EXTI_EMR3_EM67                       ((uint32_t)0x00000008)        /*!< Event Mask on line 67*/
#define  EXTI_EMR3_EM68                       ((uint32_t)0x00000010)        /*!< Event Mask on line 68*/
#define  EXTI_EMR3_EM69                       ((uint32_t)0x00000020)        /*!< Event Mask on line 69*/
#define  EXTI_EMR3_EM70                       ((uint32_t)0x00000040)        /*!< Event Mask on line 70*/
#define  EXTI_EMR3_EM71                       ((uint32_t)0x00000080)        /*!< Event Mask on line 71*/
#define  EXTI_EMR3_EM72                       ((uint32_t)0x00000100)        /*!< Event Mask on line 72*/
#define  EXTI_EMR3_EM73                       ((uint32_t)0x00000200)        /*!< Event Mask on line 73*/
#define  EXTI_EMR3_EM74                       ((uint32_t)0x00000400)        /*!< Event Mask on line 74 */
#define  EXTI_EMR3_EM75                       ((uint32_t)0x00000800)        /*!< Event Mask on line 75 */
#define  EXTI_EMR3_EM76                       ((uint32_t)0x00001000)        /*!< Event Mask on line 76 */
#define  EXTI_EMR3_EM77                       ((uint32_t)0x00002000)        /*!< Event Mask on line 77 */
#define  EXTI_EMR3_EM78                       ((uint32_t)0x00004000)        /*!< Event Mask on line 78 */
#define  EXTI_EMR3_EM79                       ((uint32_t)0x00008000)        /*!< Event Mask on line 79 */
#define  EXTI_EMR3_EM80                       ((uint32_t)0x00010000)        /*!< Event Mask on line 80 */
#define  EXTI_EMR3_EM81                       ((uint32_t)0x00020000)        /*!< Event Mask on line 81 */
#define  EXTI_EMR3_EM82                       ((uint32_t)0x00040000)        /*!< Event Mask on line 82 */
#define  EXTI_EMR3_EM84                       ((uint32_t)0x00100000)        /*!< Event Mask on line 84 */
#define  EXTI_EMR3_EM85                       ((uint32_t)0x00200000)        /*!< Event Mask on line 85 */
#define  EXTI_EMR3_EM86                       ((uint32_t)0x00400000)        /*!< Event Mask on line 86 */
#define  EXTI_EMR3_EM87                       ((uint32_t)0x00800000)        /*!< Event Mask on line 87 */
#define  EXTI_EMR3_EM88                       ((uint32_t)0x01000000)        /*!< Event Mask on line 88 */
/******************  Bit definition for EXTI_RTSR1 register  *******************/
#define  EXTI_RTSR1_TR0                       ((uint32_t)0x00000001)        /*!< Rising trigger event configuration bit of line 0 */
#define  EXTI_RTSR1_TR1                       ((uint32_t)0x00000002)        /*!< Rising trigger event configuration bit of line 1 */
#define  EXTI_RTSR1_TR2                       ((uint32_t)0x00000004)        /*!< Rising trigger event configuration bit of line 2 */
#define  EXTI_RTSR1_TR3                       ((uint32_t)0x00000008)        /*!< Rising trigger event configuration bit of line 3 */
#define  EXTI_RTSR1_TR4                       ((uint32_t)0x00000010)        /*!< Rising trigger event configuration bit of line 4 */
#define  EXTI_RTSR1_TR5                       ((uint32_t)0x00000020)        /*!< Rising trigger event configuration bit of line 5 */
#define  EXTI_RTSR1_TR6                       ((uint32_t)0x00000040)        /*!< Rising trigger event configuration bit of line 6 */
#define  EXTI_RTSR1_TR7                       ((uint32_t)0x00000080)        /*!< Rising trigger event configuration bit of line 7 */
#define  EXTI_RTSR1_TR8                       ((uint32_t)0x00000100)        /*!< Rising trigger event configuration bit of line 8 */
#define  EXTI_RTSR1_TR9                       ((uint32_t)0x00000200)        /*!< Rising trigger event configuration bit of line 9 */
#define  EXTI_RTSR1_TR10                      ((uint32_t)0x00000400)        /*!< Rising trigger event configuration bit of line 10 */
#define  EXTI_RTSR1_TR11                      ((uint32_t)0x00000800)        /*!< Rising trigger event configuration bit of line 11 */
#define  EXTI_RTSR1_TR12                      ((uint32_t)0x00001000)        /*!< Rising trigger event configuration bit of line 12 */
#define  EXTI_RTSR1_TR13                      ((uint32_t)0x00002000)        /*!< Rising trigger event configuration bit of line 13 */
#define  EXTI_RTSR1_TR14                      ((uint32_t)0x00004000)        /*!< Rising trigger event configuration bit of line 14 */
#define  EXTI_RTSR1_TR15                      ((uint32_t)0x00008000)        /*!< Rising trigger event configuration bit of line 15 */
#define  EXTI_RTSR1_TR16                      ((uint32_t)0x00010000)        /*!< Rising trigger event configuration bit of line 16 */
#define  EXTI_RTSR1_TR17                      ((uint32_t)0x00020000)        /*!< Rising trigger event configuration bit of line 17 */
#define  EXTI_RTSR1_TR18                      ((uint32_t)0x00040000)        /*!< Rising trigger event configuration bit of line 18 */
#define  EXTI_RTSR1_TR19                      ((uint32_t)0x00080000)        /*!< Rising trigger event configuration bit of line 19 */
#define  EXTI_RTSR1_TR20                      ((uint32_t)0x00100000)        /*!< Rising trigger event configuration bit of line 20 */
#define  EXTI_RTSR1_TR21                      ((uint32_t)0x00200000)        /*!< Rising trigger event configuration bit of line 21 */
/******************  Bit definition for EXTI_RTSR2 register  *******************/
#define  EXTI_RTSR2_TR49                       ((uint32_t)0x00020000)        /*!< Rising trigger event configuration bit of line 49 */
#define  EXTI_RTSR2_TR51                       ((uint32_t)0x00080000)        /*!< Rising trigger event configuration bit of line 51 */
/******************  Bit definition for EXTI_RTSR3 register  *******************/
#define  EXTI_RTSR3_TR85                       ((uint32_t)0x00200000)        /*!< Rising trigger event configuration bit of line 85 */
#define  EXTI_RTSR3_TR86                       ((uint32_t)0x00400000)        /*!< Rising trigger event configuration bit of line 86 */

/******************  Bit definition for EXTI_FTSR1 register  *******************/
#define  EXTI_FTSR1_TR0                       ((uint32_t)0x00000001)        /*!< Falling trigger event configuration bit of line 0 */
#define  EXTI_FTSR1_TR1                       ((uint32_t)0x00000002)        /*!< Falling trigger event configuration bit of line 1 */
#define  EXTI_FTSR1_TR2                       ((uint32_t)0x00000004)        /*!< Falling trigger event configuration bit of line 2 */
#define  EXTI_FTSR1_TR3                       ((uint32_t)0x00000008)        /*!< Falling trigger event configuration bit of line 3 */
#define  EXTI_FTSR1_TR4                       ((uint32_t)0x00000010)        /*!< Falling trigger event configuration bit of line 4 */
#define  EXTI_FTSR1_TR5                       ((uint32_t)0x00000020)        /*!< Falling trigger event configuration bit of line 5 */
#define  EXTI_FTSR1_TR6                       ((uint32_t)0x00000040)        /*!< Falling trigger event configuration bit of line 6 */
#define  EXTI_FTSR1_TR7                       ((uint32_t)0x00000080)        /*!< Falling trigger event configuration bit of line 7 */
#define  EXTI_FTSR1_TR8                       ((uint32_t)0x00000100)        /*!< Falling trigger event configuration bit of line 8 */
#define  EXTI_FTSR1_TR9                       ((uint32_t)0x00000200)        /*!< Falling trigger event configuration bit of line 9 */
#define  EXTI_FTSR1_TR10                      ((uint32_t)0x00000400)        /*!< Falling trigger event configuration bit of line 10 */
#define  EXTI_FTSR1_TR11                      ((uint32_t)0x00000800)        /*!< Falling trigger event configuration bit of line 11 */
#define  EXTI_FTSR1_TR12                      ((uint32_t)0x00001000)        /*!< Falling trigger event configuration bit of line 12 */
#define  EXTI_FTSR1_TR13                      ((uint32_t)0x00002000)        /*!< Falling trigger event configuration bit of line 13 */
#define  EXTI_FTSR1_TR14                      ((uint32_t)0x00004000)        /*!< Falling trigger event configuration bit of line 14 */
#define  EXTI_FTSR1_TR15                      ((uint32_t)0x00008000)        /*!< Falling trigger event configuration bit of line 15 */
#define  EXTI_FTSR1_TR16                      ((uint32_t)0x00010000)        /*!< Falling trigger event configuration bit of line 16 */
#define  EXTI_FTSR1_TR17                      ((uint32_t)0x00020000)        /*!< Falling trigger event configuration bit of line 17 */
#define  EXTI_FTSR1_TR18                      ((uint32_t)0x00040000)        /*!< Falling trigger event configuration bit of line 18 */
#define  EXTI_FTSR1_TR19                      ((uint32_t)0x00080000)        /*!< Falling trigger event configuration bit of line 19 */
#define  EXTI_FTSR1_TR20                      ((uint32_t)0x00100000)        /*!< Falling trigger event configuration bit of line 20 */
#define  EXTI_FTSR1_TR21                      ((uint32_t)0x00200000)        /*!< Falling trigger event configuration bit of line 21 */
/******************  Bit definition for EXTI_FTSR2 register  *******************/
#define  EXTI_FTSR2_TR49                       ((uint32_t)0x00020000)       /*!< Falling trigger event configuration bit of line 49 */
#define  EXTI_FTSR2_TR51                       ((uint32_t)0x00080000)       /*!< Falling trigger event configuration bit of line 51 */

/******************  Bit definition for EXTI_FTSR3 register  *******************/
#define  EXTI_FTSR3_TR85                       ((uint32_t)0x00200000)       /*!< Falling trigger event configuration bit of line 85 */
#define  EXTI_FTSR3_TR86                       ((uint32_t)0x00400000)       /*!< Falling trigger event configuration bit of line 86 */
/******************  Bit definition for EXTI_SWIER1 register  ******************/
#define  EXTI_SWIER1_SWIER0                   ((uint32_t)0x00000001)        /*!< Software Interrupt on line 0 */
#define  EXTI_SWIER1_SWIER1                   ((uint32_t)0x00000002)        /*!< Software Interrupt on line 1 */
#define  EXTI_SWIER1_SWIER2                   ((uint32_t)0x00000004)        /*!< Software Interrupt on line 2 */
#define  EXTI_SWIER1_SWIER3                   ((uint32_t)0x00000008)        /*!< Software Interrupt on line 3 */
#define  EXTI_SWIER1_SWIER4                   ((uint32_t)0x00000010)        /*!< Software Interrupt on line 4 */
#define  EXTI_SWIER1_SWIER5                   ((uint32_t)0x00000020)        /*!< Software Interrupt on line 5 */
#define  EXTI_SWIER1_SWIER6                   ((uint32_t)0x00000040)        /*!< Software Interrupt on line 6 */
#define  EXTI_SWIER1_SWIER7                   ((uint32_t)0x00000080)        /*!< Software Interrupt on line 7 */
#define  EXTI_SWIER1_SWIER8                   ((uint32_t)0x00000100)        /*!< Software Interrupt on line 8 */
#define  EXTI_SWIER1_SWIER9                   ((uint32_t)0x00000200)        /*!< Software Interrupt on line 9 */
#define  EXTI_SWIER1_SWIER10                  ((uint32_t)0x00000400)        /*!< Software Interrupt on line 10 */
#define  EXTI_SWIER1_SWIER11                  ((uint32_t)0x00000800)        /*!< Software Interrupt on line 11 */
#define  EXTI_SWIER1_SWIER12                  ((uint32_t)0x00001000)        /*!< Software Interrupt on line 12 */
#define  EXTI_SWIER1_SWIER13                  ((uint32_t)0x00002000)        /*!< Software Interrupt on line 13 */
#define  EXTI_SWIER1_SWIER14                  ((uint32_t)0x00004000)        /*!< Software Interrupt on line 14 */
#define  EXTI_SWIER1_SWIER15                  ((uint32_t)0x00008000)        /*!< Software Interrupt on line 15 */
#define  EXTI_SWIER1_SWIER16                  ((uint32_t)0x00010000)        /*!< Software Interrupt on line 16 */
#define  EXTI_SWIER1_SWIER17                  ((uint32_t)0x00020000)        /*!< Software Interrupt on line 17 */
#define  EXTI_SWIER1_SWIER18                  ((uint32_t)0x00040000)        /*!< Software Interrupt on line 18 */
#define  EXTI_SWIER1_SWIER19                  ((uint32_t)0x00080000)        /*!< Software Interrupt on line 19 */
#define  EXTI_SWIER1_SWIER20                  ((uint32_t)0x00100000)        /*!< Software Interrupt on line 20 */
#define  EXTI_SWIER1_SWIER21                  ((uint32_t)0x00200000)        /*!< Software Interrupt on line 21 */

/******************  Bit definition for EXTI_SWIER2 register  ******************/
#define  EXTI_SWIER2_SWIER49                   ((uint32_t)0x00020000)        /*!< Software Interrupt on line 49 */
#define  EXTI_SWIER2_SWIER51                   ((uint32_t)0x00080000)        /*!< Software Interrupt on line 51 */

/******************  Bit definition for EXTI_SWIER3 register  ******************/
#define  EXTI_SWIER3_SWIER85                   ((uint32_t)0x00200000)        /*!< Software Interrupt on line 85 */
#define  EXTI_SWIER3_SWIER86                   ((uint32_t)0x00400000)        /*!< Software Interrupt on line 86 */

/*******************  Bit definition for EXTI_PR1 register  ********************/
#define  EXTI_PR1_PR0                         ((uint32_t)0x00000001)        /*!< Pending bit for line 0 */
#define  EXTI_PR1_PR1                         ((uint32_t)0x00000002)        /*!< Pending bit for line 1 */
#define  EXTI_PR1_PR2                         ((uint32_t)0x00000004)        /*!< Pending bit for line 2 */
#define  EXTI_PR1_PR3                         ((uint32_t)0x00000008)        /*!< Pending bit for line 3 */
#define  EXTI_PR1_PR4                         ((uint32_t)0x00000010)        /*!< Pending bit for line 4 */
#define  EXTI_PR1_PR5                         ((uint32_t)0x00000020)        /*!< Pending bit for line 5 */
#define  EXTI_PR1_PR6                         ((uint32_t)0x00000040)        /*!< Pending bit for line 6 */
#define  EXTI_PR1_PR7                         ((uint32_t)0x00000080)        /*!< Pending bit for line 7 */
#define  EXTI_PR1_PR8                         ((uint32_t)0x00000100)        /*!< Pending bit for line 8 */
#define  EXTI_PR1_PR9                         ((uint32_t)0x00000200)        /*!< Pending bit for line 9 */
#define  EXTI_PR1_PR10                        ((uint32_t)0x00000400)        /*!< Pending bit for line 10 */
#define  EXTI_PR1_PR11                        ((uint32_t)0x00000800)        /*!< Pending bit for line 11 */
#define  EXTI_PR1_PR12                        ((uint32_t)0x00001000)        /*!< Pending bit for line 12 */
#define  EXTI_PR1_PR13                        ((uint32_t)0x00002000)        /*!< Pending bit for line 13 */
#define  EXTI_PR1_PR14                        ((uint32_t)0x00004000)        /*!< Pending bit for line 14 */
#define  EXTI_PR1_PR15                        ((uint32_t)0x00008000)        /*!< Pending bit for line 15 */
#define  EXTI_PR1_PR16                        ((uint32_t)0x00010000)        /*!< Pending bit for line 16 */
#define  EXTI_PR1_PR17                        ((uint32_t)0x00020000)        /*!< Pending bit for line 17 */
#define  EXTI_PR1_PR18                        ((uint32_t)0x00040000)        /*!< Pending bit for line 18 */
#define  EXTI_PR1_PR19                        ((uint32_t)0x00080000)        /*!< Pending bit for line 19 */
#define  EXTI_PR1_PR20                        ((uint32_t)0x00100000)        /*!< Pending bit for line 20 */
#define  EXTI_PR1_PR21                        ((uint32_t)0x00200000)        /*!< Pending bit for line 21 */
/*******************  Bit definition for EXTI_PR2 register  ********************/
#define  EXTI_PR2_PR49                        ((uint32_t)0x00020000)        /*!< Pending bit for line 49 */
#define  EXTI_PR2_PR51                        ((uint32_t)0x00080000)        /*!< Pending bit for line 51 */
/*******************  Bit definition for EXTI_PR3 register  ********************/
#define  EXTI_PR3_PR82                        ((uint32_t)0x00040000)        /*!< Pending bit for line 82 */
#define  EXTI_PR3_PR84                        ((uint32_t)0x00100000)        /*!< Pending bit for line 84 */
#define  EXTI_PR3_PR85                        ((uint32_t)0x00200000)        /*!< Pending bit for line 85 */
#define  EXTI_PR3_PR86                        ((uint32_t)0x00400000)        /*!< Pending bit for line 86 */
/******************************************************************************/
/*                                                                            */
/*                                    FLASH                                   */
/*                                                                            */
/******************************************************************************/
/*
* @brief FLASH Total Sectors Number
*/
#define FLASH_SECTOR_TOTAL  16

/*******************  Bits definition for FLASH_ACR register  **********************/
#define FLASH_ACR_LATENCY                 0x0000000FU
#define FLASH_ACR_LATENCY_0WS             0x00000000U
#define FLASH_ACR_LATENCY_1WS             0x00000001U
#define FLASH_ACR_LATENCY_2WS             0x00000002U
#define FLASH_ACR_LATENCY_3WS             0x00000003U
#define FLASH_ACR_LATENCY_4WS             0x00000004U
#define FLASH_ACR_LATENCY_5WS             0x00000005U
#define FLASH_ACR_LATENCY_6WS             0x00000006U
#define FLASH_ACR_LATENCY_7WS             0x00000007U
#define FLASH_ACR_LATENCY_8WS             0x00000008U
#define FLASH_ACR_LATENCY_9WS             0x00000009U
#define FLASH_ACR_LATENCY_10WS            0x0000000AU
#define FLASH_ACR_LATENCY_11WS            0x0000000BU
#define FLASH_ACR_LATENCY_12WS            0x0000000CU
#define FLASH_ACR_LATENCY_13WS            0x0000000DU
#define FLASH_ACR_LATENCY_14WS            0x0000000EU
#define FLASH_ACR_LATENCY_15WS            0x0000000FU
#define FLASH_ACR_WRHIGHFREQ_0            0x00000000U
#define FLASH_ACR_WRHIGHFREQ_1            0x00000010U
#define FLASH_ACR_WRHIGHFREQ_2            0x00000020U
#define FLASH_ACR_WRHIGHFREQ_3            0x00000030U

/*******************  Bits definition for FLASH_CR register  ***********************/
#define FLASH_CR_LOCK                     0x00000001U
#define FLASH_CR_PG                       0x00000002U
#define FLASH_CR_SER                      0x00000004U
#define FLASH_CR_BER                      0x00000008U

#define FLASH_CR_PSIZE                    0x00000030U
#define FLASH_CR_PSIZE_0                  0x00000010U
#define FLASH_CR_PSIZE_1                  0x00000020U
#define FLASH_CR_FW                       0x00000040U
#define FLASH_CR_START                    0x00000080U

#define FLASH_CR_SNB                      0x00000700U
#define FLASH_CR_SNB_0                    0x00000000U
#define FLASH_CR_SNB_1                    0x00000100U
#define FLASH_CR_SNB_2                    0x00000200U
#define FLASH_CR_SNB_3                    0x00000300U
#define FLASH_CR_SNB_4                    0x00000400U
#define FLASH_CR_SNB_5                    0x00000500U
#define FLASH_CR_SNB_6                    0x00000600U
#define FLASH_CR_SNB_7                    0x00000700U

#define FLASH_CR_CRC_EN                   0x00008000U

#define FLASH_CR_EOPIE                    0x00010000U
#define FLASH_CR_WRPERRIE                 0x00020000U
#define FLASH_CR_PGSERRIE                 0x00040000U
#define FLASH_CR_STRBERRIE                0x00080000U
#define FLASH_CR_INCERRIE                 0x00200000U
#define FLASH_CR_OPERRIE                  0x00400000U
#define FLASH_CR_RDPERRIE                 0x00800000U
#define FLASH_CR_RDSERRIE                 0x01000000U

#define FLASH_CR_SNECCERRIE               0x02000000U
#define FLASH_CR_DBECCERRIE               0x04000000U

#define FLASH_CR_CRCENDIE                 0x08000000U

/*******************  Bits definition for FLASH_SR register  ***********************/
#define FLASH_SR_BSY                      0x00000001U
#define FLASH_SR_WBNE                     0x00000002U
#define FLASH_SR_QW                       0x00000004U

#define FLASH_SR_CRC_BUSY                 0x00000008U

#define FLASH_SR_EOP                      0x00010000U
#define FLASH_SR_WRPERR                   0x00020000U
#define FLASH_SR_PGSERR                   0x00040000U
#define FLASH_SR_STRBERR                  0x00080000U
#define FLASH_SR_INCERR                   0x00200000U
#define FLASH_SR_OPERR                    0x00400000U

#define FLASH_SR_RDPERR                   0x00800000U
#define FLASH_SR_RDSERR                   0x01000000U

#define FLASH_SR_SNECCERR                 0x02000000U
#define FLASH_SR_DBECCERR                 0x04000000U

#define FLASH_SR_CRCEND                   0x08000000U

/*******************  Bits definition for FLASH_FCCR_A register  *******************/
#define FLASH_CCR_CLR_EOP                 0x00010000U
#define FLASH_CCR_CLR_WRPERR              0x00020000U
#define FLASH_CCR_CLR_PGSERR              0x00040000U
#define FLASH_CCR_CLR_STRBERR             0x00080000U
#define FLASH_CCR_CLR_INCERR              0x00200000U
#define FLASH_CCR_CLR_OPERR               0x00400000U

#define FLASH_CCR_CLR_RDPERR              0x00800000U
#define FLASH_CCR_CLR_RDSERR              0x01000000U

#define FLASH_CCR_CLR_SNECCERR            0x02000000U
#define FLASH_CCR_CLR_DBECCERR            0x04000000U

#define FLASH_CCR_CLR_CRCEND              0x08000000U

/*******************  Bits definition for FLASH_FOPTCR register  *******************/
#define FLASH_OPTCR_OPTLOCK               0x00000001U
#define FLASH_OPTCR_OPTSTART              0x00000002U
#define FLASH_OPTCR_OPTCHANGEERRIE        0x40000000U
#define FLASH_OPTCR_SWAP_BANK             0x80000000U

/*******************  Bits definition for FLASH_FOPTSR_CUR register  ***************/
#define FLASH_OPTSR_OPT_BUSY              0x00000001U
#define FLASH_OPTSR_BOR_LEV               0x0000000CU
#define FLASH_OPTSR_BOR_LEV_0             0x00000004U
#define FLASH_OPTSR_BOR_LEV_1             0x00000008U
#define FLASH_OPTSR_IWDG1_SW              0x00000010U


#define FLASH_OPTSR_NRST_STOP_D1          0x00000040U
#define FLASH_OPTSR_NRST_STBY_D1          0x00000080U
#define FLASH_OPTSR_RDP                   0x0000FF00U
#define FLASH_OPTCR_RDP_0                 0x00000100U
#define FLASH_OPTCR_RDP_1                 0x00000200U
#define FLASH_OPTCR_RDP_2                 0x00000400U
#define FLASH_OPTCR_RDP_3                 0x00000800U
#define FLASH_OPTCR_RDP_4                 0x00001000U
#define FLASH_OPTCR_RDP_5                 0x00002000U
#define FLASH_OPTCR_RDP_6                 0x00004000U
#define FLASH_OPTCR_RDP_7                 0x00008000U

#define FLASH_OPTSR_FZ_IWDG_STOP          0x00020000U
#define FLASH_OPTSR_FZ_IWDG_SDBY          0x00040000U
#define FLASH_OPTSR_ST_RAM_SIZE           0x00180000U
#define FLASH_OPTSR_ST_RAM_SIZE_0         0x00080000U
#define FLASH_OPTSR_ST_RAM_SIZE_1         0x00100000U
#define FLASH_OPTSR_SECURITY              0x00200000U
#define FLASH_OPTSR_RSS1                  0x04000000U
#define FLASH_OPTSR_RSS2                  0x08000000U
#define FLASH_OPTSR_PERSO_OK              0x10000000U
#define FLASH_OPTSR_IOHSLV_OPT            0x20000000U
#define FLASH_OPTSR_OPTCHANGEERR          0x40000000U
#define FLASH_OPTSR_SWAP_BANK_OPT         0x80000000U

/*******************  Bits definition for FLASH_OPTCCR register  *******************/
#define FLASH_OPTCCR_CLR_OPTCHANGEERR     0x40000000U

/*******************  Bits definition for FLASH_PRAR register  *********************/
#define FLASH_PRAR_PROT_AREA_START        0x00000FFFU
#define FLASH_PRAR_PROT_AREA_END          0x0FFF0000U
#define FLASH_PRAR_DMEP                   0x80000000U

/*******************  Bits definition for FLASH_SCAR register  *********************/
#define FLASH_SCAR_SEC_AREA_START         0x00000FFFU
#define FLASH_SCAR_SEC_AREA_END           0x0FFF0000U
#define FLASH_SCAR_DMES                   0x80000000U

/*******************  Bits definition for FLASH_WPSN register  *********************/
#define FLASH_WPSN_WRPSN                  0x000000FFU

/*******************  Bits definition for FLASH_BOOT7_CUR register  ****************/
#define FLASH_BOOT7_BCM7_ADD0             0x0000FFFFU
#define FLASH_BOOT7_BCM7_ADD1             0xFFFF0000U


/*******************  Bits definition for FLASH_CRCCR register  ********************/
#define FLASH_CRCCR_CRC_SECT              0x0000007FU
#define FLASH_CRCCR_ALL_BANK              0x00000080U
#define FLASH_CRCCR_CRC_BY_SECT           0x00000100U
#define FLASH_CRCCR_ADD_SECT              0x00000200U
#define FLASH_CRCCR_CLEAN_SECT            0x00000400U
#define FLASH_CRCCR_START_CRC             0x00010000U
#define FLASH_CRCCR_CLEAN_CRC             0x00020000U
#define FLASH_CRCCR_CRC_BURST             0x00300000U
#define FLASH_CRCCR_CRC_BURST_0           0x00000000U
#define FLASH_CRCCR_CRC_BURST_1           0x00100000U
#define FLASH_CRCCR_CRC_BURST_2           0x00200000U
#define FLASH_CRCCR_CRC_BURST_3           0x00300000U

/*******************  Bits definition for FLASH_CRCSADD_A register  ****************/
#define FLASH_CRCSADD_CRC_START_ADDR      0xFFFFFFFFU

/*******************  Bits definition for FLASH_CRCEADD_A register  ****************/
#define FLASH_CRCEADD_CRC_END_ADDR        0xFFFFFFFFU

/*******************  Bits definition for FLASH_FCRCDATA_A register  ***************/
#define FLASH_CRCDATA_CRC_DATA            0xFFFFFFFFU

/*******************  Bits definition for FLASH_ECC_FA register  *******************/
#define FLASH_ECC_FA_FAIL_ECC_ADDR        0x00007FFFU


/******************************************************************************/
/*                                                                            */
/*                          Flexible Memory Controller                        */
/*                                                                            */
/******************************************************************************/
/******************  Bit definition for FMC_BCR1 register  *******************/
#define  FMC_BCR1_MBKEN                     ((uint32_t)0x00000001)        /*!<Memory bank enable bit                 */
#define  FMC_BCR1_MUXEN                     ((uint32_t)0x00000002)        /*!<Address/data multiplexing enable bit   */

#define  FMC_BCR1_MTYP                      ((uint32_t)0x0000000C)        /*!<MTYP[1:0] bits (Memory type)           */
#define  FMC_BCR1_MTYP_0                    ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  FMC_BCR1_MTYP_1                    ((uint32_t)0x00000008)        /*!<Bit 1 */

#define  FMC_BCR1_MWID                      ((uint32_t)0x00000030)        /*!<MWID[1:0] bits (Memory data bus width) */
#define  FMC_BCR1_MWID_0                    ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BCR1_MWID_1                    ((uint32_t)0x00000020)        /*!<Bit 1 */

#define  FMC_BCR1_FACCEN                    ((uint32_t)0x00000040)        /*!<Flash access enable        */
#define  FMC_BCR1_BURSTEN                   ((uint32_t)0x00000100)        /*!<Burst enable bit           */
#define  FMC_BCR1_WAITPOL                   ((uint32_t)0x00000200)        /*!<Wait signal polarity bit   */
#define  FMC_BCR1_WRAPMOD                   ((uint32_t)0x00000400)        /*!<Wrapped burst mode support */
#define  FMC_BCR1_WAITCFG                   ((uint32_t)0x00000800)        /*!<Wait timing configuration  */
#define  FMC_BCR1_WREN                      ((uint32_t)0x00001000)        /*!<Write enable bit           */
#define  FMC_BCR1_WAITEN                    ((uint32_t)0x00002000)        /*!<Wait enable bit            */
#define  FMC_BCR1_EXTMOD                    ((uint32_t)0x00004000)        /*!<Extended mode enable       */
#define  FMC_BCR1_ASYNCWAIT                 ((uint32_t)0x00008000)        /*!<Asynchronous wait          */

#define  FMC_BCR1_CPSIZE                   ((uint32_t)0x00070000)        /*!<PSIZE[2:0] bits CRAM Page Size */
#define  FMC_BCR1_CPSIZE_0                 ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_BCR1_CPSIZE_1                 ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_BCR1_CPSIZE_2                 ((uint32_t)0x00040000)        /*!<Bit 2 */

#define  FMC_BCR1_CBURSTRW                  ((uint32_t)0x00080000)        /*!<Write burst enable         */
#define  FMC_BCR1_CCLKEN                    ((uint32_t)0x00100000)        /*!<Continous clock enable     */
#define  FMC_BCR1_WFDIS                     ((uint32_t)0x00200000)        /*!<Write FIFO Disable         */

/******************  Bit definition for FMC_BCR2 register  *******************/
#define  FMC_BCR2_MBKEN                     ((uint32_t)0x00000001)        /*!<Memory bank enable bit                 */
#define  FMC_BCR2_MUXEN                     ((uint32_t)0x00000002)        /*!<Address/data multiplexing enable bit   */

#define  FMC_BCR2_MTYP                      ((uint32_t)0x0000000C)        /*!<MTYP[1:0] bits (Memory type)           */
#define  FMC_BCR2_MTYP_0                    ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  FMC_BCR2_MTYP_1                    ((uint32_t)0x00000008)        /*!<Bit 1 */

#define  FMC_BCR2_MWID                      ((uint32_t)0x00000030)        /*!<MWID[1:0] bits (Memory data bus width) */
#define  FMC_BCR2_MWID_0                    ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BCR2_MWID_1                    ((uint32_t)0x00000020)        /*!<Bit 1 */

#define  FMC_BCR2_FACCEN                    ((uint32_t)0x00000040)        /*!<Flash access enable        */
#define  FMC_BCR2_BURSTEN                   ((uint32_t)0x00000100)        /*!<Burst enable bit           */
#define  FMC_BCR2_WAITPOL                   ((uint32_t)0x00000200)        /*!<Wait signal polarity bit   */
#define  FMC_BCR2_WRAPMOD                   ((uint32_t)0x00000400)        /*!<Wrapped burst mode support */
#define  FMC_BCR2_WAITCFG                   ((uint32_t)0x00000800)        /*!<Wait timing configuration  */
#define  FMC_BCR2_WREN                      ((uint32_t)0x00001000)        /*!<Write enable bit           */
#define  FMC_BCR2_WAITEN                    ((uint32_t)0x00002000)        /*!<Wait enable bit            */
#define  FMC_BCR2_EXTMOD                    ((uint32_t)0x00004000)        /*!<Extended mode enable       */
#define  FMC_BCR2_ASYNCWAIT                 ((uint32_t)0x00008000)        /*!<Asynchronous wait          */

#define  FMC_BCR2_PSIZE                    ((uint32_t)0x00070000)        /*!<PSIZE[2:0] bits CRAM Page Size */
#define  FMC_BCR2_PSIZE_0                  ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_BCR2_PSIZE_1                  ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_BCR2_PSIZE_2                  ((uint32_t)0x00040000)        /*!<Bit 2 */

#define  FMC_BCR2_CBURSTRW                  ((uint32_t)0x00080000)        /*!<Write burst enable         */

/******************  Bit definition for FMC_BCR3 register  *******************/
#define  FMC_BCR3_MBKEN                     ((uint32_t)0x00000001)        /*!<Memory bank enable bit                 */
#define  FMC_BCR3_MUXEN                     ((uint32_t)0x00000002)        /*!<Address/data multiplexing enable bit   */

#define  FMC_BCR3_MTYP                      ((uint32_t)0x0000000C)        /*!<MTYP[1:0] bits (Memory type)           */
#define  FMC_BCR3_MTYP_0                    ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  FMC_BCR3_MTYP_1                    ((uint32_t)0x00000008)        /*!<Bit 1 */

#define  FMC_BCR3_MWID                      ((uint32_t)0x00000030)        /*!<MWID[1:0] bits (Memory data bus width) */
#define  FMC_BCR3_MWID_0                    ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BCR3_MWID_1                    ((uint32_t)0x00000020)        /*!<Bit 1 */

#define  FMC_BCR3_FACCEN                    ((uint32_t)0x00000040)        /*!<Flash access enable        */
#define  FMC_BCR3_BURSTEN                   ((uint32_t)0x00000100)        /*!<Burst enable bit           */
#define  FMC_BCR3_WAITPOL                   ((uint32_t)0x00000200)        /*!<Wait signal polarity bit   */
#define  FMC_BCR3_WRAPMOD                   ((uint32_t)0x00000400)        /*!<Wrapped burst mode support */
#define  FMC_BCR3_WAITCFG                   ((uint32_t)0x00000800)        /*!<Wait timing configuration  */
#define  FMC_BCR3_WREN                      ((uint32_t)0x00001000)        /*!<Write enable bit           */
#define  FMC_BCR3_WAITEN                    ((uint32_t)0x00002000)        /*!<Wait enable bit            */
#define  FMC_BCR3_EXTMOD                    ((uint32_t)0x00004000)        /*!<Extended mode enable       */
#define  FMC_BCR3_ASYNCWAIT                 ((uint32_t)0x00008000)        /*!<Asynchronous wait          */

#define  FMC_BCR3_PSIZE                    ((uint32_t)0x00070000)        /*!<PSIZE[2:0] bits CRAM Page Size */
#define  FMC_BCR3_PSIZE_0                  ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_BCR3_PSIZE_1                  ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_BCR3_PSIZE_2                  ((uint32_t)0x00040000)        /*!<Bit 2 */

#define  FMC_BCR3_CBURSTRW                  ((uint32_t)0x00080000)        /*!<Write burst enable         */

/******************  Bit definition for FMC_BCR4 register  *******************/
#define  FMC_BCR4_MBKEN                     ((uint32_t)0x00000001)        /*!<Memory bank enable bit                 */
#define  FMC_BCR4_MUXEN                     ((uint32_t)0x00000002)        /*!<Address/data multiplexing enable bit   */

#define  FMC_BCR4_MTYP                      ((uint32_t)0x0000000C)        /*!<MTYP[1:0] bits (Memory type)           */
#define  FMC_BCR4_MTYP_0                    ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  FMC_BCR4_MTYP_1                    ((uint32_t)0x00000008)        /*!<Bit 1 */

#define  FMC_BCR4_MWID                      ((uint32_t)0x00000030)        /*!<MWID[1:0] bits (Memory data bus width) */
#define  FMC_BCR4_MWID_0                    ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BCR4_MWID_1                    ((uint32_t)0x00000020)        /*!<Bit 1 */

#define  FMC_BCR4_FACCEN                    ((uint32_t)0x00000040)        /*!<Flash access enable        */
#define  FMC_BCR4_BURSTEN                   ((uint32_t)0x00000100)        /*!<Burst enable bit           */
#define  FMC_BCR4_WAITPOL                   ((uint32_t)0x00000200)        /*!<Wait signal polarity bit   */
#define  FMC_BCR4_WRAPMOD                   ((uint32_t)0x00000400)        /*!<Wrapped burst mode support */
#define  FMC_BCR4_WAITCFG                   ((uint32_t)0x00000800)        /*!<Wait timing configuration  */
#define  FMC_BCR4_WREN                      ((uint32_t)0x00001000)        /*!<Write enable bit           */
#define  FMC_BCR4_WAITEN                    ((uint32_t)0x00002000)        /*!<Wait enable bit            */
#define  FMC_BCR4_EXTMOD                    ((uint32_t)0x00004000)        /*!<Extended mode enable       */
#define  FMC_BCR4_ASYNCWAIT                 ((uint32_t)0x00008000)        /*!<Asynchronous wait          */

#define  FMC_BCR4_PSIZE                    ((uint32_t)0x00070000)        /*!<PSIZE[2:0] bits CRAM Page Size */
#define  FMC_BCR4_PSIZE_0                  ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_BCR4_PSIZE_1                  ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_BCR4_PSIZE_2                  ((uint32_t)0x00040000)        /*!<Bit 2 */

#define  FMC_BCR4_CBURSTRW                  ((uint32_t)0x00080000)        /*!<Write burst enable         */

/******************  Bit definition for FMC_BTR1 register  ******************/
#define  FMC_BTR1_ADDSET                    ((uint32_t)0x0000000F)        /*!<ADDSET[3:0] bits (Address setup phase duration) */
#define  FMC_BTR1_ADDSET_0                  ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_BTR1_ADDSET_1                  ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_BTR1_ADDSET_2                  ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_BTR1_ADDSET_3                  ((uint32_t)0x00000008)        /*!<Bit 3 */

#define  FMC_BTR1_ADDHLD                    ((uint32_t)0x000000F0)        /*!<ADDHLD[3:0] bits (Address-hold phase duration)  */
#define  FMC_BTR1_ADDHLD_0                  ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BTR1_ADDHLD_1                  ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_BTR1_ADDHLD_2                  ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_BTR1_ADDHLD_3                  ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_BTR1_DATAST                    ((uint32_t)0x0000FF00)        /*!<DATAST [3:0] bits (Data-phase duration) */
#define  FMC_BTR1_DATAST_0                  ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_BTR1_DATAST_1                  ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_BTR1_DATAST_2                  ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_BTR1_DATAST_3                  ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_BTR1_DATAST_4                  ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_BTR1_DATAST_5                  ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_BTR1_DATAST_6                  ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_BTR1_DATAST_7                  ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_BTR1_BUSTURN                   ((uint32_t)0x000F0000)        /*!<BUSTURN[3:0] bits (Bus turnaround phase duration) */
#define  FMC_BTR1_BUSTURN_0                 ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_BTR1_BUSTURN_1                 ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_BTR1_BUSTURN_2                 ((uint32_t)0x00040000)        /*!<Bit 2 */
#define  FMC_BTR1_BUSTURN_3                 ((uint32_t)0x00080000)        /*!<Bit 3 */

#define  FMC_BTR1_CLKDIV                    ((uint32_t)0x00F00000)        /*!<CLKDIV[3:0] bits (Clock divide ratio) */
#define  FMC_BTR1_CLKDIV_0                  ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_BTR1_CLKDIV_1                  ((uint32_t)0x00200000)        /*!<Bit 1 */
#define  FMC_BTR1_CLKDIV_2                  ((uint32_t)0x00400000)        /*!<Bit 2 */
#define  FMC_BTR1_CLKDIV_3                  ((uint32_t)0x00800000)        /*!<Bit 3 */

#define  FMC_BTR1_DATLAT                    ((uint32_t)0x0F000000)        /*!<DATLA[3:0] bits (Data latency) */
#define  FMC_BTR1_DATLAT_0                  ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_BTR1_DATLAT_1                  ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_BTR1_DATLAT_2                  ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_BTR1_DATLAT_3                  ((uint32_t)0x08000000)        /*!<Bit 3 */

#define  FMC_BTR1_ACCMOD                    ((uint32_t)0x30000000)        /*!<ACCMOD[1:0] bits (Access mode) */
#define  FMC_BTR1_ACCMOD_0                  ((uint32_t)0x10000000)        /*!<Bit 0 */
#define  FMC_BTR1_ACCMOD_1                  ((uint32_t)0x20000000)        /*!<Bit 1 */

/******************  Bit definition for FMC_BTR2 register  *******************/
#define  FMC_BTR2_ADDSET                    ((uint32_t)0x0000000F)        /*!<ADDSET[3:0] bits (Address setup phase duration) */
#define  FMC_BTR2_ADDSET_0                  ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_BTR2_ADDSET_1                  ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_BTR2_ADDSET_2                  ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_BTR2_ADDSET_3                  ((uint32_t)0x00000008)        /*!<Bit 3 */

#define  FMC_BTR2_ADDHLD                    ((uint32_t)0x000000F0)        /*!<ADDHLD[3:0] bits (Address-hold phase duration) */
#define  FMC_BTR2_ADDHLD_0                  ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BTR2_ADDHLD_1                  ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_BTR2_ADDHLD_2                  ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_BTR2_ADDHLD_3                  ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_BTR2_DATAST                    ((uint32_t)0x0000FF00)        /*!<DATAST [3:0] bits (Data-phase duration) */
#define  FMC_BTR2_DATAST_0                  ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_BTR2_DATAST_1                  ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_BTR2_DATAST_2                  ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_BTR2_DATAST_3                  ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_BTR2_DATAST_4                  ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_BTR2_DATAST_5                  ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_BTR2_DATAST_6                  ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_BTR2_DATAST_7                  ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_BTR2_BUSTURN                   ((uint32_t)0x000F0000)        /*!<BUSTURN[3:0] bits (Bus turnaround phase duration) */
#define  FMC_BTR2_BUSTURN_0                 ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_BTR2_BUSTURN_1                 ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_BTR2_BUSTURN_2                 ((uint32_t)0x00040000)        /*!<Bit 2 */
#define  FMC_BTR2_BUSTURN_3                 ((uint32_t)0x00080000)        /*!<Bit 3 */

#define  FMC_BTR2_CLKDIV                    ((uint32_t)0x00F00000)        /*!<CLKDIV[3:0] bits (Clock divide ratio) */
#define  FMC_BTR2_CLKDIV_0                  ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_BTR2_CLKDIV_1                  ((uint32_t)0x00200000)        /*!<Bit 1 */
#define  FMC_BTR2_CLKDIV_2                  ((uint32_t)0x00400000)        /*!<Bit 2 */
#define  FMC_BTR2_CLKDIV_3                  ((uint32_t)0x00800000)        /*!<Bit 3 */

#define  FMC_BTR2_DATLAT                    ((uint32_t)0x0F000000)        /*!<DATLA[3:0] bits (Data latency) */
#define  FMC_BTR2_DATLAT_0                  ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_BTR2_DATLAT_1                  ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_BTR2_DATLAT_2                  ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_BTR2_DATLAT_3                  ((uint32_t)0x08000000)        /*!<Bit 3 */

#define  FMC_BTR2_ACCMOD                    ((uint32_t)0x30000000)        /*!<ACCMOD[1:0] bits (Access mode) */
#define  FMC_BTR2_ACCMOD_0                  ((uint32_t)0x10000000)        /*!<Bit 0 */
#define  FMC_BTR2_ACCMOD_1                  ((uint32_t)0x20000000)        /*!<Bit 1 */

/*******************  Bit definition for FMC_BTR3 register  *******************/
#define  FMC_BTR3_ADDSET                    ((uint32_t)0x0000000F)        /*!<ADDSET[3:0] bits (Address setup phase duration) */
#define  FMC_BTR3_ADDSET_0                  ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_BTR3_ADDSET_1                  ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_BTR3_ADDSET_2                  ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_BTR3_ADDSET_3                  ((uint32_t)0x00000008)        /*!<Bit 3 */

#define  FMC_BTR3_ADDHLD                    ((uint32_t)0x000000F0)        /*!<ADDHLD[3:0] bits (Address-hold phase duration) */
#define  FMC_BTR3_ADDHLD_0                  ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BTR3_ADDHLD_1                  ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_BTR3_ADDHLD_2                  ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_BTR3_ADDHLD_3                  ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_BTR3_DATAST                    ((uint32_t)0x0000FF00)        /*!<DATAST [3:0] bits (Data-phase duration) */
#define  FMC_BTR3_DATAST_0                  ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_BTR3_DATAST_1                  ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_BTR3_DATAST_2                  ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_BTR3_DATAST_3                  ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_BTR3_DATAST_4                  ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_BTR3_DATAST_5                  ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_BTR3_DATAST_6                  ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_BTR3_DATAST_7                  ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_BTR3_BUSTURN                   ((uint32_t)0x000F0000)        /*!<BUSTURN[3:0] bits (Bus turnaround phase duration) */
#define  FMC_BTR3_BUSTURN_0                 ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_BTR3_BUSTURN_1                 ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_BTR3_BUSTURN_2                 ((uint32_t)0x00040000)        /*!<Bit 2 */
#define  FMC_BTR3_BUSTURN_3                 ((uint32_t)0x00080000)        /*!<Bit 3 */

#define  FMC_BTR3_CLKDIV                    ((uint32_t)0x00F00000)        /*!<CLKDIV[3:0] bits (Clock divide ratio) */
#define  FMC_BTR3_CLKDIV_0                  ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_BTR3_CLKDIV_1                  ((uint32_t)0x00200000)        /*!<Bit 1 */
#define  FMC_BTR3_CLKDIV_2                  ((uint32_t)0x00400000)        /*!<Bit 2 */
#define  FMC_BTR3_CLKDIV_3                  ((uint32_t)0x00800000)        /*!<Bit 3 */

#define  FMC_BTR3_DATLAT                    ((uint32_t)0x0F000000)        /*!<DATLA[3:0] bits (Data latency) */
#define  FMC_BTR3_DATLAT_0                  ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_BTR3_DATLAT_1                  ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_BTR3_DATLAT_2                  ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_BTR3_DATLAT_3                  ((uint32_t)0x08000000)        /*!<Bit 3 */

#define  FMC_BTR3_ACCMOD                    ((uint32_t)0x30000000)        /*!<ACCMOD[1:0] bits (Access mode) */
#define  FMC_BTR3_ACCMOD_0                  ((uint32_t)0x10000000)        /*!<Bit 0 */
#define  FMC_BTR3_ACCMOD_1                  ((uint32_t)0x20000000)        /*!<Bit 1 */

/******************  Bit definition for FMC_BTR4 register  *******************/
#define  FMC_BTR4_ADDSET                    ((uint32_t)0x0000000F)        /*!<ADDSET[3:0] bits (Address setup phase duration) */
#define  FMC_BTR4_ADDSET_0                  ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_BTR4_ADDSET_1                  ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_BTR4_ADDSET_2                  ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_BTR4_ADDSET_3                  ((uint32_t)0x00000008)        /*!<Bit 3 */

#define  FMC_BTR4_ADDHLD                    ((uint32_t)0x000000F0)        /*!<ADDHLD[3:0] bits (Address-hold phase duration) */
#define  FMC_BTR4_ADDHLD_0                  ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BTR4_ADDHLD_1                  ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_BTR4_ADDHLD_2                  ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_BTR4_ADDHLD_3                  ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_BTR4_DATAST                    ((uint32_t)0x0000FF00)        /*!<DATAST [3:0] bits (Data-phase duration) */
#define  FMC_BTR4_DATAST_0                  ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_BTR4_DATAST_1                  ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_BTR4_DATAST_2                  ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_BTR4_DATAST_3                  ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_BTR4_DATAST_4                  ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_BTR4_DATAST_5                  ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_BTR4_DATAST_6                  ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_BTR4_DATAST_7                  ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_BTR4_BUSTURN                   ((uint32_t)0x000F0000)        /*!<BUSTURN[3:0] bits (Bus turnaround phase duration) */
#define  FMC_BTR4_BUSTURN_0                 ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_BTR4_BUSTURN_1                 ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_BTR4_BUSTURN_2                 ((uint32_t)0x00040000)        /*!<Bit 2 */
#define  FMC_BTR4_BUSTURN_3                 ((uint32_t)0x00080000)        /*!<Bit 3 */

#define  FMC_BTR4_CLKDIV                    ((uint32_t)0x00F00000)        /*!<CLKDIV[3:0] bits (Clock divide ratio) */
#define  FMC_BTR4_CLKDIV_0                  ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_BTR4_CLKDIV_1                  ((uint32_t)0x00200000)        /*!<Bit 1 */
#define  FMC_BTR4_CLKDIV_2                  ((uint32_t)0x00400000)        /*!<Bit 2 */
#define  FMC_BTR4_CLKDIV_3                  ((uint32_t)0x00800000)        /*!<Bit 3 */

#define  FMC_BTR4_DATLAT                    ((uint32_t)0x0F000000)        /*!<DATLA[3:0] bits (Data latency) */
#define  FMC_BTR4_DATLAT_0                  ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_BTR4_DATLAT_1                  ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_BTR4_DATLAT_2                  ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_BTR4_DATLAT_3                  ((uint32_t)0x08000000)        /*!<Bit 3 */

#define  FMC_BTR4_ACCMOD                    ((uint32_t)0x30000000)        /*!<ACCMOD[1:0] bits (Access mode) */
#define  FMC_BTR4_ACCMOD_0                  ((uint32_t)0x10000000)        /*!<Bit 0 */
#define  FMC_BTR4_ACCMOD_1                  ((uint32_t)0x20000000)        /*!<Bit 1 */

/******************  Bit definition for FMC_BWTR1 register  ******************/
#define  FMC_BWTR1_ADDSET                   ((uint32_t)0x0000000F)        /*!<ADDSET[3:0] bits (Address setup phase duration) */
#define  FMC_BWTR1_ADDSET_0                 ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_BWTR1_ADDSET_1                 ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_BWTR1_ADDSET_2                 ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_BWTR1_ADDSET_3                 ((uint32_t)0x00000008)        /*!<Bit 3 */

#define  FMC_BWTR1_ADDHLD                   ((uint32_t)0x000000F0)        /*!<ADDHLD[3:0] bits (Address-hold phase duration) */
#define  FMC_BWTR1_ADDHLD_0                 ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BWTR1_ADDHLD_1                 ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_BWTR1_ADDHLD_2                 ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_BWTR1_ADDHLD_3                 ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_BWTR1_DATAST                   ((uint32_t)0x0000FF00)        /*!<DATAST [3:0] bits (Data-phase duration) */
#define  FMC_BWTR1_DATAST_0                 ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_BWTR1_DATAST_1                 ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_BWTR1_DATAST_2                 ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_BWTR1_DATAST_3                 ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_BWTR1_DATAST_4                 ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_BWTR1_DATAST_5                 ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_BWTR1_DATAST_6                 ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_BWTR1_DATAST_7                 ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_BWTR1_CLKDIV                   ((uint32_t)0x00F00000)        /*!<CLKDIV[3:0] bits (Clock divide ratio) */
#define  FMC_BWTR1_CLKDIV_0                 ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_BWTR1_CLKDIV_1                 ((uint32_t)0x00200000)        /*!<Bit 1 */
#define  FMC_BWTR1_CLKDIV_2                 ((uint32_t)0x00400000)        /*!<Bit 2 */
#define  FMC_BWTR1_CLKDIV_3                 ((uint32_t)0x00800000)        /*!<Bit 3 */

#define  FMC_BWTR1_DATLAT                   ((uint32_t)0x0F000000)        /*!<DATLA[3:0] bits (Data latency) */
#define  FMC_BWTR1_DATLAT_0                 ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_BWTR1_DATLAT_1                 ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_BWTR1_DATLAT_2                 ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_BWTR1_DATLAT_3                 ((uint32_t)0x08000000)        /*!<Bit 3 */

#define  FMC_BWTR1_BUSTURN                  ((uint32_t)0x000F0000)        /*!<BUSTURN[3:0] bits (Bus turnaround phase duration) */
#define  FMC_BWTR1_BUSTURN_0                ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_BWTR1_BUSTURN_1                ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_BWTR1_BUSTURN_2                ((uint32_t)0x00040000)        /*!<Bit 2 */
#define  FMC_BWTR1_BUSTURN_3                ((uint32_t)0x00080000)        /*!<Bit 3 */


#define  FMC_BWTR1_ACCMOD                   ((uint32_t)0x30000000)        /*!<ACCMOD[1:0] bits (Access mode) */
#define  FMC_BWTR1_ACCMOD_0                 ((uint32_t)0x10000000)        /*!<Bit 0 */
#define  FMC_BWTR1_ACCMOD_1                 ((uint32_t)0x20000000)        /*!<Bit 1 */

/******************  Bit definition for FMC_BWTR2 register  ******************/
#define  FMC_BWTR2_ADDSET                   ((uint32_t)0x0000000F)        /*!<ADDSET[3:0] bits (Address setup phase duration) */
#define  FMC_BWTR2_ADDSET_0                 ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_BWTR2_ADDSET_1                 ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_BWTR2_ADDSET_2                 ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_BWTR2_ADDSET_3                 ((uint32_t)0x00000008)        /*!<Bit 3 */

#define  FMC_BWTR2_ADDHLD                   ((uint32_t)0x000000F0)        /*!<ADDHLD[3:0] bits (Address-hold phase duration) */
#define  FMC_BWTR2_ADDHLD_0                 ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BWTR2_ADDHLD_1                 ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_BWTR2_ADDHLD_2                 ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_BWTR2_ADDHLD_3                 ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_BWTR2_DATAST                   ((uint32_t)0x0000FF00)        /*!<DATAST [3:0] bits (Data-phase duration) */
#define  FMC_BWTR2_DATAST_0                 ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_BWTR2_DATAST_1                 ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_BWTR2_DATAST_2                 ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_BWTR2_DATAST_3                 ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_BWTR2_DATAST_4                 ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_BWTR2_DATAST_5                 ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_BWTR2_DATAST_6                 ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_BWTR2_DATAST_7                 ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_BWTR2_CLKDIV                   ((uint32_t)0x00F00000)        /*!<CLKDIV[3:0] bits (Clock divide ratio) */
#define  FMC_BWTR2_CLKDIV_0                 ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_BWTR2_CLKDIV_1                 ((uint32_t)0x00200000)        /*!<Bit 1*/
#define  FMC_BWTR2_CLKDIV_2                 ((uint32_t)0x00400000)        /*!<Bit 2 */
#define  FMC_BWTR2_CLKDIV_3                 ((uint32_t)0x00800000)        /*!<Bit 3 */

#define  FMC_BWTR2_DATLAT                   ((uint32_t)0x0F000000)        /*!<DATLA[3:0] bits (Data latency) */
#define  FMC_BWTR2_DATLAT_0                 ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_BWTR2_DATLAT_1                 ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_BWTR2_DATLAT_2                 ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_BWTR2_DATLAT_3                 ((uint32_t)0x08000000)        /*!<Bit 3 */

#define  FMC_BWTR2_ACCMOD                   ((uint32_t)0x30000000)        /*!<ACCMOD[1:0] bits (Access mode) */
#define  FMC_BWTR2_ACCMOD_0                 ((uint32_t)0x10000000)        /*!<Bit 0 */
#define  FMC_BWTR2_ACCMOD_1                 ((uint32_t)0x20000000)        /*!<Bit 1 */

/******************  Bit definition for FMC_BWTR3 register  ******************/
#define  FMC_BWTR3_ADDSET                   ((uint32_t)0x0000000F)        /*!<ADDSET[3:0] bits (Address setup phase duration) */
#define  FMC_BWTR3_ADDSET_0                 ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_BWTR3_ADDSET_1                 ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_BWTR3_ADDSET_2                 ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_BWTR3_ADDSET_3                 ((uint32_t)0x00000008)        /*!<Bit 3 */

#define  FMC_BWTR3_ADDHLD                   ((uint32_t)0x000000F0)        /*!<ADDHLD[3:0] bits (Address-hold phase duration) */
#define  FMC_BWTR3_ADDHLD_0                 ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BWTR3_ADDHLD_1                 ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_BWTR3_ADDHLD_2                 ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_BWTR3_ADDHLD_3                 ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_BWTR3_DATAST                   ((uint32_t)0x0000FF00)        /*!<DATAST [3:0] bits (Data-phase duration) */
#define  FMC_BWTR3_DATAST_0                 ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_BWTR3_DATAST_1                 ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_BWTR3_DATAST_2                 ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_BWTR3_DATAST_3                 ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_BWTR3_DATAST_4                 ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_BWTR3_DATAST_5                 ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_BWTR3_DATAST_6                 ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_BWTR3_DATAST_7                 ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_BWTR3_CLKDIV                   ((uint32_t)0x00F00000)        /*!<CLKDIV[3:0] bits (Clock divide ratio) */
#define  FMC_BWTR3_CLKDIV_0                 ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_BWTR3_CLKDIV_1                 ((uint32_t)0x00200000)        /*!<Bit 1 */
#define  FMC_BWTR3_CLKDIV_2                 ((uint32_t)0x00400000)        /*!<Bit 2 */
#define  FMC_BWTR3_CLKDIV_3                 ((uint32_t)0x00800000)        /*!<Bit 3 */

#define  FMC_BWTR3_DATLAT                   ((uint32_t)0x0F000000)        /*!<DATLA[3:0] bits (Data latency) */
#define  FMC_BWTR3_DATLAT_0                 ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_BWTR3_DATLAT_1                 ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_BWTR3_DATLAT_2                 ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_BWTR3_DATLAT_3                 ((uint32_t)0x08000000)        /*!<Bit 3 */

#define  FMC_BWTR3_ACCMOD                   ((uint32_t)0x30000000)        /*!<ACCMOD[1:0] bits (Access mode) */
#define  FMC_BWTR3_ACCMOD_0                 ((uint32_t)0x10000000)        /*!<Bit 0 */
#define  FMC_BWTR3_ACCMOD_1                 ((uint32_t)0x20000000)        /*!<Bit 1 */

/******************  Bit definition for FMC_BWTR4 register  ******************/
#define  FMC_BWTR4_ADDSET                   ((uint32_t)0x0000000F)        /*!<ADDSET[3:0] bits (Address setup phase duration) */
#define  FMC_BWTR4_ADDSET_0                 ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_BWTR4_ADDSET_1                 ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_BWTR4_ADDSET_2                 ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_BWTR4_ADDSET_3                 ((uint32_t)0x00000008)        /*!<Bit 3 */

#define  FMC_BWTR4_ADDHLD                   ((uint32_t)0x000000F0)        /*!<ADDHLD[3:0] bits (Address-hold phase duration) */
#define  FMC_BWTR4_ADDHLD_0                 ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_BWTR4_ADDHLD_1                 ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_BWTR4_ADDHLD_2                 ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_BWTR4_ADDHLD_3                 ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_BWTR4_DATAST                   ((uint32_t)0x0000FF00)        /*!<DATAST [3:0] bits (Data-phase duration) */
#define  FMC_BWTR4_DATAST_0                 ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_BWTR4_DATAST_1                 ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_BWTR4_DATAST_2                 ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_BWTR4_DATAST_3                 ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_BWTR4_DATAST_4                 ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_BWTR4_DATAST_5                 ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_BWTR4_DATAST_6                 ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_BWTR4_DATAST_7                 ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_BWTR4_CLKDIV                   ((uint32_t)0x00F00000)        /*!<CLKDIV[3:0] bits (Clock divide ratio) */
#define  FMC_BWTR4_CLKDIV_0                 ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_BWTR4_CLKDIV_1                 ((uint32_t)0x00200000)        /*!<Bit 1 */
#define  FMC_BWTR4_CLKDIV_2                 ((uint32_t)0x00400000)        /*!<Bit 2 */
#define  FMC_BWTR4_CLKDIV_3                 ((uint32_t)0x00800000)        /*!<Bit 3 */

#define  FMC_BWTR4_DATLAT                   ((uint32_t)0x0F000000)        /*!<DATLA[3:0] bits (Data latency) */
#define  FMC_BWTR4_DATLAT_0                 ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_BWTR4_DATLAT_1                 ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_BWTR4_DATLAT_2                 ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_BWTR4_DATLAT_3                 ((uint32_t)0x08000000)        /*!<Bit 3 */

#define  FMC_BWTR4_ACCMOD                   ((uint32_t)0x30000000)        /*!<ACCMOD[1:0] bits (Access mode) */
#define  FMC_BWTR4_ACCMOD_0                 ((uint32_t)0x10000000)        /*!<Bit 0 */
#define  FMC_BWTR4_ACCMOD_1                 ((uint32_t)0x20000000)        /*!<Bit 1 */

/******************  Bit definition for FMC_PCR register  *******************/
#define  FMC_PCR_PWAITEN                    ((uint32_t)0x00000002)        /*!<Wait feature enable bit                   */
#define  FMC_PCR_PBKEN                      ((uint32_t)0x00000004)        /*!<PC Card/NAND Flash memory bank enable bit */
#define  FMC_PCR_PTYP                       ((uint32_t)0x00000008)        /*!<Memory type                               */

#define  FMC_PCR_PWID                       ((uint32_t)0x00000030)        /*!<PWID[1:0] bits (NAND Flash databus width) */
#define  FMC_PCR_PWID_0                     ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_PCR_PWID_1                     ((uint32_t)0x00000020)        /*!<Bit 1 */

#define  FMC_PCR_ECCEN                      ((uint32_t)0x00000040)        /*!<ECC computation logic enable bit          */

#define  FMC_PCR_TCLR                       ((uint32_t)0x00001E00)        /*!<TCLR[3:0] bits (CLE to RE delay)          */
#define  FMC_PCR_TCLR_0                     ((uint32_t)0x00000200)        /*!<Bit 0 */
#define  FMC_PCR_TCLR_1                     ((uint32_t)0x00000400)        /*!<Bit 1 */
#define  FMC_PCR_TCLR_2                     ((uint32_t)0x00000800)        /*!<Bit 2 */
#define  FMC_PCR_TCLR_3                     ((uint32_t)0x00001000)        /*!<Bit 3 */

#define  FMC_PCR_TAR                        ((uint32_t)0x0001E000)        /*!<TAR[3:0] bits (ALE to RE delay)           */
#define  FMC_PCR_TAR_0                      ((uint32_t)0x00002000)        /*!<Bit 0 */
#define  FMC_PCR_TAR_1                      ((uint32_t)0x00004000)        /*!<Bit 1 */
#define  FMC_PCR_TAR_2                      ((uint32_t)0x00008000)        /*!<Bit 2 */
#define  FMC_PCR_TAR_3                      ((uint32_t)0x00010000)        /*!<Bit 3 */

#define  FMC_PCR_ECCPS                      ((uint32_t)0x000E0000)        /*!<ECCPS[1:0] bits (ECC page size)           */
#define  FMC_PCR_ECCPS_0                    ((uint32_t)0x00020000)        /*!<Bit 0 */
#define  FMC_PCR_ECCPS_1                    ((uint32_t)0x00040000)        /*!<Bit 1 */
#define  FMC_PCR_ECCPS_2                    ((uint32_t)0x00080000)        /*!<Bit 2 */

/*******************  Bit definition for FMC_SR register  *******************/
#define  FMC_SR_IRS                         ((uint8_t)0x01)               /*!<Interrupt Rising Edge status                */
#define  FMC_SR_ILS                         ((uint8_t)0x02)               /*!<Interrupt Level status                      */
#define  FMC_SR_IFS                         ((uint8_t)0x04)               /*!<Interrupt Falling Edge status               */
#define  FMC_SR_IREN                        ((uint8_t)0x08)               /*!<Interrupt Rising Edge detection Enable bit  */
#define  FMC_SR_ILEN                        ((uint8_t)0x10)               /*!<Interrupt Level detection Enable bit        */
#define  FMC_SR_IFEN                        ((uint8_t)0x20)               /*!<Interrupt Falling Edge detection Enable bit */
#define  FMC_SR_FEMPT                       ((uint8_t)0x40)               /*!<FIFO empty                                  */

/******************  Bit definition for FMC_PMEM register  ******************/
#define  FMC_PMEM_MEMSET3                   ((uint32_t)0x000000FF)        /*!<MEMSET2[7:0] bits (Common memory 2 setup time) */
#define  FMC_PMEM_MEMSET3_0                 ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_PMEM_MEMSET3_1                 ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_PMEM_MEMSET3_2                 ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_PMEM_MEMSET3_3                 ((uint32_t)0x00000008)        /*!<Bit 3 */
#define  FMC_PMEM_MEMSET3_4                 ((uint32_t)0x00000010)        /*!<Bit 4 */
#define  FMC_PMEM_MEMSET3_5                 ((uint32_t)0x00000020)        /*!<Bit 5 */
#define  FMC_PMEM_MEMSET3_6                 ((uint32_t)0x00000040)        /*!<Bit 6 */
#define  FMC_PMEM_MEMSET3_7                 ((uint32_t)0x00000080)        /*!<Bit 7 */

#define  FMC_PMEM_MEMWAIT3                  ((uint32_t)0x0000FF00)        /*!<MEMWAIT2[7:0] bits (Common memory 2 wait time) */
#define  FMC_PMEM_MEMWAIT3_0                ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_PMEM_MEMWAIT3_1                ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_PMEM_MEMWAIT3_2                ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_PMEM_MEMWAIT3_3                ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_PMEM_MEMWAIT3_4                ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_PMEM_MEMWAIT3_5                ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_PMEM_MEMWAIT3_6                ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_PMEM_MEMWAIT3_7                ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_PMEM_MEMHOLD3                  ((uint32_t)0x00FF0000)        /*!<MEMHOLD2[7:0] bits (Common memory 2 hold time) */
#define  FMC_PMEM_MEMHOLD3_0                ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_PMEM_MEMHOLD3_1                ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_PMEM_MEMHOLD3_2                ((uint32_t)0x00040000)        /*!<Bit 2 */
#define  FMC_PMEM_MEMHOLD3_3                ((uint32_t)0x00080000)        /*!<Bit 3 */
#define  FMC_PMEM_MEMHOLD3_4                ((uint32_t)0x00100000)        /*!<Bit 4 */
#define  FMC_PMEM_MEMHOLD3_5                ((uint32_t)0x00200000)        /*!<Bit 5 */
#define  FMC_PMEM_MEMHOLD3_6                ((uint32_t)0x00400000)        /*!<Bit 6 */
#define  FMC_PMEM_MEMHOLD3_7                ((uint32_t)0x00800000)        /*!<Bit 7 */

#define  FMC_PMEM_MEMHIZ3                   ((uint32_t)0xFF000000)        /*!<MEMHIZ2[7:0] bits (Common memory 2 databus HiZ time) */
#define  FMC_PMEM_MEMHIZ3_0                 ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_PMEM_MEMHIZ3_1                 ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_PMEM_MEMHIZ3_2                 ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_PMEM_MEMHIZ3_3                 ((uint32_t)0x08000000)        /*!<Bit 3 */
#define  FMC_PMEM_MEMHIZ3_4                 ((uint32_t)0x10000000)        /*!<Bit 4 */
#define  FMC_PMEM_MEMHIZ3_5                 ((uint32_t)0x20000000)        /*!<Bit 5 */
#define  FMC_PMEM_MEMHIZ3_6                 ((uint32_t)0x40000000)        /*!<Bit 6 */
#define  FMC_PMEM_MEMHIZ3_7                 ((uint32_t)0x80000000)        /*!<Bit 7 */

/******************  Bit definition for FMC_PATT register  ******************/
#define  FMC_PATT_ATTSET3                   ((uint32_t)0x000000FF)        /*!<ATTSET2[7:0] bits (Attribute memory 2 setup time) */
#define  FMC_PATT_ATTSET3_0                 ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_PATT_ATTSET3_1                 ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_PATT_ATTSET3_2                 ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_PATT_ATTSET3_3                 ((uint32_t)0x00000008)        /*!<Bit 3 */
#define  FMC_PATT_ATTSET3_4                 ((uint32_t)0x00000010)        /*!<Bit 4 */
#define  FMC_PATT_ATTSET3_5                 ((uint32_t)0x00000020)        /*!<Bit 5 */
#define  FMC_PATT_ATTSET3_6                 ((uint32_t)0x00000040)        /*!<Bit 6 */
#define  FMC_PATT_ATTSET3_7                 ((uint32_t)0x00000080)        /*!<Bit 7 */

#define  FMC_PATT_ATTWAIT3                  ((uint32_t)0x0000FF00)        /*!<ATTWAIT2[7:0] bits (Attribute memory 2 wait time) */
#define  FMC_PATT_ATTWAIT3_0                ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_PATT_ATTWAIT3_1                ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_PATT_ATTWAIT3_2                ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_PATT_ATTWAIT3_3                ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_PATT_ATTWAIT3_4                ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_PATT_ATTWAIT3_5                ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_PATT_ATTWAIT3_6                ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_PATT_ATTWAIT3_7                ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_PATT_ATTHOLD3                  ((uint32_t)0x00FF0000)        /*!<ATTHOLD2[7:0] bits (Attribute memory 2 hold time) */
#define  FMC_PATT_ATTHOLD3_0                ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_PATT_ATTHOLD3_1                ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_PATT_ATTHOLD3_2                ((uint32_t)0x00040000)        /*!<Bit 2 */
#define  FMC_PATT_ATTHOLD3_3                ((uint32_t)0x00080000)        /*!<Bit 3 */
#define  FMC_PATT_ATTHOLD3_4                ((uint32_t)0x00100000)        /*!<Bit 4 */
#define  FMC_PATT_ATTHOLD3_5                ((uint32_t)0x00200000)        /*!<Bit 5 */
#define  FMC_PATT_ATTHOLD3_6                ((uint32_t)0x00400000)        /*!<Bit 6 */
#define  FMC_PATT_ATTHOLD3_7                ((uint32_t)0x00800000)        /*!<Bit 7 */

#define  FMC_PATT_ATTHIZ3                   ((uint32_t)0xFF000000)        /*!<ATTHIZ2[7:0] bits (Attribute memory 2 databus HiZ time) */
#define  FMC_PATT_ATTHIZ3_0                 ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_PATT_ATTHIZ3_1                 ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_PATT_ATTHIZ3_2                 ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_PATT_ATTHIZ3_3                 ((uint32_t)0x08000000)        /*!<Bit 3 */
#define  FMC_PATT_ATTHIZ3_4                 ((uint32_t)0x10000000)        /*!<Bit 4 */
#define  FMC_PATT_ATTHIZ3_5                 ((uint32_t)0x20000000)        /*!<Bit 5 */
#define  FMC_PATT_ATTHIZ3_6                 ((uint32_t)0x40000000)        /*!<Bit 6 */
#define  FMC_PATT_ATTHIZ3_7                 ((uint32_t)0x80000000)        /*!<Bit 7 */Z

/******************  Bit definition for FMC_PIO4 register  *******************/
#define  FMC_PIO4_IOSET4                    ((uint32_t)0x000000FF)        /*!<IOSET4[7:0] bits (I/O 4 setup time) */
#define  FMC_PIO4_IOSET4_0                  ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_PIO4_IOSET4_1                  ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_PIO4_IOSET4_2                  ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_PIO4_IOSET4_3                  ((uint32_t)0x00000008)        /*!<Bit 3 */
#define  FMC_PIO4_IOSET4_4                  ((uint32_t)0x00000010)        /*!<Bit 4 */
#define  FMC_PIO4_IOSET4_5                  ((uint32_t)0x00000020)        /*!<Bit 5 */
#define  FMC_PIO4_IOSET4_6                  ((uint32_t)0x00000040)        /*!<Bit 6 */
#define  FMC_PIO4_IOSET4_7                  ((uint32_t)0x00000080)        /*!<Bit 7 */

#define  FMC_PIO4_IOWAIT4                   ((uint32_t)0x0000FF00)        /*!<IOWAIT4[7:0] bits (I/O 4 wait time) */
#define  FMC_PIO4_IOWAIT4_0                 ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_PIO4_IOWAIT4_1                 ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_PIO4_IOWAIT4_2                 ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_PIO4_IOWAIT4_3                 ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  FMC_PIO4_IOWAIT4_4                 ((uint32_t)0x00001000)        /*!<Bit 4 */
#define  FMC_PIO4_IOWAIT4_5                 ((uint32_t)0x00002000)        /*!<Bit 5 */
#define  FMC_PIO4_IOWAIT4_6                 ((uint32_t)0x00004000)        /*!<Bit 6 */
#define  FMC_PIO4_IOWAIT4_7                 ((uint32_t)0x00008000)        /*!<Bit 7 */

#define  FMC_PIO4_IOHOLD4                   ((uint32_t)0x00FF0000)        /*!<IOHOLD4[7:0] bits (I/O 4 hold time) */
#define  FMC_PIO4_IOHOLD4_0                 ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_PIO4_IOHOLD4_1                 ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_PIO4_IOHOLD4_2                 ((uint32_t)0x00040000)        /*!<Bit 2 */
#define  FMC_PIO4_IOHOLD4_3                 ((uint32_t)0x00080000)        /*!<Bit 3 */
#define  FMC_PIO4_IOHOLD4_4                 ((uint32_t)0x00100000)        /*!<Bit 4 */
#define  FMC_PIO4_IOHOLD4_5                 ((uint32_t)0x00200000)        /*!<Bit 5 */
#define  FMC_PIO4_IOHOLD4_6                 ((uint32_t)0x00400000)        /*!<Bit 6 */
#define  FMC_PIO4_IOHOLD4_7                 ((uint32_t)0x00800000)        /*!<Bit 7 */

#define  FMC_PIO4_IOHIZ4                    ((uint32_t)0xFF000000)        /*!<IOHIZ4[7:0] bits (I/O 4 databus HiZ time) */
#define  FMC_PIO4_IOHIZ4_0                  ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_PIO4_IOHIZ4_1                  ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_PIO4_IOHIZ4_2                  ((uint32_t)0x04000000)        /*!<Bit 2 */
#define  FMC_PIO4_IOHIZ4_3                  ((uint32_t)0x08000000)        /*!<Bit 3 */
#define  FMC_PIO4_IOHIZ4_4                  ((uint32_t)0x10000000)        /*!<Bit 4 */
#define  FMC_PIO4_IOHIZ4_5                  ((uint32_t)0x20000000)        /*!<Bit 5 */
#define  FMC_PIO4_IOHIZ4_6                  ((uint32_t)0x40000000)        /*!<Bit 6 */
#define  FMC_PIO4_IOHIZ4_7                  ((uint32_t)0x80000000)        /*!<Bit 7 */

/******************  Bit definition for FMC_ECCR2 register  ******************/
#define  FMC_ECCR2_ECC2                     ((uint32_t)0xFFFFFFFF)        /*!<ECC result */

/******************  Bit definition for FMC_ECCR3 register  ******************/
#define  FMC_ECCR3_ECC3                     ((uint32_t)0xFFFFFFFF)        /*!<ECC result */

/******************  Bit definition for FMC_SDCR1 register  ******************/
#define  FMC_SDCR1_NC                       ((uint32_t)0x00000003)        /*!<NC[1:0] bits (Number of column bits) */
#define  FMC_SDCR1_NC_0                     ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_SDCR1_NC_1                     ((uint32_t)0x00000002)        /*!<Bit 1 */

#define  FMC_SDCR1_NR                       ((uint32_t)0x0000000C)        /*!<NR[1:0] bits (Number of row bits) */
#define  FMC_SDCR1_NR_0                     ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  FMC_SDCR1_NR_1                     ((uint32_t)0x00000008)        /*!<Bit 1 */

#define  FMC_SDCR1_MWID                     ((uint32_t)0x00000030)        /*!<NR[1:0] bits (Number of row bits) */
#define  FMC_SDCR1_MWID_0                   ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_SDCR1_MWID_1                   ((uint32_t)0x00000020)        /*!<Bit 1 */

#define  FMC_SDCR1_NB                       ((uint32_t)0x00000040)        /*!<Number of internal bank */

#define  FMC_SDCR1_CAS                      ((uint32_t)0x00000180)        /*!<CAS[1:0] bits (CAS latency) */
#define  FMC_SDCR1_CAS_0                    ((uint32_t)0x00000080)        /*!<Bit 0 */
#define  FMC_SDCR1_CAS_1                    ((uint32_t)0x00000100)        /*!<Bit 1 */

#define  FMC_SDCR1_WP                       ((uint32_t)0x00000200)        /*!<Write protection */

#define  FMC_SDCR1_SDCLK                    ((uint32_t)0x00000C00)        /*!<SDRAM clock configuration */
#define  FMC_SDCR1_SDCLK_0                  ((uint32_t)0x00000400)        /*!<Bit 0 */
#define  FMC_SDCR1_SDCLK_1                  ((uint32_t)0x00000800)        /*!<Bit 1 */

#define  FMC_SDCR1_RBURST                   ((uint32_t)0x00001000)        /*!<Read burst */

#define  FMC_SDCR1_RPIPE                    ((uint32_t)0x00006000)        /*!<Write protection */
#define  FMC_SDCR1_RPIPE_0                  ((uint32_t)0x00002000)        /*!<Bit 0 */
#define  FMC_SDCR1_RPIPE_1                  ((uint32_t)0x00004000)        /*!<Bit 1 */

/******************  Bit definition for FMC_SDCR2 register  ******************/
#define  FMC_SDCR2_NC                       ((uint32_t)0x00000003)        /*!<NC[1:0] bits (Number of column bits) */
#define  FMC_SDCR2_NC_0                     ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_SDCR2_NC_1                     ((uint32_t)0x00000002)        /*!<Bit 1 */

#define  FMC_SDCR2_NR                       ((uint32_t)0x0000000C)        /*!<NR[1:0] bits (Number of row bits) */
#define  FMC_SDCR2_NR_0                     ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  FMC_SDCR2_NR_1                     ((uint32_t)0x00000008)        /*!<Bit 1 */

#define  FMC_SDCR2_MWID                     ((uint32_t)0x00000030)        /*!<NR[1:0] bits (Number of row bits) */
#define  FMC_SDCR2_MWID_0                   ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_SDCR2_MWID_1                   ((uint32_t)0x00000020)        /*!<Bit 1 */

#define  FMC_SDCR2_NB                       ((uint32_t)0x00000040)        /*!<Number of internal bank */

#define  FMC_SDCR2_CAS                      ((uint32_t)0x00000180)        /*!<CAS[1:0] bits (CAS latency) */
#define  FMC_SDCR2_CAS_0                    ((uint32_t)0x00000080)        /*!<Bit 0 */
#define  FMC_SDCR2_CAS_1                    ((uint32_t)0x00000100)        /*!<Bit 1 */

#define  FMC_SDCR2_WP                       ((uint32_t)0x00000200)        /*!<Write protection */

#define  FMC_SDCR2_SDCLK                    ((uint32_t)0x00000C00)        /*!<SDCLK[1:0] (SDRAM clock configuration) */
#define  FMC_SDCR2_SDCLK_0                  ((uint32_t)0x00000400)        /*!<Bit 0 */
#define  FMC_SDCR2_SDCLK_1                  ((uint32_t)0x00000800)        /*!<Bit 1 */

#define  FMC_SDCR2_RBURST                   ((uint32_t)0x00001000)        /*!<Read burst */

#define  FMC_SDCR2_RPIPE                    ((uint32_t)0x00006000)        /*!<RPIPE[1:0](Read pipe) */
#define  FMC_SDCR2_RPIPE_0                  ((uint32_t)0x00002000)        /*!<Bit 0 */
#define  FMC_SDCR2_RPIPE_1                  ((uint32_t)0x00004000)        /*!<Bit 1 */

/******************  Bit definition for FMC_SDTR1 register  ******************/
#define  FMC_SDTR1_TMRD                     ((uint32_t)0x0000000F)        /*!<TMRD[3:0] bits (Load mode register to active) */
#define  FMC_SDTR1_TMRD_0                   ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_SDTR1_TMRD_1                   ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_SDTR1_TMRD_2                   ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_SDTR1_TMRD_3                   ((uint32_t)0x00000008)        /*!<Bit 3 */
                                            
#define  FMC_SDTR1_TXSR                     ((uint32_t)0x000000F0)        /*!<TXSR[3:0] bits (Exit self refresh) */
#define  FMC_SDTR1_TXSR_0                   ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_SDTR1_TXSR_1                   ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_SDTR1_TXSR_2                   ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_SDTR1_TXSR_3                   ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_SDTR1_TRAS                     ((uint32_t)0x00000F00)        /*!<TRAS[3:0] bits (Self refresh time) */
#define  FMC_SDTR1_TRAS_0                   ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_SDTR1_TRAS_1                   ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_SDTR1_TRAS_2                   ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_SDTR1_TRAS_3                   ((uint32_t)0x00000800)        /*!<Bit 3 */

#define  FMC_SDTR1_TRC                      ((uint32_t)0x0000F000)        /*!<TRC[2:0] bits (Row cycle delay) */
#define  FMC_SDTR1_TRC_0                    ((uint32_t)0x00001000)        /*!<Bit 0 */
#define  FMC_SDTR1_TRC_1                    ((uint32_t)0x00002000)        /*!<Bit 1 */
#define  FMC_SDTR1_TRC_2                    ((uint32_t)0x00004000)        /*!<Bit 2 */

#define  FMC_SDTR1_TWR                      ((uint32_t)0x000F0000)        /*!<TRC[2:0] bits (Write recovery delay) */
#define  FMC_SDTR1_TWR_0                    ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_SDTR1_TWR_1                    ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_SDTR1_TWR_2                    ((uint32_t)0x00040000)        /*!<Bit 2 */

#define  FMC_SDTR1_TRP                      ((uint32_t)0x00F00000)        /*!<TRP[2:0] bits (Row precharge delay) */
#define  FMC_SDTR1_TRP_0                    ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_SDTR1_TRP_1                    ((uint32_t)0x00200000)        /*!<Bit 1 */
#define  FMC_SDTR1_TRP_2                    ((uint32_t)0x00400000)        /*!<Bit 2 */

#define  FMC_SDTR1_TRCD                     ((uint32_t)0x0F000000)        /*!<TRP[2:0] bits (Row to column delay) */
#define  FMC_SDTR1_TRCD_0                   ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_SDTR1_TRCD_1                   ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_SDTR1_TRCD_2                   ((uint32_t)0x04000000)        /*!<Bit 2 */

/******************  Bit definition for FMC_SDTR2 register  ******************/
#define  FMC_SDTR2_TMRD                     ((uint32_t)0x0000000F)        /*!<TMRD[3:0] bits (Load mode register to active) */
#define  FMC_SDTR2_TMRD_0                   ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_SDTR2_TMRD_1                   ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_SDTR2_TMRD_2                   ((uint32_t)0x00000004)        /*!<Bit 2 */
#define  FMC_SDTR2_TMRD_3                   ((uint32_t)0x00000008)        /*!<Bit 3 */
                                            
#define  FMC_SDTR2_TXSR                     ((uint32_t)0x000000F0)        /*!<TXSR[3:0] bits (Exit self refresh) */
#define  FMC_SDTR2_TXSR_0                   ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  FMC_SDTR2_TXSR_1                   ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  FMC_SDTR2_TXSR_2                   ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  FMC_SDTR2_TXSR_3                   ((uint32_t)0x00000080)        /*!<Bit 3 */

#define  FMC_SDTR2_TRAS                     ((uint32_t)0x00000F00)        /*!<TRAS[3:0] bits (Self refresh time) */
#define  FMC_SDTR2_TRAS_0                   ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  FMC_SDTR2_TRAS_1                   ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  FMC_SDTR2_TRAS_2                   ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  FMC_SDTR2_TRAS_3                   ((uint32_t)0x00000800)        /*!<Bit 3 */

#define  FMC_SDTR2_TRC                      ((uint32_t)0x0000F000)        /*!<TRC[2:0] bits (Row cycle delay) */
#define  FMC_SDTR2_TRC_0                    ((uint32_t)0x00001000)        /*!<Bit 0 */
#define  FMC_SDTR2_TRC_1                    ((uint32_t)0x00002000)        /*!<Bit 1 */
#define  FMC_SDTR2_TRC_2                    ((uint32_t)0x00004000)        /*!<Bit 2 */

#define  FMC_SDTR2_TWR                      ((uint32_t)0x000F0000)        /*!<TRC[2:0] bits (Write recovery delay) */
#define  FMC_SDTR2_TWR_0                    ((uint32_t)0x00010000)        /*!<Bit 0 */
#define  FMC_SDTR2_TWR_1                    ((uint32_t)0x00020000)        /*!<Bit 1 */
#define  FMC_SDTR2_TWR_2                    ((uint32_t)0x00040000)        /*!<Bit 2 */

#define  FMC_SDTR2_TRP                      ((uint32_t)0x00F00000)        /*!<TRP[2:0] bits (Row precharge delay) */
#define  FMC_SDTR2_TRP_0                    ((uint32_t)0x00100000)        /*!<Bit 0 */
#define  FMC_SDTR2_TRP_1                    ((uint32_t)0x00200000)        /*!<Bit 1 */
#define  FMC_SDTR2_TRP_2                    ((uint32_t)0x00400000)        /*!<Bit 2 */

#define  FMC_SDTR2_TRCD                     ((uint32_t)0x0F000000)        /*!<TRP[2:0] bits (Row to column delay) */
#define  FMC_SDTR2_TRCD_0                   ((uint32_t)0x01000000)        /*!<Bit 0 */
#define  FMC_SDTR2_TRCD_1                   ((uint32_t)0x02000000)        /*!<Bit 1 */
#define  FMC_SDTR2_TRCD_2                   ((uint32_t)0x04000000)        /*!<Bit 2 */

/******************  Bit definition for FMC_SDCMR register  ******************/
#define  FMC_SDCMR_MODE                     ((uint32_t)0x00000007)        /*!<MODE[2:0] bits (Command mode) */
#define  FMC_SDCMR_MODE_0                   ((uint32_t)0x00000001)        /*!<Bit 0 */
#define  FMC_SDCMR_MODE_1                   ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  FMC_SDCMR_MODE_2                   ((uint32_t)0x00000003)        /*!<Bit 2 */
                                            
#define  FMC_SDCMR_CTB2                     ((uint32_t)0x00000008)        /*!<Command target 2 */

#define  FMC_SDCMR_CTB1                     ((uint32_t)0x00000010)        /*!<Command target 1 */

#define  FMC_SDCMR_NRFS                     ((uint32_t)0x000001E0)        /*!<NRFS[3:0] bits (Number of auto-refresh) */
#define  FMC_SDCMR_NRFS_0                   ((uint32_t)0x00000020)        /*!<Bit 0 */
#define  FMC_SDCMR_NRFS_1                   ((uint32_t)0x00000040)        /*!<Bit 1 */
#define  FMC_SDCMR_NRFS_2                   ((uint32_t)0x00000080)        /*!<Bit 2 */
#define  FMC_SDCMR_NRFS_3                   ((uint32_t)0x00000100)        /*!<Bit 3 */

#define  FMC_SDCMR_MRD                      ((uint32_t)0x003FFE00)        /*!<MRD[12:0] bits (Mode register definition) */

/******************  Bit definition for FMC_SDRTR register  ******************/
#define  FMC_SDRTR_CRE                      ((uint32_t)0x00000001)        /*!<Clear refresh error flag */

#define  FMC_SDRTR_COUNT                    ((uint32_t)0x00003FFE)        /*!<COUNT[12:0] bits (Refresh timer count) */

#define  FMC_SDRTR_REIE                     ((uint32_t)0x00004000)        /*!<RES interupt enable */

/******************  Bit definition for FMC_SDSR register  ******************/
#define  FMC_SDSR_RE                        ((uint32_t)0x00000001)        /*!<Refresh error flag */

#define  FMC_SDSR_MODES1                    ((uint32_t)0x00000006)        /*!<MODES1[1:0]bits (Status mode for bank 1) */
#define  FMC_SDSR_MODES1_0                  ((uint32_t)0x00000002)        /*!<Bit 0 */
#define  FMC_SDSR_MODES1_1                  ((uint32_t)0x00000004)        /*!<Bit 1 */

#define  FMC_SDSR_MODES2                    ((uint32_t)0x00000018)        /*!<MODES2[1:0]bits (Status mode for bank 2) */
#define  FMC_SDSR_MODES2_0                  ((uint32_t)0x00000008)        /*!<Bit 0 */
#define  FMC_SDSR_MODES2_1                  ((uint32_t)0x00000010)        /*!<Bit 1 */

#define  FMC_SDSR_BUSY                      ((uint32_t)0x00000020)        /*!<Busy status */

/******************************************************************************/
/*                                                                            */
/*                            General Purpose I/O                             */
/*                                                                            */
/******************************************************************************/
/******************  Bits definition for GPIO_MODER register  *****************/
#define GPIO_MODER_MODER0                    ((uint32_t)0x00000003)
#define GPIO_MODER_MODER0_0                  ((uint32_t)0x00000001)
#define GPIO_MODER_MODER0_1                  ((uint32_t)0x00000002)

#define GPIO_MODER_MODER1                    ((uint32_t)0x0000000C)
#define GPIO_MODER_MODER1_0                  ((uint32_t)0x00000004)
#define GPIO_MODER_MODER1_1                  ((uint32_t)0x00000008)

#define GPIO_MODER_MODER2                    ((uint32_t)0x00000030)
#define GPIO_MODER_MODER2_0                  ((uint32_t)0x00000010)
#define GPIO_MODER_MODER2_1                  ((uint32_t)0x00000020)

#define GPIO_MODER_MODER3                    ((uint32_t)0x000000C0)
#define GPIO_MODER_MODER3_0                  ((uint32_t)0x00000040)
#define GPIO_MODER_MODER3_1                  ((uint32_t)0x00000080)

#define GPIO_MODER_MODER4                    ((uint32_t)0x00000300)
#define GPIO_MODER_MODER4_0                  ((uint32_t)0x00000100)
#define GPIO_MODER_MODER4_1                  ((uint32_t)0x00000200)

#define GPIO_MODER_MODER5                    ((uint32_t)0x00000C00)
#define GPIO_MODER_MODER5_0                  ((uint32_t)0x00000400)
#define GPIO_MODER_MODER5_1                  ((uint32_t)0x00000800)

#define GPIO_MODER_MODER6                    ((uint32_t)0x00003000)
#define GPIO_MODER_MODER6_0                  ((uint32_t)0x00001000)
#define GPIO_MODER_MODER6_1                  ((uint32_t)0x00002000)

#define GPIO_MODER_MODER7                    ((uint32_t)0x0000C000)
#define GPIO_MODER_MODER7_0                  ((uint32_t)0x00004000)
#define GPIO_MODER_MODER7_1                  ((uint32_t)0x00008000)

#define GPIO_MODER_MODER8                    ((uint32_t)0x00030000)
#define GPIO_MODER_MODER8_0                  ((uint32_t)0x00010000)
#define GPIO_MODER_MODER8_1                  ((uint32_t)0x00020000)

#define GPIO_MODER_MODER9                    ((uint32_t)0x000C0000)
#define GPIO_MODER_MODER9_0                  ((uint32_t)0x00040000)
#define GPIO_MODER_MODER9_1                  ((uint32_t)0x00080000)

#define GPIO_MODER_MODER10                   ((uint32_t)0x00300000)
#define GPIO_MODER_MODER10_0                 ((uint32_t)0x00100000)
#define GPIO_MODER_MODER10_1                 ((uint32_t)0x00200000)

#define GPIO_MODER_MODER11                   ((uint32_t)0x00C00000)
#define GPIO_MODER_MODER11_0                 ((uint32_t)0x00400000)
#define GPIO_MODER_MODER11_1                 ((uint32_t)0x00800000)

#define GPIO_MODER_MODER12                   ((uint32_t)0x03000000)
#define GPIO_MODER_MODER12_0                 ((uint32_t)0x01000000)
#define GPIO_MODER_MODER12_1                 ((uint32_t)0x02000000)

#define GPIO_MODER_MODER13                   ((uint32_t)0x0C000000)
#define GPIO_MODER_MODER13_0                 ((uint32_t)0x04000000)
#define GPIO_MODER_MODER13_1                 ((uint32_t)0x08000000)

#define GPIO_MODER_MODER14                   ((uint32_t)0x30000000)
#define GPIO_MODER_MODER14_0                 ((uint32_t)0x10000000)
#define GPIO_MODER_MODER14_1                 ((uint32_t)0x20000000)

#define GPIO_MODER_MODER15                   ((uint32_t)0xC0000000)
#define GPIO_MODER_MODER15_0                 ((uint32_t)0x40000000)
#define GPIO_MODER_MODER15_1                 ((uint32_t)0x80000000)

/******************  Bits definition for GPIO_OTYPER register  ****************/
#define GPIO_OTYPER_OT_0                     ((uint32_t)0x00000001)
#define GPIO_OTYPER_OT_1                     ((uint32_t)0x00000002)
#define GPIO_OTYPER_OT_2                     ((uint32_t)0x00000004)
#define GPIO_OTYPER_OT_3                     ((uint32_t)0x00000008)
#define GPIO_OTYPER_OT_4                     ((uint32_t)0x00000010)
#define GPIO_OTYPER_OT_5                     ((uint32_t)0x00000020)
#define GPIO_OTYPER_OT_6                     ((uint32_t)0x00000040)
#define GPIO_OTYPER_OT_7                     ((uint32_t)0x00000080)
#define GPIO_OTYPER_OT_8                     ((uint32_t)0x00000100)
#define GPIO_OTYPER_OT_9                     ((uint32_t)0x00000200)
#define GPIO_OTYPER_OT_10                    ((uint32_t)0x00000400)
#define GPIO_OTYPER_OT_11                    ((uint32_t)0x00000800)
#define GPIO_OTYPER_OT_12                    ((uint32_t)0x00001000)
#define GPIO_OTYPER_OT_13                    ((uint32_t)0x00002000)
#define GPIO_OTYPER_OT_14                    ((uint32_t)0x00004000)
#define GPIO_OTYPER_OT_15                    ((uint32_t)0x00008000)

/******************  Bits definition for GPIO_OSPEEDR register  ***************/
#define GPIO_OSPEEDER_OSPEEDR0               ((uint32_t)0x00000003)
#define GPIO_OSPEEDER_OSPEEDR0_0             ((uint32_t)0x00000001)
#define GPIO_OSPEEDER_OSPEEDR0_1             ((uint32_t)0x00000002)

#define GPIO_OSPEEDER_OSPEEDR1               ((uint32_t)0x0000000C)
#define GPIO_OSPEEDER_OSPEEDR1_0             ((uint32_t)0x00000004)
#define GPIO_OSPEEDER_OSPEEDR1_1             ((uint32_t)0x00000008)

#define GPIO_OSPEEDER_OSPEEDR2               ((uint32_t)0x00000030)
#define GPIO_OSPEEDER_OSPEEDR2_0             ((uint32_t)0x00000010)
#define GPIO_OSPEEDER_OSPEEDR2_1             ((uint32_t)0x00000020)

#define GPIO_OSPEEDER_OSPEEDR3               ((uint32_t)0x000000C0)
#define GPIO_OSPEEDER_OSPEEDR3_0             ((uint32_t)0x00000040)
#define GPIO_OSPEEDER_OSPEEDR3_1             ((uint32_t)0x00000080)

#define GPIO_OSPEEDER_OSPEEDR4               ((uint32_t)0x00000300)
#define GPIO_OSPEEDER_OSPEEDR4_0             ((uint32_t)0x00000100)
#define GPIO_OSPEEDER_OSPEEDR4_1             ((uint32_t)0x00000200)

#define GPIO_OSPEEDER_OSPEEDR5               ((uint32_t)0x00000C00)
#define GPIO_OSPEEDER_OSPEEDR5_0             ((uint32_t)0x00000400)
#define GPIO_OSPEEDER_OSPEEDR5_1             ((uint32_t)0x00000800)

#define GPIO_OSPEEDER_OSPEEDR6               ((uint32_t)0x00003000)
#define GPIO_OSPEEDER_OSPEEDR6_0             ((uint32_t)0x00001000)
#define GPIO_OSPEEDER_OSPEEDR6_1             ((uint32_t)0x00002000)

#define GPIO_OSPEEDER_OSPEEDR7               ((uint32_t)0x0000C000)
#define GPIO_OSPEEDER_OSPEEDR7_0             ((uint32_t)0x00004000)
#define GPIO_OSPEEDER_OSPEEDR7_1             ((uint32_t)0x00008000)

#define GPIO_OSPEEDER_OSPEEDR8               ((uint32_t)0x00030000)
#define GPIO_OSPEEDER_OSPEEDR8_0             ((uint32_t)0x00010000)
#define GPIO_OSPEEDER_OSPEEDR8_1             ((uint32_t)0x00020000)

#define GPIO_OSPEEDER_OSPEEDR9               ((uint32_t)0x000C0000)
#define GPIO_OSPEEDER_OSPEEDR9_0             ((uint32_t)0x00040000)
#define GPIO_OSPEEDER_OSPEEDR9_1             ((uint32_t)0x00080000)

#define GPIO_OSPEEDER_OSPEEDR10              ((uint32_t)0x00300000)
#define GPIO_OSPEEDER_OSPEEDR10_0            ((uint32_t)0x00100000)
#define GPIO_OSPEEDER_OSPEEDR10_1            ((uint32_t)0x00200000)

#define GPIO_OSPEEDER_OSPEEDR11              ((uint32_t)0x00C00000)
#define GPIO_OSPEEDER_OSPEEDR11_0            ((uint32_t)0x00400000)
#define GPIO_OSPEEDER_OSPEEDR11_1            ((uint32_t)0x00800000)

#define GPIO_OSPEEDER_OSPEEDR12              ((uint32_t)0x03000000)
#define GPIO_OSPEEDER_OSPEEDR12_0            ((uint32_t)0x01000000)
#define GPIO_OSPEEDER_OSPEEDR12_1            ((uint32_t)0x02000000)

#define GPIO_OSPEEDER_OSPEEDR13              ((uint32_t)0x0C000000)
#define GPIO_OSPEEDER_OSPEEDR13_0            ((uint32_t)0x04000000)
#define GPIO_OSPEEDER_OSPEEDR13_1            ((uint32_t)0x08000000)

#define GPIO_OSPEEDER_OSPEEDR14              ((uint32_t)0x30000000)
#define GPIO_OSPEEDER_OSPEEDR14_0            ((uint32_t)0x10000000)
#define GPIO_OSPEEDER_OSPEEDR14_1            ((uint32_t)0x20000000)

#define GPIO_OSPEEDER_OSPEEDR15              ((uint32_t)0xC0000000)
#define GPIO_OSPEEDER_OSPEEDR15_0            ((uint32_t)0x40000000)
#define GPIO_OSPEEDER_OSPEEDR15_1            ((uint32_t)0x80000000)

/******************  Bits definition for GPIO_PUPDR register  *****************/
#define GPIO_PUPDR_PUPDR0                    ((uint32_t)0x00000003)
#define GPIO_PUPDR_PUPDR0_0                  ((uint32_t)0x00000001)
#define GPIO_PUPDR_PUPDR0_1                  ((uint32_t)0x00000002)

#define GPIO_PUPDR_PUPDR1                    ((uint32_t)0x0000000C)
#define GPIO_PUPDR_PUPDR1_0                  ((uint32_t)0x00000004)
#define GPIO_PUPDR_PUPDR1_1                  ((uint32_t)0x00000008)

#define GPIO_PUPDR_PUPDR2                    ((uint32_t)0x00000030)
#define GPIO_PUPDR_PUPDR2_0                  ((uint32_t)0x00000010)
#define GPIO_PUPDR_PUPDR2_1                  ((uint32_t)0x00000020)

#define GPIO_PUPDR_PUPDR3                    ((uint32_t)0x000000C0)
#define GPIO_PUPDR_PUPDR3_0                  ((uint32_t)0x00000040)
#define GPIO_PUPDR_PUPDR3_1                  ((uint32_t)0x00000080)

#define GPIO_PUPDR_PUPDR4                    ((uint32_t)0x00000300)
#define GPIO_PUPDR_PUPDR4_0                  ((uint32_t)0x00000100)
#define GPIO_PUPDR_PUPDR4_1                  ((uint32_t)0x00000200)

#define GPIO_PUPDR_PUPDR5                    ((uint32_t)0x00000C00)
#define GPIO_PUPDR_PUPDR5_0                  ((uint32_t)0x00000400)
#define GPIO_PUPDR_PUPDR5_1                  ((uint32_t)0x00000800)

#define GPIO_PUPDR_PUPDR6                    ((uint32_t)0x00003000)
#define GPIO_PUPDR_PUPDR6_0                  ((uint32_t)0x00001000)
#define GPIO_PUPDR_PUPDR6_1                  ((uint32_t)0x00002000)

#define GPIO_PUPDR_PUPDR7                    ((uint32_t)0x0000C000)
#define GPIO_PUPDR_PUPDR7_0                  ((uint32_t)0x00004000)
#define GPIO_PUPDR_PUPDR7_1                  ((uint32_t)0x00008000)

#define GPIO_PUPDR_PUPDR8                    ((uint32_t)0x00030000)
#define GPIO_PUPDR_PUPDR8_0                  ((uint32_t)0x00010000)
#define GPIO_PUPDR_PUPDR8_1                  ((uint32_t)0x00020000)

#define GPIO_PUPDR_PUPDR9                    ((uint32_t)0x000C0000)
#define GPIO_PUPDR_PUPDR9_0                  ((uint32_t)0x00040000)
#define GPIO_PUPDR_PUPDR9_1                  ((uint32_t)0x00080000)

#define GPIO_PUPDR_PUPDR10                   ((uint32_t)0x00300000)
#define GPIO_PUPDR_PUPDR10_0                 ((uint32_t)0x00100000)
#define GPIO_PUPDR_PUPDR10_1                 ((uint32_t)0x00200000)

#define GPIO_PUPDR_PUPDR11                   ((uint32_t)0x00C00000)
#define GPIO_PUPDR_PUPDR11_0                 ((uint32_t)0x00400000)
#define GPIO_PUPDR_PUPDR11_1                 ((uint32_t)0x00800000)

#define GPIO_PUPDR_PUPDR12                   ((uint32_t)0x03000000)
#define GPIO_PUPDR_PUPDR12_0                 ((uint32_t)0x01000000)
#define GPIO_PUPDR_PUPDR12_1                 ((uint32_t)0x02000000)

#define GPIO_PUPDR_PUPDR13                   ((uint32_t)0x0C000000)
#define GPIO_PUPDR_PUPDR13_0                 ((uint32_t)0x04000000)
#define GPIO_PUPDR_PUPDR13_1                 ((uint32_t)0x08000000)

#define GPIO_PUPDR_PUPDR14                   ((uint32_t)0x30000000)
#define GPIO_PUPDR_PUPDR14_0                 ((uint32_t)0x10000000)
#define GPIO_PUPDR_PUPDR14_1                 ((uint32_t)0x20000000)

#define GPIO_PUPDR_PUPDR15                   ((uint32_t)0xC0000000)
#define GPIO_PUPDR_PUPDR15_0                 ((uint32_t)0x40000000)
#define GPIO_PUPDR_PUPDR15_1                 ((uint32_t)0x80000000)

/******************  Bits definition for GPIO_IDR register  *******************/
#define GPIO_IDR_IDR_0                       ((uint32_t)0x00000001)
#define GPIO_IDR_IDR_1                       ((uint32_t)0x00000002)
#define GPIO_IDR_IDR_2                       ((uint32_t)0x00000004)
#define GPIO_IDR_IDR_3                       ((uint32_t)0x00000008)
#define GPIO_IDR_IDR_4                       ((uint32_t)0x00000010)
#define GPIO_IDR_IDR_5                       ((uint32_t)0x00000020)
#define GPIO_IDR_IDR_6                       ((uint32_t)0x00000040)
#define GPIO_IDR_IDR_7                       ((uint32_t)0x00000080)
#define GPIO_IDR_IDR_8                       ((uint32_t)0x00000100)
#define GPIO_IDR_IDR_9                       ((uint32_t)0x00000200)
#define GPIO_IDR_IDR_10                      ((uint32_t)0x00000400)
#define GPIO_IDR_IDR_11                      ((uint32_t)0x00000800)
#define GPIO_IDR_IDR_12                      ((uint32_t)0x00001000)
#define GPIO_IDR_IDR_13                      ((uint32_t)0x00002000)
#define GPIO_IDR_IDR_14                      ((uint32_t)0x00004000)
#define GPIO_IDR_IDR_15                      ((uint32_t)0x00008000)
/* Old GPIO_IDR register bits definition, maintained for legacy purpose */
#define GPIO_OTYPER_IDR_0                    GPIO_IDR_IDR_0
#define GPIO_OTYPER_IDR_1                    GPIO_IDR_IDR_1
#define GPIO_OTYPER_IDR_2                    GPIO_IDR_IDR_2
#define GPIO_OTYPER_IDR_3                    GPIO_IDR_IDR_3
#define GPIO_OTYPER_IDR_4                    GPIO_IDR_IDR_4
#define GPIO_OTYPER_IDR_5                    GPIO_IDR_IDR_5
#define GPIO_OTYPER_IDR_6                    GPIO_IDR_IDR_6
#define GPIO_OTYPER_IDR_7                    GPIO_IDR_IDR_7
#define GPIO_OTYPER_IDR_8                    GPIO_IDR_IDR_8
#define GPIO_OTYPER_IDR_9                    GPIO_IDR_IDR_9
#define GPIO_OTYPER_IDR_10                   GPIO_IDR_IDR_10
#define GPIO_OTYPER_IDR_11                   GPIO_IDR_IDR_11
#define GPIO_OTYPER_IDR_12                   GPIO_IDR_IDR_12
#define GPIO_OTYPER_IDR_13                   GPIO_IDR_IDR_13
#define GPIO_OTYPER_IDR_14                   GPIO_IDR_IDR_14
#define GPIO_OTYPER_IDR_15                   GPIO_IDR_IDR_15

/******************  Bits definition for GPIO_ODR register  *******************/
#define GPIO_ODR_ODR_0                       ((uint32_t)0x00000001)
#define GPIO_ODR_ODR_1                       ((uint32_t)0x00000002)
#define GPIO_ODR_ODR_2                       ((uint32_t)0x00000004)
#define GPIO_ODR_ODR_3                       ((uint32_t)0x00000008)
#define GPIO_ODR_ODR_4                       ((uint32_t)0x00000010)
#define GPIO_ODR_ODR_5                       ((uint32_t)0x00000020)
#define GPIO_ODR_ODR_6                       ((uint32_t)0x00000040)
#define GPIO_ODR_ODR_7                       ((uint32_t)0x00000080)
#define GPIO_ODR_ODR_8                       ((uint32_t)0x00000100)
#define GPIO_ODR_ODR_9                       ((uint32_t)0x00000200)
#define GPIO_ODR_ODR_10                      ((uint32_t)0x00000400)
#define GPIO_ODR_ODR_11                      ((uint32_t)0x00000800)
#define GPIO_ODR_ODR_12                      ((uint32_t)0x00001000)
#define GPIO_ODR_ODR_13                      ((uint32_t)0x00002000)
#define GPIO_ODR_ODR_14                      ((uint32_t)0x00004000)
#define GPIO_ODR_ODR_15                      ((uint32_t)0x00008000)
/* Old GPIO_ODR register bits definition, maintained for legacy purpose */
#define GPIO_OTYPER_ODR_0                    GPIO_ODR_ODR_0
#define GPIO_OTYPER_ODR_1                    GPIO_ODR_ODR_1
#define GPIO_OTYPER_ODR_2                    GPIO_ODR_ODR_2
#define GPIO_OTYPER_ODR_3                    GPIO_ODR_ODR_3
#define GPIO_OTYPER_ODR_4                    GPIO_ODR_ODR_4
#define GPIO_OTYPER_ODR_5                    GPIO_ODR_ODR_5
#define GPIO_OTYPER_ODR_6                    GPIO_ODR_ODR_6
#define GPIO_OTYPER_ODR_7                    GPIO_ODR_ODR_7
#define GPIO_OTYPER_ODR_8                    GPIO_ODR_ODR_8
#define GPIO_OTYPER_ODR_9                    GPIO_ODR_ODR_9
#define GPIO_OTYPER_ODR_10                   GPIO_ODR_ODR_10
#define GPIO_OTYPER_ODR_11                   GPIO_ODR_ODR_11
#define GPIO_OTYPER_ODR_12                   GPIO_ODR_ODR_12
#define GPIO_OTYPER_ODR_13                   GPIO_ODR_ODR_13
#define GPIO_OTYPER_ODR_14                   GPIO_ODR_ODR_14
#define GPIO_OTYPER_ODR_15                   GPIO_ODR_ODR_15

/******************  Bits definition for GPIO_BSRR register  ******************/
#define GPIO_BSRR_BS_0                       ((uint32_t)0x00000001)
#define GPIO_BSRR_BS_1                       ((uint32_t)0x00000002)
#define GPIO_BSRR_BS_2                       ((uint32_t)0x00000004)
#define GPIO_BSRR_BS_3                       ((uint32_t)0x00000008)
#define GPIO_BSRR_BS_4                       ((uint32_t)0x00000010)
#define GPIO_BSRR_BS_5                       ((uint32_t)0x00000020)
#define GPIO_BSRR_BS_6                       ((uint32_t)0x00000040)
#define GPIO_BSRR_BS_7                       ((uint32_t)0x00000080)
#define GPIO_BSRR_BS_8                       ((uint32_t)0x00000100)
#define GPIO_BSRR_BS_9                       ((uint32_t)0x00000200)
#define GPIO_BSRR_BS_10                      ((uint32_t)0x00000400)
#define GPIO_BSRR_BS_11                      ((uint32_t)0x00000800)
#define GPIO_BSRR_BS_12                      ((uint32_t)0x00001000)
#define GPIO_BSRR_BS_13                      ((uint32_t)0x00002000)
#define GPIO_BSRR_BS_14                      ((uint32_t)0x00004000)
#define GPIO_BSRR_BS_15                      ((uint32_t)0x00008000)
#define GPIO_BSRR_BR_0                       ((uint32_t)0x00010000)
#define GPIO_BSRR_BR_1                       ((uint32_t)0x00020000)
#define GPIO_BSRR_BR_2                       ((uint32_t)0x00040000)
#define GPIO_BSRR_BR_3                       ((uint32_t)0x00080000)
#define GPIO_BSRR_BR_4                       ((uint32_t)0x00100000)
#define GPIO_BSRR_BR_5                       ((uint32_t)0x00200000)
#define GPIO_BSRR_BR_6                       ((uint32_t)0x00400000)
#define GPIO_BSRR_BR_7                       ((uint32_t)0x00800000)
#define GPIO_BSRR_BR_8                       ((uint32_t)0x01000000)
#define GPIO_BSRR_BR_9                       ((uint32_t)0x02000000)
#define GPIO_BSRR_BR_10                      ((uint32_t)0x04000000)
#define GPIO_BSRR_BR_11                      ((uint32_t)0x08000000)
#define GPIO_BSRR_BR_12                      ((uint32_t)0x10000000)
#define GPIO_BSRR_BR_13                      ((uint32_t)0x20000000)
#define GPIO_BSRR_BR_14                      ((uint32_t)0x40000000)
#define GPIO_BSRR_BR_15                      ((uint32_t)0x80000000)

/******************  Bits definition for GPIO_BRR register  ******************/
#define GPIO_BRR_BR_0                       ((uint32_t)0x00000001)
#define GPIO_BRR_BR_1                       ((uint32_t)0x00000002)
#define GPIO_BRR_BR_2                       ((uint32_t)0x00000004)
#define GPIO_BRR_BR_3                       ((uint32_t)0x00000008)
#define GPIO_BRR_BR_4                       ((uint32_t)0x00000010)
#define GPIO_BRR_BR_5                       ((uint32_t)0x00000020)
#define GPIO_BRR_BR_6                       ((uint32_t)0x00000040)
#define GPIO_BRR_BR_7                       ((uint32_t)0x00000080)
#define GPIO_BRR_BR_8                       ((uint32_t)0x00000100)
#define GPIO_BRR_BR_9                       ((uint32_t)0x00000200)
#define GPIO_BRR_BR_10                      ((uint32_t)0x00000400)
#define GPIO_BRR_BR_11                      ((uint32_t)0x00000800)
#define GPIO_BRR_BR_12                      ((uint32_t)0x00001000)
#define GPIO_BRR_BR_13                      ((uint32_t)0x00002000)
#define GPIO_BRR_BR_14                      ((uint32_t)0x00004000)
#define GPIO_BRR_BR_15                      ((uint32_t)0x00008000)

/****************** Bit definition for GPIO_LCKR register *********************/
#define GPIO_LCKR_LCK0                       ((uint32_t)0x00000001)
#define GPIO_LCKR_LCK1                       ((uint32_t)0x00000002)
#define GPIO_LCKR_LCK2                       ((uint32_t)0x00000004)
#define GPIO_LCKR_LCK3                       ((uint32_t)0x00000008)
#define GPIO_LCKR_LCK4                       ((uint32_t)0x00000010)
#define GPIO_LCKR_LCK5                       ((uint32_t)0x00000020)
#define GPIO_LCKR_LCK6                       ((uint32_t)0x00000040)
#define GPIO_LCKR_LCK7                       ((uint32_t)0x00000080)
#define GPIO_LCKR_LCK8                       ((uint32_t)0x00000100)
#define GPIO_LCKR_LCK9                       ((uint32_t)0x00000200)
#define GPIO_LCKR_LCK10                      ((uint32_t)0x00000400)
#define GPIO_LCKR_LCK11                      ((uint32_t)0x00000800)
#define GPIO_LCKR_LCK12                      ((uint32_t)0x00001000)
#define GPIO_LCKR_LCK13                      ((uint32_t)0x00002000)
#define GPIO_LCKR_LCK14                      ((uint32_t)0x00004000)
#define GPIO_LCKR_LCK15                      ((uint32_t)0x00008000)
#define GPIO_LCKR_LCKK                       ((uint32_t)0x00010000)

/******************  Bits definition for GPIO_RLAR register  *******************/
#define GPIO_RLA_EN_0                       ((uint32_t)0x00000001)
#define GPIO_RLA_EN_1                       ((uint32_t)0x00000002)
#define GPIO_RLA_EN_2                       ((uint32_t)0x00000004)
#define GPIO_RLA_EN_3                       ((uint32_t)0x00000008)
#define GPIO_RLA_EN_4                       ((uint32_t)0x00000010)
#define GPIO_RLA_EN_5                       ((uint32_t)0x00000020)
#define GPIO_RLA_EN_6                       ((uint32_t)0x00000040)
#define GPIO_RLA_EN_7                       ((uint32_t)0x00000080)
#define GPIO_RLA_EN_8                       ((uint32_t)0x00000100)
#define GPIO_RLA_EN_9                       ((uint32_t)0x00000200)
#define GPIO_RLA_EN_10                      ((uint32_t)0x00000400)
#define GPIO_RLA_EN_11                      ((uint32_t)0x00000800)
#define GPIO_RLA_EN_12                      ((uint32_t)0x00001000)
#define GPIO_RLA_EN_13                      ((uint32_t)0x00002000)
#define GPIO_RLA_EN_14                      ((uint32_t)0x00004000)
#define GPIO_RLA_EN_15                      ((uint32_t)0x00008000)

/******************************************************************************/
/*                                                                            */
/*                        HSEM HW Semaphore                                   */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for HSEM_R register  ********************/
#define  HSEM_R_PROCID                        ((uint32_t)0x000000FF)            /*!<Semaphore ProcessID */
#define  HSEM_R_COREID                        ((uint32_t)0x0000FF00)            /*!<Semaphore CoreID. */
#define  HSEM_R_LOCK                          ((uint32_t)0x80000000)            /*!<Lock indication. */

/********************  Bit definition for HSEM_RLR register  ******************/
#define  HSEM_RLR_PROCID                       ((uint32_t)0x000000FF)           /*!<Semaphore ProcessID */
#define  HSEM_RLR_COREID                       ((uint32_t)0x0000FF00)           /*!<Semaphore CoreID. */
#define  HSEM_RLR_LOCK                         ((uint32_t)0x80000000)           /*!<Lock indication. */

/********************  Bit definition for HSEM_IER0 register  *****************/
#define  HSEM_IER0_ISEM0                       ((uint32_t)0x00000001)           /*!<semaphore 0 , interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM1                       ((uint32_t)0x00000002)           /*!<semaphore 1 , interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM2                       ((uint32_t)0x00000004)           /*!<semaphore 2 , interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM3                       ((uint32_t)0x00000008)           /*!<semaphore 3 , interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM4                       ((uint32_t)0x00000010)           /*!<semaphore 4 , interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM5                       ((uint32_t)0x00000020)           /*!<semaphore 5 interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM6                       ((uint32_t)0x00000040)           /*!<semaphore 6 interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM7                       ((uint32_t)0x00000080)           /*!<semaphore 7 interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM8                       ((uint32_t)0x00000100)           /*!<semaphore 8 interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM9                       ((uint32_t)0x00000200)           /*!<semaphore 9 interrupt 0 enable bit.  */
#define  HSEM_IER0_ISEM10                      ((uint32_t)0x00000400)           /*!<semaphore 10 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM11                      ((uint32_t)0x00000800)           /*!<semaphore 11 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM12                      ((uint32_t)0x00001000)           /*!<semaphore 12 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM13                      ((uint32_t)0x00002000)           /*!<semaphore 13 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM14                      ((uint32_t)0x00004000)           /*!<semaphore 14 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM15                      ((uint32_t)0x00008000)           /*!<semaphore 15 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM16                      ((uint32_t)0x00010000)           /*!<semaphore 16 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM17                      ((uint32_t)0x00020000)           /*!<semaphore 17 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM18                      ((uint32_t)0x00040000)           /*!<semaphore 18 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM19                      ((uint32_t)0x00080000)           /*!<semaphore 19 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM20                      ((uint32_t)0x00100000)           /*!<semaphore 20 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM21                      ((uint32_t)0x00200000)           /*!<semaphore 21 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM22                      ((uint32_t)0x00400000)           /*!<semaphore 22 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM23                      ((uint32_t)0x00800000)           /*!<semaphore 23 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM24                      ((uint32_t)0x01000000)           /*!<semaphore 24 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM25                      ((uint32_t)0x02000000)           /*!<semaphore 25 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM26                      ((uint32_t)0x04000000)           /*!<semaphore 26 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM27                      ((uint32_t)0x08000000)           /*!<semaphore 27 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM28                      ((uint32_t)0x10000000)           /*!<semaphore 28 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM29                      ((uint32_t)0x20000000)           /*!<semaphore 29 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM30                      ((uint32_t)0x40000000)           /*!<semaphore 30 interrupt 0 enable bit. */
#define  HSEM_IER0_ISEM31                      ((uint32_t)0x80000000)           /*!<semaphore 31 interrupt 0 enable bit. */

/********************  Bit definition for HSEM_ICR0 register  *****************/
#define  HSEM_ICR0_ISEM0                       ((uint32_t)0x00000001)           /*!<semaphore 0 , interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM1                       ((uint32_t)0x00000002)           /*!<semaphore 1 , interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM2                       ((uint32_t)0x00000004)           /*!<semaphore 2 , interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM3                       ((uint32_t)0x00000008)           /*!<semaphore 3 , interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM4                       ((uint32_t)0x00000010)           /*!<semaphore 4 , interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM5                       ((uint32_t)0x00000020)           /*!<semaphore 5 interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM6                       ((uint32_t)0x00000040)           /*!<semaphore 6 interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM7                       ((uint32_t)0x00000080)           /*!<semaphore 7 interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM8                       ((uint32_t)0x00000100)           /*!<semaphore 8 interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM9                       ((uint32_t)0x00000200)           /*!<semaphore 9 interrupt 0 clear bit.  */
#define  HSEM_ICR0_ISEM10                      ((uint32_t)0x00000400)           /*!<semaphore 10 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM11                      ((uint32_t)0x00000800)           /*!<semaphore 11 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM12                      ((uint32_t)0x00001000)           /*!<semaphore 12 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM13                      ((uint32_t)0x00002000)           /*!<semaphore 13 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM14                      ((uint32_t)0x00004000)           /*!<semaphore 14 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM15                      ((uint32_t)0x00008000)           /*!<semaphore 15 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM16                      ((uint32_t)0x00010000)           /*!<semaphore 16 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM17                      ((uint32_t)0x00020000)           /*!<semaphore 17 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM18                      ((uint32_t)0x00040000)           /*!<semaphore 18 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM19                      ((uint32_t)0x00080000)           /*!<semaphore 19 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM20                      ((uint32_t)0x00100000)           /*!<semaphore 20 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM21                      ((uint32_t)0x00200000)           /*!<semaphore 21 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM22                      ((uint32_t)0x00400000)           /*!<semaphore 22 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM23                      ((uint32_t)0x00800000)           /*!<semaphore 23 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM24                      ((uint32_t)0x01000000)           /*!<semaphore 24 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM25                      ((uint32_t)0x02000000)           /*!<semaphore 25 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM26                      ((uint32_t)0x04000000)           /*!<semaphore 26 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM27                      ((uint32_t)0x08000000)           /*!<semaphore 27 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM28                      ((uint32_t)0x10000000)           /*!<semaphore 28 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM29                      ((uint32_t)0x20000000)           /*!<semaphore 29 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM30                      ((uint32_t)0x40000000)           /*!<semaphore 30 interrupt 0 clear bit. */
#define  HSEM_ICR0_ISEM31                      ((uint32_t)0x80000000)           /*!<semaphore 31 interrupt 0 clear bit. */

/********************  Bit definition for HSEM_ISR0 register  *****************/
#define  HSEM_ISR0_ISEM0                       ((uint32_t)0x00000001)           /*!<semaphore 0 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM1                       ((uint32_t)0x00000002)           /*!<semaphore 1 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM2                       ((uint32_t)0x00000004)           /*!<semaphore 2 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM3                       ((uint32_t)0x00000008)           /*!<semaphore 3 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM4                       ((uint32_t)0x00000010)           /*!<semaphore 4 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM5                       ((uint32_t)0x00000020)           /*!<semaphore 5 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM6                       ((uint32_t)0x00000040)           /*!<semaphore 6 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM7                       ((uint32_t)0x00000080)           /*!<semaphore 7 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM8                       ((uint32_t)0x00000100)           /*!<semaphore 8 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM9                       ((uint32_t)0x00000200)           /*!<semaphore 9 interrupt 0 status bit.  */
#define  HSEM_ISR0_ISEM10                      ((uint32_t)0x00000400)           /*!<semaphore 10 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM11                      ((uint32_t)0x00000800)           /*!<semaphore 11 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM12                      ((uint32_t)0x00001000)           /*!<semaphore 12 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM13                      ((uint32_t)0x00002000)           /*!<semaphore 13 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM14                      ((uint32_t)0x00004000)           /*!<semaphore 14 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM15                      ((uint32_t)0x00008000)           /*!<semaphore 15 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM16                      ((uint32_t)0x00010000)           /*!<semaphore 16 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM17                      ((uint32_t)0x00020000)           /*!<semaphore 17 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM18                      ((uint32_t)0x00040000)           /*!<semaphore 18 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM19                      ((uint32_t)0x00080000)           /*!<semaphore 19 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM20                      ((uint32_t)0x00100000)           /*!<semaphore 20 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM21                      ((uint32_t)0x00200000)           /*!<semaphore 21 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM22                      ((uint32_t)0x00400000)           /*!<semaphore 22 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM23                      ((uint32_t)0x00800000)           /*!<semaphore 23 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM24                      ((uint32_t)0x01000000)           /*!<semaphore 24 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM25                      ((uint32_t)0x02000000)           /*!<semaphore 25 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM26                      ((uint32_t)0x04000000)           /*!<semaphore 26 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM27                      ((uint32_t)0x08000000)           /*!<semaphore 27 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM28                      ((uint32_t)0x10000000)           /*!<semaphore 28 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM29                      ((uint32_t)0x20000000)           /*!<semaphore 29 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM30                      ((uint32_t)0x40000000)           /*!<semaphore 30 interrupt 0 status bit. */
#define  HSEM_ISR0_ISEM31                      ((uint32_t)0x80000000)           /*!<semaphore 31 interrupt 0 status bit. */

/********************  Bit definition for HSEM_MISR0 register  *****************/
#define  HSEM_MISR0_ISEM0                       ((uint32_t)0x00000001)           /*!<semaphore 0 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM1                       ((uint32_t)0x00000002)           /*!<semaphore 1 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM2                       ((uint32_t)0x00000004)           /*!<semaphore 2 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM3                       ((uint32_t)0x00000008)           /*!<semaphore 3 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM4                       ((uint32_t)0x00000010)           /*!<semaphore 4 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM5                       ((uint32_t)0x00000020)           /*!<semaphore 5 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM6                       ((uint32_t)0x00000040)           /*!<semaphore 6 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM7                       ((uint32_t)0x00000080)           /*!<semaphore 7 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM8                       ((uint32_t)0x00000100)           /*!<semaphore 8 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM9                       ((uint32_t)0x00000200)           /*!<semaphore 9 interrupt 0 masked status bit.  */
#define  HSEM_MISR0_ISEM10                      ((uint32_t)0x00000400)           /*!<semaphore 10 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM11                      ((uint32_t)0x00000800)           /*!<semaphore 11 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM12                      ((uint32_t)0x00001000)           /*!<semaphore 12 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM13                      ((uint32_t)0x00002000)           /*!<semaphore 13 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM14                      ((uint32_t)0x00004000)           /*!<semaphore 14 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM15                      ((uint32_t)0x00008000)           /*!<semaphore 15 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM16                      ((uint32_t)0x00010000)           /*!<semaphore 16 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM17                      ((uint32_t)0x00020000)           /*!<semaphore 17 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM18                      ((uint32_t)0x00040000)           /*!<semaphore 18 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM19                      ((uint32_t)0x00080000)           /*!<semaphore 19 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM20                      ((uint32_t)0x00100000)           /*!<semaphore 20 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM21                      ((uint32_t)0x00200000)           /*!<semaphore 21 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM22                      ((uint32_t)0x00400000)           /*!<semaphore 22 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM23                      ((uint32_t)0x00800000)           /*!<semaphore 23 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM24                      ((uint32_t)0x01000000)           /*!<semaphore 24 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM25                      ((uint32_t)0x02000000)           /*!<semaphore 25 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM26                      ((uint32_t)0x04000000)           /*!<semaphore 26 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM27                      ((uint32_t)0x08000000)           /*!<semaphore 27 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM28                      ((uint32_t)0x10000000)           /*!<semaphore 28 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM29                      ((uint32_t)0x20000000)           /*!<semaphore 29 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM30                      ((uint32_t)0x40000000)           /*!<semaphore 30 interrupt 0 masked status bit. */
#define  HSEM_MISR0_ISEM31                      ((uint32_t)0x80000000)           /*!<semaphore 31 interrupt 0 masked status bit. */

/********************  Bit definition for HSEM_IER1 register  *****************/
#define  HSEM_IER1_ISEM0                       ((uint32_t)0x00000001)           /*!<semaphore 0 , interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM1                       ((uint32_t)0x00000002)           /*!<semaphore 1 , interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM2                       ((uint32_t)0x00000004)           /*!<semaphore 2 , interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM3                       ((uint32_t)0x00000008)           /*!<semaphore 3 , interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM4                       ((uint32_t)0x00000010)           /*!<semaphore 4 , interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM5                       ((uint32_t)0x00000020)           /*!<semaphore 5 interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM6                       ((uint32_t)0x00000040)           /*!<semaphore 6 interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM7                       ((uint32_t)0x00000080)           /*!<semaphore 7 interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM8                       ((uint32_t)0x00000100)           /*!<semaphore 8 interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM9                       ((uint32_t)0x00000200)           /*!<semaphore 9 interrupt 1 enable bit.  */
#define  HSEM_IER1_ISEM10                      ((uint32_t)0x00000400)           /*!<semaphore 10 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM11                      ((uint32_t)0x00000800)           /*!<semaphore 11 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM12                      ((uint32_t)0x00001000)           /*!<semaphore 12 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM13                      ((uint32_t)0x00002000)           /*!<semaphore 13 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM14                      ((uint32_t)0x00004000)           /*!<semaphore 14 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM15                      ((uint32_t)0x00008000)           /*!<semaphore 15 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM16                      ((uint32_t)0x00010000)           /*!<semaphore 16 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM17                      ((uint32_t)0x00020000)           /*!<semaphore 17 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM18                      ((uint32_t)0x00040000)           /*!<semaphore 18 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM19                      ((uint32_t)0x00080000)           /*!<semaphore 19 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM20                      ((uint32_t)0x00100000)           /*!<semaphore 20 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM21                      ((uint32_t)0x00200000)           /*!<semaphore 21 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM22                      ((uint32_t)0x00400000)           /*!<semaphore 22 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM23                      ((uint32_t)0x00800000)           /*!<semaphore 23 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM24                      ((uint32_t)0x01000000)           /*!<semaphore 24 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM25                      ((uint32_t)0x02000000)           /*!<semaphore 25 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM26                      ((uint32_t)0x04000000)           /*!<semaphore 26 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM27                      ((uint32_t)0x08000000)           /*!<semaphore 27 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM28                      ((uint32_t)0x10000000)           /*!<semaphore 28 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM29                      ((uint32_t)0x20000000)           /*!<semaphore 29 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM30                      ((uint32_t)0x40000000)           /*!<semaphore 30 interrupt 1 enable bit. */
#define  HSEM_IER1_ISEM31                      ((uint32_t)0x80000000)           /*!<semaphore 31 interrupt 1 enable bit. */

/********************  Bit definition for HSEM_ICR1 register  *****************/
#define  HSEM_ICR1_ISEM0                       ((uint32_t)0x00000001)           /*!<semaphore 0 , interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM1                       ((uint32_t)0x00000002)           /*!<semaphore 1 , interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM2                       ((uint32_t)0x00000004)           /*!<semaphore 2 , interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM3                       ((uint32_t)0x00000008)           /*!<semaphore 3 , interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM4                       ((uint32_t)0x00000010)           /*!<semaphore 4 , interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM5                       ((uint32_t)0x00000020)           /*!<semaphore 5 interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM6                       ((uint32_t)0x00000040)           /*!<semaphore 6 interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM7                       ((uint32_t)0x00000080)           /*!<semaphore 7 interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM8                       ((uint32_t)0x00000100)           /*!<semaphore 8 interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM9                       ((uint32_t)0x00000200)           /*!<semaphore 9 interrupt 1 clear bit.  */
#define  HSEM_ICR1_ISEM10                      ((uint32_t)0x00000400)           /*!<semaphore 10 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM11                      ((uint32_t)0x00000800)           /*!<semaphore 11 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM12                      ((uint32_t)0x00001000)           /*!<semaphore 12 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM13                      ((uint32_t)0x00002000)           /*!<semaphore 13 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM14                      ((uint32_t)0x00004000)           /*!<semaphore 14 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM15                      ((uint32_t)0x00008000)           /*!<semaphore 15 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM16                      ((uint32_t)0x00010000)           /*!<semaphore 16 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM17                      ((uint32_t)0x00020000)           /*!<semaphore 17 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM18                      ((uint32_t)0x00040000)           /*!<semaphore 18 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM19                      ((uint32_t)0x00080000)           /*!<semaphore 19 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM20                      ((uint32_t)0x00100000)           /*!<semaphore 20 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM21                      ((uint32_t)0x00200000)           /*!<semaphore 21 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM22                      ((uint32_t)0x00400000)           /*!<semaphore 22 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM23                      ((uint32_t)0x00800000)           /*!<semaphore 23 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM24                      ((uint32_t)0x01000000)           /*!<semaphore 24 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM25                      ((uint32_t)0x02000000)           /*!<semaphore 25 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM26                      ((uint32_t)0x04000000)           /*!<semaphore 26 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM27                      ((uint32_t)0x08000000)           /*!<semaphore 27 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM28                      ((uint32_t)0x10000000)           /*!<semaphore 28 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM29                      ((uint32_t)0x20000000)           /*!<semaphore 29 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM30                      ((uint32_t)0x40000000)           /*!<semaphore 30 interrupt 1 clear bit. */
#define  HSEM_ICR1_ISEM31                      ((uint32_t)0x80000000)           /*!<semaphore 31 interrupt 1 clear bit. */

/********************  Bit definition for HSEM_ISR1 register  *****************/
#define  HSEM_ISR1_ISEM0                       ((uint32_t)0x00000001)           /*!<semaphore 0 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM1                       ((uint32_t)0x00000002)           /*!<semaphore 1 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM2                       ((uint32_t)0x00000004)           /*!<semaphore 2 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM3                       ((uint32_t)0x00000008)           /*!<semaphore 3 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM4                       ((uint32_t)0x00000010)           /*!<semaphore 4 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM5                       ((uint32_t)0x00000020)           /*!<semaphore 5 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM6                       ((uint32_t)0x00000040)           /*!<semaphore 6 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM7                       ((uint32_t)0x00000080)           /*!<semaphore 7 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM8                       ((uint32_t)0x00000100)           /*!<semaphore 8 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM9                       ((uint32_t)0x00000200)           /*!<semaphore 9 interrupt 1 status bit.  */
#define  HSEM_ISR1_ISEM10                      ((uint32_t)0x00000400)           /*!<semaphore 10 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM11                      ((uint32_t)0x00000800)           /*!<semaphore 11 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM12                      ((uint32_t)0x00001000)           /*!<semaphore 12 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM13                      ((uint32_t)0x00002000)           /*!<semaphore 13 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM14                      ((uint32_t)0x00004000)           /*!<semaphore 14 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM15                      ((uint32_t)0x00008000)           /*!<semaphore 15 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM16                      ((uint32_t)0x00010000)           /*!<semaphore 16 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM17                      ((uint32_t)0x00020000)           /*!<semaphore 17 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM18                      ((uint32_t)0x00040000)           /*!<semaphore 18 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM19                      ((uint32_t)0x00080000)           /*!<semaphore 19 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM20                      ((uint32_t)0x00100000)           /*!<semaphore 20 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM21                      ((uint32_t)0x00200000)           /*!<semaphore 21 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM22                      ((uint32_t)0x00400000)           /*!<semaphore 22 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM23                      ((uint32_t)0x00800000)           /*!<semaphore 23 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM24                      ((uint32_t)0x01000000)           /*!<semaphore 24 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM25                      ((uint32_t)0x02000000)           /*!<semaphore 25 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM26                      ((uint32_t)0x04000000)           /*!<semaphore 26 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM27                      ((uint32_t)0x08000000)           /*!<semaphore 27 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM28                      ((uint32_t)0x10000000)           /*!<semaphore 28 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM29                      ((uint32_t)0x20000000)           /*!<semaphore 29 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM30                      ((uint32_t)0x40000000)           /*!<semaphore 30 interrupt 1 status bit. */
#define  HSEM_ISR1_ISEM31                      ((uint32_t)0x80000000)           /*!<semaphore 31 interrupt 1 status bit. */

/********************  Bit definition for HSEM_MISR1 register  *****************/
#define  HSEM_MISR1_ISEM0                       ((uint32_t)0x00000001)           /*!<semaphore 0 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM1                       ((uint32_t)0x00000002)           /*!<semaphore 1 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM2                       ((uint32_t)0x00000004)           /*!<semaphore 2 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM3                       ((uint32_t)0x00000008)           /*!<semaphore 3 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM4                       ((uint32_t)0x00000010)           /*!<semaphore 4 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM5                       ((uint32_t)0x00000020)           /*!<semaphore 5 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM6                       ((uint32_t)0x00000040)           /*!<semaphore 6 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM7                       ((uint32_t)0x00000080)           /*!<semaphore 7 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM8                       ((uint32_t)0x00000100)           /*!<semaphore 8 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM9                       ((uint32_t)0x00000200)           /*!<semaphore 9 interrupt 1 masked status bit.  */
#define  HSEM_MISR1_ISEM10                      ((uint32_t)0x00000400)           /*!<semaphore 10 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM11                      ((uint32_t)0x00000800)           /*!<semaphore 11 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM12                      ((uint32_t)0x00001000)           /*!<semaphore 12 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM13                      ((uint32_t)0x00002000)           /*!<semaphore 13 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM14                      ((uint32_t)0x00004000)           /*!<semaphore 14 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM15                      ((uint32_t)0x00008000)           /*!<semaphore 15 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM16                      ((uint32_t)0x00010000)           /*!<semaphore 16 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM17                      ((uint32_t)0x00020000)           /*!<semaphore 17 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM18                      ((uint32_t)0x00040000)           /*!<semaphore 18 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM19                      ((uint32_t)0x00080000)           /*!<semaphore 19 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM20                      ((uint32_t)0x00100000)           /*!<semaphore 20 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM21                      ((uint32_t)0x00200000)           /*!<semaphore 21 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM22                      ((uint32_t)0x00400000)           /*!<semaphore 22 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM23                      ((uint32_t)0x00800000)           /*!<semaphore 23 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM24                      ((uint32_t)0x01000000)           /*!<semaphore 24 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM25                      ((uint32_t)0x02000000)           /*!<semaphore 25 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM26                      ((uint32_t)0x04000000)           /*!<semaphore 26 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM27                      ((uint32_t)0x08000000)           /*!<semaphore 27 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM28                      ((uint32_t)0x10000000)           /*!<semaphore 28 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM29                      ((uint32_t)0x20000000)           /*!<semaphore 29 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM30                      ((uint32_t)0x40000000)           /*!<semaphore 30 interrupt 1 masked status bit. */
#define  HSEM_MISR1_ISEM31                      ((uint32_t)0x80000000)           /*!<semaphore 31 interrupt 1 masked status bit. */

/********************  Bit definition for HSEM_CR register  *****************/
#define  HSEM_CR_COREID                         ((uint32_t)0x0000FF00)           /*!<CoreID of semaphores to be cleared. */
#define  HSEM_CR_KEY                            ((uint32_t)0xFFFF0000)           /*!<semaphores clear key. */

/********************  Bit definition for HSEM_KEYR register  *****************/
#define  HSEM_KEYR_KEY                          ((uint32_t)0xFFFF0000)           /*!<semaphores clear key. */

/******************************************************************************/
/*                                                                            */
/*                                    HASH                                    */
/*                                                                            */
/******************************************************************************/
/******************  Bits definition for HASH_CR register  ********************/
#define HASH_CR_INIT                         ((uint32_t)0x00000004)
#define HASH_CR_DMAE                         ((uint32_t)0x00000008)
#define HASH_CR_DATATYPE                     ((uint32_t)0x00000030)
#define HASH_CR_DATATYPE_0                   ((uint32_t)0x00000010)
#define HASH_CR_DATATYPE_1                   ((uint32_t)0x00000020)
#define HASH_CR_MODE                         ((uint32_t)0x00000040)
#define HASH_CR_ALGO                         ((uint32_t)0x00040080)
#define HASH_CR_ALGO_0                       ((uint32_t)0x00000080)
#define HASH_CR_ALGO_1                       ((uint32_t)0x00040000)
#define HASH_CR_NBW                          ((uint32_t)0x00000F00)
#define HASH_CR_NBW_0                        ((uint32_t)0x00000100)
#define HASH_CR_NBW_1                        ((uint32_t)0x00000200)
#define HASH_CR_NBW_2                        ((uint32_t)0x00000400)
#define HASH_CR_NBW_3                        ((uint32_t)0x00000800)
#define HASH_CR_DINNE                        ((uint32_t)0x00001000)
#define HASH_CR_MDMAT                        ((uint32_t)0x00002000)
#define HASH_CR_LKEY                         ((uint32_t)0x00010000)

/******************  Bits definition for HASH_STR register  *******************/
#define HASH_STR_NBLW                        ((uint32_t)0x0000001F)
#define HASH_STR_NBLW_0                      ((uint32_t)0x00000001)
#define HASH_STR_NBLW_1                      ((uint32_t)0x00000002)
#define HASH_STR_NBLW_2                      ((uint32_t)0x00000004)
#define HASH_STR_NBLW_3                      ((uint32_t)0x00000008)
#define HASH_STR_NBLW_4                      ((uint32_t)0x00000010)
#define HASH_STR_DCAL                        ((uint32_t)0x00000100)

/******************  Bits definition for HASH_IMR register  *******************/
#define HASH_IMR_DINIE                       ((uint32_t)0x00000001)
#define HASH_IMR_DCIE                        ((uint32_t)0x00000002)

/******************  Bits definition for HASH_SR register  ********************/
#define HASH_SR_DINIS                        ((uint32_t)0x00000001)
#define HASH_SR_DCIS                         ((uint32_t)0x00000002)
#define HASH_SR_DMAS                         ((uint32_t)0x00000004)
#define HASH_SR_BUSY                         ((uint32_t)0x00000008)

/******************************************************************************/
/*                                                                            */
/*                      Inter-integrated Circuit Interface (I2C)              */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for I2C_CR1 register  *******************/
#define  I2C_CR1_PE                          ((uint32_t)0x00000001)        /*!< Peripheral enable */
#define  I2C_CR1_TXIE                        ((uint32_t)0x00000002)        /*!< TX interrupt enable */
#define  I2C_CR1_RXIE                        ((uint32_t)0x00000004)        /*!< RX interrupt enable */
#define  I2C_CR1_ADDRIE                      ((uint32_t)0x00000008)        /*!< Address match interrupt enable */
#define  I2C_CR1_NACKIE                      ((uint32_t)0x00000010)        /*!< NACK received interrupt enable */
#define  I2C_CR1_STOPIE                      ((uint32_t)0x00000020)        /*!< STOP detection interrupt enable */
#define  I2C_CR1_TCIE                        ((uint32_t)0x00000040)        /*!< Transfer complete interrupt enable */
#define  I2C_CR1_ERRIE                       ((uint32_t)0x00000080)        /*!< Errors interrupt enable */
#define  I2C_CR1_DNF                         ((uint32_t)0x00000F00)        /*!< Digital noise filter */
#define  I2C_CR1_ANFOFF                      ((uint32_t)0x00001000)        /*!< Analog noise filter OFF */
#define  I2C_CR1_SWRST                       ((uint32_t)0x00002000)        /*!< Software reset */
#define  I2C_CR1_TXDMAEN                     ((uint32_t)0x00004000)        /*!< DMA transmission requests enable */
#define  I2C_CR1_RXDMAEN                     ((uint32_t)0x00008000)        /*!< DMA reception requests enable */
#define  I2C_CR1_SBC                         ((uint32_t)0x00010000)        /*!< Slave byte control */
#define  I2C_CR1_NOSTRETCH                   ((uint32_t)0x00020000)        /*!< Clock stretching disable */
#define  I2C_CR1_WUPEN                       ((uint32_t)0x00040000)        /*!< Wakeup from STOP enable */
#define  I2C_CR1_GCEN                        ((uint32_t)0x00080000)        /*!< General call enable */
#define  I2C_CR1_SMBHEN                      ((uint32_t)0x00100000)        /*!< SMBus host address enable */
#define  I2C_CR1_SMBDEN                      ((uint32_t)0x00200000)        /*!< SMBus device default address enable */
#define  I2C_CR1_ALERTEN                     ((uint32_t)0x00400000)        /*!< SMBus alert enable */
#define  I2C_CR1_PECEN                       ((uint32_t)0x00800000)        /*!< PEC enable */

/******************  Bit definition for I2C_CR2 register  ********************/
#define  I2C_CR2_SADD                        ((uint32_t)0x000003FF)        /*!< Slave address (master mode) */
#define  I2C_CR2_RD_WRN                      ((uint32_t)0x00000400)        /*!< Transfer direction (master mode) */
#define  I2C_CR2_ADD10                       ((uint32_t)0x00000800)        /*!< 10-bit addressing mode (master mode) */
#define  I2C_CR2_HEAD10R                     ((uint32_t)0x00001000)        /*!< 10-bit address header only read direction (master mode) */
#define  I2C_CR2_START                       ((uint32_t)0x00002000)        /*!< START generation */
#define  I2C_CR2_STOP                        ((uint32_t)0x00004000)        /*!< STOP generation (master mode) */
#define  I2C_CR2_NACK                        ((uint32_t)0x00008000)        /*!< NACK generation (slave mode) */
#define  I2C_CR2_NBYTES                      ((uint32_t)0x00FF0000)        /*!< Number of bytes */
#define  I2C_CR2_RELOAD                      ((uint32_t)0x01000000)        /*!< NBYTES reload mode */
#define  I2C_CR2_AUTOEND                     ((uint32_t)0x02000000)        /*!< Automatic end mode (master mode) */
#define  I2C_CR2_PECBYTE                     ((uint32_t)0x04000000)        /*!< Packet error checking byte */

/*******************  Bit definition for I2C_OAR1 register  ******************/
#define  I2C_OAR1_OA1                        ((uint32_t)0x000003FF)        /*!< Interface own address 1 */
#define  I2C_OAR1_OA1MODE                    ((uint32_t)0x00000400)        /*!< Own address 1 10-bit mode */
#define  I2C_OAR1_OA1EN                      ((uint32_t)0x00008000)        /*!< Own address 1 enable */

/*******************  Bit definition for I2C_OAR2 register  ******************/
#define  I2C_OAR2_OA2                        ((uint32_t)0x000000FE)        /*!< Interface own address 2 */
#define  I2C_OAR2_OA2MSK                     ((uint32_t)0x00000700)        /*!< Own address 2 masks */
#define  I2C_OAR2_OA2EN                      ((uint32_t)0x00008000)        /*!< Own address 2 enable */

/*******************  Bit definition for I2C_TIMINGR register *******************/
#define  I2C_TIMINGR_SCLL                    ((uint32_t)0x000000FF)        /*!< SCL low period (master mode) */
#define  I2C_TIMINGR_SCLH                    ((uint32_t)0x0000FF00)        /*!< SCL high period (master mode) */
#define  I2C_TIMINGR_SDADEL                  ((uint32_t)0x000F0000)        /*!< Data hold time */
#define  I2C_TIMINGR_SCLDEL                  ((uint32_t)0x00F00000)        /*!< Data setup time */
#define  I2C_TIMINGR_PRESC                   ((uint32_t)0xF0000000)        /*!< Timings prescaler */

/******************* Bit definition for I2C_TIMEOUTR register *******************/
#define  I2C_TIMEOUTR_TIMEOUTA               ((uint32_t)0x00000FFF)        /*!< Bus timeout A */
#define  I2C_TIMEOUTR_TIDLE                  ((uint32_t)0x00001000)        /*!< Idle clock timeout detection */
#define  I2C_TIMEOUTR_TIMOUTEN               ((uint32_t)0x00008000)        /*!< Clock timeout enable */
#define  I2C_TIMEOUTR_TIMEOUTB               ((uint32_t)0x0FFF0000)        /*!< Bus timeout B*/
#define  I2C_TIMEOUTR_TEXTEN                 ((uint32_t)0x80000000)        /*!< Extended clock timeout enable */

/******************  Bit definition for I2C_ISR register  *********************/
#define  I2C_ISR_TXE                         ((uint32_t)0x00000001)        /*!< Transmit data register empty */
#define  I2C_ISR_TXIS                        ((uint32_t)0x00000002)        /*!< Transmit interrupt status */
#define  I2C_ISR_RXNE                        ((uint32_t)0x00000004)        /*!< Receive data register not empty */
#define  I2C_ISR_ADDR                        ((uint32_t)0x00000008)        /*!< Address matched (slave mode)*/
#define  I2C_ISR_NACKF                       ((uint32_t)0x00000010)        /*!< NACK received flag */
#define  I2C_ISR_STOPF                       ((uint32_t)0x00000020)        /*!< STOP detection flag */
#define  I2C_ISR_TC                          ((uint32_t)0x00000040)        /*!< Transfer complete (master mode) */
#define  I2C_ISR_TCR                         ((uint32_t)0x00000080)        /*!< Transfer complete reload */
#define  I2C_ISR_BERR                        ((uint32_t)0x00000100)        /*!< Bus error */
#define  I2C_ISR_ARLO                        ((uint32_t)0x00000200)        /*!< Arbitration lost */
#define  I2C_ISR_OVR                         ((uint32_t)0x00000400)        /*!< Overrun/Underrun */
#define  I2C_ISR_PECERR                      ((uint32_t)0x00000800)        /*!< PEC error in reception */
#define  I2C_ISR_TIMEOUT                     ((uint32_t)0x00001000)        /*!< Timeout or Tlow detection flag */
#define  I2C_ISR_ALERT                       ((uint32_t)0x00002000)        /*!< SMBus alert */
#define  I2C_ISR_BUSY                        ((uint32_t)0x00008000)        /*!< Bus busy */
#define  I2C_ISR_DIR                         ((uint32_t)0x00010000)        /*!< Transfer direction (slave mode) */
#define  I2C_ISR_ADDCODE                     ((uint32_t)0x00FE0000)        /*!< Address match code (slave mode) */

/******************  Bit definition for I2C_ICR register  *********************/
#define  I2C_ICR_ADDRCF                      ((uint32_t)0x00000008)        /*!< Address matched clear flag */
#define  I2C_ICR_NACKCF                      ((uint32_t)0x00000010)        /*!< NACK clear flag */
#define  I2C_ICR_STOPCF                      ((uint32_t)0x00000020)        /*!< STOP detection clear flag */
#define  I2C_ICR_BERRCF                      ((uint32_t)0x00000100)        /*!< Bus error clear flag */
#define  I2C_ICR_ARLOCF                      ((uint32_t)0x00000200)        /*!< Arbitration lost clear flag */
#define  I2C_ICR_OVRCF                       ((uint32_t)0x00000400)        /*!< Overrun/Underrun clear flag */
#define  I2C_ICR_PECCF                       ((uint32_t)0x00000800)        /*!< PAC error clear flag */
#define  I2C_ICR_TIMOUTCF                    ((uint32_t)0x00001000)        /*!< Timeout clear flag */
#define  I2C_ICR_ALERTCF                     ((uint32_t)0x00002000)        /*!< Alert clear flag */

/******************  Bit definition for I2C_PECR register  *********************/
#define  I2C_PECR_PEC                        ((uint32_t)0x000000FF)        /*!< PEC register */

/******************  Bit definition for I2C_RXDR register  *********************/
#define  I2C_RXDR_RXDATA                     ((uint32_t)0x000000FF)        /*!< 8-bit receive data */

/******************  Bit definition for I2C_TXDR register  *********************/
#define  I2C_TXDR_TXDATA                     ((uint32_t)0x000000FF)        /*!< 8-bit transmit data */

/******************************************************************************/
/*                                                                            */
/*                           Independent WATCHDOG                             */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for IWDG_KR register  ********************/
#define  IWDG_KR_KEY                         ((uint16_t)0xFFFF)            /*!<Key value (write only, read 0000h)  */

/*******************  Bit definition for IWDG_PR register  ********************/
#define  IWDG_PR_PR                          ((uint8_t)0x07)               /*!<PR[2:0] (Prescaler divider)         */
#define  IWDG_PR_PR_0                        ((uint8_t)0x01)               /*!<Bit 0 */
#define  IWDG_PR_PR_1                        ((uint8_t)0x02)               /*!<Bit 1 */
#define  IWDG_PR_PR_2                        ((uint8_t)0x04)               /*!<Bit 2 */

/*******************  Bit definition for IWDG_RLR register  *******************/
#define  IWDG_RLR_RL                         ((uint16_t)0x0FFF)            /*!<Watchdog counter reload value        */

/*******************  Bit definition for IWDG_SR register  ********************/
#define  IWDG_SR_PVU                         ((uint8_t)0x01)               /*!< Watchdog prescaler value update */
#define  IWDG_SR_RVU                         ((uint8_t)0x02)               /*!< Watchdog counter reload value update */
#define  IWDG_SR_WVU                         ((uint8_t)0x04)               /*!< Watchdog counter window value update */

/*******************  Bit definition for IWDG_KR register  ********************/
#define  IWDG_WINR_WIN                         ((uint16_t)0x0FFF)            /*!< Watchdog counter window value */

/******************************************************************************/
/*                                                                            */
/*                        JPEG Encoder/Decoder                                */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for CONFR0 register  ********************/
#define  JPEG_CONFR0_START                       ((uint32_t)0x00000001)        /*!<Start/Stop bit */  

/********************  Bit definition for CONFR1 register  ********************/
#define  JPEG_CONFR1_NF                          ((uint32_t)0x00000003)        /*!<Number of color components */  
#define  JPEG_CONFR1_NF_0                        ((uint32_t)0x00000001)        /*!<Bit 0 */   
#define  JPEG_CONFR1_NF_1                        ((uint32_t)0x00000002)        /*!<Bit 1 */
#define  JPEG_CONFR1_RE                          ((uint32_t)0x00000004)        /*!<Restart maker Enable */  
#define  JPEG_CONFR1_DE                          ((uint32_t)0x00000008)        /*!<Decoding Enable */  
#define  JPEG_CONFR1_COLORSPACE                  ((uint32_t)0x00000030)        /*!<Color Space */  
#define  JPEG_CONFR1_COLORSPACE_0                ((uint32_t)0x00000010)        /*!<Bit 0 */  
#define  JPEG_CONFR1_COLORSPACE_1                ((uint32_t)0x00000020)        /*!<Bit 1 */  
#define  JPEG_CONFR1_NS                          ((uint32_t)0x000000C0)        /*!<Number of components for Scan */  
#define  JPEG_CONFR1_NS_0                        ((uint32_t)0x00000040)        /*!<Bit 0 */  
#define  JPEG_CONFR1_NS_1                        ((uint32_t)0x00000080)        /*!<Bit 1 */
#define  JPEG_CONFR1_HDR                         ((uint32_t)0x00000100)        /*!<Header Processing On/Off */
#define  JPEG_CONFR1_YSIZE                       ((uint32_t)0xFFFF0000)        /*!<Number of lines in source image */

/********************  Bit definition for CONFR2 register  ********************/
#define  JPEG_CONFR2_NMCU                        ((uint32_t)0x03FFFFFF)        /*!<Number of MCU units minus 1 to encode */

/********************  Bit definition for CONFR3 register  ********************/
#define  JPEG_CONFR3_NRST                        ((uint32_t)0x0000FFFF)        /*!<Number of MCU between two restart makers minus 1 */
#define  JPEG_CONFR3_XSIZE                       ((uint32_t)0xFFFF0000)        /*!<Number of pixels per line */

/********************  Bit definition for CONFR4 register  ********************/
#define  JPEG_CONFR4_HD                          ((uint32_t)0x00000001)        /*!<Selects the Huffman table for encoding the DC coefficients */  
#define  JPEG_CONFR4_HA                          ((uint32_t)0x00000002)        /*!<Selects the Huffman table for encoding the AC coefficients */ 
#define  JPEG_CONFR4_QT                          ((uint32_t)0x0000000C)        /*!<Selects quantization table associated with a color component */
#define  JPEG_CONFR4_QT_0                        ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  JPEG_CONFR4_QT_1                        ((uint32_t)0x00000008)        /*!<Bit 1 */
#define  JPEG_CONFR4_NB                          ((uint32_t)0x000000F0)        /*!<Number of data units minus 1 that belong to a particular color in the MCU */
#define  JPEG_CONFR4_NB_0                        ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  JPEG_CONFR4_NB_1                        ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  JPEG_CONFR4_NB_2                        ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  JPEG_CONFR4_NB_3                        ((uint32_t)0x00000080)        /*!<Bit 3 */
#define  JPEG_CONFR4_VSF                         ((uint32_t)0x00000F00)        /*!<Vertical sampling factor for component 1 */
#define  JPEG_CONFR4_VSF_0                       ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  JPEG_CONFR4_VSF_1                       ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  JPEG_CONFR4_VSF_2                       ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  JPEG_CONFR4_VSF_3                       ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  JPEG_CONFR4_HSF                         ((uint32_t)0x0000F000)        /*!<Horizontal sampling factor for component 1 */
#define  JPEG_CONFR4_HSF_0                       ((uint32_t)0x00001000)        /*!<Bit 0 */
#define  JPEG_CONFR4_HSF_1                       ((uint32_t)0x00002000)        /*!<Bit 1 */
#define  JPEG_CONFR4_HSF_2                       ((uint32_t)0x00004000)        /*!<Bit 2 */
#define  JPEG_CONFR4_HSF_3                       ((uint32_t)0x00008000)        /*!<Bit 3 */

/********************  Bit definition for CONFR5 register  ********************/
#define  JPEG_CONFR5_HD                          ((uint32_t)0x00000001)        /*!<Selects the Huffman table for encoding the DC coefficients */  
#define  JPEG_CONFR5_HA                          ((uint32_t)0x00000002)        /*!<Selects the Huffman table for encoding the AC coefficients */ 
#define  JPEG_CONFR5_QT                          ((uint32_t)0x0000000C)        /*!<Selects quantization table associated with a color component */
#define  JPEG_CONFR5_QT_0                        ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  JPEG_CONFR5_QT_1                        ((uint32_t)0x00000008)        /*!<Bit 1 */
#define  JPEG_CONFR5_NB                          ((uint32_t)0x000000F0)        /*!<Number of data units minus 1 that belong to a particular color in the MCU */
#define  JPEG_CONFR5_NB_0                        ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  JPEG_CONFR5_NB_1                        ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  JPEG_CONFR5_NB_2                        ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  JPEG_CONFR5_NB_3                        ((uint32_t)0x00000080)        /*!<Bit 3 */
#define  JPEG_CONFR5_VSF                         ((uint32_t)0x00000F00)        /*!<Vertical sampling factor for component 2 */
#define  JPEG_CONFR5_VSF_0                       ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  JPEG_CONFR5_VSF_1                       ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  JPEG_CONFR5_VSF_2                       ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  JPEG_CONFR5_VSF_3                       ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  JPEG_CONFR5_HSF                         ((uint32_t)0x0000F000)        /*!<Horizontal sampling factor for component 2 */
#define  JPEG_CONFR5_HSF_0                       ((uint32_t)0x00001000)        /*!<Bit 0 */
#define  JPEG_CONFR5_HSF_1                       ((uint32_t)0x00002000)        /*!<Bit 1 */
#define  JPEG_CONFR5_HSF_2                       ((uint32_t)0x00004000)        /*!<Bit 2 */
#define  JPEG_CONFR5_HSF_3                       ((uint32_t)0x00008000)        /*!<Bit 3 */

/********************  Bit definition for CONFR6 register  ********************/
#define  JPEG_CONFR6_HD                          ((uint32_t)0x00000001)        /*!<Selects the Huffman table for encoding the DC coefficients */  
#define  JPEG_CONFR6_HA                          ((uint32_t)0x00000002)        /*!<Selects the Huffman table for encoding the AC coefficients */ 
#define  JPEG_CONFR6_QT                          ((uint32_t)0x0000000C)        /*!<Selects quantization table associated with a color component */
#define  JPEG_CONFR6_QT_0                        ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  JPEG_CONFR6_QT_1                        ((uint32_t)0x00000008)        /*!<Bit 1 */
#define  JPEG_CONFR6_NB                          ((uint32_t)0x000000F0)        /*!<Number of data units minus 1 that belong to a particular color in the MCU */
#define  JPEG_CONFR6_NB_0                        ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  JPEG_CONFR6_NB_1                        ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  JPEG_CONFR6_NB_2                        ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  JPEG_CONFR6_NB_3                        ((uint32_t)0x00000080)        /*!<Bit 3 */
#define  JPEG_CONFR6_VSF                         ((uint32_t)0x00000F00)        /*!<Vertical sampling factor for component 2 */
#define  JPEG_CONFR6_VSF_0                       ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  JPEG_CONFR6_VSF_1                       ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  JPEG_CONFR6_VSF_2                       ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  JPEG_CONFR6_VSF_3                       ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  JPEG_CONFR6_HSF                         ((uint32_t)0x0000F000)        /*!<Horizontal sampling factor for component 2 */
#define  JPEG_CONFR6_HSF_0                       ((uint32_t)0x00001000)        /*!<Bit 0 */
#define  JPEG_CONFR6_HSF_1                       ((uint32_t)0x00002000)        /*!<Bit 1 */
#define  JPEG_CONFR6_HSF_2                       ((uint32_t)0x00004000)        /*!<Bit 2 */
#define  JPEG_CONFR6_HSF_3                       ((uint32_t)0x00008000)        /*!<Bit 3 */

/********************  Bit definition for CONFR7 register  ********************/
#define  JPEG_CONFR7_HD                          ((uint32_t)0x00000001)        /*!<Selects the Huffman table for encoding the DC coefficients */  
#define  JPEG_CONFR7_HA                          ((uint32_t)0x00000002)        /*!<Selects the Huffman table for encoding the AC coefficients */ 
#define  JPEG_CONFR7_QT                          ((uint32_t)0x0000000C)        /*!<Selects quantization table associated with a color component */
#define  JPEG_CONFR7_QT_0                        ((uint32_t)0x00000004)        /*!<Bit 0 */
#define  JPEG_CONFR7_QT_1                        ((uint32_t)0x00000008)        /*!<Bit 1 */
#define  JPEG_CONFR7_NB                          ((uint32_t)0x000000F0)        /*!<Number of data units minus 1 that belong to a particular color in the MCU */
#define  JPEG_CONFR7_NB_0                        ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  JPEG_CONFR7_NB_1                        ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  JPEG_CONFR7_NB_2                        ((uint32_t)0x00000040)        /*!<Bit 2 */
#define  JPEG_CONFR7_NB_3                        ((uint32_t)0x00000080)        /*!<Bit 3 */
#define  JPEG_CONFR7_VSF                         ((uint32_t)0x00000F00)        /*!<Vertical sampling factor for component 2 */
#define  JPEG_CONFR7_VSF_0                       ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  JPEG_CONFR7_VSF_1                       ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  JPEG_CONFR7_VSF_2                       ((uint32_t)0x00000400)        /*!<Bit 2 */
#define  JPEG_CONFR7_VSF_3                       ((uint32_t)0x00000800)        /*!<Bit 3 */
#define  JPEG_CONFR7_HSF                         ((uint32_t)0x0000F000)        /*!<Horizontal sampling factor for component 2 */
#define  JPEG_CONFR7_HSF_0                       ((uint32_t)0x00001000)        /*!<Bit 0 */
#define  JPEG_CONFR7_HSF_1                       ((uint32_t)0x00002000)        /*!<Bit 1 */
#define  JPEG_CONFR7_HSF_2                       ((uint32_t)0x00004000)        /*!<Bit 2 */
#define  JPEG_CONFR7_HSF_3                       ((uint32_t)0x00008000)        /*!<Bit 3 */

/********************  Bit definition for CR register  ********************/
#define  JPEG_CR_JCEN                            ((uint32_t)0x00000001)        /*!<Enable the JPEG Codec Core */
#define  JPEG_CR_IFTIE                           ((uint32_t)0x00000002)        /*!<Input FIFO Threshold Interrupt Enable */
#define  JPEG_CR_IFNFIE                          ((uint32_t)0x00000004)        /*!<Input FIFO Not Full Interrupt Enable */
#define  JPEG_CR_OFTIE                           ((uint32_t)0x00000008)        /*!<Output FIFO Threshold Interrupt Enable */
#define  JPEG_CR_OFNEIE                          ((uint32_t)0x00000010)        /*!<Output FIFO Not Empty Interrupt Enable */
#define  JPEG_CR_EOCIE                           ((uint32_t)0x00000020)        /*!<End of Conversion Interrupt Enable */
#define  JPEG_CR_HPDIE                           ((uint32_t)0x00000040)        /*!<Header Parsing Done Interrupt Enable */
#define  JPEG_CR_IDMAEN                          ((uint32_t)0x00000800)        /*!<Enable the DMA request generation for the input FIFO */
#define  JPEG_CR_ODMAEN                          ((uint32_t)0x00001000)        /*!<Enable the DMA request generation for the output FIFO */
#define  JPEG_CR_IFF                             ((uint32_t)0x00002000)        /*!<Flush the input FIFO */
#define  JPEG_CR_OFF                             ((uint32_t)0x00004000)        /*!<Flush the output FIFO */

/********************  Bit definition for SR register  ********************/
#define  JPEG_SR_IFTF                            ((uint32_t)0x00000002)        /*!<Input FIFO is not full and is bellow its threshold flag */
#define  JPEG_SR_IFNFF                           ((uint32_t)0x00000004)        /*!<Input FIFO Not Full Flag, a data can be written */
#define  JPEG_SR_OFTF                            ((uint32_t)0x00000008)        /*!<Output FIFO is not empty and has reach its threshold */
#define  JPEG_SR_OFNEF                           ((uint32_t)0x000000010)        /*!<Output FIFO is not empty, a data is available */
#define  JPEG_SR_EOCF                            ((uint32_t)0x000000020)        /*!<JPEG Codec core has finished the encoding or the decoding process and than last data has been sent to the output FIFO */
#define  JPEG_SR_HPDF                            ((uint32_t)0x000000040)        /*!<JPEG Codec has finished the parsing of the headers and the internal registers have been updated */
#define  JPEG_SR_COF                             ((uint32_t)0x000000080)       /*!<JPEG Codec operation on going flag */

/********************  Bit definition for CFR register  ********************/
#define  JPEG_CFR_CEOCF                          ((uint32_t)0x00000010)        /*!<Clear End of Conversion Flag */
#define  JPEG_CFR_CHPDF                          ((uint32_t)0x00000020)        /*!<Clear Header Parsing Done Flag */

/********************  Bit definition for DIR register  ********************/
#define  JPEG_DIR_DATAIN                         ((uint32_t)0xFFFFFFFF)        /*!<Data Input FIFO */

/********************  Bit definition for DOR register  ********************/
#define  JPEG_DOR_DATAOUT                        ((uint32_t)0xFFFFFFFF)        /*!<Data Output FIFO */

/******************************************************************************/
/*                                                                            */
/*                      LCD-TFT Display Controller (LTDC)                     */
/*                                                                            */
/******************************************************************************/

/********************  Bit definition for LTDC_SSCR register  *****************/

#define LTDC_SSCR_VSH                       ((uint32_t)0x000007FFU)              /*!< Vertical Synchronization Height  */
#define LTDC_SSCR_HSW                       ((uint32_t)0x0FFF0000U)              /*!< Horizontal Synchronization Width */

/********************  Bit definition for LTDC_BPCR register  *****************/

#define LTDC_BPCR_AVBP                      ((uint32_t)0x000007FFU)              /*!< Accumulated Vertical Back Porch   */
#define LTDC_BPCR_AHBP                      ((uint32_t)0x0FFF0000U)              /*!< Accumulated Horizontal Back Porch */

/********************  Bit definition for LTDC_AWCR register  *****************/

#define LTDC_AWCR_AAH                       ((uint32_t)0x000007FFU)              /*!< Accumulated Active heigh */
#define LTDC_AWCR_AAW                       ((uint32_t)0x0FFF0000U)              /*!< Accumulated Active Width */

/********************  Bit definition for LTDC_TWCR register  *****************/

#define LTDC_TWCR_TOTALH                    ((uint32_t)0x000007FFU)              /*!< Total Heigh */
#define LTDC_TWCR_TOTALW                    ((uint32_t)0x0FFF0000U)              /*!< Total Width */

/********************  Bit definition for LTDC_GCR register  ******************/

#define LTDC_GCR_LTDCEN                     ((uint32_t)0x00000001U)              /*!< LCD-TFT controller enable bit       */
#define LTDC_GCR_DBW                        ((uint32_t)0x00000070U)              /*!< Dither Blue Width                   */
#define LTDC_GCR_DGW                        ((uint32_t)0x00000700U)              /*!< Dither Green Width                  */
#define LTDC_GCR_DRW                        ((uint32_t)0x00007000U)              /*!< Dither Red Width                    */
#define LTDC_GCR_DEN                        ((uint32_t)0x00010000U)              /*!< Dither Enable                       */
#define LTDC_GCR_PCPOL                      ((uint32_t)0x10000000U)              /*!< Pixel Clock Polarity                */
#define LTDC_GCR_DEPOL                      ((uint32_t)0x20000000U)              /*!< Data Enable Polarity                */
#define LTDC_GCR_VSPOL                      ((uint32_t)0x40000000U)              /*!< Vertical Synchronization Polarity   */
#define LTDC_GCR_HSPOL                      ((uint32_t)0x80000000U)              /*!< Horizontal Synchronization Polarity */


/********************  Bit definition for LTDC_SRCR register  *****************/

#define LTDC_SRCR_IMR                      ((uint32_t)0x00000001U)               /*!< Immediate Reload         */
#define LTDC_SRCR_VBR                      ((uint32_t)0x00000002U)               /*!< Vertical Blanking Reload */

/********************  Bit definition for LTDC_BCCR register  *****************/

#define LTDC_BCCR_BCBLUE                    ((uint32_t)0x000000FFU)              /*!< Background Blue value  */
#define LTDC_BCCR_BCGREEN                   ((uint32_t)0x0000FF00U)              /*!< Background Green value */
#define LTDC_BCCR_BCRED                     ((uint32_t)0x00FF0000U)              /*!< Background Red value   */

/********************  Bit definition for LTDC_IER register  ******************/

#define LTDC_IER_LIE                        ((uint32_t)0x00000001U)              /*!< Line Interrupt Enable            */
#define LTDC_IER_FUIE                       ((uint32_t)0x00000002U)              /*!< FIFO Underrun Interrupt Enable   */
#define LTDC_IER_TERRIE                     ((uint32_t)0x00000004U)              /*!< Transfer Error Interrupt Enable  */
#define LTDC_IER_RRIE                       ((uint32_t)0x00000008U)              /*!< Register Reload interrupt enable */

/********************  Bit definition for LTDC_ISR register  ******************/

#define LTDC_ISR_LIF                        ((uint32_t)0x00000001U)              /*!< Line Interrupt Flag */
#define LTDC_ISR_FUIF                       ((uint32_t)0x00000002U)              /*!< FIFO Underrun Interrupt Flag */
#define LTDC_ISR_TERRIF                     ((uint32_t)0x00000004U)              /*!< Transfer Error Interrupt Flag */
#define LTDC_ISR_RRIF                       ((uint32_t)0x00000008U)              /*!< Register Reload interrupt Flag */

/********************  Bit definition for LTDC_ICR register  ******************/

#define LTDC_ICR_CLIF                       ((uint32_t)0x00000001U)              /*!< Clears the Line Interrupt Flag */
#define LTDC_ICR_CFUIF                      ((uint32_t)0x00000002U)              /*!< Clears the FIFO Underrun Interrupt Flag */
#define LTDC_ICR_CTERRIF                    ((uint32_t)0x00000004U)              /*!< Clears the Transfer Error Interrupt Flag */
#define LTDC_ICR_CRRIF                      ((uint32_t)0x00000008U)              /*!< Clears Register Reload interrupt Flag */

/********************  Bit definition for LTDC_LIPCR register  ****************/

#define LTDC_LIPCR_LIPOS                    ((uint32_t)0x000007FFU)              /*!< Line Interrupt Position */

/********************  Bit definition for LTDC_CPSR register  *****************/

#define LTDC_CPSR_CYPOS                     ((uint32_t)0x0000FFFFU)              /*!< Current Y Position */
#define LTDC_CPSR_CXPOS                     ((uint32_t)0xFFFF0000U)              /*!< Current X Position */

/********************  Bit definition for LTDC_CDSR register  *****************/

#define LTDC_CDSR_VDES                      ((uint32_t)0x00000001U)              /*!< Vertical Data Enable Status       */
#define LTDC_CDSR_HDES                      ((uint32_t)0x00000002U)              /*!< Horizontal Data Enable Status     */
#define LTDC_CDSR_VSYNCS                    ((uint32_t)0x00000004U)              /*!< Vertical Synchronization Status   */
#define LTDC_CDSR_HSYNCS                    ((uint32_t)0x00000008U)              /*!< Horizontal Synchronization Status */

/********************  Bit definition for LTDC_LxCR register  *****************/

#define LTDC_LxCR_LEN                       ((uint32_t)0x00000001U)              /*!< Layer Enable              */
#define LTDC_LxCR_COLKEN                    ((uint32_t)0x00000002U)              /*!< Color Keying Enable       */
#define LTDC_LxCR_CLUTEN                    ((uint32_t)0x00000010U)              /*!< Color Lockup Table Enable */

/********************  Bit definition for LTDC_LxWHPCR register  **************/

#define LTDC_LxWHPCR_WHSTPOS                ((uint32_t)0x00000FFFU)              /*!< Window Horizontal Start Position */
#define LTDC_LxWHPCR_WHSPPOS                ((uint32_t)0xFFFF0000U)              /*!< Window Horizontal Stop Position  */

/********************  Bit definition for LTDC_LxWVPCR register  **************/

#define LTDC_LxWVPCR_WVSTPOS                ((uint32_t)0x00000FFFU)              /*!< Window Vertical Start Position */
#define LTDC_LxWVPCR_WVSPPOS                ((uint32_t)0xFFFF0000U)              /*!< Window Vertical Stop Position  */

/********************  Bit definition for LTDC_LxCKCR register  ***************/

#define LTDC_LxCKCR_CKBLUE                  ((uint32_t)0x000000FFU)              /*!< Color Key Blue value  */
#define LTDC_LxCKCR_CKGREEN                 ((uint32_t)0x0000FF00U)              /*!< Color Key Green value */
#define LTDC_LxCKCR_CKRED                   ((uint32_t)0x00FF0000U)              /*!< Color Key Red value   */

/********************  Bit definition for LTDC_LxPFCR register  ***************/

#define LTDC_LxPFCR_PF                      ((uint32_t)0x00000007U)              /*!< Pixel Format */

/********************  Bit definition for LTDC_LxCACR register  ***************/

#define LTDC_LxCACR_CONSTA                  ((uint32_t)0x000000FFU)              /*!< Constant Alpha */

/********************  Bit definition for LTDC_LxDCCR register  ***************/

#define LTDC_LxDCCR_DCBLUE                  ((uint32_t)0x000000FFU)              /*!< Default Color Blue  */
#define LTDC_LxDCCR_DCGREEN                 ((uint32_t)0x0000FF00U)              /*!< Default Color Green */
#define LTDC_LxDCCR_DCRED                   ((uint32_t)0x00FF0000U)              /*!< Default Color Red   */
#define LTDC_LxDCCR_DCALPHA                 ((uint32_t)0xFF000000U)              /*!< Default Color Alpha */
                                
/********************  Bit definition for LTDC_LxBFCR register  ***************/

#define LTDC_LxBFCR_BF2                     ((uint32_t)0x00000007U)              /*!< Blending Factor 2 */
#define LTDC_LxBFCR_BF1                     ((uint32_t)0x00000700U)              /*!< Blending Factor 1 */

/********************  Bit definition for LTDC_LxCFBAR register  **************/

#define LTDC_LxCFBAR_CFBADD                 ((uint32_t)0xFFFFFFFFU)              /*!< Color Frame Buffer Start Address */

/********************  Bit definition for LTDC_LxCFBLR register  **************/

#define LTDC_LxCFBLR_CFBLL                  ((uint32_t)0x00001FFFU)              /*!< Color Frame Buffer Line Length    */
#define LTDC_LxCFBLR_CFBP                   ((uint32_t)0x1FFF0000U)              /*!< Color Frame Buffer Pitch in bytes */

/********************  Bit definition for LTDC_LxCFBLNR register  *************/

#define LTDC_LxCFBLNR_CFBLNBR               ((uint32_t)0x000007FFU)              /*!< Frame Buffer Line Number */

/********************  Bit definition for LTDC_LxCLUTWR register  *************/

#define LTDC_LxCLUTWR_BLUE                  ((uint32_t)0x000000FFU)              /*!< Blue value   */
#define LTDC_LxCLUTWR_GREEN                 ((uint32_t)0x0000FF00U)              /*!< Green value  */
#define LTDC_LxCLUTWR_RED                   ((uint32_t)0x00FF0000U)              /*!< Red value    */
#define LTDC_LxCLUTWR_CLUTADD               ((uint32_t)0xFF000000U)              /*!< CLUT address */

/******************************************************************************/
/*                                                                            */
/*                                     MDMA                                   */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for MDMA_GISR0 register  ****************/
#define MDMA_GISR0_GIF0                           ((uint32_t)0x00000001)              /*!< Channel 0 global interrupt flag */
#define MDMA_GISR0_GIF1                           ((uint32_t)0x00000002)              /*!< Channel 1 global interrupt flag */
#define MDMA_GISR0_GIF2                           ((uint32_t)0x00000004)              /*!< Channel 2 global interrupt flag */
#define MDMA_GISR0_GIF3                           ((uint32_t)0x00000008)              /*!< Channel 3 global interrupt flag */
#define MDMA_GISR0_GIF4                           ((uint32_t)0x00000010)              /*!< Channel 4 global interrupt flag */
#define MDMA_GISR0_GIF5                           ((uint32_t)0x00000020)              /*!< Channel 5 global interrupt flag */
#define MDMA_GISR0_GIF6                           ((uint32_t)0x00000040)              /*!< Channel 6 global interrupt flag */
#define MDMA_GISR0_GIF7                           ((uint32_t)0x00000080)              /*!< Channel 7 global interrupt flag */
#define MDMA_GISR0_GIF8                           ((uint32_t)0x00000100)              /*!< Channel 8 global interrupt flag */
#define MDMA_GISR0_GIF9                           ((uint32_t)0x00000200)              /*!< Channel 9 global interrupt flag */
#define MDMA_GISR0_GIF10                          ((uint32_t)0x00000400)              /*!< Channel 10 global interrupt flag */
#define MDMA_GISR0_GIF11                          ((uint32_t)0x00000800)              /*!< Channel 11 global interrupt flag */
#define MDMA_GISR0_GIF12                          ((uint32_t)0x00001000)              /*!< Channel 12 global interrupt flag */
#define MDMA_GISR0_GIF13                          ((uint32_t)0x00002000)              /*!< Channel 13 global interrupt flag */
#define MDMA_GISR0_GIF14                          ((uint32_t)0x00004000)              /*!< Channel 14 global interrupt flag */
#define MDMA_GISR0_GIF15                          ((uint32_t)0x00008000)              /*!< Channel 15 global interrupt flag */
#define MDMA_GISR0_GIF16                          ((uint32_t)0x00010000)              /*!< Channel 16 global interrupt flag */
#define MDMA_GISR0_GIF17                          ((uint32_t)0x00020000)              /*!< Channel 17 global interrupt flag */
#define MDMA_GISR0_GIF18                          ((uint32_t)0x00040000)              /*!< Channel 18 global interrupt flag */
#define MDMA_GISR0_GIF19                          ((uint32_t)0x00080000)              /*!< Channel 19 global interrupt flag */
#define MDMA_GISR0_GIF20                          ((uint32_t)0x00100000)              /*!< Channel 20 global interrupt flag */
#define MDMA_GISR0_GIF21                          ((uint32_t)0x00200000)              /*!< Channel 21 global interrupt flag */
#define MDMA_GISR0_GIF22                          ((uint32_t)0x00400000)              /*!< Channel 22 global interrupt flag */
#define MDMA_GISR0_GIF23                          ((uint32_t)0x00800000)              /*!< Channel 23 global interrupt flag */
#define MDMA_GISR0_GIF24                          ((uint32_t)0x01000000)              /*!< Channel 24 global interrupt flag */
#define MDMA_GISR0_GIF25                          ((uint32_t)0x02000000)              /*!< Channel 25 global interrupt flag */
#define MDMA_GISR0_GIF26                          ((uint32_t)0x04000000)              /*!< Channel 26 global interrupt flag */
#define MDMA_GISR0_GIF27                          ((uint32_t)0x08000000)              /*!< Channel 27 global interrupt flag */
#define MDMA_GISR0_GIF28                          ((uint32_t)0x10000000)              /*!< Channel 28 global interrupt flag */
#define MDMA_GISR0_GIF29                          ((uint32_t)0x20000000)              /*!< Channel 29 global interrupt flag */
#define MDMA_GISR0_GIF30                          ((uint32_t)0x40000000)              /*!< Channel 30 global interrupt flag */
#define MDMA_GISR0_GIF31                          ((uint32_t)0x80000000)              /*!< Channel 31 global interrupt flag */

/********************  Bit definition for MDMA_GISR1 register  ****************/
#define MDMA_GISR1_GIF32                          ((uint32_t)0x00000001)              /*!< Channel 32 global interrupt flag */
#define MDMA_GISR1_GIF33                          ((uint32_t)0x00000002)              /*!< Channel 33 global interrupt flag */
#define MDMA_GISR1_GIF34                          ((uint32_t)0x00000004)              /*!< Channel 34 global interrupt flag */
#define MDMA_GISR1_GIF35                          ((uint32_t)0x00000008)              /*!< Channel 35 global interrupt flag */
#define MDMA_GISR1_GIF36                          ((uint32_t)0x00000010)              /*!< Channel 36 global interrupt flag */
#define MDMA_GISR1_GIF37                          ((uint32_t)0x00000020)              /*!< Channel 37 global interrupt flag */
#define MDMA_GISR1_GIF38                          ((uint32_t)0x00000040)              /*!< Channel 38 global interrupt flag */
#define MDMA_GISR1_GIF39                          ((uint32_t)0x00000080)              /*!< Channel 39 global interrupt flag */
#define MDMA_GISR1_GIF40                          ((uint32_t)0x00000100)              /*!< Channel 40 global interrupt flag */
#define MDMA_GISR1_GIF41                          ((uint32_t)0x00000200)              /*!< Channel 41 global interrupt flag */
#define MDMA_GISR1_GIF42                          ((uint32_t)0x00000400)              /*!< Channel 42 global interrupt flag */
#define MDMA_GISR1_GIF43                          ((uint32_t)0x00000800)              /*!< Channel 43 global interrupt flag */
#define MDMA_GISR1_GIF44                          ((uint32_t)0x00001000)              /*!< Channel 44 global interrupt flag */
#define MDMA_GISR1_GIF45                          ((uint32_t)0x00002000)              /*!< Channel 45 global interrupt flag */
#define MDMA_GISR1_GIF46                          ((uint32_t)0x00004000)              /*!< Channel 46 global interrupt flag */
#define MDMA_GISR1_GIF47                          ((uint32_t)0x00008000)              /*!< Channel 47 global interrupt flag */
#define MDMA_GISR1_GIF48                          ((uint32_t)0x00010000)              /*!< Channel 48 global interrupt flag */
#define MDMA_GISR1_GIF49                          ((uint32_t)0x00020000)              /*!< Channel 49 global interrupt flag */
#define MDMA_GISR1_GIF50                          ((uint32_t)0x00040000)              /*!< Channel 50 global interrupt flag */
#define MDMA_GISR1_GIF51                          ((uint32_t)0x00080000)              /*!< Channel 51 global interrupt flag */
#define MDMA_GISR1_GIF52                          ((uint32_t)0x00100000)              /*!< Channel 52 global interrupt flag */
#define MDMA_GISR1_GIF53                          ((uint32_t)0x00200000)              /*!< Channel 53 global interrupt flag */
#define MDMA_GISR1_GIF54                          ((uint32_t)0x00400000)              /*!< Channel 54 global interrupt flag */
#define MDMA_GISR1_GIF55                          ((uint32_t)0x00800000)              /*!< Channel 55 global interrupt flag */
#define MDMA_GISR1_GIF56                          ((uint32_t)0x01000000)              /*!< Channel 56 global interrupt flag */
#define MDMA_GISR1_GIF57                          ((uint32_t)0x02000000)              /*!< Channel 57 global interrupt flag */
#define MDMA_GISR1_GIF58                          ((uint32_t)0x04000000)              /*!< Channel 58 global interrupt flag */
#define MDMA_GISR1_GIF59                          ((uint32_t)0x08000000)              /*!< Channel 59 global interrupt flag */
#define MDMA_GISR1_GIF60                          ((uint32_t)0x10000000)              /*!< Channel 60 global interrupt flag */
#define MDMA_GISR1_GIF61                          ((uint32_t)0x20000000)              /*!< Channel 61 global interrupt flag */
#define MDMA_GISR1_GIF62                          ((uint32_t)0x40000000)              /*!< Channel 62 global interrupt flag */

/********************  Bit definition for MDMA_CxISR register  ****************/
#define MDMA_CISR_TEIF                            ((uint32_t)0x00000001)              /*!< Channel x transfer error interrupt flag */
#define MDMA_CISR_CTCIF                           ((uint32_t)0x00000002)              /*!< Channel x Channel Transfer Complete interrupt flag */
#define MDMA_CISR_BRTIF                           ((uint32_t)0x00000004)              /*!< Channel x block repeat transfer complete interrupt flag */
#define MDMA_CISR_BTIF                            ((uint32_t)0x00000008)              /*!< Channel x block transfer complete interrupt flag */
#define MDMA_CISR_TCIF                            ((uint32_t)0x00000010)              /*!< Channel x buffer transfer complete interrupt flag */
#define MDMA_CISR_CRQA                            ((uint32_t)0x00010000)              /*!< Channel x ReQest Active flag */

/********************  Bit definition for MDMA_CxIFCR register  ****************/
#define MDMA_CIFCR_CTEIF                          ((uint32_t)0x00000001)              /*!< Channel x clear transfer error interrupt flag */
#define MDMA_CIFCR_CCTCIF                         ((uint32_t)0x00000002)              /*!< Clear Channel transfer complete interrupt flag for channel x */
#define MDMA_CIFCR_CBRTIF                         ((uint32_t)0x00000004)              /*!< Channel x clear block repeat transfer complete interrupt flag */
#define MDMA_CIFCR_CBTIF                          ((uint32_t)0x00000008)              /*!< Channel x Clear block transfer complete interrupt flag */
#define MDMA_CIFCR_CLTCIF                         ((uint32_t)0x00000010)              /*!< CLear Transfer buffer Complete Interrupt Flag for channel */

/********************  Bit definition for MDMA_CxESR register  ****************/
#define MDMA_CESR_TEA                            ((uint32_t)0x0000007F)              /*!< Transfer Error Address */
#define MDMA_CESR_TED                            ((uint32_t)0x00000080)              /*!< Transfer Error Direction */
#define MDMA_CESR_TELD                           ((uint32_t)0x00000100)              /*!< Transfer Error Link Data */
#define MDMA_CESR_TEMD                           ((uint32_t)0x00000200)              /*!< Transfer Error Mask Data */
#define MDMA_CESR_ASE                            ((uint32_t)0x00000400)              /*!< Address/Size Error       */
#define MDMA_CESR_BSE                            ((uint32_t)0x00000800)              /*!< Block Size Error         */

/********************  Bit definition for MDMA_CxCR register  ****************/
#define MDMA_CCR_EN                              ((uint32_t)0x00000001)              /*!< Channel enable / flag channel ready when read low */
#define MDMA_CCR_TEIE                            ((uint32_t)0x00000002)              /*!< Transfer error interrupt enable */
#define MDMA_CCR_CTCIE                           ((uint32_t)0x00000004)              /*!< Channel Transfer Complete interrupt enable */
#define MDMA_CCR_BRTIE                           ((uint32_t)0x00000008)              /*!< Block Repeat transfer interrupt enable */
#define MDMA_CCR_BTIE                            ((uint32_t)0x00000010)              /*!< Block Transfer interrupt enable */
#define MDMA_CCR_TCIE                            ((uint32_t)0x00000020)              /*!< buffer Transfer Complete interrupt enable */
#define MDMA_CCR_PL                              ((uint32_t)0x000000C0)              /*!< Priority level */
#define MDMA_CCR_PL_0                            ((uint32_t)0x00000040)              /*!< Bit 0 */
#define MDMA_CCR_PL_1                            ((uint32_t)0x00000080)              /*!< Bit 1 */
#define MDMA_CCR_BEX                             ((uint32_t)0x00001000)              /*!< Byte Endianess eXchange */
#define MDMA_CCR_HEX                             ((uint32_t)0x00002000)              /*!< Half word Endianess eXchange */
#define MDMA_CCR_WEX                             ((uint32_t)0x00004000)              /*!< Word Endianess eXchange */
#define MDMA_CCR_SWRQ                            ((uint32_t)0x00010000)              /*!< SW ReQuest */

/********************  Bit definition for MDMA_CxTCR register  ****************/
#define MDMA_CTCR_SINC                           ((uint32_t)0x00000003)              /*!< Source increment mode */
#define MDMA_CTCR_SINC_0                         ((uint32_t)0x00000001)              /*!< Bit 0 */
#define MDMA_CTCR_SINC_1                         ((uint32_t)0x00000002)              /*!< Bit 1 */
#define MDMA_CTCR_DINC                           ((uint32_t)0x0000000C)              /*!< Source increment mode */
#define MDMA_CTCR_DINC_0                         ((uint32_t)0x00000004)              /*!< Bit 0 */
#define MDMA_CTCR_DINC_1                         ((uint32_t)0x00000008)              /*!< Bit 1 */
#define MDMA_CTCR_SSIZE                          ((uint32_t)0x00000030)              /*!< Source data size */
#define MDMA_CTCR_SSIZE_0                        ((uint32_t)0x00000010)              /*!< Bit 0 */
#define MDMA_CTCR_SSIZE_1                        ((uint32_t)0x00000020)              /*!< Bit 1 */
#define MDMA_CTCR_DSIZE                          ((uint32_t)0x000000C0)              /*!< Destination data size */
#define MDMA_CTCR_DSIZE_0                        ((uint32_t)0x00000040)              /*!< Bit 0 */
#define MDMA_CTCR_DSIZE_1                        ((uint32_t)0x00000080)              /*!< Bit 1 */
#define MDMA_CTCR_SINCOS                         ((uint32_t)0x00000300)              /*!< Source increment offset size */
#define MDMA_CTCR_SINCOS_0                       ((uint32_t)0x00000100)              /*!< Bit 0 */
#define MDMA_CTCR_SINCOS_1                       ((uint32_t)0x00000200)              /*!< Bit 1 */
#define MDMA_CTCR_DINCOS                         ((uint32_t)0x00000C00)              /*!< Destination increment offset size */
#define MDMA_CTCR_DINCOS_0                       ((uint32_t)0x00000400)              /*!< Bit 0 */
#define MDMA_CTCR_DINCOS_1                       ((uint32_t)0x00000800)              /*!< Bit 1 */
#define MDMA_CTCR_SBURST                         ((uint32_t)0x00007000)              /*!< Source burst transfer configuration */
#define MDMA_CTCR_SBURST_0                       ((uint32_t)0x00001000)              /*!< Bit 0 */
#define MDMA_CTCR_SBURST_1                       ((uint32_t)0x00002000)              /*!< Bit 1 */
#define MDMA_CTCR_SBURST_2                       ((uint32_t)0x00003000)              /*!< Bit 2 */
#define MDMA_CTCR_DBURST                         ((uint32_t)0x00038000)              /*!< Destination burst transfer configuration */
#define MDMA_CTCR_DBURST_0                       ((uint32_t)0x00008000)              /*!< Bit 0 */
#define MDMA_CTCR_DBURST_1                       ((uint32_t)0x00010000)              /*!< Bit 1 */
#define MDMA_CTCR_DBURST_2                       ((uint32_t)0x00020000)              /*!< Bit 2 */
#define MDMA_CTCR_TLEN                           ((uint32_t)0x01FC0000)              /*!< buffer Transfer Length (number of bytes - 1) */
#define MDMA_CTCR_PKE                            ((uint32_t)0x2000000)               /*!< PacK Enable */
#define MDMA_CTCR_PAM                            ((uint32_t)0xC000000)               /*!< Padding/Alignement Mode */
#define MDMA_CTCR_PAM_0                          ((uint32_t)0x4000000)               /*!< Bit 0 */
#define MDMA_CTCR_PAM_1                          ((uint32_t)0x8000000)               /*!< Bit 1 */
#define MDMA_CTCR_TRGM                           ((uint32_t)0x30000000)              /*!< Trigger Mode */
#define MDMA_CTCR_TRGM_0                         ((uint32_t)0x10000000)              /*!< Bit 0 */
#define MDMA_CTCR_TRGM_1                         ((uint32_t)0x20000000)              /*!< Bit 1 */
#define MDMA_CTCR_SWRM                           ((uint32_t)0x40000000)              /*!< SW Request Mode */
#define MDMA_CTCR_BWM                            ((uint32_t)0x80000000)              /*!< Bufferable Write Mode */

/********************  Bit definition for MDMA_CxBNDTR register  ****************/
#define MDMA_CBNDTR_BNDT                         ((uint32_t)0x0001FFFF)              /*!< Block Number of data bytes to transfer */
#define MDMA_CBNDTR_BRSUM                        ((uint32_t)0x00040000)              /*!< Block Repeat Source address Update Mode */
#define MDMA_CBNDTR_BRDUM                        ((uint32_t)0x00080000)              /*!< Block Repeat Destination address Update Mode */
#define MDMA_CBNDTR_BRC                          ((uint32_t)0xFFF00000)              /*!< Block Repeat Count */

/********************  Bit definition for MDMA_CxSAR register  ****************/
#define MDMA_CSAR_SAR                         ((uint32_t)0xFFFFFFFF)              /*!< Source address */

/********************  Bit definition for MDMA_CxDAR register  ****************/
#define MDMA_CDAR_DAR                         ((uint32_t)0xFFFFFFFF)              /*!< Destination address */

/********************  Bit definition for MDMA_CxBRUR  ************************/
#define MDMA_CBRUR_SUV                         ((uint32_t)0x0000FFFF)              /*!< Source address Update Value */
#define MDMA_CBRUR_DUV                         ((uint32_t)0xFFFF0000)              /*!< Destination address Update Value */

/********************  Bit definition for MDMA_CxLAR  *************************/
#define MDMA_CLAR_LAR                         ((uint32_t)0xFFFFFFFF)              /*!< Link Address Register */

/********************  Bit definition for MDMA_CxTBR)  ************************/
#define MDMA_CTBR_TSEL                         ((uint32_t)0x000000FF)              /*!< Trigger SELection */
#define MDMA_CTBR_SBUS                         ((uint32_t)0x00010000)              /*!< Source BUS select */
#define MDMA_CTBR_DBUS                         ((uint32_t)0x00020000)              /*!< Destination BUS select */

/********************  Bit definition for MDMA_CxMAR)  ************************/
#define MDMA_CMAR_MAR                          ((uint32_t)0xFFFFFFFF)                  /*!< Mask address */

/********************  Bit definition for MDMA_CxMDR)  ************************/
#define MDMA_CMDR_MDR                          ((uint32_t)0xFFFFFFFF)                  /*!< Mask address */

/******************************************************************************/
/*                                                                            */
/*                         Operational Amplifier (OPAMP)                      */
/*                                                                            */
/******************************************************************************/
/*********************  Bit definition for OPAMPx_CSR register  ***************/
#define OPAMP_CSR_OPAMPxEN            ((uint32_t)0x00000001) /*!< OPAMP enable */
#define OPAMP_CSR_FORCEVP                ((uint32_t)0x00000002)  /*!< Force internal reference on VP */

#define OPAMP_CSR_VPSEL                  ((uint32_t)0x0000000C)  /*!< Non inverted input selection */
#define OPAMP_CSR_VPSEL_0                ((uint32_t)0x00000004) /*!< Bit 0 */
#define OPAMP_CSR_VPSEL_1                ((uint32_t)0x00000008) /*!< Bit 1 */

#define OPAMP_CSR_VMSEL                 ((uint32_t)0x00000060) /*!< Inverting input selection */
#define OPAMP_CSR_VMSEL_0               ((uint32_t)0x00000020) /*!< Bit 0 */
#define OPAMP_CSR_VMSEL_1               ((uint32_t)0x00000040) /*!< Bit 1 */

#define OPAMP_CSR_OPAHSM                ((uint32_t)0x00000100) /*!< Operational amplifier high speed mode */
#define OPAMP_CSR_CALON                 ((uint32_t)0x00000800) /*!< Calibration mode enable */

#define OPAMP_CSR_CALSEL                ((uint32_t)0x00003000) /*!< Calibration selection */
#define OPAMP_CSR_CALSEL_0               ((uint32_t)0x00001000) /*!< Bit 0 */
#define OPAMP_CSR_CALSEL_1               ((uint32_t)0x00002000) /*!< Bit 1 */

#define OPAMP_CSR_PGGAIN                 ((uint32_t)0x0003C000) /*!< Operational amplifier Programmable amplifier gain value */
#define OPAMP_CSR_PGGAIN_0               ((uint32_t)0x00004000) /*!< Bit 0 */
#define OPAMP_CSR_PGGAIN_1               ((uint32_t)0x00008000) /*!< Bit 1 */
#define OPAMP_CSR_PGGAIN_2               ((uint32_t)0x00010000) /*!< Bit 2 */
#define OPAMP_CSR_PGGAIN_3               ((uint32_t)0x00020000) /*!< Bit 3 */

#define OPAMP_CSR_USERTRIM              ((uint32_t)0x00040000) /*!< User trimming enable */
#define OPAMP_CSR_TSTREF                ((uint32_t)0x20000000) /*!< OpAmp calibration reference voltage output control */
#define OPAMP_CSR_CALOUT                ((uint32_t)0x40000000) /*!< Operational amplifier calibration output */

/*********************  Bit definition for OPAMP1_CSR register  ***************/
#define OPAMP1_CSR_OPAEN               ((uint32_t)0x00000001) /*!< Operational amplifier1 Enable */
#define OPAMP1_CSR_FORCEVP              ((uint32_t)0x00000002)  /*!< Force internal reference on VP */

#define OPAMP1_CSR_VPSEL                ((uint32_t)0x0000000C)  /*!< Non inverted input selection */
#define OPAMP1_CSR_VPSEL_0              ((uint32_t)0x00000004) /*!< Bit 0 */
#define OPAMP1_CSR_VPSEL_1              ((uint32_t)0x00000008) /*!< Bit 1 */

#define OPAMP1_CSR_VMSEL                 ((uint32_t)0x00000060) /*!< Inverting input selection */
#define OPAMP1_CSR_VMSEL_0               ((uint32_t)0x00000020) /*!< Bit 0 */
#define OPAMP1_CSR_VMSEL_1               ((uint32_t)0x00000040) /*!< Bit 1 */

#define OPAMP1_CSR_OPAHSM                ((uint32_t)0x00000100) /*!< Operational amplifier1 high speed mode */
#define OPAMP1_CSR_CALON                 ((uint32_t)0x00000800) /*!< Calibration mode enable */

#define OPAMP1_CSR_CALSEL                ((uint32_t)0x00003000) /*!< Calibration selection */
#define OPAMP1_CSR_CALSEL_0             ((uint32_t)0x00001000) /*!< Bit 0 */
#define OPAMP1_CSR_CALSEL_1             ((uint32_t)0x00002000) /*!< Bit 1 */

#define OPAMP1_CSR_PGGAIN               ((uint32_t)0x0003C000) /*!< Operational amplifier1 Programmable amplifier gain value */
#define OPAMP1_CSR_PGGAIN_0             ((uint32_t)0x00004000) /*!< Bit 0 */
#define OPAMP1_CSR_PGGAIN_1             ((uint32_t)0x00008000) /*!< Bit 1 */
#define OPAMP1_CSR_PGGAIN_2             ((uint32_t)0x00010000) /*!< Bit 2 */
#define OPAMP1_CSR_PGGAIN_3             ((uint32_t)0x00020000) /*!< Bit 3 */

#define OPAMP1_CSR_USERTRIM              ((uint32_t)0x00040000) /*!< User trimming enable */
#define OPAMP1_CSR_TSTREF                ((uint32_t)0x20000000) /*!< OpAmp calibration reference voltage output control */
#define OPAMP1_CSR_CALOUT                ((uint32_t)0x40000000) /*!< Operational amplifier1 calibration output */

/*********************  Bit definition for OPAMP2_CSR register  ***************/
#define OPAMP2_CSR_OPAEN               ((uint32_t)0x00000001) /*!< Operational amplifier2 Enable */
#define OPAMP2_CSR_FORCEVP              ((uint32_t)0x00000002)  /*!< Force internal reference on VP */

#define OPAMP2_CSR_VPSEL                ((uint32_t)0x0000000C)  /*!< Non inverted input selection */
#define OPAMP2_CSR_VPSEL_0              ((uint32_t)0x00000004) /*!< Bit 0 */
#define OPAMP2_CSR_VPSEL_1              ((uint32_t)0x00000008) /*!< Bit 1 */

#define OPAMP2_CSR_VMSEL                 ((uint32_t)0x00000060) /*!< Inverting input selection */
#define OPAMP2_CSR_VMSEL_0               ((uint32_t)0x00000020) /*!< Bit 0 */
#define OPAMP2_CSR_VMSEL_1               ((uint32_t)0x00000040) /*!< Bit 1 */

#define OPAMP2_CSR_OPAHSM                ((uint32_t)0x00000100) /*!< Operational amplifier2 high speed mode */
#define OPAMP2_CSR_CALON                 ((uint32_t)0x00000800) /*!< Calibration mode enable */

#define OPAMP2_CSR_CALSEL                ((uint32_t)0x00003000) /*!< Calibration selection */
#define OPAMP2_CSR_CALSEL_0             ((uint32_t)0x00001000) /*!< Bit 0 */
#define OPAMP2_CSR_CALSEL_1             ((uint32_t)0x00002000) /*!< Bit 1 */

#define OPAMP2_CSR_PGGAIN               ((uint32_t)0x0003C000) /*!< Operational amplifier2 Programmable amplifier gain value */
#define OPAMP2_CSR_PGGAIN_0             ((uint32_t)0x00004000) /*!< Bit 0 */
#define OPAMP2_CSR_PGGAIN_1             ((uint32_t)0x00008000) /*!< Bit 1 */
#define OPAMP2_CSR_PGGAIN_2             ((uint32_t)0x00010000) /*!< Bit 2 */
#define OPAMP2_CSR_PGGAIN_3             ((uint32_t)0x00020000) /*!< Bit 3 */

#define OPAMP2_CSR_USERTRIM              ((uint32_t)0x00040000) /*!< User trimming enable */
#define OPAMP2_CSR_TSTREF                ((uint32_t)0x20000000) /*!< OpAmp calibration reference voltage output control */
#define OPAMP2_CSR_CALOUT                ((uint32_t)0x40000000) /*!< Operational amplifier2 calibration output */

/*******************  Bit definition for OPAMP_OTR register  ******************/
#define OPAMP_OTR_TRIMOFFSETN            ((uint32_t)0x0000001F)        /*!< Trim for NMOS differential pairs */
#define OPAMP_OTR_TRIMOFFSETP            ((uint32_t)0x00001F00)        /*!< Trim for PMOS differential pairs */

/*******************  Bit definition for OPAMP1_OTR register  ******************/
#define OPAMP1_OTR_TRIMOFFSETN            ((uint32_t)0x0000001F)        /*!< Trim for NMOS differential pairs */
#define OPAMP1_OTR_TRIMOFFSETP            ((uint32_t)0x00001F00)        /*!< Trim for PMOS differential pairs */

/*******************  Bit definition for OPAMP2_OTR register  ******************/
#define OPAMP2_OTR_TRIMOFFSETN            ((uint32_t)0x0000001F)        /*!< Trim for NMOS differential pairs */
#define OPAMP2_OTR_TRIMOFFSETP            ((uint32_t)0x00001F00)        /*!< Trim for PMOS differential pairs */

/*******************  Bit definition for OPAMP_HSOTR register  ****************/
#define OPAMP_HSOTR_TRIMHSOFFSETN        ((uint32_t)0x0000001F)        /*!< Trim for NMOS differential pairs */
#define OPAMP_HSOTR_TRIMHSOFFSETP        ((uint32_t)0x00001F00)        /*!< Trim for PMOS differential pairs */

/*******************  Bit definition for OPAMP1_HSOTR register  ****************/
#define OPAMP1_HSOTR_TRIMHSOFFSETN        ((uint32_t)0x0000001F)        /*!< Trim for NMOS differential pairs */
#define OPAMP1_HSOTR_TRIMHSOFFSETP        ((uint32_t)0x00001F00)        /*!< Trim for PMOS differential pairs */

/*******************  Bit definition for OPAMP2_HSOTR register  ****************/
#define OPAMP2_HSOTR_TRIMHSOFFSETN        ((uint32_t)0x0000001F)        /*!< Trim for NMOS differential pairs */
#define OPAMP2_HSOTR_TRIMHSOFFSETP        ((uint32_t)0x00001F00)        /*!< Trim for PMOS differential pairs */

/******************************************************************************/
/*                                                                            */
/*                             Power Control                                  */
/*                                                                            */
/******************************************************************************/

/********************  Bit definition for PWR_CR1 register  ********************/
#define  PWR_CR1_ALS               ((uint32_t)0x00060000U)   /*!< Analog Voltage Detector level selection */
#define  PWR_CR1_ALS_0             ((uint32_t)0x00020000U)   /*!< Bit 0 */
#define  PWR_CR1_ALS_1             ((uint32_t)0x00040000U)   /*!< Bit 1 */
#define  PWR_CR1_AVDEN             ((uint32_t)0x00010000U)     /*!< Analog Voltage Detector Enable       */
#define  PWR_CR1_SVOS              ((uint32_t)0x0000C000U)   /*!< System STOP mode Voltage Scaling selection. */
#define  PWR_CR1_SVOS_0            ((uint32_t)0x00004000U)   /*!< Bit 0 */
#define  PWR_CR1_SVOS_1            ((uint32_t)0x00008000U)   /*!< Bit 1 */
#define  PWR_CR1_RLPSN             ((uint32_t)0x00000400U)   /*!< RAM low power mode disable in STOP. */
#define  PWR_CR1_FLPS              ((uint32_t)0x00000200U)   /*!< Flash low power mode in DSTOP */
#define  PWR_CR1_DBP               ((uint32_t)0x00000100U)   /*!< Disable Back-up domain Protection */
#define  PWR_CR1_PLS               ((uint32_t)0x000000E0U)   /*!< Programmable Voltage Detector level selection */
#define  PWR_CR1_PLS_0             ((uint32_t)0x00000020U)   /*!< Bit 0 */
#define  PWR_CR1_PLS_1             ((uint32_t)0x00000040U)   /*!< Bit 1 */
#define  PWR_CR1_PLS_2             ((uint32_t)0x00000080U)   /*!< Bit 2 */
#define  PWR_CR1_PVDEN             ((uint32_t)0x00000010U)   /*!< Programmable Voltage detector enable. */
#define  PWR_CR1_LPDS              ((uint32_t)0x00000001U)   /*!< Low Power Deepsleep with SVOS3 */

/*!< PVD level configuration */
#define  PWR_CR1_PLS_LEV0          ((uint32_t)0x00000000U)   /*!< PVD level 0 */
#define  PWR_CR1_PLS_LEV1          ((uint32_t)0x00000020U)   /*!< PVD level 1 */
#define  PWR_CR1_PLS_LEV2          ((uint32_t)0x00000040U)   /*!< PVD level 2 */
#define  PWR_CR1_PLS_LEV3          ((uint32_t)0x00000060U)   /*!< PVD level 3 */
#define  PWR_CR1_PLS_LEV4          ((uint32_t)0x00000080U)   /*!< PVD level 4 */
#define  PWR_CR1_PLS_LEV5          ((uint32_t)0x000000A0U)   /*!< PVD level 5 */
#define  PWR_CR1_PLS_LEV6          ((uint32_t)0x000000C0U)   /*!< PVD level 6 */
#define  PWR_CR1_PLS_LEV7          ((uint32_t)0x000000E0U)   /*!< PVD level 7 */

/*!< AVD level configuration */
#define  PWR_CR1_ALS_LEV0          ((uint32_t)0x00000000U)   /*!< AVD level 0 */
#define  PWR_CR1_ALS_LEV1          ((uint32_t)0x00020000U)   /*!< AVD level 1 */
#define  PWR_CR1_ALS_LEV2          ((uint32_t)0x00040000U)   /*!< AVD level 2 */
#define  PWR_CR1_ALS_LEV3          ((uint32_t)0x00060000U)   /*!< AVD level 3 */

/********************  Bit definition for PWR_CSR1 register  ********************/
#define  PWR_CSR1_AVDO             ((uint32_t)0x00010000U)   /*!< Analog Voltage Detect Output */
#define  PWR_CSR1_ACTVOS           ((uint32_t)0x0000C000U)   /*!< Current actual used VOS for VDD11 Voltage Scaling */
#define  PWR_CSR1_ACTVOS_0         ((uint32_t)0x00004000U)   /*!< Bit 0 */
#define  PWR_CSR1_ACTVOS_1         ((uint32_t)0x00008000U)   /*!< Bit 1 */
#define  PWR_CSR1_ACTVOSRDY        ((uint32_t)0x00002000U)   /*!< Ready bit for current actual used VOS for VDD11 Voltage Scaling  */
#define  PWR_CSR1_PVDO             ((uint32_t)0x00000010U)   /*!< Programmable Voltage Detect Output */

/********************  Bit definition for PWR_CR2 register  ********************/
#define  PWR_CR2_TEMPH             ((uint32_t)0x00800000U)   /*!< Monitored temperature level above high threshold */
#define  PWR_CR2_TEMPL             ((uint32_t)0x00400000U)   /*!< Monitored temperature level above low threshold */
#define  PWR_CR2_VBATH             ((uint32_t)0x00200000U)   /*!< Monitored VBAT level above high threshold */
#define  PWR_CR2_VBATL             ((uint32_t)0x00100000U)   /*!< Monitored VBAT level above low threshold */
#define  PWR_CR2_BRRDY             ((uint32_t)0x00010000U)   /*!< Backup regulator ready */
#define  PWR_CR2_MONEN             ((uint32_t)0x00000010U)   /*!< VBAT and temperature monitoring enable */
#define  PWR_CR2_BREN              ((uint32_t)0x00000001U)   /*!< Backup regulator enable */

/********************  Bit definition for PWR_CR3 register  ********************/
#define  PWR_CR3_USB33RDY          ((uint32_t)0x04000000U)   /*!< USB supply ready */
#define  PWR_CR3_USBREGEN          ((uint32_t)0x02000000U)   /*!< USB regulator enable */
#define  PWR_CR3_USB33DEN          ((uint32_t)0x01000000U)   /*!< VDD33_USB voltage level detector enable */
#define  PWR_CR3_SDEXTRDY          ((uint32_t)0x00010000U)   /*!< Step Down converter External supply ready */
#define  PWR_CR3_VBRS              ((uint32_t)0x00000200U)   /*!< VBAT charging resistor selection */
#define  PWR_CR3_VBE               ((uint32_t)0x00000100U)   /*!< VBAT charging enable */
#define  PWR_CR3_SCUEN             ((uint32_t)0x00000004U)   /*!< Supply configuration update enable */
#define  PWR_CR3_LDOEN             ((uint32_t)0x00000002U)   /*!< Low Drop Output regulator enable */
#define  PWR_CR3_BYPASS            ((uint32_t)0x00000001U)   /*!< Power Management Unit bypass */

/********************  Bit definition for PWR_CPUCR register  ********************/
#define   PWR_CPUCR_RUN_D3          ((uint32_t)0x00000800U)   /*!< Keep system D3 domain in RUN mode regardless of the CPU sub-systems modes */
#define   PWR_CPUCR_CSSF            ((uint32_t)0x00000200U)   /*!< Clear D1 domain CPU1 STANDBY, STOP and HOLD flags */
#define   PWR_CPUCR_SBF_D2          ((uint32_t)0x00000100U)   /*!< D2 domain DSTANDBY Flag */
#define   PWR_CPUCR_SBF_D1          ((uint32_t)0x00000080U)   /*!< D1 domain DSTANDBY Flag */
#define   PWR_CPUCR_SBF             ((uint32_t)0x00000040U)   /*!< System STANDBY Flag */
#define   PWR_CPUCR_STOPF           ((uint32_t)0x00000020U)   /*!< STOP Flag */
#define   PWR_CPUCR_PDDS_D3         ((uint32_t)0x00000004U)   /*!< System D3 domain Power Down Deepsleep */
#define   PWR_CPUCR_PDDS_D2         ((uint32_t)0x00000002U)   /*!< D2 domain Power Down Deepsleep */
#define   PWR_CPUCR_PDDS_D1         ((uint32_t)0x00000001U)   /*!< D1 domain Power Down Deepsleep selection */


/********************  Bit definition for PWR_D3CR register  ********************/
#define   PWR_D3CR_VOS             ((uint32_t)0x0000C000U)   /*!< Voltage Scaling selection according performance */
#define   PWR_D3CR_VOS_0           ((uint32_t)0x00004000U)   /*!< Bit 0 */
#define   PWR_D3CR_VOS_1           ((uint32_t)0x00008000U)   /*!< Bit 1 */
#define   PWR_D3CR_VOSRDY          ((uint32_t)0x00002000U)   /*!< VOS Ready bit for VDD11 Voltage Scaling output selection */

/********************  Bit definition for PWR_WKUPCR register  ********************/
#define   PWR_WKUPCR_WKUPC6        ((uint32_t)0x00000020U)   /*!< Clear Wakeup Pin Flag 6 */
#define   PWR_WKUPCR_WKUPC5        ((uint32_t)0x00000010U)   /*!< Clear Wakeup Pin Flag 5 */
#define   PWR_WKUPCR_WKUPC4        ((uint32_t)0x00000008U)   /*!< Clear Wakeup Pin Flag 4 */
#define   PWR_WKUPCR_WKUPC3        ((uint32_t)0x00000004U)   /*!< Clear Wakeup Pin Flag 3 */
#define   PWR_WKUPCR_WKUPC2        ((uint32_t)0x00000002U)   /*!< Clear Wakeup Pin Flag 2 */
#define   PWR_WKUPCR_WKUPC1        ((uint32_t)0x00000001U)   /*!< Clear Wakeup Pin Flag 1 */

/********************  Bit definition for PWR_WKUPFR register  ********************/
#define   PWR_WKUPFR_WKUPC6        ((uint32_t)0x00000020U)   /*!< Wakeup Pin Flag 6 */
#define   PWR_WKUPFR_WKUPC5        ((uint32_t)0x00000010U)   /*!< Wakeup Pin Flag 5 */
#define   PWR_WKUPFR_WKUPC4        ((uint32_t)0x00000008U)   /*!< Wakeup Pin Flag 4 */
#define   PWR_WKUPFR_WKUPC3        ((uint32_t)0x00000004U)   /*!< Wakeup Pin Flag 3 */
#define   PWR_WKUPFR_WKUPC2        ((uint32_t)0x00000002U)   /*!< Wakeup Pin Flag 2 */
#define   PWR_WKUPFR_WKUPC1        ((uint32_t)0x00000001U)   /*!< Wakeup Pin Flag 1 */

/********************  Bit definition for PWR_PUCRA register  ********************/
#define   PWR_WKUPEPR_WKUPPUPD6    ((uint32_t)0x0C000000U)   /*!< Wakeup Pin pull configuration for WKUP6 */
#define   PWR_WKUPEPR_WKUPPUPD6_0  ((uint32_t)0x04000000U)   /*!< Bit 0 */
#define   PWR_WKUPEPR_WKUPPUPD6_1  ((uint32_t)0x08000000U)   /*!< Bit 1 */
#define   PWR_WKUPEPR_WKUPPUPD5    ((uint32_t)0x03000000U)   /*!< Wakeup Pin pull configuration for WKUP5 */
#define   PWR_WKUPEPR_WKUPPUPD5_0  ((uint32_t)0x01000000U)   /*!< Bit 0 */
#define   PWR_WKUPEPR_WKUPPUPD5_1  ((uint32_t)0x02000000U)   /*!< Bit 1 */
#define   PWR_WKUPEPR_WKUPPUPD4    ((uint32_t)0x00C00000U)   /*!< Wakeup Pin pull configuration for WKUP4 */
#define   PWR_WKUPEPR_WKUPPUPD4_0  ((uint32_t)0x00400000U)   /*!< Bit 0 */
#define   PWR_WKUPEPR_WKUPPUPD4_1  ((uint32_t)0x00800000U)   /*!< Bit 1 */
#define   PWR_WKUPEPR_WKUPPUPD3    ((uint32_t)0x00300000U)   /*!< Wakeup Pin pull configuration for WKUP3 */
#define   PWR_WKUPEPR_WKUPPUPD3_0  ((uint32_t)0x00100000U)   /*!< Bit 0 */
#define   PWR_WKUPEPR_WKUPPUPD3_1  ((uint32_t)0x00200000U)   /*!< Bit 1 */
#define   PWR_WKUPEPR_WKUPPUPD2    ((uint32_t)0x000C0000U)   /*!< Wakeup Pin pull configuration for WKUP2 */
#define   PWR_WKUPEPR_WKUPPUPD2_0  ((uint32_t)0x00040000U)   /*!< Bit 0 */
#define   PWR_WKUPEPR_WKUPPUPD2_1  ((uint32_t)0x00080000U)   /*!< Bit 1 */
#define   PWR_WKUPEPR_WKUPPUPD1    ((uint32_t)0x00030000U)   /*!< Wakeup Pin pull configuration for WKUP1 */
#define   PWR_WKUPEPR_WKUPPUPD1_0  ((uint32_t)0x00010000U)   /*!< Bit 0 */ 
#define   PWR_WKUPEPR_WKUPPUPD1_1  ((uint32_t)0x00020000U)   /*!< Bit 1 */ 
#define   PWR_WKUPEPR_WKUPP_6      ((uint32_t)0x00002000U)   /*!< Wakeup Pin Polarity for WKUP6 */
#define   PWR_WKUPEPR_WKUPP_5      ((uint32_t)0x00001000U)   /*!< Wakeup Pin Polarity for WKUP5 */
#define   PWR_WKUPEPR_WKUPP_4      ((uint32_t)0x00000800U)   /*!< Wakeup Pin Polarity for WKUP4 */
#define   PWR_WKUPEPR_WKUPP_3      ((uint32_t)0x00000400U)   /*!< Wakeup Pin Polarity for WKUP3 */
#define   PWR_WKUPEPR_WKUPP_2      ((uint32_t)0x00000200U)   /*!< Wakeup Pin Polarity for WKUP2 */
#define   PWR_WKUPEPR_WKUPP_1      ((uint32_t)0x00000100U)   /*!< Wakeup Pin Polarity for WKUP1 */
#define   PWR_WKUPEPR_WKUPEN_6     ((uint32_t)0x00000020U)   /*!< Enable Wakeup Pin WKUP6 */
#define   PWR_WKUPEPR_WKUPEN_5     ((uint32_t)0x00000010U)   /*!< Enable Wakeup Pin WKUP5 */
#define   PWR_WKUPEPR_WKUPEN_4     ((uint32_t)0x00000008U)   /*!< Enable Wakeup Pin WKUP4 */
#define   PWR_WKUPEPR_WKUPEN_3     ((uint32_t)0x00000004U)   /*!< Enable Wakeup Pin WKUP3 */
#define   PWR_WKUPEPR_WKUPEN_2     ((uint32_t)0x00000002U)   /*!< Enable Wakeup Pin WKUP2 */
#define   PWR_WKUPEPR_WKUPEN_1     ((uint32_t)0x00000001U)   /*!< Enable Wakeup Pin WKUP1 */


/******************************************************************************/
/*                                                                            */
/*                         Reset and Clock Control                            */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for RCC_CR register  ********************/
#define  RCC_CR_HSION                        ((uint32_t)0x00000001)       /*!< Internal High Speed clock enable */
#define  RCC_CR_HSIKERON                     ((uint32_t)0x00000002)       /*!< Internal High Speed clock enable for some IPs Kernel */
#define  RCC_CR_HSIRDY                       ((uint32_t)0x00000004)       /*!< Internal High Speed clock ready flag */
#define  RCC_CR_HSIDIV                       ((uint32_t)0x00000018)       /*!< Internal High Speed clock divider selection */
#define  RCC_CR_HSIDIV_1                     ((uint32_t)0x00000000)       /*!< Internal High Speed clock divider selection : Division by 1 */
#define  RCC_CR_HSIDIV_2                     ((uint32_t)0x00000008)       /*!< Internal High Speed clock divider selection : Division by 2 */
#define  RCC_CR_HSIDIV_4                     ((uint32_t)0x00000010)       /*!< Internal High Speed clock divider selection : Division by 4 */
#define  RCC_CR_HSIDIV_8                     ((uint32_t)0x00000018)       /*!< Internal High Speed clock divider selection : Division by 8 */

#define  RCC_CR_HSIDIVF                      ((uint32_t)0x00000020)       /*!< HSI Divider flag */
#define  RCC_CR_CSION                        ((uint32_t)0x00000080)       /*!< The Internal RC 4MHz oscillator clock enable */
#define  RCC_CR_CSIRDY                       ((uint32_t)0x00000100)       /*!< The Internal RC 4MHz oscillator clock ready */
#define  RCC_CR_CSIKERON                     ((uint32_t)0x00000200)       /*!< Internal RC 4MHz oscillator clock enable for some IPs Kernel */
#define  RCC_CR_HSI48ON                      ((uint32_t)0x00001000)       /*!< HSI48 clock enable clock enable  */
#define  RCC_CR_HSI48RDY                     ((uint32_t)0x00002000)       /*!< HSI48 clock ready */


#define  RCC_CR_HSEON                        ((uint32_t)0x00010000)       /*!< External High Speed clock enable */
#define  RCC_CR_HSERDY                       ((uint32_t)0x00020000)       /*!< External High Speed clock ready */
#define  RCC_CR_HSEBYP                       ((uint32_t)0x00040000)       /*!< External High Speed clock Bypass */
#define  RCC_CR_CSSHSEON                     ((uint32_t)0x00080000)       /*!< HSE Clock security System enable */

#define  RCC_CR_PLL1ON                        ((uint32_t)0x01000000)       /*!< System PLL1 clock enable */
#define  RCC_CR_PLL1RDY                       ((uint32_t)0x02000000)       /*!< System PLL1 clock ready */
#define  RCC_CR_PLL2ON                        ((uint32_t)0x04000000)       /*!< System PLL2 clock enable */
#define  RCC_CR_PLL2RDY                       ((uint32_t)0x08000000)       /*!< System PLL2 clock ready */
#define  RCC_CR_PLL3ON                        ((uint32_t)0x10000000)       /*!< System PLL3 clock enable */
#define  RCC_CR_PLL3RDY                       ((uint32_t)0x20000000)       /*!< System PLL3 clock ready */

/*Legacy */
#define  RCC_CR_PLLON                         ((uint32_t)0x01000000)       /*!< System PLL clock enable */
#define  RCC_CR_PLLRDY                        ((uint32_t)0x02000000)       /*!< System PLL clock ready */
/********************  Bit definition for RCC_ICSCR register  ***************/
/*!< HSICAL configuration */
#define  RCC_ICSCR_HSICAL                    ((uint32_t)0x00000FFF)       /*!< MSICAL[11:0] bits */
#define  RCC_ICSCR_HSICAL_0                  ((uint32_t)0x00000001)       /*!<Bit 0 */
#define  RCC_ICSCR_HSICAL_1                  ((uint32_t)0x00000002)       /*!<Bit 1 */
#define  RCC_ICSCR_HSICAL_2                  ((uint32_t)0x00000004)       /*!<Bit 2 */
#define  RCC_ICSCR_HSICAL_3                  ((uint32_t)0x00000008)       /*!<Bit 3 */
#define  RCC_ICSCR_HSICAL_4                  ((uint32_t)0x00000010)       /*!<Bit 4 */
#define  RCC_ICSCR_HSICAL_5                  ((uint32_t)0x00000020)       /*!<Bit 5 */
#define  RCC_ICSCR_HSICAL_6                  ((uint32_t)0x00000040)       /*!<Bit 6 */
#define  RCC_ICSCR_HSICAL_7                  ((uint32_t)0x00000080)       /*!<Bit 7 */
#define  RCC_ICSCR_HSICAL_8                  ((uint32_t)0x00000100)       /*!<Bit 8 */
#define  RCC_ICSCR_HSICAL_9                  ((uint32_t)0x00000200)       /*!<Bit 9 */
#define  RCC_ICSCR_HSICAL_10                 ((uint32_t)0x00000400)       /*!<Bit 10 */
#define  RCC_ICSCR_HSICAL_11                 ((uint32_t)0x00000800)       /*!<Bit 11 */

/*!< HSITRIM configuration */
#define  RCC_ICSCR_HSITRIM                   ((uint32_t)0x0003F000)       /*!< HSITRIM[5:0] bits */
#define  RCC_ICSCR_HSITRIM_0                 ((uint32_t)0x00001000)       /*!<Bit 0 */
#define  RCC_ICSCR_HSITRIM_1                 ((uint32_t)0x00002000)       /*!<Bit 1 */
#define  RCC_ICSCR_HSITRIM_2                 ((uint32_t)0x00004000)       /*!<Bit 2 */
#define  RCC_ICSCR_HSITRIM_3                 ((uint32_t)0x00008000)       /*!<Bit 3 */
#define  RCC_ICSCR_HSITRIM_4                 ((uint32_t)0x00010000)       /*!<Bit 4 */
#define  RCC_ICSCR_HSITRIM_5                 ((uint32_t)0x00020000)       /*!<Bit 5 */


/*!< CSICAL configuration */
#define  RCC_ICSCR_CSICAL                    ((uint32_t)0x03FC0000)       /*!< CSICAL[7:0] bits */
#define  RCC_ICSCR_CSICAL_0                  ((uint32_t)0x00040000)        /*!<Bit 0 */
#define  RCC_ICSCR_CSICAL_1                  ((uint32_t)0x00080000)        /*!<Bit 1 */
#define  RCC_ICSCR_CSICAL_2                  ((uint32_t)0x00100000)        /*!<Bit 2 */
#define  RCC_ICSCR_CSICAL_3                  ((uint32_t)0x00200000)        /*!<Bit 3 */
#define  RCC_ICSCR_CSICAL_4                  ((uint32_t)0x00400000)        /*!<Bit 4 */
#define  RCC_ICSCR_CSICAL_5                  ((uint32_t)0x00800000)        /*!<Bit 5 */
#define  RCC_ICSCR_CSICAL_6                  ((uint32_t)0x01000000)        /*!<Bit 6 */
#define  RCC_ICSCR_CSICAL_7                  ((uint32_t)0x02000000)        /*!<Bit 7 */

/*!< CSITRIM configuration */
#define  RCC_ICSCR_CSITRIM                   ((uint32_t)0x7C000000)       /*!< CSITRIM[4:0] bits */
#define  RCC_ICSCR_CSITRIM_0                 ((uint32_t)0x04000000)        /*!<Bit 0 */
#define  RCC_ICSCR_CSITRIM_1                 ((uint32_t)0x08000000)        /*!<Bit 1 */
#define  RCC_ICSCR_CSITRIM_2                 ((uint32_t)0x10000000)        /*!<Bit 2 */
#define  RCC_ICSCR_CSITRIM_3                 ((uint32_t)0x20000000)        /*!<Bit 3 */
#define  RCC_ICSCR_CSITRIM_4                 ((uint32_t)0x40000000)        /*!<Bit 4 */


/********************  Bit definition for RCC_PLLCFGR register  ***************/

#define  RCC_PLLCFGR_PLL1FRACEN                 ((uint32_t)0x00000001)
#define  RCC_PLLCFGR_PLL1VCOSEL                 ((uint32_t)0x00000002)
#define  RCC_PLLCFGR_PLL1RGE                    ((uint32_t)0x0000000C)
#define  RCC_PLLCFGR_PLL1RGE_0                  ((uint32_t)0x00000000)
#define  RCC_PLLCFGR_PLL1RGE_1                  ((uint32_t)0x00000004)
#define  RCC_PLLCFGR_PLL1RGE_2                  ((uint32_t)0x00000008)
#define  RCC_PLLCFGR_PLL1RGE_3                  ((uint32_t)0x0000000C)

#define  RCC_PLLCFGR_PLL2FRACEN                 ((uint32_t)0x00000010)
#define  RCC_PLLCFGR_PLL2VCOSEL                 ((uint32_t)0x00000020)
#define  RCC_PLLCFGR_PLL2RGE                    ((uint32_t)0x000000C0)
#define  RCC_PLLCFGR_PLL2RGE_0                  ((uint32_t)0x00000000)
#define  RCC_PLLCFGR_PLL2RGE_1                  ((uint32_t)0x00000040)
#define  RCC_PLLCFGR_PLL2RGE_2                  ((uint32_t)0x00000080)
#define  RCC_PLLCFGR_PLL2RGE_3                  ((uint32_t)0x000000C0)

#define  RCC_PLLCFGR_PLL3FRACEN                 ((uint32_t)0x00000100)
#define  RCC_PLLCFGR_PLL3VCOSEL                 ((uint32_t)0x00000200)
#define  RCC_PLLCFGR_PLL3RGE                    ((uint32_t)0x00000C00)
#define  RCC_PLLCFGR_PLL3RGE_0                  ((uint32_t)0x00000000)
#define  RCC_PLLCFGR_PLL3RGE_1                  ((uint32_t)0x00000400)
#define  RCC_PLLCFGR_PLL3RGE_2                  ((uint32_t)0x00000800)
#define  RCC_PLLCFGR_PLL3RGE_3                  ((uint32_t)0x00000C00)

#define  RCC_PLLCFGR_DIVP1EN                    ((uint32_t)0x00010000)
#define  RCC_PLLCFGR_DIVQ1EN                    ((uint32_t)0x00020000)
#define  RCC_PLLCFGR_DIVR1EN                    ((uint32_t)0x00040000)

#define  RCC_PLLCFGR_DIVP2EN                    ((uint32_t)0x00080000)
#define  RCC_PLLCFGR_DIVQ2EN                    ((uint32_t)0x00100000)
#define  RCC_PLLCFGR_DIVR2EN                    ((uint32_t)0x00200000)

#define  RCC_PLLCFGR_DIVP3EN                    ((uint32_t)0x00400000)
#define  RCC_PLLCFGR_DIVQ3EN                    ((uint32_t)0x00800000)
#define  RCC_PLLCFGR_DIVR3EN                    ((uint32_t)0x01000000)


/********************  Bit definition for RCC_PLL1DIVR register  ***************/
#define  RCC_PLL1DIVR_N1                        ((uint32_t)0x000001FF)
#define  RCC_PLL1DIVR_P1                        ((uint32_t)0x0000FE00)
#define  RCC_PLL1DIVR_Q1                        ((uint32_t)0x007F0000)
#define  RCC_PLL1DIVR_R1                        ((uint32_t)0x7F000000)

/********************  Bit definition for RCC_PLL2DIVR register  ***************/
#define  RCC_PLL2DIVR_N2                        ((uint32_t)0x000001FF)
#define  RCC_PLL2DIVR_P2                        ((uint32_t)0x0000FE00)
#define  RCC_PLL2DIVR_Q2                        ((uint32_t)0x007F0000)
#define  RCC_PLL2DIVR_R2                        ((uint32_t)0x7F000000)

/********************  Bit definition for RCC_PLL3DIVR register  ***************/
#define  RCC_PLL3DIVR_N3                        ((uint32_t)0x000001FF)
#define  RCC_PLL3DIVR_P3                        ((uint32_t)0x0000FE00)
#define  RCC_PLL3DIVR_Q3                        ((uint32_t)0x007F0000)
#define  RCC_PLL3DIVR_R3                        ((uint32_t)0x7F000000)

/********************  Bit definition for RCC_PLL1FRACR register  ***************/
#define  RCC_PLL1FRACR_FRACN1                   ((uint32_t)0x0000FFF8)

/********************  Bit definition for RCC_PLL2FRACR register  ***************/
#define  RCC_PLL2FRACR_FRACN2                   ((uint32_t)0x0000FFF8)

/********************  Bit definition for RCC_PLL3FRACR register  ***************/
#define  RCC_PLL3FRACR_FRACN3                   ((uint32_t)0x0000FFF8)


/********************  Bit definition for RCC_PLLCKSELR register  *************/

#define  RCC_PLLCKSELR_PLLSRC                     ((uint32_t)0x00000003)

#define  RCC_PLLCKSELR_PLLSRC_HSI                 ((uint32_t)0x00000000)     /*!< HSI source clock selected */
#define  RCC_PLLCKSELR_PLLSRC_CSI                 ((uint32_t)0x00000001)     /*!< CSI source clock selected */
#define  RCC_PLLCKSELR_PLLSRC_HSE                 ((uint32_t)0x00000002)     /*!< HSE source clock selected */
#define  RCC_PLLCKSELR_PLLSRC_NONE                ((uint32_t)0x00000003)     /*!< No source clock selected  */

#define  RCC_PLLCKSELR_DIVM1                      ((uint32_t)0x000003F0)
#define  RCC_PLLCKSELR_DIVM1_0                    ((uint32_t)0x00000010)
#define  RCC_PLLCKSELR_DIVM1_1                    ((uint32_t)0x00000020)
#define  RCC_PLLCKSELR_DIVM1_2                    ((uint32_t)0x00000040)
#define  RCC_PLLCKSELR_DIVM1_3                    ((uint32_t)0x00000080)
#define  RCC_PLLCKSELR_DIVM1_4                    ((uint32_t)0x00000100)
#define  RCC_PLLCKSELR_DIVM1_5                    ((uint32_t)0x00000200)

#define  RCC_PLLCKSELR_DIVM2                      ((uint32_t)0x0003F000)
#define  RCC_PLLCKSELR_DIVM2_0                    ((uint32_t)0x00001000)
#define  RCC_PLLCKSELR_DIVM2_1                    ((uint32_t)0x00002000)
#define  RCC_PLLCKSELR_DIVM2_2                    ((uint32_t)0x00004000)
#define  RCC_PLLCKSELR_DIVM2_3                    ((uint32_t)0x00008000)
#define  RCC_PLLCKSELR_DIVM2_4                    ((uint32_t)0x00010000)
#define  RCC_PLLCKSELR_DIVM2_5                    ((uint32_t)0x00020000)

#define  RCC_PLLCKSELR_DIVM3                      ((uint32_t)0x03F00000)
#define  RCC_PLLCKSELR_DIVM3_0                    ((uint32_t)0x00100000)
#define  RCC_PLLCKSELR_DIVM3_1                    ((uint32_t)0x00200000)
#define  RCC_PLLCKSELR_DIVM3_2                    ((uint32_t)0x00400000)
#define  RCC_PLLCKSELR_DIVM3_3                    ((uint32_t)0x00800000)
#define  RCC_PLLCKSELR_DIVM3_4                    ((uint32_t)0x01000000)
#define  RCC_PLLCKSELR_DIVM3_5                    ((uint32_t)0x02000000)


/********************  Bit definition for RCC_CFGR register  ******************/
/*!< SW configuration */
#define  RCC_CFGR_SW                          ((uint32_t)0x00000003)       /*!< SW[1:0] bits (System clock Switch) */
#define  RCC_CFGR_SW_0                        ((uint32_t)0x00000001)       /*!<Bit 0 */
#define  RCC_CFGR_SW_1                        ((uint32_t)0x00000002)       /*!<Bit 1 */

#define  RCC_CFGR_SW_HSI                      ((uint32_t)0x00000000)       /*!< HSI selection as system clock */
#define  RCC_CFGR_SW_CSI                      ((uint32_t)0x00000001)       /*!< CSI selection as system clock */
#define  RCC_CFGR_SW_HSE                      ((uint32_t)0x00000002)       /*!< HSE selection as system clock */
#define  RCC_CFGR_SW_PLL1                     ((uint32_t)0x00000003)       /*!< PLL1 selection as system clock */

#define  RCC_CFGR_SWS_HSI                     ((uint32_t)0x00000000)       /*!< HSI used as system clock */
#define  RCC_CFGR_SWS_CSI                     ((uint32_t)0x00000008)       /*!< CSI used as system clock */
#define  RCC_CFGR_SWS_HSE                     ((uint32_t)0x00000010)       /*!< HSE used as system clock */
#define  RCC_CFGR_SWS_PLL1                    ((uint32_t)0x00000018)       /*!< PLL1 used as system clock */

/*!< SWS configuration */
#define  RCC_CFGR_SWS                         ((uint32_t)0x00000018)       /*!< SWS[1:0] bits (System Clock Switch Status) */
#define  RCC_CFGR_SWS_0                       ((uint32_t)0x00000008)       /*!<Bit 0 */
#define  RCC_CFGR_SWS_1                       ((uint32_t)0x00000010)       /*!<Bit 1 */

#define  RCC_CFGR_STOPWUCK                    ((uint32_t)0x00000040)       /*!< Wake Up from stop and CSS backup clock selection */
#define  RCC_CFGR_STOPKERWUCK                 ((uint32_t)0x00000080)       /*!< Kernel Clock Selection after a Wake Up from STOP */

/*!< RTCPRE configuration */
#define  RCC_CFGR_RTCPRE                     ((uint32_t)0x00003F00)
#define  RCC_CFGR_RTCPRE_0                   ((uint32_t)0x00000100)
#define  RCC_CFGR_RTCPRE_1                   ((uint32_t)0x00000200)
#define  RCC_CFGR_RTCPRE_2                   ((uint32_t)0x00000400)
#define  RCC_CFGR_RTCPRE_3                   ((uint32_t)0x00000800)
#define  RCC_CFGR_RTCPRE_4                   ((uint32_t)0x00001000)
#define  RCC_CFGR_RTCPRE_5                   ((uint32_t)0x00002000)

#define  RCC_CFGR_HRTIMSEL                   ((uint32_t)0x00004000)
#define  RCC_CFGR_TIMPRE                     ((uint32_t)0x00008000)


/*!< MCO1 configuration */
#define  RCC_CFGR_MCO1                       ((uint32_t)0x01C00000)
#define  RCC_CFGR_MCO1_0                     ((uint32_t)0x00400000)
#define  RCC_CFGR_MCO1_1                     ((uint32_t)0x00800000)
#define  RCC_CFGR_MCO1_2                     ((uint32_t)0x01000000)

#define  RCC_CFGR_MCO1PRE                    ((uint32_t)0x003C0000)
#define  RCC_CFGR_MCO1PRE_0                  ((uint32_t)0x00040000)
#define  RCC_CFGR_MCO1PRE_1                  ((uint32_t)0x00080000)
#define  RCC_CFGR_MCO1PRE_2                  ((uint32_t)0x00100000)
#define  RCC_CFGR_MCO1PRE_3                  ((uint32_t)0x00200000)

#define  RCC_CFGR_MCO2PRE                    ((uint32_t)0x1E000000)
#define  RCC_CFGR_MCO2PRE_0                  ((uint32_t)0x02000000)
#define  RCC_CFGR_MCO2PRE_1                  ((uint32_t)0x04000000)
#define  RCC_CFGR_MCO2PRE_2                  ((uint32_t)0x08000000)
#define  RCC_CFGR_MCO2PRE_3                  ((uint32_t)0x10000000)

#define  RCC_CFGR_MCO2                       ((uint32_t)0xE0000000)
#define  RCC_CFGR_MCO2_0                     ((uint32_t)0x20000000)
#define  RCC_CFGR_MCO2_1                     ((uint32_t)0x40000000)
#define  RCC_CFGR_MCO2_2                     ((uint32_t)0x80000000)

/********************  Bit definition for RCC_D1CFGR register  ******************/
/*!< D1HPRE configuration */
#define  RCC_D1CFGR_HPRE                        ((uint32_t)0x0000000F)       /*!< HPRE[3:0] bits (Domain1 AHB prescaler) */
#define  RCC_D1CFGR_HPRE_0                      ((uint32_t)0x00000001)       /*!<Bit 0 */
#define  RCC_D1CFGR_HPRE_1                      ((uint32_t)0x00000002)       /*!<Bit 1 */
#define  RCC_D1CFGR_HPRE_2                      ((uint32_t)0x00000004)       /*!<Bit 2 */
#define  RCC_D1CFGR_HPRE_3                      ((uint32_t)0x00000008)       /*!<Bit 3 */


#define  RCC_D1CFGR_HPRE_DIV1                  ((uint32_t)0x00000000)        /*!< Domain1 AHB Clock not divided */
#define  RCC_D1CFGR_HPRE_DIV2                  ((uint32_t)0x00000008)        /*!< Domain1 AHB Clock divided by 2 */
#define  RCC_D1CFGR_HPRE_DIV4                  ((uint32_t)0x00000009)        /*!< Domain1 AHB Clock divided by 4 */
#define  RCC_D1CFGR_HPRE_DIV8                  ((uint32_t)0x0000000A)        /*!< Domain1 AHB Clock divided by 8 */
#define  RCC_D1CFGR_HPRE_DIV16                 ((uint32_t)0x0000000B)        /*!< Domain1 AHB Clock divided by 16 */
#define  RCC_D1CFGR_HPRE_DIV64                 ((uint32_t)0x0000000C)        /*!< Domain1 AHB Clock divided by 64 */
#define  RCC_D1CFGR_HPRE_DIV128                ((uint32_t)0x0000000D)        /*!< Domain1 AHB Clock divided by 128 */
#define  RCC_D1CFGR_HPRE_DIV256                ((uint32_t)0x0000000E)        /*!< Domain1 AHB Clock divided by 256 */
#define  RCC_D1CFGR_HPRE_DIV512                ((uint32_t)0x0000000F)        /*!< Domain1 AHB Clock divided by 512 */

/*!< D1PPRE configuration */
#define  RCC_D1CFGR_D1PPRE                       ((uint32_t)0x00000070)       /*!< D1PRE[2:0] bits (Domain1 APB prescaler) */
#define  RCC_D1CFGR_D1PPRE_0                     ((uint32_t)0x00000010)       /*!<Bit 0 */
#define  RCC_D1CFGR_D1PPRE_1                     ((uint32_t)0x00000020)       /*!<Bit 1 */
#define  RCC_D1CFGR_D1PPRE_2                     ((uint32_t)0x00000040)       /*!<Bit 2 */

#define  RCC_D1CFGR_D1PPRE_DIV1                 ((uint32_t)0x00000000)        /*!< Domain1 APB clock not divided */
#define  RCC_D1CFGR_D1PPRE_DIV2                 ((uint32_t)0x00000040)        /*!< Domain1 APB clock divided by 2 */
#define  RCC_D1CFGR_D1PPRE_DIV4                 ((uint32_t)0x00000050)        /*!< Domain1 APB clock divided by 4 */
#define  RCC_D1CFGR_D1PPRE_DIV8                 ((uint32_t)0x00000060)        /*!< Domain1 APB clock divided by 8 */
#define  RCC_D1CFGR_D1PPRE_DIV16                ((uint32_t)0x00000070)        /*!< Domain1 APB clock divided by 16 */

#define  RCC_D1CFGR_D1CPRE                      ((uint32_t)0x00000F00)       /*!< D1CPRE[2:0] bits (Domain 1 Core prescaler) */
#define  RCC_D1CFGR_D1CPRE_0                    ((uint32_t)0x00000100)       /*!<Bit 0 */
#define  RCC_D1CFGR_D1CPRE_1                    ((uint32_t)0x00000200)       /*!<Bit 1 */
#define  RCC_D1CFGR_D1CPRE_2                    ((uint32_t)0x00000400)       /*!<Bit 2 */
#define  RCC_D1CFGR_D1CPRE_3                    ((uint32_t)0x00000800)       /*!<Bit 3 */

#define  RCC_D1CFGR_D1CPRE_DIV1                 ((uint32_t)0x00000000)        /*!< Domain 1 Core clock  clock not divided */
#define  RCC_D1CFGR_D1CPRE_DIV2                 ((uint32_t)0x00000800)        /*!< Domain 1 Core clock divided by 2 */
#define  RCC_D1CFGR_D1CPRE_DIV4                 ((uint32_t)0x00000900)        /*!< Domain 1 Core clock divided by 4 */
#define  RCC_D1CFGR_D1CPRE_DIV8                 ((uint32_t)0x00000A00)        /*!< Domain 1 Core clock divided by 8 */
#define  RCC_D1CFGR_D1CPRE_DIV16                ((uint32_t)0x00000B00)        /*!< Domain 1 Core clock divided by 16 */
#define  RCC_D1CFGR_D1CPRE_DIV64                ((uint32_t)0x00000C00)        /*!< Domain 1 Core clock divided by 64 */
#define  RCC_D1CFGR_D1CPRE_DIV128               ((uint32_t)0x00000D00)        /*!< Domain 1 Core clock divided by 128 */
#define  RCC_D1CFGR_D1CPRE_DIV256               ((uint32_t)0x00000E00)        /*!< Domain 1 Core clock divided by 256 */
#define  RCC_D1CFGR_D1CPRE_DIV512               ((uint32_t)0x00000F00)        /*!< Domain 1 Core clockdivided by 512 */

/********************  Bit definition for RCC_D2CFGR register  ******************/
/*!< D2PPRE1 configuration */
#define  RCC_D2CFGR_D2PPRE1                       ((uint32_t)0x00000070)        /*!< D1PPRE1[2:0] bits (Domain2 APB1 prescaler) */
#define  RCC_D2CFGR_D2PPRE1_0                     ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  RCC_D2CFGR_D2PPRE1_1                     ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  RCC_D2CFGR_D2PPRE1_2                     ((uint32_t)0x00000040)        /*!<Bit 2 */

#define  RCC_D2CFGR_D2PPRE1_DIV1                  ((uint32_t)0x00000000)        /*!< Domain2 APB1 clock not divided */
#define  RCC_D2CFGR_D2PPRE1_DIV2                  ((uint32_t)0x00000040)        /*!< Domain2 APB1 clock divided by 2 */
#define  RCC_D2CFGR_D2PPRE1_DIV4                  ((uint32_t)0x00000050)        /*!< Domain2 APB1 clock divided by 4 */
#define  RCC_D2CFGR_D2PPRE1_DIV8                  ((uint32_t)0x00000060)        /*!< Domain2 APB1 clock divided by 8 */
#define  RCC_D2CFGR_D2PPRE1_DIV16                 ((uint32_t)0x00000070)        /*!< Domain2 APB1 clock divided by 16 */

/*!< D2PPRE2 configuration */
#define  RCC_D2CFGR_D2PPRE2                       ((uint32_t)0x00000700)        /*!< D2PPRE2[2:0] bits (Domain2 APB2 prescaler) */
#define  RCC_D2CFGR_D2PPRE2_0                     ((uint32_t)0x00000100)        /*!<Bit 0 */
#define  RCC_D2CFGR_D2PPRE2_1                     ((uint32_t)0x00000200)        /*!<Bit 1 */
#define  RCC_D2CFGR_D2PPRE2_2                     ((uint32_t)0x00000400)        /*!<Bit 2 */

#define  RCC_D2CFGR_D2PPRE2_DIV1                  ((uint32_t)0x00000000)        /*!< Domain2 APB2 clock not divided */
#define  RCC_D2CFGR_D2PPRE2_DIV2                  ((uint32_t)0x00000400)        /*!< Domain2 APB2 clock divided by 2 */
#define  RCC_D2CFGR_D2PPRE2_DIV4                  ((uint32_t)0x00000500)        /*!< Domain2 APB2 clock divided by 4 */
#define  RCC_D2CFGR_D2PPRE2_DIV8                  ((uint32_t)0x00000600)        /*!< Domain2 APB2 clock divided by 8 */
#define  RCC_D2CFGR_D2PPRE2_DIV16                 ((uint32_t)0x00000700)        /*!< Domain2 APB2 clock divided by 16 */

/********************  Bit definition for RCC_D3CFGR register  ******************/
/*!< D3PPRE configuration */
#define  RCC_D3CFGR_D3PPRE                       ((uint32_t)0x00000070)        /*!< D3PPRE1[2:0] bits (Domain3 APB1 prescaler) */
#define  RCC_D3CFGR_D3PPRE_0                     ((uint32_t)0x00000010)        /*!<Bit 0 */
#define  RCC_D3CFGR_D3PPRE_1                     ((uint32_t)0x00000020)        /*!<Bit 1 */
#define  RCC_D3CFGR_D3PPRE_2                     ((uint32_t)0x00000040)        /*!<Bit 2 */

#define  RCC_D3CFGR_D3PPRE_DIV1                  ((uint32_t)0x00000000)        /*!< Domain3 APB1 clock not divided */
#define  RCC_D3CFGR_D3PPRE_DIV2                  ((uint32_t)0x00000040)        /*!< Domain3 APB1 clock divided by 2 */
#define  RCC_D3CFGR_D3PPRE_DIV4                  ((uint32_t)0x00000050)        /*!< Domain3 APB1 clock divided by 4 */
#define  RCC_D3CFGR_D3PPRE_DIV8                  ((uint32_t)0x00000060)        /*!< Domain3 APB1 clock divided by 8 */
#define  RCC_D3CFGR_D3PPRE_DIV16                 ((uint32_t)0x00000070)        /*!< Domain3 APB1 clock divided by 16 */

/********************  Bit definition for RCC_CIERR register  ******************/
#define  RCC_CIER_LSIRDYIE                    ((uint32_t)0x00000001)
#define  RCC_CIER_LSERDYIE                    ((uint32_t)0x00000002)
#define  RCC_CIER_MSIRDYIE                    ((uint32_t)0x00000004)
#define  RCC_CIER_HSIRDYIE                    ((uint32_t)0x00000008)
#define  RCC_CIER_HSERDYIE                    ((uint32_t)0x00000010)
#define  RCC_CIER_PLLRDYIE                    ((uint32_t)0x00000020)
#define  RCC_CIER_PLLSAI1RDYIE                ((uint32_t)0x00000040)
#define  RCC_CIER_PLLSAI2RDYIE                ((uint32_t)0x00000080)
#define  RCC_CIER_LSECSSIE                    ((uint32_t)0x00000200)

/********************  Bit definition for RCC_CIFR register  ******************/
#define  RCC_CIER_LSIRDYF                     ((uint32_t)0x00000001)
#define  RCC_CIER_LSERDYF                     ((uint32_t)0x00000002)
#define  RCC_CIER_MSIRDYF                     ((uint32_t)0x00000004)
#define  RCC_CIER_HSIRDYF                     ((uint32_t)0x00000008)
#define  RCC_CIER_HSERDYF                     ((uint32_t)0x00000010)
#define  RCC_CIER_PLLRDYF                     ((uint32_t)0x00000020)
#define  RCC_CIER_PLLSAI1RDYF                 ((uint32_t)0x00000040)
#define  RCC_CIER_PLLSAI2RDYF                 ((uint32_t)0x00000080)
#define  RCC_CIER_HSECSSF                     ((uint32_t)0x00000100)
#define  RCC_CIER_LSECSSF                     ((uint32_t)0x00000200)

/********************  Bit definition for RCC_CICR register  ******************/
#define  RCC_CIER_LSIRDYC                     ((uint32_t)0x00000001)
#define  RCC_CIER_LSERDYC                     ((uint32_t)0x00000002)
#define  RCC_CIER_MSIRDYC                     ((uint32_t)0x00000004)
#define  RCC_CIER_HSIRDYC                     ((uint32_t)0x00000008)
#define  RCC_CIER_HSERDYC                     ((uint32_t)0x00000010)
#define  RCC_CIER_PLLRDYC                     ((uint32_t)0x00000020)
#define  RCC_CIER_PLLSAI1RDYC                 ((uint32_t)0x00000040)
#define  RCC_CIER_PLLSAI2RDYC                 ((uint32_t)0x00000080)
#define  RCC_CIER_HSECSSC                     ((uint32_t)0x00000100)
#define  RCC_CIER_CSSC                        ((uint32_t)0x00000200)

/********************  Bit definition for RCC_D1CCIPR register  ***************/
#define  RCC_D1CCIPR_FMCSEL                  ((uint32_t)0x00000003)
#define  RCC_D1CCIPR_FMCSEL_0                ((uint32_t)0x00000001)
#define  RCC_D1CCIPR_FMCSEL_1                ((uint32_t)0x00000002)
#define  RCC_D1CCIPR_QSPISEL                 ((uint32_t)0x00000030)
#define  RCC_D1CCIPR_QSPISEL_0               ((uint32_t)0x00000010)
#define  RCC_D1CCIPR_QSPISEL_1               ((uint32_t)0x00000020)
#define  RCC_D1CCIPR_SDMMCSEL                ((uint32_t)0x00010000)
#define  RCC_D1CCIPR_CKPERSEL                ((uint32_t)0x30000000)
#define  RCC_D1CCIPR_CKPERSEL_0              ((uint32_t)0x10000000)
#define  RCC_D1CCIPR_CKPERSEL_1              ((uint32_t)0x20000000)

/********************  Bit definition for RCC_D2CCIP1R register  ***************/
#define  RCC_D2CCIP1R_SAI1SEL                  ((uint32_t)0x00000007)
#define  RCC_D2CCIP1R_SAI1SEL_0                ((uint32_t)0x00000001)
#define  RCC_D2CCIP1R_SAI1SEL_1                ((uint32_t)0x00000002)
#define  RCC_D2CCIP1R_SAI1SEL_2                ((uint32_t)0x00000004)

#define  RCC_D2CCIP1R_SAI23SEL                 ((uint32_t)0x000001C0)
#define  RCC_D2CCIP1R_SAI23SEL_0               ((uint32_t)0x00000040)
#define  RCC_D2CCIP1R_SAI23SEL_1               ((uint32_t)0x00000080)
#define  RCC_D2CCIP1R_SAI23SEL_2               ((uint32_t)0x00000100)

#define  RCC_D2CCIP1R_SPI123SEL                ((uint32_t)0x00007000)
#define  RCC_D2CCIP1R_SPI123SEL_0              ((uint32_t)0x00001000)
#define  RCC_D2CCIP1R_SPI123SEL_1              ((uint32_t)0x00002000)
#define  RCC_D2CCIP1R_SPI123SEL_2              ((uint32_t)0x00004000)

#define  RCC_D2CCIP1R_SPI45SEL                 ((uint32_t)0x00070000)
#define  RCC_D2CCIP1R_SPI45SEL_0               ((uint32_t)0x00010000)
#define  RCC_D2CCIP1R_SPI45SEL_1               ((uint32_t)0x00020000)
#define  RCC_D2CCIP1R_SPI45SEL_2               ((uint32_t)0x00040000)

#define  RCC_D2CCIP1R_SPDIFSEL                 ((uint32_t)0x00300000)
#define  RCC_D2CCIP1R_SPDIFSEL_0               ((uint32_t)0x00100000)
#define  RCC_D2CCIP1R_SPDIFSEL_1               ((uint32_t)0x00200000)

#define  RCC_D2CCIP1R_DFSDM1SEL                ((uint32_t)0x01000000)

#define  RCC_D2CCIP1R_FDCANSEL                 ((uint32_t)0x30000000)
#define  RCC_D2CCIP1R_FDCANSEL_0               ((uint32_t)0x10000000)
#define  RCC_D2CCIP1R_FDCANSEL_1               ((uint32_t)0x20000000)

#define  RCC_D2CCIP1R_FDCANSEL                 ((uint32_t)0x30000000)
#define  RCC_D2CCIP1R_SWPSEL                  ((uint32_t)0x80000000)

/********************  Bit definition for RCC_D2CCIP2R register  ***************/
#define  RCC_D2CCIP2R_USART16SEL               ((uint32_t)0x00000038)
#define  RCC_D2CCIP2R_USART16SEL_0             ((uint32_t)0x00000008)
#define  RCC_D2CCIP2R_USART16SEL_1             ((uint32_t)0x00000010)
#define  RCC_D2CCIP2R_USART16SEL_2             ((uint32_t)0x00000020)

#define  RCC_D2CCIP2R_USART28SEL               ((uint32_t)0x00000007)
#define  RCC_D2CCIP2R_USART28SEL_0             ((uint32_t)0x00000001)
#define  RCC_D2CCIP2R_USART28SEL_1             ((uint32_t)0x00000002)
#define  RCC_D2CCIP2R_USART28SEL_2             ((uint32_t)0x00000004)

#define  RCC_D2CCIP2R_RNGSEL                   ((uint32_t)0x00000300)
#define  RCC_D2CCIP2R_RNGSEL_0                 ((uint32_t)0x00000100)
#define  RCC_D2CCIP2R_RNGSEL_1                 ((uint32_t)0x00000200)

#define  RCC_D2CCIP2R_I2C123SEL                ((uint32_t)0x00003000)
#define  RCC_D2CCIP2R_I2C123SEL_0              ((uint32_t)0x00001000)
#define  RCC_D2CCIP2R_I2C123SEL_1              ((uint32_t)0x00002000)

#define  RCC_D2CCIP2R_USBSEL                   ((uint32_t)0x00300000)
#define  RCC_D2CCIP2R_USBSEL_0                 ((uint32_t)0x00100000)
#define  RCC_D2CCIP2R_USBSEL_1                 ((uint32_t)0x00200000)

#define  RCC_D2CCIP2R_CECSEL                   ((uint32_t)0x00C00000)
#define  RCC_D2CCIP2R_CECSEL_0                 ((uint32_t)0x00400000)
#define  RCC_D2CCIP2R_CECSEL_1                 ((uint32_t)0x00800000)

#define  RCC_D2CCIP2R_LPTIM1SEL                ((uint32_t)0x70000000)
#define  RCC_D2CCIP2R_LPTIM1SEL_0              ((uint32_t)0x10000000)
#define  RCC_D2CCIP2R_LPTIM1SEL_1              ((uint32_t)0x20000000)
#define  RCC_D2CCIP2R_LPTIM1SEL_2              ((uint32_t)0x40000000)

/********************  Bit definition for RCC_D3CCIPR register  ***************/
#define  RCC_D3CCIPR_LPUART1SEL               ((uint32_t)0x00000007)
#define  RCC_D3CCIPR_LPUART1SEL_0             ((uint32_t)0x00000001)
#define  RCC_D3CCIPR_LPUART1SEL_1             ((uint32_t)0x00000002)
#define  RCC_D3CCIPR_LPUART1SEL_2             ((uint32_t)0x00000004)

#define  RCC_D3CCIPR_I2C4SEL                  ((uint32_t)0x00000300)
#define  RCC_D3CCIPR_I2C4SEL_0                ((uint32_t)0x00000100)
#define  RCC_D3CCIPR_I2C4SEL_1                ((uint32_t)0x00000200)

#define  RCC_D3CCIPR_LPTIM2SEL                ((uint32_t)0x00001C00)
#define  RCC_D3CCIPR_LPTIM2SEL_0              ((uint32_t)0x00000400)
#define  RCC_D3CCIPR_LPTIM2SEL_1              ((uint32_t)0x00000800)
#define  RCC_D3CCIPR_LPTIM2SEL_2              ((uint32_t)0x00001000)

#define  RCC_D3CCIPR_LPTIM345SEL              ((uint32_t)0x0000E000)
#define  RCC_D3CCIPR_LPTIM345SEL_0            ((uint32_t)0x00002000)
#define  RCC_D3CCIPR_LPTIM345SEL_1            ((uint32_t)0x00004000)
#define  RCC_D3CCIPR_LPTIM345SEL_2            ((uint32_t)0x00008000)

#define  RCC_D3CCIPR_SAI4ASEL                  ((uint32_t)0x00E00000)
#define  RCC_D3CCIPR_SAI4ASEL_0                ((uint32_t)0x00200000)
#define  RCC_D3CCIPR_SAI4ASEL_1                ((uint32_t)0x00400000)
#define  RCC_D3CCIPR_SAI4ASEL_2                ((uint32_t)0x00800000)

#define  RCC_D3CCIPR_SAI4BSEL                  ((uint32_t)0x07000000)
#define  RCC_D3CCIPR_SAI4BSEL_0                ((uint32_t)0x01000000)
#define  RCC_D3CCIPR_SAI4BSEL_1                ((uint32_t)0x02000000)
#define  RCC_D3CCIPR_SAI4BSEL_2                ((uint32_t)0x04000000)

#define  RCC_D3CCIPR_ADCSEL                    ((uint32_t)0x00030000)
#define  RCC_D3CCIPR_ADCSEL_0                  ((uint32_t)0x00010000)
#define  RCC_D3CCIPR_ADCSEL_1                  ((uint32_t)0x00020000)

#define  RCC_D3CCIPR_SPI6SEL                   ((uint32_t)0x70000000)
#define  RCC_D3CCIPR_SPI6SEL_0                 ((uint32_t)0x10000000)
#define  RCC_D3CCIPR_SPI6SEL_1                 ((uint32_t)0x20000000)
#define  RCC_D3CCIPR_SPI6SEL_2                 ((uint32_t)0x40000000)

/********************  Bit definition for RCC_D1AHB1ENR register  **************/
#define  RCC_D1AHB1ENR_MDMAEN                 ((uint32_t)0x00000001)
#define  RCC_D1AHB1ENR_DMA2DEN                 ((uint32_t)0x00000010)
#define  RCC_D1AHB1ENR_JPGDECEN                ((uint32_t)0x00000020)
#define  RCC_D1AHB1ENR_FLASHEN                 ((uint32_t)0x00000100)
#define  RCC_D1AHB1ENR_FMCEN                   ((uint32_t)0x00001000)
#define  RCC_D1AHB1ENR_QSPIEN                  ((uint32_t)0x00004000)
#define  RCC_D1AHB1ENR_SDMMC1EN                ((uint32_t)0x00010000)
#define  RCC_D1AHB1ENR_DTCM1EN                 ((uint32_t)0x10000000)
#define  RCC_D1AHB1ENR_DTCM2EN                 ((uint32_t)0x20000000)
#define  RCC_D1AHB1ENR_ITCMEN                  ((uint32_t)0x40000000)
#define  RCC_D1AHB1ENR_D1SRAM1EN               ((uint32_t)0x80000000)


/********************  Bit definition for RCC_D2AHB1ENR register  ***************/
#define  RCC_D2AHB1ENR_DMA1EN                    ((uint32_t)0x00000001)
#define  RCC_D2AHB1ENR_DMA2EN                    ((uint32_t)0x00000002)
#define  RCC_D2AHB1ENR_ADC12EN                   ((uint32_t)0x00000020)
#define  RCC_D2AHB1ENR_ARTEN                     ((uint32_t)0x00004000)
#define  RCC_D2AHB1ENR_ETH1MACEN                 ((uint32_t)0x00008000)
#define  RCC_D2AHB1ENR_ETH1TXEN                  ((uint32_t)0x00010000)
#define  RCC_D2AHB1ENR_ETH1RXEN                  ((uint32_t)0x00020000)
#define  RCC_D2AHB1ENR_ETH1PTPEN                 ((uint32_t)0x00040000)
#define  RCC_D2AHB1ENR_USB1OTGHSEN               ((uint32_t)0x02000000)
#define  RCC_D2AHB1ENR_USB1OTGHSULPIEN           ((uint32_t)0x04000000)
#define  RCC_D2AHB1ENR_USB2OTGHSEN               ((uint32_t)0x08000000)
#define  RCC_D2AHB1ENR_USB2OTGHSULPIEN           ((uint32_t)0x10000000)

/********************  Bit definition for RCC_D2AHB2ENR register  ***************/
#define  RCC_D2AHB2ENR_DCMIEN                   ((uint32_t)0x00000001)
#define  RCC_D2AHB2ENR_CRYPEN                   ((uint32_t)0x00000010)
#define  RCC_D2AHB2ENR_HASHEN                   ((uint32_t)0x00000020)
#define  RCC_D2AHB2ENR_RNGEN                    ((uint32_t)0x00000040)
#define  RCC_D2AHB2ENR_SDMMC2EN                 ((uint32_t)0x00000200)
#define  RCC_D2AHB2ENR_D2SRAM1EN                ((uint32_t)0x40000000)
#define  RCC_D2AHB2ENR_D2SRAM2EN                ((uint32_t)0x40000000)
#define  RCC_D2AHB2ENR_D2SRAM3EN                ((uint32_t)0x80000000)


/********************  Bit definition for D3AHB1ENR register  ******************/
#define  RCC_D3AHB1ENR_GPIOAEN                 ((uint32_t)0x00000001)
#define  RCC_D3AHB1ENR_GPIOBEN                 ((uint32_t)0x00000002)
#define  RCC_D3AHB1ENR_GPIOCEN                 ((uint32_t)0x00000004)
#define  RCC_D3AHB1ENR_GPIODEN                 ((uint32_t)0x00000008)
#define  RCC_D3AHB1ENR_GPIOEEN                 ((uint32_t)0x00000010)
#define  RCC_D3AHB1ENR_GPIOFEN                 ((uint32_t)0x00000020)
#define  RCC_D3AHB1ENR_GPIOGEN                 ((uint32_t)0x00000040)
#define  RCC_D3AHB1ENR_GPIOHEN                 ((uint32_t)0x00000080)
#define  RCC_D3AHB1ENR_GPIOIEN                 ((uint32_t)0x00000100)
#define  RCC_D3AHB1ENR_GPIOJEN                 ((uint32_t)0x00000200)
#define  RCC_D3AHB1ENR_GPIOKEN                 ((uint32_t)0x00000400)
#define  RCC_D3AHB1ENR_PWREN                   ((uint32_t)0x00040000)
#define  RCC_D3AHB1ENR_CRCEN                   ((uint32_t)0x00080000)
#define  RCC_D3AHB1ENR_BDMAEN                  ((uint32_t)0x00200000)
#define  RCC_D3AHB1ENR_ADC3EN                  ((uint32_t)0x01000000)
#define  RCC_D3AHB1ENR_HSEMEN                  ((uint32_t)0x02000000)
#define  RCC_D3AHB1ENR_BKPRAMEN                ((uint32_t)0x10000000)
#define  RCC_D3AHB1ENR_D3SRAM1EN               ((uint32_t)0x20000000)

/********************  Bit definition for D1APB1ENR register  ******************/

#define  RCC_D1APB1ENR_LTDCEN                 ((uint32_t)0x00000008)
#define  RCC_D1APB1ENR_WWDG1EN                ((uint32_t)0x00000040)

/********************  Bit definition for D2APB1LENR register  ******************/

#define  RCC_D2APB1LENR_TIM2EN                 ((uint32_t)0x00000001)
#define  RCC_D2APB1LENR_TIM3EN                 ((uint32_t)0x00000002)
#define  RCC_D2APB1LENR_TIM4EN                 ((uint32_t)0x00000004)
#define  RCC_D2APB1LENR_TIM5EN                 ((uint32_t)0x00000008)
#define  RCC_D2APB1LENR_TIM6EN                 ((uint32_t)0x00000010)
#define  RCC_D2APB1LENR_TIM7EN                 ((uint32_t)0x00000020)
#define  RCC_D2APB1LENR_TIM12EN                ((uint32_t)0x00000040)
#define  RCC_D2APB1LENR_TIM13EN                ((uint32_t)0x00000080)
#define  RCC_D2APB1LENR_TIM14EN                ((uint32_t)0x00000100)
#define  RCC_D2APB1LENR_LPTIM1EN               ((uint32_t)0x00000200)


#define  RCC_D2APB1LENR_SPI2EN                 ((uint32_t)0x00004000)
#define  RCC_D2APB1LENR_SPI3EN                 ((uint32_t)0x00008000)
#define  RCC_D2APB1LENR_SPDIFRXEN              ((uint32_t)0x00010000)
#define  RCC_D2APB1LENR_USART2EN               ((uint32_t)0x00020000)
#define  RCC_D2APB1LENR_USART3EN               ((uint32_t)0x00040000)
#define  RCC_D2APB1LENR_UART4EN                ((uint32_t)0x00080000)
#define  RCC_D2APB1LENR_UART5EN                ((uint32_t)0x00100000)
#define  RCC_D2APB1LENR_I2C1EN                 ((uint32_t)0x00200000)
#define  RCC_D2APB1LENR_I2C2EN                 ((uint32_t)0x00400000)
#define  RCC_D2APB1LENR_I2C3EN                 ((uint32_t)0x00800000)
#define  RCC_D2APB1LENR_CECEN                  ((uint32_t)0x08000000)
#define  RCC_D2APB1LENR_DAC12EN                ((uint32_t)0x20000000)
#define  RCC_D2APB1LENR_UART7EN               ((uint32_t)0x40000000)
#define  RCC_D2APB1LENR_UART8EN               ((uint32_t)0x80000000)

/********************  Bit definition for D2APB1HENR register  ******************/
#define  RCC_D2APB1HENR_CRSEN                  ((uint32_t)0x00000002)
#define  RCC_D2APB1HENR_SWPMIEN                ((uint32_t)0x00000004)
#define  RCC_D2APB1HENR_OPAMPEN                ((uint32_t)0x00000010)
#define  RCC_D2APB1HENR_MDIOSEN                ((uint32_t)0x00000020)
#define  RCC_D2APB1HENR_FDCANEN                ((uint32_t)0x00000100)

/********************  Bit definition for D2APB2ENR register  ******************/
#define  RCC_D2APB2ENR_TIM1EN                  ((uint32_t)0x00000001)
#define  RCC_D2APB2ENR_TIM8EN                  ((uint32_t)0x00000002)
#define  RCC_D2APB2ENR_USART1EN                ((uint32_t)0x00000010)
#define  RCC_D2APB2ENR_USART6EN                ((uint32_t)0x00000020)
#define  RCC_D2APB2ENR_SPI1EN                  ((uint32_t)0x00001000)
#define  RCC_D2APB2ENR_SPI4EN                  ((uint32_t)0x00002000)
#define  RCC_D2APB2ENR_TIM15EN                 ((uint32_t)0x00010000)
#define  RCC_D2APB2ENR_TIM16EN                 ((uint32_t)0x00020000)
#define  RCC_D2APB2ENR_TIM17EN                 ((uint32_t)0x00040000)
#define  RCC_D2APB2ENR_SPI5EN                  ((uint32_t)0x00100000)
#define  RCC_D2APB2ENR_SAI1EN                  ((uint32_t)0x00400000)
#define  RCC_D2APB2ENR_SAI2EN                  ((uint32_t)0x00800000)
#define  RCC_D2APB2ENR_SAI3EN                  ((uint32_t)0x01000000)
#define  RCC_D2APB2ENR_DFSDM1EN                ((uint32_t)0x10000000)
#define  RCC_D2APB2ENR_HRTIMEN                 ((uint32_t)0x20000000)

/********************  Bit definition for D3APB1ENR register  ******************/
#define  RCC_D3APB1ENR_SYSCFGEN                ((uint32_t)0x00000002)
#define  RCC_D3APB1ENR_LPUART1EN               ((uint32_t)0x00000008)
#define  RCC_D3APB1ENR_SPI6EN                  ((uint32_t)0x00000020)
#define  RCC_D3APB1ENR_I2C4EN                  ((uint32_t)0x00000080)
#define  RCC_D3APB1ENR_LPTIM2EN                ((uint32_t)0x00000200)
#define  RCC_D3APB1ENR_LPTIM3EN                ((uint32_t)0x00000400)
#define  RCC_D3APB1ENR_LPTIM4EN                ((uint32_t)0x00000800)
#define  RCC_D3APB1ENR_LPTIM5EN                ((uint32_t)0x00001000)
#define  RCC_D3APB1ENR_COMP12EN                ((uint32_t)0x00004000)
#define  RCC_D3APB1ENR_SAI4EN                  ((uint32_t)0x00200000)


/********************  Bit definition for RCC_D1AHB1RSTR register  ***************/
#define  RCC_D1AHB1RSTR_MDMARST                 ((uint32_t)0x00000001)
#define  RCC_D1AHB1RSTR_DMA2DRST                 ((uint32_t)0x00000010)
#define  RCC_D1AHB1RSTR_JPGDECRST                ((uint32_t)0x00000020)
#define  RCC_D1AHB1RSTR_FMCRST                   ((uint32_t)0x00001000)
#define  RCC_D1AHB1RSTR_QSPIRST                  ((uint32_t)0x00004000)
#define  RCC_D1AHB1RSTR_SDMMC1RST                ((uint32_t)0x00010000)
#define  RCC_D1AHB1RSTR_CPURST                   ((uint32_t)0x80000000)


/********************  Bit definition for RCC_D2AHB1RSTR register  ***************/
#define  RCC_D2AHB1RSTR_DMA1RST                    ((uint32_t)0x00000001)
#define  RCC_D2AHB1RSTR_DMA2RST                    ((uint32_t)0x00000002)
#define  RCC_D2AHB1RSTR_DMAMUX1RST                 ((uint32_t)0x00000004)
#define  RCC_D2AHB1RSTR_ADC12RST                   ((uint32_t)0x00000020)
#define  RCC_D2AHB1RSTR_ARTRST                     ((uint32_t)0x00004000)
#define  RCC_D2AHB1RSTR_ETH1MACRST                 ((uint32_t)0x00008000)
#define  RCC_D2AHB1RSTR_USB1OTGHSRST               ((uint32_t)0x02000000)
#define  RCC_D2AHB1RSTR_USB2OTGHSRST               ((uint32_t)0x08000000)
/********************  Bit definition for RCC_D2AHB2RSTR register  ***************/
#define  RCC_D2AHB2RSTR_DCMIRST                   ((uint32_t)0x00000001)
#define  RCC_D2AHB2RSTR_CRYPRST                  ((uint32_t)0x00000010)
#define  RCC_D2AHB2RSTR_HASHRST                   ((uint32_t)0x00000020)
#define  RCC_D2AHB2RSTR_RNGRST                    ((uint32_t)0x00000040)
#define  RCC_D2AHB2RSTR_SDMMC2RST                 ((uint32_t)0x00000200)

/********************  Bit definition for D3AHB1RSTR register  ******************/
#define  RCC_D3AHB1RSTR_GPIOARST                 ((uint32_t)0x00000001)
#define  RCC_D3AHB1RSTR_GPIOBRST                 ((uint32_t)0x00000002)
#define  RCC_D3AHB1RSTR_GPIOCRST                 ((uint32_t)0x00000004)
#define  RCC_D3AHB1RSTR_GPIODRST                 ((uint32_t)0x00000008)
#define  RCC_D3AHB1RSTR_GPIOERST                 ((uint32_t)0x00000010)
#define  RCC_D3AHB1RSTR_GPIOFRST                 ((uint32_t)0x00000020)
#define  RCC_D3AHB1RSTR_GPIOGRST                 ((uint32_t)0x00000040)
#define  RCC_D3AHB1RSTR_GPIOHRST                 ((uint32_t)0x00000080)
#define  RCC_D3AHB1RSTR_GPIOIRST                 ((uint32_t)0x00000100)
#define  RCC_D3AHB1RSTR_GPIOJRST                 ((uint32_t)0x00000200)
#define  RCC_D3AHB1RSTR_GPIOKRST                 ((uint32_t)0x00000400)
#define  RCC_D3AHB1RSTR_PWRRST                   ((uint32_t)0x00040000)
#define  RCC_D3AHB1RSTR_CRCRST                   ((uint32_t)0x00080000)
#define  RCC_D3AHB1RSTR_BDMARST                  ((uint32_t)0x00200000)
#define  RCC_D3AHB1RSTR_DMAMUX2RST               ((uint32_t)0x00400000)
#define  RCC_D3AHB1RSTR_ADC3RST                  ((uint32_t)0x01000000)
#define  RCC_D3AHB1RSTR_HSEMRST                  ((uint32_t)0x02000000)


/********************  Bit definition for D1APB1RSTR register  ******************/

#define  RCC_D1APB1RSTR_LTDCRST                 ((uint32_t)0x00000008)
/********************  Bit definition for D2APB1LRSTR register  ******************/

#define  RCC_D2APB1LRSTR_TIM2RST                 ((uint32_t)0x00000001)
#define  RCC_D2APB1LRSTR_TIM3RST                 ((uint32_t)0x00000002)
#define  RCC_D2APB1LRSTR_TIM4RST                 ((uint32_t)0x00000004)
#define  RCC_D2APB1LRSTR_TIM5RST                 ((uint32_t)0x00000008)
#define  RCC_D2APB1LRSTR_TIM6RST                 ((uint32_t)0x00000010)
#define  RCC_D2APB1LRSTR_TIM7RST                 ((uint32_t)0x00000020)
#define  RCC_D2APB1LRSTR_TIM12RST                ((uint32_t)0x00000040)
#define  RCC_D2APB1LRSTR_TIM13RST                ((uint32_t)0x00000080)
#define  RCC_D2APB1LRSTR_TIM14RST                ((uint32_t)0x00000100)
#define  RCC_D2APB1LRSTR_LPTIM1RST               ((uint32_t)0x00000200)
#define  RCC_D2APB1LRSTR_SPI2RST                 ((uint32_t)0x00004000)
#define  RCC_D2APB1LRSTR_SPI3RST                 ((uint32_t)0x00008000)
#define  RCC_D2APB1LRSTR_SPDIFRXRST              ((uint32_t)0x00010000)
#define  RCC_D2APB1LRSTR_USART2RST               ((uint32_t)0x00020000)
#define  RCC_D2APB1LRSTR_USART3RST               ((uint32_t)0x00040000)
#define  RCC_D2APB1LRSTR_UART4RST                ((uint32_t)0x00080000)
#define  RCC_D2APB1LRSTR_UART5RST                ((uint32_t)0x00100000)
#define  RCC_D2APB1LRSTR_I2C1RST                 ((uint32_t)0x00200000)
#define  RCC_D2APB1LRSTR_I2C2RST                 ((uint32_t)0x00400000)
#define  RCC_D2APB1LRSTR_I2C3RST                 ((uint32_t)0x00800000)
#define  RCC_D2APB1LRSTR_CECRST                  ((uint32_t)0x08000000)
#define  RCC_D2APB1LRSTR_DAC12RST                ((uint32_t)0x20000000)
#define  RCC_D2APB1LRSTR_UART7RST               ((uint32_t)0x40000000)
#define  RCC_D2APB1LRSTR_UART8RST               ((uint32_t)0x80000000)

/********************  Bit definition for D2APB1HRSTR register  ******************/
#define  RCC_D2APB1HRSTR_CRSRST                  ((uint32_t)0x00000002)
#define  RCC_D2APB1HRSTR_SWPMIRST                ((uint32_t)0x00000004)
#define  RCC_D2APB1HRSTR_OPAMPRST                ((uint32_t)0x00000010)
#define  RCC_D2APB1HRSTR_MDIOSRST                ((uint32_t)0x00000020)
#define  RCC_D2APB1HRSTR_FDCANRST                ((uint32_t)0x00000100)

/********************  Bit definition for D2APB2RSTR register  ******************/
#define  RCC_D2APB2RSTR_TIM1RST                  ((uint32_t)0x00000001)
#define  RCC_D2APB2RSTR_TIM8RST                  ((uint32_t)0x00000002)
#define  RCC_D2APB2RSTR_USART1RST                ((uint32_t)0x00000010)
#define  RCC_D2APB2RSTR_USART6RST                ((uint32_t)0x00000020)
#define  RCC_D2APB2RSTR_SPI1RST                  ((uint32_t)0x00001000)
#define  RCC_D2APB2RSTR_SPI4RST                  ((uint32_t)0x00002000)
#define  RCC_D2APB2RSTR_TIM15RST                 ((uint32_t)0x00010000)
#define  RCC_D2APB2RSTR_TIM16RST                 ((uint32_t)0x00020000)
#define  RCC_D2APB2RSTR_TIM17RST                 ((uint32_t)0x00040000)
#define  RCC_D2APB2RSTR_SPI5RST                  ((uint32_t)0x00100000)
#define  RCC_D2APB2RSTR_SAI1RST                  ((uint32_t)0x00400000)
#define  RCC_D2APB2RSTR_SAI2RST                  ((uint32_t)0x00800000)
#define  RCC_D2APB2RSTR_SAI3RST                  ((uint32_t)0x01000000)
#define  RCC_D2APB2RSTR_DFSDM1RST                ((uint32_t)0x10000000)
#define  RCC_D2APB2RSTR_HRTIMRST                 ((uint32_t)0x20000000)

/********************  Bit definition for D3APB1RSTR register  ******************/
#define  RCC_D3APB1RSTR_SYSCFGRST                ((uint32_t)0x00000002)
#define  RCC_D3APB1RSTR_LPUART1RST               ((uint32_t)0x00000008)
#define  RCC_D3APB1RSTR_SPI6RST                  ((uint32_t)0x00000020)
#define  RCC_D3APB1RSTR_I2C4RST                  ((uint32_t)0x00000080)
#define  RCC_D3APB1RSTR_LPTIM2RST                ((uint32_t)0x00000200)
#define  RCC_D3APB1RSTR_LPTIM3RST                ((uint32_t)0x00000400)
#define  RCC_D3APB1RSTR_LPTIM4RST                ((uint32_t)0x00000800)
#define  RCC_D3APB1RSTR_LPTIM5RST                ((uint32_t)0x00001000)
#define  RCC_D3APB1RSTR_COMP12RST                ((uint32_t)0x00004000)
#define  RCC_D3APB1RSTR_SAI4RST                  ((uint32_t)0x00200000)


/********************  Bit definition for RCC_GCR register  ********************/
#define  RCC_GCR_WW1RSC                          ((uint32_t)0x00000001)
#define  RCC_GCR_WW2RSC                          ((uint32_t)0x00000002)
#define  RCC_GCR_BOOT_C1                         ((uint32_t)0x00000004)
#define  RCC_GCR_BOOT_C2                         ((uint32_t)0x00000008)

/********************  Bit definition for RCC_D3AMR register  ********************/
#define  RCC_D3AMR_BDMAAMEN                       ((uint32_t)0x00000001)
#define  RCC_D3AMR_LPUART1AMEN                    ((uint32_t)0x00000008)
#define  RCC_D3AMR_SPI6AMEN                       ((uint32_t)0x00000020)
#define  RCC_D3AMR_I2C4AMEN                       ((uint32_t)0x00000080)
#define  RCC_D3AMR_LPTIM2AMEN                     ((uint32_t)0x00000200)
#define  RCC_D3AMR_LPTIM3AMEN                     ((uint32_t)0x00000400)
#define  RCC_D3AMR_LPTIM4AMEN                     ((uint32_t)0x00000800)
#define  RCC_D3AMR_LPTIM5AMEN                     ((uint32_t)0x00001000)
#define  RCC_D3AMR_COMP12AMEN                     ((uint32_t)0x00004000)
#define  RCC_D3AMR_VREFAMEN                       ((uint32_t)0x00008000)
#define  RCC_D3AMR_RTCAMEN                        ((uint32_t)0x00010000)
#define  RCC_D3AMR_CRCAMEN                        ((uint32_t)0x00080000)
#define  RCC_D3AMR_SAI4AMEN                       ((uint32_t)0x00200000)
#define  RCC_D3AMR_ADC3AMEN                       ((uint32_t)0x01000000)


#define  RCC_D3AMR_BKPRAMAMEN                     ((uint32_t)0x10000000)
#define  RCC_D3AMR_D3SRAM1AMEN                    ((uint32_t)0x20000000)
/********************  Bit definition for RCC_D1AHB1ENR register  **************/
#define  RCC_D1AHB1SMENR_MDMASMEN                 ((uint32_t)0x00000001)
#define  RCC_D1AHB1SMENR_DMA2DSMEN                 ((uint32_t)0x00000010)
#define  RCC_D1AHB1SMENR_JPGDECSMEN                ((uint32_t)0x00000020)
#define  RCC_D1AHB1SMENR_FLASHSMEN                 ((uint32_t)0x00000100)
#define  RCC_D1AHB1SMENR_FMCSMEN                   ((uint32_t)0x00001000)
#define  RCC_D1AHB1SMENR_QSPISMEN                  ((uint32_t)0x00004000)
#define  RCC_D1AHB1SMENR_SDMMC1SMEN                ((uint32_t)0x00010000)
#define  RCC_D1AHB1SMENR_DTCM1SMEN                 ((uint32_t)0x10000000)
#define  RCC_D1AHB1SMENR_DTCM2SMEN                 ((uint32_t)0x20000000)
#define  RCC_D1AHB1SMENR_ITCMSMEN                  ((uint32_t)0x40000000)
#define  RCC_D1AHB1SMENR_D1SRAM1SMEN               ((uint32_t)0x80000000)


/********************  Bit definition for RCC_D2AHB1SMENR register  ***************/
#define  RCC_D2AHB1SMENR_DMA1SMEN                    ((uint32_t)0x00000001)
#define  RCC_D2AHB1SMENR_DMA2SMEN                    ((uint32_t)0x00000002)
#define  RCC_D2AHB1SMENR_ADC12SMEN                   ((uint32_t)0x00000020)
#define  RCC_D2AHB1SMENR_ARTSMEN                     ((uint32_t)0x00004000)
#define  RCC_D2AHB1SMENR_ETH1MACSMEN                 ((uint32_t)0x00008000)
#define  RCC_D2AHB1SMENR_ETH1TXSMEN                  ((uint32_t)0x00010000)
#define  RCC_D2AHB1SMENR_ETH1RXSMEN                  ((uint32_t)0x00020000)
#define  RCC_D2AHB1SMENR_ETH1PTPSMEN                 ((uint32_t)0x00040000)
#define  RCC_D2AHB1SMENR_USB1OTGHSSMEN               ((uint32_t)0x02000000)
#define  RCC_D2AHB1SMENR_USB1OTGHSULPISMEN           ((uint32_t)0x04000000)
#define  RCC_D2AHB1SMENR_USB2OTGHSSMEN               ((uint32_t)0x08000000)
#define  RCC_D2AHB1SMENR_USB2OTGHSULPISMEN           ((uint32_t)0x10000000)

/********************  Bit definition for RCC_D2AHB2SMENR register  ***************/
#define  RCC_D2AHB2SMENR_DCMISMEN                   ((uint32_t)0x00000001)
#define  RCC_D2AHB2SMENR_CRYPSMEN                  ((uint32_t)0x00000010)
#define  RCC_D2AHB2SMENR_HASHSMEN                   ((uint32_t)0x00000020)
#define  RCC_D2AHB2SMENR_RNGSMEN                    ((uint32_t)0x00000040)
#define  RCC_D2AHB2SMENR_SDMMC2SMEN                 ((uint32_t)0x00000200)
#define  RCC_D2AHB2SMENR_D2SRAM1SMEN                ((uint32_t)0x40000000)
#define  RCC_D2AHB2SMENR_D2SRAM2SMEN                ((uint32_t)0x40000000)
#define  RCC_D2AHB2SMENR_D2SRAM3SMEN                ((uint32_t)0x80000000)


/********************  Bit definition for D3AHB1SMENR register  ******************/
#define  RCC_D3AHB1SMENR_GPIOASMEN                 ((uint32_t)0x00000001)
#define  RCC_D3AHB1SMENR_GPIOBSMEN                 ((uint32_t)0x00000002)
#define  RCC_D3AHB1SMENR_GPIOCSMEN                 ((uint32_t)0x00000004)
#define  RCC_D3AHB1SMENR_GPIODSMEN                 ((uint32_t)0x00000008)
#define  RCC_D3AHB1SMENR_GPIOESMEN                 ((uint32_t)0x00000010)
#define  RCC_D3AHB1SMENR_GPIOFSMEN                 ((uint32_t)0x00000020)
#define  RCC_D3AHB1SMENR_GPIOGSMEN                 ((uint32_t)0x00000040)
#define  RCC_D3AHB1SMENR_GPIOHSMEN                 ((uint32_t)0x00000080)
#define  RCC_D3AHB1SMENR_GPIOISMEN                 ((uint32_t)0x00000100)
#define  RCC_D3AHB1SMENR_GPIOJSMEN                 ((uint32_t)0x00000200)
#define  RCC_D3AHB1SMENR_GPIOKSMEN                 ((uint32_t)0x00000400)
#define  RCC_D3AHB1SMENR_PWRSMEN                   ((uint32_t)0x00040000)
#define  RCC_D3AHB1SMENR_CRCSMEN                   ((uint32_t)0x00080000)
#define  RCC_D3AHB1SMENR_BDMASMEN                  ((uint32_t)0x00200000)
#define  RCC_D3AHB1SMENR_ADC3SMEN                  ((uint32_t)0x01000000)
#define  RCC_D3AHB1SMENR_BKPRAMSMEN                ((uint32_t)0x10000000)
#define  RCC_D3AHB1SMENR_D3SRAM1SMEN               ((uint32_t)0x20000000)

/********************  Bit definition for D1APB1SMENR register  ******************/

#define  RCC_D1APB1SMENR_LTDCSMEN                 ((uint32_t)0x00000008)
#define  RCC_D1APB1SMENR_WWDG1SMEN                ((uint32_t)0x00000040)

/********************  Bit definition for D2APB1LSMENR register  ******************/

#define  RCC_D2APB1LSMENR_TIM2SMEN                 ((uint32_t)0x00000001)
#define  RCC_D2APB1LSMENR_TIM3SMEN                 ((uint32_t)0x00000002)
#define  RCC_D2APB1LSMENR_TIM4SMEN                 ((uint32_t)0x00000004)
#define  RCC_D2APB1LSMENR_TIM5SMEN                 ((uint32_t)0x00000008)
#define  RCC_D2APB1LSMENR_TIM6SMEN                 ((uint32_t)0x00000010)
#define  RCC_D2APB1LSMENR_TIM7SMEN                 ((uint32_t)0x00000020)
#define  RCC_D2APB1LSMENR_TIM12SMEN                ((uint32_t)0x00000040)
#define  RCC_D2APB1LSMENR_TIM13SMEN                ((uint32_t)0x00000080)
#define  RCC_D2APB1LSMENR_TIM14SMEN                ((uint32_t)0x00000100)
#define  RCC_D2APB1LSMENR_LPTIM1SMEN               ((uint32_t)0x00000200)


#define  RCC_D2APB1LSMENR_SPI2SMEN                 ((uint32_t)0x00004000)
#define  RCC_D2APB1LSMENR_SPI3SMEN                 ((uint32_t)0x00008000)
#define  RCC_D2APB1LSMENR_SPDIFRXSMEN              ((uint32_t)0x00010000)
#define  RCC_D2APB1LSMENR_USART2SMEN               ((uint32_t)0x00020000)
#define  RCC_D2APB1LSMENR_USART3SMEN               ((uint32_t)0x00040000)
#define  RCC_D2APB1LSMENR_UART4SMEN                ((uint32_t)0x00080000)
#define  RCC_D2APB1LSMENR_UART5SMEN                ((uint32_t)0x00100000)
#define  RCC_D2APB1LSMENR_I2C1SMEN                 ((uint32_t)0x00200000)
#define  RCC_D2APB1LSMENR_I2C2SMEN                 ((uint32_t)0x00400000)
#define  RCC_D2APB1LSMENR_I2C3SMEN                 ((uint32_t)0x00800000)
#define  RCC_D2APB1LSMENR_CECSMEN                  ((uint32_t)0x08000000)
#define  RCC_D2APB1LSMENR_DAC12SMEN                ((uint32_t)0x20000000)
#define  RCC_D2APB1LSMENR_UART7SMEN               ((uint32_t)0x40000000)
#define  RCC_D2APB1LSMENR_UART8SMEN               ((uint32_t)0x80000000)

/********************  Bit definition for D2APB1HSMENR register  ******************/
#define  RCC_D2APB1HSMENR_CRSSMEN                  ((uint32_t)0x00000002)
#define  RCC_D2APB1HSMENR_SWPMISMEN                ((uint32_t)0x00000004)
#define  RCC_D2APB1HSMENR_OPAMPSMEN                ((uint32_t)0x00000010)
#define  RCC_D2APB1HSMENR_MDIOSSMEN                ((uint32_t)0x00000020)
#define  RCC_D2APB1HSMENR_FDCANSMEN                ((uint32_t)0x00000100)

/********************  Bit definition for D2APB2SMENR register  ******************/
#define  RCC_D2APB2SMENR_TIM1SMEN                  ((uint32_t)0x00000001)
#define  RCC_D2APB2SMENR_TIM8SMEN                  ((uint32_t)0x00000002)
#define  RCC_D2APB2SMENR_USART1SMEN                ((uint32_t)0x00000010)
#define  RCC_D2APB2SMENR_USART6SMEN                ((uint32_t)0x00000020)
#define  RCC_D2APB2SMENR_SPI1SMEN                  ((uint32_t)0x00001000)
#define  RCC_D2APB2SMENR_SPI4SMEN                  ((uint32_t)0x00002000)
#define  RCC_D2APB2SMENR_TIM15SMEN                 ((uint32_t)0x00010000)
#define  RCC_D2APB2SMENR_TIM16SMEN                 ((uint32_t)0x00020000)
#define  RCC_D2APB2SMENR_TIM17SMEN                 ((uint32_t)0x00040000)
#define  RCC_D2APB2SMENR_SPI5SMEN                  ((uint32_t)0x00100000)
#define  RCC_D2APB2SMENR_SAI1SMEN                  ((uint32_t)0x00400000)
#define  RCC_D2APB2SMENR_SAI2SMEN                  ((uint32_t)0x00800000)
#define  RCC_D2APB2SMENR_SAI3SMEN                  ((uint32_t)0x01000000)
#define  RCC_D2APB2SMENR_DFSDM1SMEN                ((uint32_t)0x10000000)
#define  RCC_D2APB2SMENR_HRTIMSMEN                 ((uint32_t)0x20000000)

/********************  Bit definition for D3APB1SMENR register  ******************/
#define  RCC_D3APB1SMENR_SYSCFGSMEN                ((uint32_t)0x00000002)
#define  RCC_D3APB1SMENR_LPUART1SMEN               ((uint32_t)0x00000008)
#define  RCC_D3APB1SMENR_SPI6SMEN                  ((uint32_t)0x00000020)
#define  RCC_D3APB1SMENR_I2C4SMEN                  ((uint32_t)0x00000080)
#define  RCC_D3APB1SMENR_LPTIM2SMEN                ((uint32_t)0x00000200)
#define  RCC_D3APB1SMENR_LPTIM3SMEN                ((uint32_t)0x00000400)
#define  RCC_D3APB1SMENR_LPTIM4SMEN                ((uint32_t)0x00000800)
#define  RCC_D3APB1SMENR_LPTIM5SMEN                ((uint32_t)0x00001000)
#define  RCC_D3APB1SMENR_COMP12SMEN                ((uint32_t)0x00004000)
#define  RCC_D3APB1SMENR_SAI4SMEN                  ((uint32_t)0x00200000) 

/********************  Bit definition for RCC_BDCR register  ******************/
#define  RCC_BDCR_LSEON                      ((uint32_t)0x00000001)
#define  RCC_BDCR_LSERDY                     ((uint32_t)0x00000002)
#define  RCC_BDCR_LSEBYP                     ((uint32_t)0x00000004)

#define  RCC_BDCR_LSEDRV                     ((uint32_t)0x00000018)
#define  RCC_BDCR_LSEDRV_0                   ((uint32_t)0x00000008)
#define  RCC_BDCR_LSEDRV_1                   ((uint32_t)0x00000010)

#define  RCC_BDCR_LSECSSON                   ((uint32_t)0x00000020)
#define  RCC_BDCR_LSECSSD                    ((uint32_t)0x00000040)

#define  RCC_BDCR_RTCSEL                     ((uint32_t)0x00000300)
#define  RCC_BDCR_RTCSEL_0                   ((uint32_t)0x00000100)
#define  RCC_BDCR_RTCSEL_1                   ((uint32_t)0x00000200)

#define  RCC_BDCR_RTCEN                      ((uint32_t)0x00008000)
#define  RCC_BDCR_BDRST                      ((uint32_t)0x00010000)
/********************  Bit definition for RCC_CSR register  *******************/
#define  RCC_CSR_LSION                       ((uint32_t)0x00000001)
#define  RCC_CSR_LSIRDY                      ((uint32_t)0x00000002)
         
/********************  Bit definition for RCC_RSR register  *******************/
#define  RCC_RSR_RMVF                        ((uint32_t)0x00010000)
#define  RCC_RSR_C1RSTF                      ((uint32_t)0x00020000)
#define  RCC_RSR_D1RSTF                      ((uint32_t)0x00080000)
#define  RCC_RSR_D2RSTF                      ((uint32_t)0x00100000)
#define  RCC_RSR_BORRSTF                     ((uint32_t)0x00200000)
#define  RCC_RSR_PADRSTF                     ((uint32_t)0x00400000)
#define  RCC_RSR_PORRSTF                     ((uint32_t)0x00800000)
#define  RCC_RSR_SFT1RSTF                    ((uint32_t)0x01000000)
#define  RCC_RSR_IWDG1RSTF                   ((uint32_t)0x04000000)
#define  RCC_RSR_WWDG1RSTF                   ((uint32_t)0x10000000)

#define  RCC_RSR_LPWR1RSTF                   ((uint32_t)0x40000000)
#define  RCC_RSR_LPWR2RSTF                   ((uint32_t)0x80000000)

/******************************************************************************/
/*                                                                            */
/*                                    RNG                                     */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for RNG_CR register  *******************/
#define RNG_CR_RNGEN                         ((uint32_t)0x00000004)
#define RNG_CR_IE                            ((uint32_t)0x00000008)
#define RNG_CR_CED                           ((uint32_t)0x00000020)

/********************  Bits definition for RNG_SR register  *******************/
#define RNG_SR_DRDY                          ((uint32_t)0x00000001)
#define RNG_SR_CECS                          ((uint32_t)0x00000002)
#define RNG_SR_SECS                          ((uint32_t)0x00000004)
#define RNG_SR_CEIS                          ((uint32_t)0x00000020)
#define RNG_SR_SEIS                          ((uint32_t)0x00000040)

/******************************************************************************/
/*                                                                            */
/*                           Real-Time Clock (RTC)                            */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for RTC_TR register  *******************/
#define RTC_TR_PM                            ((uint32_t)0x00400000)
#define RTC_TR_HT                            ((uint32_t)0x00300000)
#define RTC_TR_HT_0                          ((uint32_t)0x00100000)
#define RTC_TR_HT_1                          ((uint32_t)0x00200000)
#define RTC_TR_HU                            ((uint32_t)0x000F0000)
#define RTC_TR_HU_0                          ((uint32_t)0x00010000)
#define RTC_TR_HU_1                          ((uint32_t)0x00020000)
#define RTC_TR_HU_2                          ((uint32_t)0x00040000)
#define RTC_TR_HU_3                          ((uint32_t)0x00080000)
#define RTC_TR_MNT                           ((uint32_t)0x00007000)
#define RTC_TR_MNT_0                         ((uint32_t)0x00001000)
#define RTC_TR_MNT_1                         ((uint32_t)0x00002000)
#define RTC_TR_MNT_2                         ((uint32_t)0x00004000)
#define RTC_TR_MNU                           ((uint32_t)0x00000F00)
#define RTC_TR_MNU_0                         ((uint32_t)0x00000100)
#define RTC_TR_MNU_1                         ((uint32_t)0x00000200)
#define RTC_TR_MNU_2                         ((uint32_t)0x00000400)
#define RTC_TR_MNU_3                         ((uint32_t)0x00000800)
#define RTC_TR_ST                            ((uint32_t)0x00000070)
#define RTC_TR_ST_0                          ((uint32_t)0x00000010)
#define RTC_TR_ST_1                          ((uint32_t)0x00000020)
#define RTC_TR_ST_2                          ((uint32_t)0x00000040)
#define RTC_TR_SU                            ((uint32_t)0x0000000F)
#define RTC_TR_SU_0                          ((uint32_t)0x00000001)
#define RTC_TR_SU_1                          ((uint32_t)0x00000002)
#define RTC_TR_SU_2                          ((uint32_t)0x00000004)
#define RTC_TR_SU_3                          ((uint32_t)0x00000008)

/********************  Bits definition for RTC_DR register  *******************/
#define RTC_DR_YT                            ((uint32_t)0x00F00000)
#define RTC_DR_YT_0                          ((uint32_t)0x00100000)
#define RTC_DR_YT_1                          ((uint32_t)0x00200000)
#define RTC_DR_YT_2                          ((uint32_t)0x00400000)
#define RTC_DR_YT_3                          ((uint32_t)0x00800000)
#define RTC_DR_YU                            ((uint32_t)0x000F0000)
#define RTC_DR_YU_0                          ((uint32_t)0x00010000)
#define RTC_DR_YU_1                          ((uint32_t)0x00020000)
#define RTC_DR_YU_2                          ((uint32_t)0x00040000)
#define RTC_DR_YU_3                          ((uint32_t)0x00080000)
#define RTC_DR_WDU                           ((uint32_t)0x0000E000)
#define RTC_DR_WDU_0                         ((uint32_t)0x00002000)
#define RTC_DR_WDU_1                         ((uint32_t)0x00004000)
#define RTC_DR_WDU_2                         ((uint32_t)0x00008000)
#define RTC_DR_MT                            ((uint32_t)0x00001000)
#define RTC_DR_MU                            ((uint32_t)0x00000F00)
#define RTC_DR_MU_0                          ((uint32_t)0x00000100)
#define RTC_DR_MU_1                          ((uint32_t)0x00000200)
#define RTC_DR_MU_2                          ((uint32_t)0x00000400)
#define RTC_DR_MU_3                          ((uint32_t)0x00000800)
#define RTC_DR_DT                            ((uint32_t)0x00000030)
#define RTC_DR_DT_0                          ((uint32_t)0x00000010)
#define RTC_DR_DT_1                          ((uint32_t)0x00000020)
#define RTC_DR_DU                            ((uint32_t)0x0000000F)
#define RTC_DR_DU_0                          ((uint32_t)0x00000001)
#define RTC_DR_DU_1                          ((uint32_t)0x00000002)
#define RTC_DR_DU_2                          ((uint32_t)0x00000004)
#define RTC_DR_DU_3                          ((uint32_t)0x00000008)

/********************  Bits definition for RTC_CR register  *******************/
#define RTC_CR_ITSE                          ((uint32_t)0x01000000)
#define RTC_CR_COE                           ((uint32_t)0x00800000)
#define RTC_CR_OSEL                          ((uint32_t)0x00600000)
#define RTC_CR_OSEL_0                        ((uint32_t)0x00200000)
#define RTC_CR_OSEL_1                        ((uint32_t)0x00400000)
#define RTC_CR_POL                           ((uint32_t)0x00100000)
#define RTC_CR_COSEL                         ((uint32_t)0x00080000)
#define RTC_CR_BCK                           ((uint32_t)0x00040000)
#define RTC_CR_SUB1H                         ((uint32_t)0x00020000)
#define RTC_CR_ADD1H                         ((uint32_t)0x00010000)
#define RTC_CR_TSIE                          ((uint32_t)0x00008000)
#define RTC_CR_WUTIE                         ((uint32_t)0x00004000)
#define RTC_CR_ALRBIE                        ((uint32_t)0x00002000)
#define RTC_CR_ALRAIE                        ((uint32_t)0x00001000)
#define RTC_CR_TSE                           ((uint32_t)0x00000800)
#define RTC_CR_WUTE                          ((uint32_t)0x00000400)
#define RTC_CR_ALRBE                         ((uint32_t)0x00000200)
#define RTC_CR_ALRAE                         ((uint32_t)0x00000100)
#define RTC_CR_FMT                           ((uint32_t)0x00000040)
#define RTC_CR_BYPSHAD                       ((uint32_t)0x00000020)
#define RTC_CR_REFCKON                       ((uint32_t)0x00000010)
#define RTC_CR_TSEDGE                        ((uint32_t)0x00000008)
#define RTC_CR_WUCKSEL                       ((uint32_t)0x00000007)
#define RTC_CR_WUCKSEL_0                     ((uint32_t)0x00000001)
#define RTC_CR_WUCKSEL_1                     ((uint32_t)0x00000002)
#define RTC_CR_WUCKSEL_2                     ((uint32_t)0x00000004)

/********************  Bits definition for RTC_ISR register  ******************/
#define RTC_ISR_ITSF                         ((uint32_t)0x00020000)
#define RTC_ISR_RECALPF                      ((uint32_t)0x00010000)
#define RTC_ISR_TAMP3F                       ((uint32_t)0x00008000)
#define RTC_ISR_TAMP2F                       ((uint32_t)0x00004000)
#define RTC_ISR_TAMP1F                       ((uint32_t)0x00002000)
#define RTC_ISR_TSOVF                        ((uint32_t)0x00001000)
#define RTC_ISR_TSF                          ((uint32_t)0x00000800)
#define RTC_ISR_WUTF                         ((uint32_t)0x00000400)
#define RTC_ISR_ALRBF                        ((uint32_t)0x00000200)
#define RTC_ISR_ALRAF                        ((uint32_t)0x00000100)
#define RTC_ISR_INIT                         ((uint32_t)0x00000080)
#define RTC_ISR_INITF                        ((uint32_t)0x00000040)
#define RTC_ISR_RSF                          ((uint32_t)0x00000020)
#define RTC_ISR_INITS                        ((uint32_t)0x00000010)
#define RTC_ISR_SHPF                         ((uint32_t)0x00000008)
#define RTC_ISR_WUTWF                        ((uint32_t)0x00000004)
#define RTC_ISR_ALRBWF                       ((uint32_t)0x00000002)
#define RTC_ISR_ALRAWF                       ((uint32_t)0x00000001)

/********************  Bits definition for RTC_PRER register  *****************/
#define RTC_PRER_PREDIV_A                    ((uint32_t)0x007F0000)
#define RTC_PRER_PREDIV_S                    ((uint32_t)0x00007FFF)

/********************  Bits definition for RTC_WUTR register  *****************/
#define RTC_WUTR_WUT                         ((uint32_t)0x0000FFFF)

/********************  Bits definition for RTC_ALRMAR register  ***************/
#define RTC_ALRMAR_MSK4                      ((uint32_t)0x80000000)
#define RTC_ALRMAR_WDSEL                     ((uint32_t)0x40000000)
#define RTC_ALRMAR_DT                        ((uint32_t)0x30000000)
#define RTC_ALRMAR_DT_0                      ((uint32_t)0x10000000)
#define RTC_ALRMAR_DT_1                      ((uint32_t)0x20000000)
#define RTC_ALRMAR_DU                        ((uint32_t)0x0F000000)
#define RTC_ALRMAR_DU_0                      ((uint32_t)0x01000000)
#define RTC_ALRMAR_DU_1                      ((uint32_t)0x02000000)
#define RTC_ALRMAR_DU_2                      ((uint32_t)0x04000000)
#define RTC_ALRMAR_DU_3                      ((uint32_t)0x08000000)
#define RTC_ALRMAR_MSK3                      ((uint32_t)0x00800000)
#define RTC_ALRMAR_PM                        ((uint32_t)0x00400000)
#define RTC_ALRMAR_HT                        ((uint32_t)0x00300000)
#define RTC_ALRMAR_HT_0                      ((uint32_t)0x00100000)
#define RTC_ALRMAR_HT_1                      ((uint32_t)0x00200000)
#define RTC_ALRMAR_HU                        ((uint32_t)0x000F0000)
#define RTC_ALRMAR_HU_0                      ((uint32_t)0x00010000)
#define RTC_ALRMAR_HU_1                      ((uint32_t)0x00020000)
#define RTC_ALRMAR_HU_2                      ((uint32_t)0x00040000)
#define RTC_ALRMAR_HU_3                      ((uint32_t)0x00080000)
#define RTC_ALRMAR_MSK2                      ((uint32_t)0x00008000)
#define RTC_ALRMAR_MNT                       ((uint32_t)0x00007000)
#define RTC_ALRMAR_MNT_0                     ((uint32_t)0x00001000)
#define RTC_ALRMAR_MNT_1                     ((uint32_t)0x00002000)
#define RTC_ALRMAR_MNT_2                     ((uint32_t)0x00004000)
#define RTC_ALRMAR_MNU                       ((uint32_t)0x00000F00)
#define RTC_ALRMAR_MNU_0                     ((uint32_t)0x00000100)
#define RTC_ALRMAR_MNU_1                     ((uint32_t)0x00000200)
#define RTC_ALRMAR_MNU_2                     ((uint32_t)0x00000400)
#define RTC_ALRMAR_MNU_3                     ((uint32_t)0x00000800)
#define RTC_ALRMAR_MSK1                      ((uint32_t)0x00000080)
#define RTC_ALRMAR_ST                        ((uint32_t)0x00000070)
#define RTC_ALRMAR_ST_0                      ((uint32_t)0x00000010)
#define RTC_ALRMAR_ST_1                      ((uint32_t)0x00000020)
#define RTC_ALRMAR_ST_2                      ((uint32_t)0x00000040)
#define RTC_ALRMAR_SU                        ((uint32_t)0x0000000F)
#define RTC_ALRMAR_SU_0                      ((uint32_t)0x00000001)
#define RTC_ALRMAR_SU_1                      ((uint32_t)0x00000002)
#define RTC_ALRMAR_SU_2                      ((uint32_t)0x00000004)
#define RTC_ALRMAR_SU_3                      ((uint32_t)0x00000008)

/********************  Bits definition for RTC_ALRMBR register  ***************/
#define RTC_ALRMBR_MSK4                      ((uint32_t)0x80000000)
#define RTC_ALRMBR_WDSEL                     ((uint32_t)0x40000000)
#define RTC_ALRMBR_DT                        ((uint32_t)0x30000000)
#define RTC_ALRMBR_DT_0                      ((uint32_t)0x10000000)
#define RTC_ALRMBR_DT_1                      ((uint32_t)0x20000000)
#define RTC_ALRMBR_DU                        ((uint32_t)0x0F000000)
#define RTC_ALRMBR_DU_0                      ((uint32_t)0x01000000)
#define RTC_ALRMBR_DU_1                      ((uint32_t)0x02000000)
#define RTC_ALRMBR_DU_2                      ((uint32_t)0x04000000)
#define RTC_ALRMBR_DU_3                      ((uint32_t)0x08000000)
#define RTC_ALRMBR_MSK3                      ((uint32_t)0x00800000)
#define RTC_ALRMBR_PM                        ((uint32_t)0x00400000)
#define RTC_ALRMBR_HT                        ((uint32_t)0x00300000)
#define RTC_ALRMBR_HT_0                      ((uint32_t)0x00100000)
#define RTC_ALRMBR_HT_1                      ((uint32_t)0x00200000)
#define RTC_ALRMBR_HU                        ((uint32_t)0x000F0000)
#define RTC_ALRMBR_HU_0                      ((uint32_t)0x00010000)
#define RTC_ALRMBR_HU_1                      ((uint32_t)0x00020000)
#define RTC_ALRMBR_HU_2                      ((uint32_t)0x00040000)
#define RTC_ALRMBR_HU_3                      ((uint32_t)0x00080000)
#define RTC_ALRMBR_MSK2                      ((uint32_t)0x00008000)
#define RTC_ALRMBR_MNT                       ((uint32_t)0x00007000)
#define RTC_ALRMBR_MNT_0                     ((uint32_t)0x00001000)
#define RTC_ALRMBR_MNT_1                     ((uint32_t)0x00002000)
#define RTC_ALRMBR_MNT_2                     ((uint32_t)0x00004000)
#define RTC_ALRMBR_MNU                       ((uint32_t)0x00000F00)
#define RTC_ALRMBR_MNU_0                     ((uint32_t)0x00000100)
#define RTC_ALRMBR_MNU_1                     ((uint32_t)0x00000200)
#define RTC_ALRMBR_MNU_2                     ((uint32_t)0x00000400)
#define RTC_ALRMBR_MNU_3                     ((uint32_t)0x00000800)
#define RTC_ALRMBR_MSK1                      ((uint32_t)0x00000080)
#define RTC_ALRMBR_ST                        ((uint32_t)0x00000070)
#define RTC_ALRMBR_ST_0                      ((uint32_t)0x00000010)
#define RTC_ALRMBR_ST_1                      ((uint32_t)0x00000020)
#define RTC_ALRMBR_ST_2                      ((uint32_t)0x00000040)
#define RTC_ALRMBR_SU                        ((uint32_t)0x0000000F)
#define RTC_ALRMBR_SU_0                      ((uint32_t)0x00000001)
#define RTC_ALRMBR_SU_1                      ((uint32_t)0x00000002)
#define RTC_ALRMBR_SU_2                      ((uint32_t)0x00000004)
#define RTC_ALRMBR_SU_3                      ((uint32_t)0x00000008)

/********************  Bits definition for RTC_WPR register  ******************/
#define RTC_WPR_KEY                          ((uint32_t)0x000000FF)

/********************  Bits definition for RTC_SSR register  ******************/
#define RTC_SSR_SS                           ((uint32_t)0x0000FFFF)

/********************  Bits definition for RTC_SHIFTR register  ***************/
#define RTC_SHIFTR_SUBFS                     ((uint32_t)0x00007FFF)
#define RTC_SHIFTR_ADD1S                     ((uint32_t)0x80000000)

/********************  Bits definition for RTC_TSTR register  *****************/
#define RTC_TSTR_PM                          ((uint32_t)0x00400000)
#define RTC_TSTR_HT                          ((uint32_t)0x00300000)
#define RTC_TSTR_HT_0                        ((uint32_t)0x00100000)
#define RTC_TSTR_HT_1                        ((uint32_t)0x00200000)
#define RTC_TSTR_HU                          ((uint32_t)0x000F0000)
#define RTC_TSTR_HU_0                        ((uint32_t)0x00010000)
#define RTC_TSTR_HU_1                        ((uint32_t)0x00020000)
#define RTC_TSTR_HU_2                        ((uint32_t)0x00040000)
#define RTC_TSTR_HU_3                        ((uint32_t)0x00080000)
#define RTC_TSTR_MNT                         ((uint32_t)0x00007000)
#define RTC_TSTR_MNT_0                       ((uint32_t)0x00001000)
#define RTC_TSTR_MNT_1                       ((uint32_t)0x00002000)
#define RTC_TSTR_MNT_2                       ((uint32_t)0x00004000)
#define RTC_TSTR_MNU                         ((uint32_t)0x00000F00)
#define RTC_TSTR_MNU_0                       ((uint32_t)0x00000100)
#define RTC_TSTR_MNU_1                       ((uint32_t)0x00000200)
#define RTC_TSTR_MNU_2                       ((uint32_t)0x00000400)
#define RTC_TSTR_MNU_3                       ((uint32_t)0x00000800)
#define RTC_TSTR_ST                          ((uint32_t)0x00000070)
#define RTC_TSTR_ST_0                        ((uint32_t)0x00000010)
#define RTC_TSTR_ST_1                        ((uint32_t)0x00000020)
#define RTC_TSTR_ST_2                        ((uint32_t)0x00000040)
#define RTC_TSTR_SU                          ((uint32_t)0x0000000F)
#define RTC_TSTR_SU_0                        ((uint32_t)0x00000001)
#define RTC_TSTR_SU_1                        ((uint32_t)0x00000002)
#define RTC_TSTR_SU_2                        ((uint32_t)0x00000004)
#define RTC_TSTR_SU_3                        ((uint32_t)0x00000008)

/********************  Bits definition for RTC_TSDR register  *****************/
#define RTC_TSDR_WDU                         ((uint32_t)0x0000E000)
#define RTC_TSDR_WDU_0                       ((uint32_t)0x00002000)
#define RTC_TSDR_WDU_1                       ((uint32_t)0x00004000)
#define RTC_TSDR_WDU_2                       ((uint32_t)0x00008000)
#define RTC_TSDR_MT                          ((uint32_t)0x00001000)
#define RTC_TSDR_MU                          ((uint32_t)0x00000F00)
#define RTC_TSDR_MU_0                        ((uint32_t)0x00000100)
#define RTC_TSDR_MU_1                        ((uint32_t)0x00000200)
#define RTC_TSDR_MU_2                        ((uint32_t)0x00000400)
#define RTC_TSDR_MU_3                        ((uint32_t)0x00000800)
#define RTC_TSDR_DT                          ((uint32_t)0x00000030)
#define RTC_TSDR_DT_0                        ((uint32_t)0x00000010)
#define RTC_TSDR_DT_1                        ((uint32_t)0x00000020)
#define RTC_TSDR_DU                          ((uint32_t)0x0000000F)
#define RTC_TSDR_DU_0                        ((uint32_t)0x00000001)
#define RTC_TSDR_DU_1                        ((uint32_t)0x00000002)
#define RTC_TSDR_DU_2                        ((uint32_t)0x00000004)
#define RTC_TSDR_DU_3                        ((uint32_t)0x00000008)

/********************  Bits definition for RTC_TSSSR register  ****************/
#define RTC_TSSSR_SS                         ((uint32_t)0x0000FFFF)

/********************  Bits definition for RTC_CAL register  *****************/
#define RTC_CALR_CALP                        ((uint32_t)0x00008000)
#define RTC_CALR_CALW8                       ((uint32_t)0x00004000)
#define RTC_CALR_CALW16                      ((uint32_t)0x00002000)
#define RTC_CALR_CALM                        ((uint32_t)0x000001FF)
#define RTC_CALR_CALM_0                      ((uint32_t)0x00000001)
#define RTC_CALR_CALM_1                      ((uint32_t)0x00000002)
#define RTC_CALR_CALM_2                      ((uint32_t)0x00000004)
#define RTC_CALR_CALM_3                      ((uint32_t)0x00000008)
#define RTC_CALR_CALM_4                      ((uint32_t)0x00000010)
#define RTC_CALR_CALM_5                      ((uint32_t)0x00000020)
#define RTC_CALR_CALM_6                      ((uint32_t)0x00000040)
#define RTC_CALR_CALM_7                      ((uint32_t)0x00000080)
#define RTC_CALR_CALM_8                      ((uint32_t)0x00000100)

/********************  Bits definition for RTC_TAFCR register  ****************/
#define RTC_TAMPCR_TAMP3MF                   ((uint32_t)0x01000000)
#define RTC_TAMPCR_TAMP3NOERASE              ((uint32_t)0x00800000)
#define RTC_TAMPCR_TAMP3IE                   ((uint32_t)0x00400000)
#define RTC_TAMPCR_TAMP2MF                   ((uint32_t)0x00200000)
#define RTC_TAMPCR_TAMP2NOERASE              ((uint32_t)0x00100000)
#define RTC_TAMPCR_TAMP2IE                   ((uint32_t)0x00080000)
#define RTC_TAMPCR_TAMP1MF                   ((uint32_t)0x00040000)
#define RTC_TAMPCR_TAMP1NOERASE              ((uint32_t)0x00020000)
#define RTC_TAMPCR_TAMP1IE                   ((uint32_t)0x00010000)
#define RTC_TAMPCR_TAMPPUDIS                 ((uint32_t)0x00008000)
#define RTC_TAMPCR_TAMPPRCH                  ((uint32_t)0x00006000)
#define RTC_TAMPCR_TAMPPRCH_0                ((uint32_t)0x00002000)
#define RTC_TAMPCR_TAMPPRCH_1                ((uint32_t)0x00004000)
#define RTC_TAMPCR_TAMPFLT                   ((uint32_t)0x00001800)
#define RTC_TAMPCR_TAMPFLT_0                 ((uint32_t)0x00000800)
#define RTC_TAMPCR_TAMPFLT_1                 ((uint32_t)0x00001000)
#define RTC_TAMPCR_TAMPFREQ                  ((uint32_t)0x00000700)
#define RTC_TAMPCR_TAMPFREQ_0                ((uint32_t)0x00000100)
#define RTC_TAMPCR_TAMPFREQ_1                ((uint32_t)0x00000200)
#define RTC_TAMPCR_TAMPFREQ_2                ((uint32_t)0x00000400)
#define RTC_TAMPCR_TAMPTS                    ((uint32_t)0x00000080)
#define RTC_TAMPCR_TAMP3_TRG                 ((uint32_t)0x00000040)
#define RTC_TAMPCR_TAMP3E                    ((uint32_t)0x00000020)
#define RTC_TAMPCR_TAMP2_TRG                 ((uint32_t)0x00000010)
#define RTC_TAMPCR_TAMP2E                    ((uint32_t)0x00000008)
#define RTC_TAMPCR_TAMPIE                    ((uint32_t)0x00000004)
#define RTC_TAMPCR_TAMP1_TRG                 ((uint32_t)0x00000002)
#define RTC_TAMPCR_TAMP1E                    ((uint32_t)0x00000001)

/********************  Bits definition for RTC_ALRMASSR register  *************/
#define RTC_ALRMASSR_MASKSS                  ((uint32_t)0x0F000000)
#define RTC_ALRMASSR_MASKSS_0                ((uint32_t)0x01000000)
#define RTC_ALRMASSR_MASKSS_1                ((uint32_t)0x02000000)
#define RTC_ALRMASSR_MASKSS_2                ((uint32_t)0x04000000)
#define RTC_ALRMASSR_MASKSS_3                ((uint32_t)0x08000000)
#define RTC_ALRMASSR_SS                      ((uint32_t)0x00007FFF)

/********************  Bits definition for RTC_ALRMBSSR register  *************/
#define RTC_ALRMBSSR_MASKSS                  ((uint32_t)0x0F000000)
#define RTC_ALRMBSSR_MASKSS_0                ((uint32_t)0x01000000)
#define RTC_ALRMBSSR_MASKSS_1                ((uint32_t)0x02000000)
#define RTC_ALRMBSSR_MASKSS_2                ((uint32_t)0x04000000)
#define RTC_ALRMBSSR_MASKSS_3                ((uint32_t)0x08000000)
#define RTC_ALRMBSSR_SS                      ((uint32_t)0x00007FFF)

/********************  Bits definition for RTC_BKP0R register  ****************/
#define RTC_OR_OUT_RMP                      ((uint32_t)0x00000002)
#define RTC_OR_ALARMOUTTYPE                 ((uint32_t)0x00000001)


/********************  Bits definition for RTC_BKP0R register  ****************/
#define RTC_BKP0R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP1R register  ****************/
#define RTC_BKP1R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP2R register  ****************/
#define RTC_BKP2R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP3R register  ****************/
#define RTC_BKP3R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP4R register  ****************/
#define RTC_BKP4R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP5R register  ****************/
#define RTC_BKP5R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP6R register  ****************/
#define RTC_BKP6R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP7R register  ****************/
#define RTC_BKP7R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP8R register  ****************/
#define RTC_BKP8R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP9R register  ****************/
#define RTC_BKP9R                            ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP10R register  ***************/
#define RTC_BKP10R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP11R register  ***************/
#define RTC_BKP11R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP12R register  ***************/
#define RTC_BKP12R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP13R register  ***************/
#define RTC_BKP13R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP14R register  ***************/
#define RTC_BKP14R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP15R register  ***************/
#define RTC_BKP15R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP16R register  ***************/
#define RTC_BKP16R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP17R register  ***************/
#define RTC_BKP17R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP18R register  ***************/
#define RTC_BKP18R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP19R register  ***************/
#define RTC_BKP19R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP20R register  ***************/
#define RTC_BKP20R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP21R register  ***************/
#define RTC_BKP21R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP22R register  ***************/
#define RTC_BKP22R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP23R register  ***************/
#define RTC_BKP23R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP24R register  ***************/
#define RTC_BKP24R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP25R register  ***************/
#define RTC_BKP25R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP26R register  ***************/
#define RTC_BKP26R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP27R register  ***************/
#define RTC_BKP27R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP28R register  ***************/
#define RTC_BKP28R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP29R register  ***************/
#define RTC_BKP29R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP30R register  ***************/
#define RTC_BKP30R                           ((uint32_t)0xFFFFFFFF)

/********************  Bits definition for RTC_BKP31R register  ***************/
#define RTC_BKP31R                           ((uint32_t)0xFFFFFFFF)

/******************** Number of backup registers ******************************/
#define RTC_BKP_NUMBER                       ((uint32_t)0x00000020)

/******************************************************************************/
/*                                                                            */
/*                              SPDIF-RX Interface                            */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for SPDIF_CR register  *******************/
#define  SPDIFRX_CR_SPDIFEN                  ((uint32_t)0x00000003)        /*!<Peripheral Block Enable                      */
#define  SPDIFRX_CR_RXDMAEN                  ((uint32_t)0x00000004)        /*!<Receiver DMA Enable for data flow            */
#define  SPDIFRX_CR_RXSTEO                   ((uint32_t)0x00000008)        /*!<Stereo Mode                                  */
#define  SPDIFRX_CR_DRFMT                    ((uint32_t)0x00000030)        /*!<RX Data format                               */
#define  SPDIFRX_CR_PMSK                     ((uint32_t)0x00000040)        /*!<Mask Parity error bit                        */
#define  SPDIFRX_CR_VMSK                     ((uint32_t)0x00000080)        /*!<Mask of Validity bit                         */
#define  SPDIFRX_CR_CUMSK                    ((uint32_t)0x00000100)        /*!<Mask of channel status and user bits         */
#define  SPDIFRX_CR_PTMSK                    ((uint32_t)0x00000200)        /*!<Mask of Preamble Type bits                   */
#define  SPDIFRX_CR_CBDMAEN                  ((uint32_t)0x00000400)        /*!<Control Buffer DMA ENable for control flow   */
#define  SPDIFRX_CR_CHSEL                    ((uint32_t)0x00000800)        /*!<Channel Selection                            */
#define  SPDIFRX_CR_NBTR                     ((uint32_t)0x00003000)        /*!<Maximum allowed re-tries during synchronization phase */
#define  SPDIFRX_CR_WFA                      ((uint32_t)0x00004000)        /*!<Wait For Activity     */
#define  SPDIFRX_CR_INSEL                    ((uint32_t)0x00070000)        /*!<SPDIF input selection */

/*******************  Bit definition for SPDIFRX_IMR register  *******************/
#define  SPDIFRX_IMR_RXNEIE                   ((uint32_t)0x00000001)        /*!<RXNE interrupt enable                              */
#define  SPDIFRX_IMR_CSRNEIE                  ((uint32_t)0x00000002)        /*!<Control Buffer Ready Interrupt Enable              */
#define  SPDIFRX_IMR_PERRIE                   ((uint32_t)0x00000004)        /*!<Parity error interrupt enable                      */
#define  SPDIFRX_IMR_OVRIE                    ((uint32_t)0x00000008)        /*!<Overrun error Interrupt Enable                     */
#define  SPDIFRX_IMR_SBLKIE                   ((uint32_t)0x00000010)        /*!<Synchronization Block Detected Interrupt Enable    */
#define  SPDIFRX_IMR_SYNCDIE                  ((uint32_t)0x00000020)        /*!<Synchronization Done                               */
#define  SPDIFRX_IMR_IFEIE                    ((uint32_t)0x00000040)        /*!<Serial Interface Error Interrupt Enable            */

/*******************  Bit definition for SPDIFRX_SR register  *******************/
#define  SPDIFRX_SR_RXNE                   ((uint32_t)0x00000001)       /*!<Read data register not empty                          */
#define  SPDIFRX_SR_CSRNE                  ((uint32_t)0x00000002)       /*!<The Control Buffer register is not empty              */
#define  SPDIFRX_SR_PERR                   ((uint32_t)0x00000004)       /*!<Parity error                                          */
#define  SPDIFRX_SR_OVR                    ((uint32_t)0x00000008)       /*!<Overrun error                                         */
#define  SPDIFRX_SR_SBD                    ((uint32_t)0x00000010)       /*!<Synchronization Block Detected                        */
#define  SPDIFRX_SR_SYNCD                  ((uint32_t)0x00000020)       /*!<Synchronization Done                                  */
#define  SPDIFRX_SR_FERR                   ((uint32_t)0x00000040)       /*!<Framing error                                         */
#define  SPDIFRX_SR_SERR                   ((uint32_t)0x00000080)       /*!<Synchronization error                                 */
#define  SPDIFRX_SR_TERR                   ((uint32_t)0x00000100)       /*!<Time-out error                                        */
#define  SPDIFRX_SR_WIDTH5                 ((uint32_t)0x7FFF0000)       /*!<Duration of 5 symbols counted with spdif_clk          */

/*******************  Bit definition for SPDIFRX_IFCR register  *******************/
#define  SPDIFRX_IFCR_PERRCF               ((uint32_t)0x00000004)       /*!<Clears the Parity error flag                         */
#define  SPDIFRX_IFCR_OVRCF                ((uint32_t)0x00000008)       /*!<Clears the Overrun error flag                        */
#define  SPDIFRX_IFCR_SBDCF                ((uint32_t)0x00000010)       /*!<Clears the Synchronization Block Detected flag       */
#define  SPDIFRX_IFCR_SYNCDCF              ((uint32_t)0x00000020)       /*!<Clears the Synchronization Done flag                 */

/*******************  Bit definition for SPDIFRX_DR register  (DRFMT = 0b00 case) *******************/
#define  SPDIFRX_DR0_DR                    ((uint32_t)0x00FFFFFF)        /*!<Data value            */
#define  SPDIFRX_DR0_PE                    ((uint32_t)0x01000000)        /*!<Parity Error bit      */
#define  SPDIFRX_DR0_V                     ((uint32_t)0x02000000)        /*!<Validity bit          */
#define  SPDIFRX_DR0_U                     ((uint32_t)0x04000000)        /*!<User bit              */
#define  SPDIFRX_DR0_C                     ((uint32_t)0x08000000)        /*!<Channel Status bit    */
#define  SPDIFRX_DR0_PT                    ((uint32_t)0x30000000)        /*!<Preamble Type         */

/*******************  Bit definition for SPDIFRX_DR register  (DRFMT = 0b01 case) *******************/
#define  SPDIFRX_DR1_DR                    ((uint32_t)0xFFFFFF00)        /*!<Data value            */
#define  SPDIFRX_DR1_PT                    ((uint32_t)0x00000030)        /*!<Preamble Type         */
#define  SPDIFRX_DR1_C                     ((uint32_t)0x00000008)        /*!<Channel Status bit    */
#define  SPDIFRX_DR1_U                     ((uint32_t)0x00000004)        /*!<User bit              */
#define  SPDIFRX_DR1_V                     ((uint32_t)0x00000002)        /*!<Validity bit          */
#define  SPDIFRX_DR1_PE                    ((uint32_t)0x00000001)        /*!<Parity Error bit      */

/*******************  Bit definition for SPDIFRX_DR register  (DRFMT = 0b10 case) *******************/
#define  SPDIFRX_DR1_DRNL1                 ((uint32_t)0xFFFF0000)        /*!<Data value Channel B      */
#define  SPDIFRX_DR1_DRNL2                 ((uint32_t)0x0000FFFF)        /*!<Data value Channel A      */

/*******************  Bit definition for SPDIFRX_CSR register   *******************/
#define  SPDIFRX_CSR_USR                     ((uint32_t)0x0000FFFF)        /*!<User data information           */
#define  SPDIFRX_CSR_CS                      ((uint32_t)0x00FF0000)        /*!<Channel A status information    */
#define  SPDIFRX_CSR_SOB                     ((uint32_t)0x01000000)        /*!<Start Of Block                  */

/*******************  Bit definition for SPDIFRX_DIR register    *******************/
#define  SPDIFRX_DIR_THI                 ((uint32_t)0x00001FFF)        /*!<Threshold LOW      */
#define  SPDIFRX_DIR_TLO                 ((uint32_t)0x1FFF0000)        /*!<Threshold HIGH     */


/******************************************************************************/
/*                                                                            */
/*                          Serial Audio Interface                            */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for SAI_GCR register  *******************/
#define  SAI_GCR_SYNCIN                      0x00000003U        /*!<SYNCIN[1:0] bits (Synchronization Inputs)   */
#define  SAI_GCR_SYNCIN_0                    0x00000001U        /*!<Bit 0 */
#define  SAI_GCR_SYNCIN_1                    0x00000002U        /*!<Bit 1 */

#define  SAI_GCR_SYNCOUT                     0x00000030U        /*!<SYNCOUT[1:0] bits (Synchronization Outputs) */
#define  SAI_GCR_SYNCOUT_0                   0x00000010U        /*!<Bit 0 */
#define  SAI_GCR_SYNCOUT_1                   0x00000020U        /*!<Bit 1 */

/*******************  Bit definition for SAI_xCR1 register  *******************/
#define  SAI_xCR1_MODE                       0x00000003U        /*!<MODE[1:0] bits (Audio Block Mode)           */
#define  SAI_xCR1_MODE_0                     0x00000001U        /*!<Bit 0 */
#define  SAI_xCR1_MODE_1                     0x00000002U        /*!<Bit 1 */

#define  SAI_xCR1_PRTCFG                     0x0000000CU        /*!<PRTCFG[1:0] bits (Protocol Configuration)   */
#define  SAI_xCR1_PRTCFG_0                   0x00000004U        /*!<Bit 0 */
#define  SAI_xCR1_PRTCFG_1                   0x00000008U        /*!<Bit 1 */

#define  SAI_xCR1_DS                         0x000000E0U        /*!<DS[1:0] bits (Data Size) */
#define  SAI_xCR1_DS_0                       0x00000020U        /*!<Bit 0 */
#define  SAI_xCR1_DS_1                       0x00000040U        /*!<Bit 1 */
#define  SAI_xCR1_DS_2                       0x00000080U        /*!<Bit 2 */

#define  SAI_xCR1_LSBFIRST                   0x00000100U        /*!<LSB First Configuration  */
#define  SAI_xCR1_CKSTR                      0x00000200U        /*!<ClocK STRobing edge      */

#define  SAI_xCR1_SYNCEN                     0x00000C00U        /*!<SYNCEN[1:0](SYNChronization ENable) */
#define  SAI_xCR1_SYNCEN_0                   0x00000400U        /*!<Bit 0 */
#define  SAI_xCR1_SYNCEN_1                   0x00000800U        /*!<Bit 1 */

#define  SAI_xCR1_MONO                       0x00001000U        /*!<Mono mode                  */
#define  SAI_xCR1_OUTDRIV                    0x00002000U        /*!<Output Drive               */
#define  SAI_xCR1_SAIEN                      0x00010000U        /*!<Audio Block enable         */
#define  SAI_xCR1_DMAEN                      0x00020000U        /*!<DMA enable                 */
#define  SAI_xCR1_NOMCK                      0x00080000U        /*!<No Divider Configuration   */

#define  SAI_xCR1_MCKDIV                     0x03F00000U        /*!<MCKDIV[5:0] (Master ClocK Divider)  */
#define  SAI_xCR1_MCKDIV_0                   0x00100000U        /*!<Bit 0  */
#define  SAI_xCR1_MCKDIV_1                   0x00200000U        /*!<Bit 1  */
#define  SAI_xCR1_MCKDIV_2                   0x00400000U        /*!<Bit 2  */
#define  SAI_xCR1_MCKDIV_3                   0x00800000U        /*!<Bit 3  */
#define  SAI_xCR1_MCKDIV_4                   0x01000000U        /*!<Bit 4  */
#define  SAI_xCR1_MCKDIV_5                   0x02000000U        /*!<Bit 5  */

#define  SAI_xCR1_OSR                        0x04000000U        /*!<OverSampling Ratio for master clock  */

/*******************  Bit definition for SAI_xCR2 register  *******************/
#define  SAI_xCR2_FTH                        0x00000007U        /*!<FTH[2:0](Fifo THreshold)  */
#define  SAI_xCR2_FTH_0                      0x00000001U        /*!<Bit 0 */
#define  SAI_xCR2_FTH_1                      0x00000002U        /*!<Bit 1 */
#define  SAI_xCR2_FTH_2                      0x00000004U        /*!<Bit 2 */

#define  SAI_xCR2_FFLUSH                     0x00000008U        /*!<Fifo FLUSH                       */
#define  SAI_xCR2_TRIS                       0x00000010U        /*!<TRIState Management on data line */
#define  SAI_xCR2_MUTE                       0x00000020U        /*!<Mute mode                        */
#define  SAI_xCR2_MUTEVAL                    0x00000040U        /*!<Muate value                      */

#define  SAI_xCR2_MUTECNT                    0x00001F80U       /*!<MUTECNT[5:0] (MUTE counter) */
#define  SAI_xCR2_MUTECNT_0                  0x00000080U        /*!<Bit 0 */
#define  SAI_xCR2_MUTECNT_1                  0x00000100U        /*!<Bit 1 */
#define  SAI_xCR2_MUTECNT_2                  0x00000200U        /*!<Bit 2 */
#define  SAI_xCR2_MUTECNT_3                  0x00000400U        /*!<Bit 3 */
#define  SAI_xCR2_MUTECNT_4                  0x00000800U        /*!<Bit 4 */
#define  SAI_xCR2_MUTECNT_5                  0x00001000U        /*!<Bit 5 */

#define  SAI_xCR2_CPL                        0x00002000U        /*!< Complement Bit             */

#define  SAI_xCR2_COMP                       0x0000C000U        /*!<COMP[1:0] (Companding mode) */
#define  SAI_xCR2_COMP_0                     0x00004000U        /*!<Bit 0 */
#define  SAI_xCR2_COMP_1                     0x00008000U        /*!<Bit 1 */

/******************  Bit definition for SAI_xFRCR register  *******************/
#define  SAI_xFRCR_FRL                       0x000000FFU        /*!<FRL[7:0](FRame Length)  */
#define  SAI_xFRCR_FRL_0                     0x00000001U        /*!<Bit 0 */
#define  SAI_xFRCR_FRL_1                     0x00000002U        /*!<Bit 1 */
#define  SAI_xFRCR_FRL_2                     0x00000004U        /*!<Bit 2 */
#define  SAI_xFRCR_FRL_3                     0x00000008U        /*!<Bit 3 */
#define  SAI_xFRCR_FRL_4                     0x00000010U        /*!<Bit 4 */
#define  SAI_xFRCR_FRL_5                     0x00000020U        /*!<Bit 5 */
#define  SAI_xFRCR_FRL_6                     0x00000040U        /*!<Bit 6 */
#define  SAI_xFRCR_FRL_7                     0x00000080U        /*!<Bit 7 */

#define  SAI_xFRCR_FSALL                     0x00007F00U        /*!<FSALL[6:0] (Frame Synchronization Active Level Length)  */
#define  SAI_xFRCR_FSALL_0                   0x00000100U        /*!<Bit 0 */
#define  SAI_xFRCR_FSALL_1                   0x00000200U        /*!<Bit 1 */
#define  SAI_xFRCR_FSALL_2                   0x00000400U        /*!<Bit 2 */
#define  SAI_xFRCR_FSALL_3                   0x00000800U        /*!<Bit 3 */
#define  SAI_xFRCR_FSALL_4                   0x00001000U        /*!<Bit 4 */
#define  SAI_xFRCR_FSALL_5                   0x00002000U        /*!<Bit 5 */
#define  SAI_xFRCR_FSALL_6                   0x00004000U        /*!<Bit 6 */

#define  SAI_xFRCR_FSDEF                     0x00010000U        /*!<Frame Synchronization Definition  */
#define  SAI_xFRCR_FSPOL                     0x00020000U        /*!<Frame Synchronization POLarity    */
#define  SAI_xFRCR_FSOFF                     0x00040000U        /*!<Frame Synchronization OFFset      */

/* Legacy define */                          
#define  SAI_xFRCR_FSPO                      SAI_xFRCR_FSPOL

/******************  Bit definition for SAI_xSLOTR register  *******************/
#define  SAI_xSLOTR_FBOFF                    0x0000001FU        /*!<FBOFF[4:0](First Bit Offset)  */
#define  SAI_xSLOTR_FBOFF_0                  0x00000001U        /*!<Bit 0 */
#define  SAI_xSLOTR_FBOFF_1                  0x00000002U        /*!<Bit 1 */
#define  SAI_xSLOTR_FBOFF_2                  0x00000004U        /*!<Bit 2 */
#define  SAI_xSLOTR_FBOFF_3                  0x00000008U        /*!<Bit 3 */
#define  SAI_xSLOTR_FBOFF_4                  0x00000010U        /*!<Bit 4 */

#define  SAI_xSLOTR_SLOTSZ                   0x000000C0U        /*!<SLOTSZ[1:0] (Slot size)  */
#define  SAI_xSLOTR_SLOTSZ_0                 0x00000040U        /*!<Bit 0 */
#define  SAI_xSLOTR_SLOTSZ_1                 0x00000080U        /*!<Bit 1 */

#define  SAI_xSLOTR_NBSLOT                   0x00000F00U        /*!<NBSLOT[3:0] (Number of Slot in audio Frame)  */
#define  SAI_xSLOTR_NBSLOT_0                 0x00000100U        /*!<Bit 0 */
#define  SAI_xSLOTR_NBSLOT_1                 0x00000200U        /*!<Bit 1 */
#define  SAI_xSLOTR_NBSLOT_2                 0x00000400U        /*!<Bit 2 */
#define  SAI_xSLOTR_NBSLOT_3                 0x00000800U        /*!<Bit 3 */

#define  SAI_xSLOTR_SLOTEN                   0xFFFF0000U        /*!<SLOTEN[15:0] (Slot Enable)  */

/*******************  Bit definition for SAI_xIMR register  *******************/
#define  SAI_xIMR_OVRUDRIE                   0x00000001U        /*!<Overrun underrun interrupt enable                              */
#define  SAI_xIMR_MUTEDETIE                  0x00000002U        /*!<Mute detection interrupt enable                                */
#define  SAI_xIMR_WCKCFGIE                   0x00000004U        /*!<Wrong Clock Configuration interrupt enable                     */
#define  SAI_xIMR_FREQIE                     0x00000008U        /*!<FIFO request interrupt enable                                  */
#define  SAI_xIMR_CNRDYIE                    0x00000010U        /*!<Codec not ready interrupt enable                               */
#define  SAI_xIMR_AFSDETIE                   0x00000020U        /*!<Anticipated frame synchronization detection interrupt enable   */
#define  SAI_xIMR_LFSDETIE                   0x00000040U        /*!<Late frame synchronization detection interrupt enable          */

/********************  Bit definition for SAI_xSR register  *******************/
#define  SAI_xSR_OVRUDR                      0x00000001U         /*!<Overrun underrun                               */
#define  SAI_xSR_MUTEDET                     0x00000002U         /*!<Mute detection                                 */
#define  SAI_xSR_WCKCFG                      0x00000004U         /*!<Wrong Clock Configuration                      */
#define  SAI_xSR_FREQ                        0x00000008U         /*!<FIFO request                                   */
#define  SAI_xSR_CNRDY                       0x00000010U         /*!<Codec not ready                                */
#define  SAI_xSR_AFSDET                      0x00000020U         /*!<Anticipated frame synchronization detection    */
#define  SAI_xSR_LFSDET                      0x00000040U         /*!<Late frame synchronization detection           */

#define  SAI_xSR_FLVL                        0x00070000U         /*!<FLVL[2:0] (FIFO Level Threshold)               */
#define  SAI_xSR_FLVL_0                      0x00010000U         /*!<Bit 0 */
#define  SAI_xSR_FLVL_1                      0x00020000U         /*!<Bit 1 */
#define  SAI_xSR_FLVL_2                      0x00040000U         /*!<Bit 2 */

/******************  Bit definition for SAI_xCLRFR register  ******************/
#define  SAI_xCLRFR_COVRUDR                  0x00000001U        /*!<Clear Overrun underrun                               */
#define  SAI_xCLRFR_CMUTEDET                 0x00000002U        /*!<Clear Mute detection                                 */
#define  SAI_xCLRFR_CWCKCFG                  0x00000004U        /*!<Clear Wrong Clock Configuration                      */
#define  SAI_xCLRFR_CFREQ                    0x00000008U        /*!<Clear FIFO request                                   */
#define  SAI_xCLRFR_CCNRDY                   0x00000010U        /*!<Clear Codec not ready                                */
#define  SAI_xCLRFR_CAFSDET                  0x00000020U        /*!<Clear Anticipated frame synchronization detection    */
#define  SAI_xCLRFR_CLFSDET                  0x00000040U        /*!<Clear Late frame synchronization detection           */

/******************  Bit definition for SAI_xDR register  *********************/
#define  SAI_xDR_DATA                        0xFFFFFFFFU        

/*******************  Bit definition for SAI_PDMCR register  ******************/
#define  SAI_PDMCR_PDMEN                  0x00000001U           /*!<PDM Enable                                          */

#define  SAI_PDMCR_MICNBR                 0x00000030U           /*!<Number of microphones                               */
#define  SAI_PDMCR_MICNBR_0               0x00000010U           /*!<Bit 0 */
#define  SAI_PDMCR_MICNBR_1               0x00000020U           /*!<Bit 1 */

#define  SAI_PDMCR_CKEN1                  0x00000100U           /*!<Clock enable of bitstream clock number 1            */
#define  SAI_PDMCR_CKEN2                  0x00000200U           /*!<Clock enable of bitstream clock number 2            */
#define  SAI_PDMCR_CKEN3                  0x00000400U           /*!<Clock enable of bitstream clock number 3            */
#define  SAI_PDMCR_CKEN4                  0x00000800U           /*!<Clock enable of bitstream clock number 4            */

/******************  Bit definition for SAI_PDMDLY register  ******************/
#define  SAI_PDMDLY_DLYM1L                0x00000007U           /*!<DLYM1L[2:0] (Delay line adjust for left microphone of pair 1) */
#define  SAI_PDMDLY_DLYM1L_0              0x00000001U           /*!<Bit 0 */
#define  SAI_PDMDLY_DLYM1L_1              0x00000002U           /*!<Bit 1 */
#define  SAI_PDMDLY_DLYM1L_2              0x00000004U           /*!<Bit 2 */

#define  SAI_PDMDLY_DLYM1R                0x00000070U           /*!<DLYM1R[2:0] (Delay line adjust for right microphone of pair 1) */
#define  SAI_PDMDLY_DLYM1R_0              0x00000010U           /*!<Bit 0 */
#define  SAI_PDMDLY_DLYM1R_1              0x00000020U           /*!<Bit 1 */
#define  SAI_PDMDLY_DLYM1R_2              0x00000040U           /*!<Bit 2 */

#define  SAI_PDMDLY_DLYM2L                0x00000700U           /*!<DLYM2L[2:0] (Delay line adjust for left microphone of pair 2) */
#define  SAI_PDMDLY_DLYM2L_0              0x00000100U           /*!<Bit 0 */
#define  SAI_PDMDLY_DLYM2L_1              0x00000200U           /*!<Bit 1 */
#define  SAI_PDMDLY_DLYM2L_2              0x00000400U           /*!<Bit 2 */

#define  SAI_PDMDLY_DLYM2R                0x00007000U           /*!<DLYM2R[2:0] (Delay line adjust for right microphone of pair 2)*/
#define  SAI_PDMDLY_DLYM2R_0              0x00001000U           /*!<Bit 0 */
#define  SAI_PDMDLY_DLYM2R_1              0x00002000U           /*!<Bit 1 */
#define  SAI_PDMDLY_DLYM2R_2              0x00004000U           /*!<Bit 2 */

#define  SAI_PDMDLY_DLYM3L                0x00070000U           /*!<DLYM3L[2:0] (Delay line adjust for left microphone of pair 3)*/
#define  SAI_PDMDLY_DLYM3L_0              0x00010000U           /*!<Bit 0 */
#define  SAI_PDMDLY_DLYM3L_1              0x00020000U           /*!<Bit 1 */
#define  SAI_PDMDLY_DLYM3L_2              0x00040000U           /*!<Bit 2 */

#define  SAI_PDMDLY_DLYM3R                0x00700000U           /*!<DLYM3R[2:0] (Delay line adjust for right microphone of pair 3)*/
#define  SAI_PDMDLY_DLYM3R_0              0x00100000U           /*!<Bit 0 */
#define  SAI_PDMDLY_DLYM3R_1              0x00200000U           /*!<Bit 1 */
#define  SAI_PDMDLY_DLYM3R_2              0x00400000U           /*!<Bit 2 */

#define  SAI_PDMDLY_DLYM4L                0x07000000U           /*!<DLYM4L[2:0] (Delay line adjust for left microphone of pair 4)*/
#define  SAI_PDMDLY_DLYM4L_0              0x01000000U           /*!<Bit 0 */
#define  SAI_PDMDLY_DLYM4L_1              0x02000000U           /*!<Bit 1 */
#define  SAI_PDMDLY_DLYM4L_2              0x04000000U           /*!<Bit 2 */

#define  SAI_PDMDLY_DLYM4R                0x70000000U           /*!<DLYM4R[2:0] (Delay line adjust for right microphone of pair 4)*/
#define  SAI_PDMDLY_DLYM4R_0              0x10000000U           /*!<Bit 0 */
#define  SAI_PDMDLY_DLYM4R_1              0x20000000U           /*!<Bit 1 */
#define  SAI_PDMDLY_DLYM4R_2              0x40000000U           /*!<Bit 2 */

/******************************************************************************/
/*                                                                            */
/*                          LCD Controller (LCD)                              */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for LCD_CR register  *********************/
#define LCD_CR_LCDEN               ((uint32_t)0x00000001)     /*!< LCD Enable Bit */
#define LCD_CR_VSEL                ((uint32_t)0x00000002)     /*!< Voltage source selector Bit */

#define LCD_CR_DUTY                ((uint32_t)0x0000001C)     /*!< DUTY[2:0] bits (Duty selector) */
#define LCD_CR_DUTY_0              ((uint32_t)0x00000004)     /*!< Duty selector Bit 0 */
#define LCD_CR_DUTY_1              ((uint32_t)0x00000008)     /*!< Duty selector Bit 1 */
#define LCD_CR_DUTY_2              ((uint32_t)0x00000010)     /*!< Duty selector Bit 2 */

#define LCD_CR_BIAS                ((uint32_t)0x00000060)     /*!< BIAS[1:0] bits (Bias selector) */
#define LCD_CR_BIAS_0              ((uint32_t)0x00000020)     /*!< Bias selector Bit 0 */
#define LCD_CR_BIAS_1              ((uint32_t)0x00000040)     /*!< Bias selector Bit 1 */

#define LCD_CR_MUX_SEG             ((uint32_t)0x00000080)     /*!< Mux Segment Enable Bit */
#define LCD_CR_BUFEN               ((uint32_t)0x00000100)     /*!< Voltage output buffer enable */
/*******************  Bit definition for LCD_FCR register  ********************/
#define LCD_FCR_HD                 ((uint32_t)0x00000001)     /*!< High Drive Enable Bit */
#define LCD_FCR_SOFIE              ((uint32_t)0x00000002)     /*!< Start of Frame Interrupt Enable Bit */
#define LCD_FCR_UDDIE              ((uint32_t)0x00000008)     /*!< Update Display Done Interrupt Enable Bit */

#define LCD_FCR_PON                ((uint32_t)0x00000070)     /*!< PON[2:0] bits (Puls ON Duration) */
#define LCD_FCR_PON_0              ((uint32_t)0x00000010)     /*!< Bit 0 */
#define LCD_FCR_PON_1              ((uint32_t)0x00000020)     /*!< Bit 1 */
#define LCD_FCR_PON_2              ((uint32_t)0x00000040)     /*!< Bit 2 */

#define LCD_FCR_DEAD               ((uint32_t)0x00000380)     /*!< DEAD[2:0] bits (DEAD Time) */
#define LCD_FCR_DEAD_0             ((uint32_t)0x00000080)     /*!< Bit 0 */
#define LCD_FCR_DEAD_1             ((uint32_t)0x00000100)     /*!< Bit 1 */
#define LCD_FCR_DEAD_2             ((uint32_t)0x00000200)     /*!< Bit 2 */

#define LCD_FCR_CC                 ((uint32_t)0x00001C00)     /*!< CC[2:0] bits (Contrast Control) */
#define LCD_FCR_CC_0               ((uint32_t)0x00000400)     /*!< Bit 0 */
#define LCD_FCR_CC_1               ((uint32_t)0x00000800)     /*!< Bit 1 */
#define LCD_FCR_CC_2               ((uint32_t)0x00001000)     /*!< Bit 2 */

#define LCD_FCR_BLINKF             ((uint32_t)0x0000E000)     /*!< BLINKF[2:0] bits (Blink Frequency) */
#define LCD_FCR_BLINKF_0           ((uint32_t)0x00002000)     /*!< Bit 0 */
#define LCD_FCR_BLINKF_1           ((uint32_t)0x00004000)     /*!< Bit 1 */
#define LCD_FCR_BLINKF_2           ((uint32_t)0x00008000)     /*!< Bit 2 */

#define LCD_FCR_BLINK              ((uint32_t)0x00030000)     /*!< BLINK[1:0] bits (Blink Enable) */
#define LCD_FCR_BLINK_0            ((uint32_t)0x00010000)     /*!< Bit 0 */
#define LCD_FCR_BLINK_1            ((uint32_t)0x00020000)     /*!< Bit 1 */

#define LCD_FCR_DIV                ((uint32_t)0x003C0000)     /*!< DIV[3:0] bits (Divider) */
#define LCD_FCR_PS                 ((uint32_t)0x03C00000)     /*!< PS[3:0] bits (Prescaler) */

/*******************  Bit definition for LCD_SR register  *********************/
#define LCD_SR_ENS                 ((uint32_t)0x00000001)     /*!< LCD Enabled Bit */
#define LCD_SR_SOF                 ((uint32_t)0x00000002)     /*!< Start Of Frame Flag Bit */
#define LCD_SR_UDR                 ((uint32_t)0x00000004)     /*!< Update Display Request Bit */
#define LCD_SR_UDD                 ((uint32_t)0x00000008)     /*!< Update Display Done Flag Bit */
#define LCD_SR_RDY                 ((uint32_t)0x00000010)     /*!< Ready Flag Bit */
#define LCD_SR_FCRSR               ((uint32_t)0x00000020)     /*!< LCD FCR Register Synchronization Flag Bit */

/*******************  Bit definition for LCD_CLR register  ********************/
#define LCD_CLR_SOFC               ((uint32_t)0x00000002)     /*!< Start Of Frame Flag Clear Bit */
#define LCD_CLR_UDDC               ((uint32_t)0x00000008)     /*!< Update Display Done Flag Clear Bit */

/*******************  Bit definition for LCD_RAM register  ********************/
#define LCD_RAM_SEGMENT_DATA       ((uint32_t)0xFFFFFFFF)     /*!< Segment Data Bits */

/******************************************************************************/
/*                                                                            */
/*                           SDMMC Interface                                  */
/*                                                                            */
/******************************************************************************/
/******************  Bit definition for SDMMC_POWER register  ******************/
#define  SDMMC_POWER_PWRCTRL                  ((uint32_t)0x00000003)               /*!<PWRCTRL[1:0] bits (Power supply control bits) */
#define  SDMMC_POWER_PWRCTRL_0                ((uint32_t)0x00000001)               /*!<Bit 0 */
#define  SDMMC_POWER_PWRCTRL_1                ((uint32_t)0x00000002)               /*!<Bit 1 */
#define  SDMMC_POWER_VSWITCH                  ((uint32_t)0x00000004)               /*!<Voltage switch sequence start */
#define  SDMMC_POWER_VSWITCHEN                ((uint32_t)0x00000008)               /*!<Voltage switch procedure enable */
#define  SDMMC_POWER_DIRPOL                   ((uint32_t)0x00000010)               /*!<Data and Command direction signals polarity selection */

/******************  Bit definition for SDMMC_CLKCR register  ******************/
#define  SDMMC_CLKCR_CLKDIV                   ((uint32_t)0x000003FF)            /*!<Clock divide factor             */
#define  SDMMC_CLKCR_PWRSAV                   ((uint32_t)0x00001000)            /*!<Power saving configuration bit  */

#define  SDMMC_CLKCR_WIDBUS                   ((uint32_t)0x0000C000)            /*!<WIDBUS[1:0] bits (Wide bus mode enable bit) */
#define  SDMMC_CLKCR_WIDBUS_0                 ((uint32_t)0x00004000)            /*!<Bit 0 */
#define  SDMMC_CLKCR_WIDBUS_1                 ((uint32_t)0x00008000)            /*!<Bit 1 */

#define  SDMMC_CLKCR_NEGEDGE                  ((uint32_t)0x00010000)            /*!<SDMMC_CK dephasing selection bit */
#define  SDMMC_CLKCR_HWFC_EN                  ((uint32_t)0x00020000)            /*!<HW Flow Control enable           */
#define  SDMMC_CLKCR_DDR                      ((uint32_t)0x00040000)            /*!<Data rate signaling selection    */
#define  SDMMC_CLKCR_BUSSPEED                 ((uint32_t)0x00080000)            /*!<Bus speed mode selection         */
#define  SDMMC_CLKCR_SELCLKRX                 ((uint32_t)0x00300000)           /*!<SELCLKRX[1:0] bits (Receive clock selection) */
#define  SDMMC_CLKCR_SELCLKRX_0               ((uint32_t)0x00100000)           /*!<Bit 0 */
#define  SDMMC_CLKCR_SELCLKRX_1               ((uint32_t)0x00200000)           /*!<Bit 1 */

/*******************  Bit definition for SDMMC_ARG register  *******************/
#define  SDMMC_ARG_CMDARG                     ((uint32_t)0xFFFFFFFF)            /*!<Command argument */

/*******************  Bit definition for SDMMC_CMD register  *******************/
#define  SDMMC_CMD_CMDINDEX                   ((uint32_t)0x0000003F)            /*!<Command Index                               */
#define  SDMMC_CMD_CMDTRANS                   ((uint32_t)0x00000040)            /*!<CPSM Treats command as a Data Transfer      */
#define  SDMMC_CMD_CMDSTOP                    ((uint32_t)0x00000080)            /*!<CPSM Treats command as a Stop               */

#define  SDMMC_CMD_WAITRESP                   ((uint32_t)0x00000300)            /*!<WAITRESP[1:0] bits (Wait for response bits) */
#define  SDMMC_CMD_WAITRESP_0                 ((uint32_t)0x00000100)            /*!< Bit 0 */
#define  SDMMC_CMD_WAITRESP_1                 ((uint32_t)0x00000200)            /*!< Bit 1 */

#define  SDMMC_CMD_WAITINT                    ((uint32_t)0x00000400)            /*!<CPSM Waits for Interrupt Request                               */
#define  SDMMC_CMD_WAITPEND                   ((uint32_t)0x00000800)            /*!<CPSM Waits for ends of data transfer (CmdPend internal signal) */
#define  SDMMC_CMD_CPSMEN                     ((uint32_t)0x00001000)            /*!<Command path state machine (CPSM) Enable bit                   */
#define  SDMMC_CMD_DTHOLD                     ((uint32_t)0x00002000)            /*!<Hold new data block transmission and reception in the DPSM     */
#define  SDMMC_CMD_BOOTMODE                   ((uint32_t)0x00004000)            /*!<Boot mode                                                      */
#define  SDMMC_CMD_BOOTEN                     ((uint32_t)0x00008000)            /*!<Enable Boot mode procedure                                     */
#define  SDMMC_CMD_CMDSUSPEND                 ((uint32_t)0x00010000)            /*!<CPSM Treats command as a Suspend or Resume command             */

/*****************  Bit definition for SDMMC_RESPCMD register  *****************/
#define  SDMMC_RESPCMD_RESPCMD                ((uint32_t)0x3F)               /*!<Response command index */

/******************  Bit definition for SDMMC_RESP0 register  ******************/
#define  SDMMC_RESP0_CARDSTATUS0              ((uint32_t)0xFFFFFFFF)        /*!<Card Status */

/******************  Bit definition for SDMMC_RESP1 register  ******************/
#define  SDMMC_RESP1_CARDSTATUS1              ((uint32_t)0xFFFFFFFF)        /*!<Card Status */

/******************  Bit definition for SDMMC_RESP2 register  ******************/
#define  SDMMC_RESP2_CARDSTATUS2              ((uint32_t)0xFFFFFFFF)        /*!<Card Status */

/******************  Bit definition for SDMMC_RESP3 register  ******************/
#define  SDMMC_RESP3_CARDSTATUS3              ((uint32_t)0xFFFFFFFF)        /*!<Card Status */

/******************  Bit definition for SDMMC_RESP4 register  ******************/
#define  SDMMC_RESP4_CARDSTATUS4              ((uint32_t)0xFFFFFFFF)        /*!<Card Status */

/******************  Bit definition for SDMMC_DTIMER register  *****************/
#define  SDMMC_DTIMER_DATATIME                ((uint32_t)0xFFFFFFFF)        /*!<Data timeout period. */

/******************  Bit definition for SDMMC_DLEN register  *******************/
#define  SDMMC_DLEN_DATALENGTH                ((uint32_t)0x01FFFFFF)        /*!<Data length value    */

/******************  Bit definition for SDMMC_DCTRL register  ******************/
#define  SDMMC_DCTRL_DTEN                     ((uint32_t)0x0001)            /*!<Data transfer enabled bit                */
#define  SDMMC_DCTRL_DTDIR                    ((uint32_t)0x0002)            /*!<Data transfer direction selection        */
#define  SDMMC_DCTRL_DTMODE                   ((uint32_t)0x000C)            /*!<DTMODE[1:0] Data transfer mode selection */
#define  SDMMC_DCTRL_DTMODE_0                 ((uint32_t)0x0004)            /*!<Bit 0                                    */
#define  SDMMC_DCTRL_DTMODE_1                 ((uint32_t)0x0008)            /*!<Bit 1                                    */

#define  SDMMC_DCTRL_DBLOCKSIZE               ((uint32_t)0x00F0)            /*!<DBLOCKSIZE[3:0] bits (Data block size) */
#define  SDMMC_DCTRL_DBLOCKSIZE_0             ((uint32_t)0x0010)            /*!<Bit 0 */
#define  SDMMC_DCTRL_DBLOCKSIZE_1             ((uint32_t)0x0020)            /*!<Bit 1 */
#define  SDMMC_DCTRL_DBLOCKSIZE_2             ((uint32_t)0x0040)            /*!<Bit 2 */
#define  SDMMC_DCTRL_DBLOCKSIZE_3             ((uint32_t)0x0080)            /*!<Bit 3 */

#define  SDMMC_DCTRL_RWSTART                  ((uint32_t)0x0100)            /*!<Read wait start                                 */
#define  SDMMC_DCTRL_RWSTOP                   ((uint32_t)0x0200)            /*!<Read wait stop                                  */
#define  SDMMC_DCTRL_RWMOD                    ((uint32_t)0x0400)            /*!<Read wait mode                                  */
#define  SDMMC_DCTRL_SDMMCEN                  ((uint32_t)0x0800)            /*!<SD I/O enable functions                         */
#define  SDMMC_DCTRL_BOOTACKEN                ((uint32_t)0x1000)            /*!<Enable the reception of the Boot Acknowledgment */
#define  SDMMC_DCTRL_FIFORST                  ((uint32_t)0x2000)            /*!<FIFO reset                                      */

/******************  Bit definition for SDMMC_DCOUNT register  *****************/
#define  SDMMC_DCOUNT_DATACOUNT               ((uint32_t)0x01FFFFFF)        /*!<Data count value */

/******************  Bit definition for SDMMC_STA register  ********************/
#define  SDMMC_STA_CCRCFAIL                   ((uint32_t)0x00000001)        /*!<Command response received (CRC check failed)  */
#define  SDMMC_STA_DCRCFAIL                   ((uint32_t)0x00000002)        /*!<Data block sent/received (CRC check failed)   */
#define  SDMMC_STA_CTIMEOUT                   ((uint32_t)0x00000004)        /*!<Command response timeout                      */
#define  SDMMC_STA_DTIMEOUT                   ((uint32_t)0x00000008)        /*!<Data timeout                                  */
#define  SDMMC_STA_TXUNDERR                   ((uint32_t)0x00000010)        /*!<Transmit FIFO underrun error                  */
#define  SDMMC_STA_RXOVERR                    ((uint32_t)0x00000020)        /*!<Received FIFO overrun error                   */
#define  SDMMC_STA_CMDREND                    ((uint32_t)0x00000040)        /*!<Command response received (CRC check passed)  */
#define  SDMMC_STA_CMDSENT                    ((uint32_t)0x00000080)        /*!<Command sent (no response required)           */
#define  SDMMC_STA_DATAEND                    ((uint32_t)0x00000100)        /*!<Data end (data counter, SDIDCOUNT, is zero)   */
#define  SDMMC_STA_DHOLD                      ((uint32_t)0x00000200)        /*!<Data transfer Hold                                                      */
#define  SDMMC_STA_DBCKEND                    ((uint32_t)0x00000400)        /*!<Data block sent/received (CRC check passed)   */
#define  SDMMC_STA_DABORT                     ((uint32_t)0x00000800)        /*!<Data transfer aborted by CMD12                                          */
#define  SDMMC_STA_CPSMACT                    ((uint32_t)0x00001000)        /*!<Data path state machine active                                          */
#define  SDMMC_STA_DPSMACT                    ((uint32_t)0x00002000)        /*!<Command path state machine active                                       */
#define  SDMMC_STA_TXFIFOHE                   ((uint32_t)0x00004000)        /*!<Transmit FIFO Half Empty: at least 8 words can be written into the FIFO */
#define  SDMMC_STA_RXFIFOHF                   ((uint32_t)0x00008000)        /*!<Receive FIFO Half Full: there are at least 8 words in the FIFO */
#define  SDMMC_STA_TXFIFOF                    ((uint32_t)0x00010000)        /*!<Transmit FIFO full                            */
#define  SDMMC_STA_RXFIFOF                    ((uint32_t)0x00020000)        /*!<Receive FIFO full                             */
#define  SDMMC_STA_TXFIFOE                    ((uint32_t)0x00040000)        /*!<Transmit FIFO empty                           */
#define  SDMMC_STA_RXFIFOE                    ((uint32_t)0x00080000)        /*!<Receive FIFO empty                            */
#define  SDMMC_STA_BUSYD0                     ((uint32_t)0x00100000)        /*!<Inverted value of SDMMC_D0 line (Busy)                                  */
#define  SDMMC_STA_BUSYD0END                  ((uint32_t)0x00200000)        /*!<End of SDMMC_D0 Busy following a CMD response detected                  */
#define  SDMMC_STA_SDMMCIT                    ((uint32_t)0x00400000)        /*!<SDIO interrupt received                                                 */
#define  SDMMC_STA_ACKFAIL                    ((uint32_t)0x00800000)        /*!<Boot Acknowledgment received (BootAck check fail)                       */
#define  SDMMC_STA_ACKTIMEOUT                 ((uint32_t)0x01000000)        /*!<Boot Acknowledgment timeout                                             */
#define  SDMMC_STA_VSWEND                     ((uint32_t)0x02000000)        /*!<Voltage switch critical timing section completion                       */
#define  SDMMC_STA_CKSTOP                     ((uint32_t)0x04000000)        /*!<SDMMC_CK stopped in Voltage switch procedure                            */
#define  SDMMC_STA_IDMATE                     ((uint32_t)0x08000000)        /*!<IDMA transfer error                                                     */
#define  SDMMC_STA_IDMABTC                    ((uint32_t)0x10000000)        /*!<IDMA buffer transfer complete                                           */

/*******************  Bit definition for SDMMC_ICR register  *******************/
#define  SDMMC_ICR_CCRCFAILC                  ((uint32_t)0x00000001)        /*!<CCRCFAIL flag clear bit */
#define  SDMMC_ICR_DCRCFAILC                  ((uint32_t)0x00000002)        /*!<DCRCFAIL flag clear bit */
#define  SDMMC_ICR_CTIMEOUTC                  ((uint32_t)0x00000004)        /*!<CTIMEOUT flag clear bit */
#define  SDMMC_ICR_DTIMEOUTC                  ((uint32_t)0x00000008)        /*!<DTIMEOUT flag clear bit */
#define  SDMMC_ICR_TXUNDERRC                  ((uint32_t)0x00000010)        /*!<TXUNDERR flag clear bit */
#define  SDMMC_ICR_RXOVERRC                   ((uint32_t)0x00000020)        /*!<RXOVERR flag clear bit  */
#define  SDMMC_ICR_CMDRENDC                   ((uint32_t)0x00000040)        /*!<CMDREND flag clear bit  */
#define  SDMMC_ICR_CMDSENTC                   ((uint32_t)0x00000080)        /*!<CMDSENT flag clear bit  */
#define  SDMMC_ICR_DATAENDC                   ((uint32_t)0x00000100)        /*!<DATAEND flag clear bit  */
#define  SDMMC_ICR_DHOLDC                     ((uint32_t)0x00000200)        /*!<DHOLD flag clear bit       */
#define  SDMMC_ICR_DBCKENDC                   ((uint32_t)0x00000400)        /*!<DBCKEND flag clear bit  */
#define  SDMMC_ICR_DABORTC                    ((uint32_t)0x00000800)        /*!<DABORTC flag clear bit     */
#define  SDMMC_ICR_BUSYD0ENDC                 ((uint32_t)0x00200000)        /*!<BUSYD0ENDC flag clear bit  */
#define  SDMMC_ICR_SDMMCITC                   ((uint32_t)0x00400000)        /*!<SDIOIT flag clear bit      */
#define  SDMMC_ICR_ACKFAILC                   ((uint32_t)0x00800000)        /*!<ACKFAILC flag clear bit    */
#define  SDMMC_ICR_ACKTIMEOUTC                ((uint32_t)0x01000000)        /*!<ACKTIMEOUTC flag clear bit */
#define  SDMMC_ICR_VSWENDC                    ((uint32_t)0x02000000)        /*!<VSWENDC flag clear bit     */
#define  SDMMC_ICR_CKSTOPC                    ((uint32_t)0x04000000)        /*!<CKSTOPC flag clear bit     */
#define  SDMMC_ICR_IDMATEC                    ((uint32_t)0x08000000)        /*!<IDMATEC flag clear bit     */
#define  SDMMC_ICR_IDMABTCC                   ((uint32_t)0x10000000)        /*!<IDMABTCC flag clear bit    */

/******************  Bit definition for SDMMC_MASK register  *******************/
#define  SDMMC_MASK_CCRCFAILIE                ((uint32_t)0x00000001)        /*!<Command CRC Fail Interrupt Enable          */
#define  SDMMC_MASK_DCRCFAILIE                ((uint32_t)0x00000002)        /*!<Data CRC Fail Interrupt Enable             */
#define  SDMMC_MASK_CTIMEOUTIE                ((uint32_t)0x00000004)        /*!<Command TimeOut Interrupt Enable           */
#define  SDMMC_MASK_DTIMEOUTIE                ((uint32_t)0x00000008)        /*!<Data TimeOut Interrupt Enable              */
#define  SDMMC_MASK_TXUNDERRIE                ((uint32_t)0x00000010)        /*!<Tx FIFO UnderRun Error Interrupt Enable    */
#define  SDMMC_MASK_RXOVERRIE                 ((uint32_t)0x00000020)        /*!<Rx FIFO OverRun Error Interrupt Enable     */
#define  SDMMC_MASK_CMDRENDIE                 ((uint32_t)0x00000040)        /*!<Command Response Received Interrupt Enable */
#define  SDMMC_MASK_CMDSENTIE                 ((uint32_t)0x00000080)        /*!<Command Sent Interrupt Enable              */
#define  SDMMC_MASK_DATAENDIE                 ((uint32_t)0x00000100)        /*!<Data End Interrupt Enable                  */
#define  SDMMC_MASK_DHOLDIE                   ((uint32_t)0x00000200)        /*!<Data Hold Interrupt Enable                 */
#define  SDMMC_MASK_DBCKENDIE                 ((uint32_t)0x00000400)        /*!<Data Block End Interrupt Enable            */
#define  SDMMC_MASK_DABORTIE                  ((uint32_t)0x00000800)        /*!<Data transfer aborted interrupt enable     */

#define  SDMMC_MASK_TXFIFOHEIE                ((uint32_t)0x00004000)        /*!<Tx FIFO Half Empty interrupt Enable        */
#define  SDMMC_MASK_RXFIFOHFIE                ((uint32_t)0x00008000)        /*!<Rx FIFO Half Full interrupt Enable         */

#define  SDMMC_MASK_RXFIFOFIE                 ((uint32_t)0x00020000)        /*!<Rx FIFO Full interrupt Enable              */
#define  SDMMC_MASK_TXFIFOEIE                 ((uint32_t)0x00040000)        /*!<Tx FIFO Empty interrupt Enable             */

#define  SDMMC_MASK_BUSYD0ENDIE               ((uint32_t)0x00200000)        /*!<BUSYD0ENDIE interrupt Enable */
#define  SDMMC_MASK_SDMMCITIE                 ((uint32_t)0x00400000)        /*!<SDMMC Mode Interrupt Received interrupt Enable */
#define  SDMMC_MASK_ACKFAILIE                 ((uint32_t)0x00800000)        /*!<Acknowledgment Fail Interrupt Enable */
#define  SDMMC_MASK_ACKTIMEOUTIE              ((uint32_t)0x01000000)        /*!<Acknowledgment timeout Interrupt Enable */
#define  SDMMC_MASK_VSWENDIE                  ((uint32_t)0x02000000)        /*!<Voltage switch critical timing section completion Interrupt Enable */
#define  SDMMC_MASK_CKSTOPIE                  ((uint32_t)0x04000000)        /*!<Voltage Switch clock stopped Interrupt Enable */
#define  SDMMC_MASK_IDMABTCIE                 ((uint32_t)0x10000000)        /*!<IDMA buffer transfer complete Interrupt Enable */

/*****************  Bit definition for SDMMC_FIFOCNT register  *****************/
#define  SDMMC_FIFOCNT_FIFOCOUNT              ((uint32_t)0x00FFFFFF)        /*!<Remaining number of words to be written to or read from the FIFO */

/******************  Bit definition for SDMMC_FIFO register  *******************/
#define  SDMMC_FIFO_FIFODATA                  ((uint32_t)0xFFFFFFFF)        /*!<Receive and transmit FIFO data */

/******************  Bit definition for SDMMC_IDMACTRL register ****************/
#define SDMMC_IDMA_IDMAEN                     ((uint32_t)0x00000001)        /*!< Enable the internal DMA of the SDMMC peripheral */
#define SDMMC_IDMA_IDMABMODE                  ((uint32_t)0x00000002)        /*!< Enable double buffer mode for IDMA */
#define SDMMC_IDMA_IDMABACT                   ((uint32_t)0x00000004)        /*!< Uses buffer 1 when double buffer mode is selected */ 

/******************************************************************************/
/*                                                                            */
/*                        Serial Peripheral Interface (SPI)                   */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for SPI_CR1 register  ********************/
#define  SPI_CR1_SPE                         ((uint32_t)0x00000001)        /*!<Serial Peripheral Enable                       */

#define  SPI_CR1_MASRX                       ((uint32_t)0x00000100)        /*!<Master automatic SUSP in Receive mode          */
#define  SPI_CR1_CSTART                      ((uint32_t)0x00000200)        /*!<Master transfer start                          */
#define  SPI_CR1_CSUSP                       ((uint32_t)0x00000400)        /*!<Master SUSPend request                         */
#define  SPI_CR1_HDDIR                       ((uint32_t)0x00000800)        /*!<Rx/Tx direction at Half-duplex mode            */

#define  SPI_CR1_SSI                         ((uint32_t)0x00001000)        /*!<Internal SS signal input level                 */

#define  SPI_CR1_IOLOCK                      ((uint32_t)0x00010000)        /*!<Locking the AF configuration of associated IOs */

/*******************  Bit definition for SPI_CR2 register  ********************/
#define  SPI_CR2_TSER                      ((uint32_t)0xFFFF0000)         /*!<Number of data transfer extension                */

#define  SPI_CR2_TSIZE                     ((uint32_t)0x0000FFFF)         /*!<Number of data at current transfer               */

/*******************  Bit definition for SPI_CFG1 register  ********************/
#define  SPI_CFG1_DSIZE                      ((uint32_t)0x0000001F)        /*!<DSIZE [4:0]: Number of bits in at single SPI data frame */
#define  SPI_CFG1_DSIZE_0                    ((uint32_t)0x00000001)        /*!<Bit 0                */
#define  SPI_CFG1_DSIZE_1                    ((uint32_t)0x00000002)        /*!<Bit 1                */
#define  SPI_CFG1_DSIZE_2                    ((uint32_t)0x00000004)        /*!<Bit 2                */
#define  SPI_CFG1_DSIZE_3                    ((uint32_t)0x00000008)        /*!<Bit 3                */
#define  SPI_CFG1_DSIZE_4                    ((uint32_t)0x00000010)        /*!<Bit 4                */

#define  SPI_CFG1_FTHLV                      ((uint32_t)0x000001E0)        /*!<FTHVL [3:0]: FIFO threshold level*/
#define  SPI_CFG1_FTHLV_0                    ((uint32_t)0x00000020)        /*!<Bit 0                */
#define  SPI_CFG1_FTHLV_1                    ((uint32_t)0x00000040)        /*!<Bit 1                */
#define  SPI_CFG1_FTHLV_2                    ((uint32_t)0x00000080)        /*!<Bit 2                */
#define  SPI_CFG1_FTHLV_3                    ((uint32_t)0x00000100)        /*!<Bit 3                */

#define  SPI_CFG1_UDRCFG                      ((uint32_t)0x00000600)        /*!<UDRCFG [1:0]: Behavior of slave transmitter at underrun condition*/
#define  SPI_CFG1_UDRCFG_0                    ((uint32_t)0x00000200)        /*!<Bit 0                */
#define  SPI_CFG1_UDRCFG_1                    ((uint32_t)0x00000400)        /*!<Bit 1                */


#define  SPI_CFG1_UDRDET                      ((uint32_t)0x00001800)        /*!<UDRDET [1:0]: Detection of underrun condition at slave transmitter*/
#define  SPI_CFG1_UDRDET_0                    ((uint32_t)0x00000800)        /*!<Bit 0                */
#define  SPI_CFG1_UDRDET_1                    ((uint32_t)0x00001000)        /*!<Bit 1                */

#define  SPI_CFG1_RXDMAEN                     ((uint32_t)0x00004000)        /*!<Rx DMA stream enable                */
#define  SPI_CFG1_TXDMAEN                     ((uint32_t)0x00008000)        /*!<Tx DMA stream enable                */

#define  SPI_CFG1_CRCSIZE                      ((uint32_t)0x001F0000)        /*!<CRCSIZE [4:0]: Length of CRC frame*/
#define  SPI_CFG1_CRCSIZE_0                    ((uint32_t)0x00010000)        /*!<Bit 0                */
#define  SPI_CFG1_CRCSIZE_1                    ((uint32_t)0x00020000)        /*!<Bit 1                */
#define  SPI_CFG1_CRCSIZE_2                    ((uint32_t)0x00040000)        /*!<Bit 2                */
#define  SPI_CFG1_CRCSIZE_3                    ((uint32_t)0x00080000)        /*!<Bit 3                */
#define  SPI_CFG1_CRCSIZE_4                    ((uint32_t)0x00100000)        /*!<Bit 4                */

#define  SPI_CFG1_CRC32                        ((uint32_t)0x00200000)        /*!<32-bit CRC polynomial configuration */
#define  SPI_CFG1_CRCEN                        ((uint32_t)0x00400000)        /*!<Hardware CRC computation enable */
#define  SPI_CFG1_MRSAMPE                      ((uint32_t)0x06000000)        /*!< Master receiver sampling edge at synchronous sampling */
#define  SPI_CFG1_MRSAMPE_0                    ((uint32_t)0x02000000)        /*!<Bit 0                */
#define  SPI_CFG1_MRSAMPE_1                    ((uint32_t)0x04000000)        /*!<Bit 1                */

#define  SPI_CFG1_MRSAMP                       ((uint32_t)0x08000000)        /*!< Master receiver sampling clock*/

#define  SPI_CFG1_MBR                          ((uint32_t)0x70000000)        /*!<Master baud rate                */
#define  SPI_CFG1_MBR_0                        ((uint32_t)0x10000000)        /*!<Bit 0                */
#define  SPI_CFG1_MBR_1                        ((uint32_t)0x20000000)        /*!<Bit 1                */
#define  SPI_CFG1_MBR_2                        ((uint32_t)0x40000000)        /*!<Bit 2                */

#define  SPI_CFG1_MCKS                         ((uint32_t)0x80000000)        /*!<Master clock source   */

/*******************  Bit definition for SPI_CFG2 register  ********************/
#define  SPI_CFG2_CPHA                         ((uint16_t)0x01000000)            /*!<Clock Phase      */
#define  SPI_CFG2_CPOL                         ((uint16_t)0x02000000)            /*!<Clock Polarity   */

#define  SPI_CFG2_COMM                         ((uint32_t)0x00060000)        /*!<COMM [1:0]: SPI Communication Mode*/
#define  SPI_CFG2_COMM_0                       ((uint32_t)0x00020000)        /*!<Bit 0                */
#define  SPI_CFG2_COMM_1                       ((uint32_t)0x00040000)        /*!<Bit 1                */
#define  SPI_CFG2_MASTER                       ((uint32_t)0x00400000)        /*!<SPI Master               */

#define  SPI_CFG2_SP                          ((uint32_t)0x00380000)        /*!<SP[2:0]: Serial Protocol */
#define  SPI_CFG2_SP_0                        ((uint32_t)0x00080000)        /*!<Bit 0                */
#define  SPI_CFG2_SP_1                        ((uint32_t)0x00100000)        /*!<Bit 1                */
#define  SPI_CFG2_SP_2                        ((uint32_t)0x00200000)        /*!<Bit 2                */


#define  SPI_CFG2_LSBFRST                     ((uint32_t)0x00800000)        /*!<Data frame format               */

#define  SPI_CFG2_SSM                         ((uint32_t)0x04000000)        /*!<Software slave management */

#define  SPI_CFG2_AFCNTR                      ((uint32_t)0x80000000)        /*!<Alternate function GPIOs control */

/*******************  Bit definition for SPI_SR register  ********************/
#define  SPI_SR_TXP                           ((uint32_t)0x00000002)        /*!<Tx-Packet space available      */
#define  SPI_SR_RXP                           ((uint32_t)0x00000001)        /*!<Rx-Packet available            */
#define  SPI_SR_UDR                           ((uint32_t)0x00000020)        /*!<TXP interrupt enable */
#define  SPI_SR_OVR                           ((uint32_t)0x00000040)        /*!<Rx-Packet available            */



/*******************  Bit definition for SPI_IER register  ********************/
#define  SPI_IER_RXP                          ((uint32_t)0x00000001)        /*!<RXP Interrupt Enable*/
#define  SPI_IER_TXP                          ((uint32_t)0x00000002)        /*!<TXP interrupt enable*/
#define  SPI_IER_UDRIE                        ((uint32_t)0x00000020)        /*!<TXP interrupt enable */
#define  SPI_IER_OVRIE                        ((uint32_t)0x00000040)        /*!<TXP interrupt enable */

/*******************  Bit definition for SPI_IFCR register  ********************/
#define  SPI_IFCR_UDRC                         ((uint32_t)0x00000020)        /*!<TXP interrupt enable */

#define  SPI_IFCR_OVRC                         ((uint32_t)0x00000040)        /*!<TXP interrupt enable */

/******************  Bit definition for SPI_I2SCGFR register  *****************/
#define SPI_I2SCGFR_CHLEN                   ((uint32_t)0x00000400)            /*!<Channel length (number of bits per audio channel) */
#define SPI_I2SCGFR_DATLEN                  ((uint32_t)0x00000300)            /*!<DATLEN[1:0] bits (Data length to be transferred) */
#define SPI_I2SCGFR_DATLEN_0                ((uint32_t)0x00000100)            /*!<Bit 0 */
#define SPI_I2SCGFR_DATLEN_1                ((uint32_t)0x00000200)            /*!<Bit 1 */
#define SPI_I2SCGFR_CKPOL                   ((uint32_t)0x00000800)            /*!<steady state clock polarity */
#define SPI_I2SCGFR_I2SSTD                  ((uint32_t)0x00000030)            /*!<I2SSTD[1:0] bits (I2S standard selection) */
#define SPI_I2SCGFR_I2SSTD_0                ((uint32_t)0x00000010)            /*!<Bit 0 */
#define SPI_I2SCGFR_I2SSTD_1                ((uint32_t)0x00000020)            /*!<Bit 1 */
#define SPI_I2SCGFR_PCMSYNC                 ((uint32_t)0x00000080)            /*!<PCM frame synchronization */
#define SPI_I2SCGFR_I2SCFG                  ((uint32_t)0x0000000E)            /*!<I2SCGFR[1:0] bits (I2S configuration mode) */
#define SPI_I2SCGFR_I2SCFG_0                ((uint32_t)0x00000002)            /*!<Bit 0 */
#define SPI_I2SCGFR_I2SCFG_1                ((uint32_t)0x00000004)            /*!<Bit 1 */
#define SPI_I2SCGFR_I2SCFG_2                ((uint32_t)0x00000008)            /*!<Bit 2 */

#define SPI_I2SCGFR_I2SMOD                  ((uint32_t)0x00000001)            /*!<I2S mode selection */

#define SPI_I2SCGFR_I2SDIV                  ((uint32_t)0x00FF0000)            /*!<I2S Linear prescaler */
#define SPI_I2SCGFR_ODD                     ((uint32_t)0x01000000)            /*!<Odd factor for the prescaler */
#define SPI_I2SCGFR_MCKOE                   ((uint32_t)0x02000000)            /*!<Master Clock Output Enable */


/******************************************************************************/
/*                                                                            */
/*                                    QUADSPI                                 */
/*                                                                            */
/******************************************************************************/
/*****************  Bit definition for QUADSPI_CR register  *******************/
#define  QUADSPI_CR_EN                           ((uint32_t)0x00000001)            /*!< Enable */
#define  QUADSPI_CR_ABORT                        ((uint32_t)0x00000002)            /*!< Abort request */
#define  QUADSPI_CR_DMAEN                        ((uint32_t)0x00000004)            /*!< DMA Enable */
#define  QUADSPI_CR_TCEN                         ((uint32_t)0x00000008)            /*!< Timeout Counter Enable */
#define  QUADSPI_CR_SSHIFT                       ((uint32_t)0x00000010)            /*!< SSHIFT Sample Shift */
#define  QUADSPI_CR_DFM                          ((uint32_t)0x00000040)            /*!< Dual Flash Mode */
#define  QUADSPI_CR_FSEL                         ((uint32_t)0x00000080)            /*!< Flash Select */
#define  QUADSPI_CR_FTHRES                       ((uint32_t)0x00000F00)            /*!< FTHRES[3:0] FIFO Level */
#define  QUADSPI_CR_FTHRES_0                     ((uint32_t)0x00000100)            /*!< Bit 0 */
#define  QUADSPI_CR_FTHRES_1                     ((uint32_t)0x00000200)            /*!< Bit 1 */
#define  QUADSPI_CR_FTHRES_2                     ((uint32_t)0x00000400)            /*!< Bit 2 */
#define  QUADSPI_CR_FTHRES_3                     ((uint32_t)0x00000800)            /*!< Bit 3 */
#define  QUADSPI_CR_TEIE                         ((uint32_t)0x00010000)            /*!< Transfer Error Interrupt Enable */
#define  QUADSPI_CR_TCIE                         ((uint32_t)0x00020000)            /*!< Transfer Complete Interrupt Enable */
#define  QUADSPI_CR_FTIE                         ((uint32_t)0x00040000)            /*!< FIFO Threshold Interrupt Enable */
#define  QUADSPI_CR_SMIE                         ((uint32_t)0x00080000)            /*!< Status Match Interrupt Enable */
#define  QUADSPI_CR_TOIE                         ((uint32_t)0x00100000)            /*!< TimeOut Interrupt Enable */
#define  QUADSPI_CR_APMS                         ((uint32_t)0x00400000)            /*!< Bit 1 */
#define  QUADSPI_CR_PMM                          ((uint32_t)0x00800000)            /*!< Polling Match Mode */
#define  QUADSPI_CR_PRESCALER                    ((uint32_t)0xFF000000)            /*!< PRESCALER[7:0] Clock prescaler */
#define  QUADSPI_CR_PRESCALER_0                  ((uint32_t)0x01000000)            /*!< Bit 0 */
#define  QUADSPI_CR_PRESCALER_1                  ((uint32_t)0x02000000)            /*!< Bit 1 */
#define  QUADSPI_CR_PRESCALER_2                  ((uint32_t)0x04000000)            /*!< Bit 2 */
#define  QUADSPI_CR_PRESCALER_3                  ((uint32_t)0x08000000)            /*!< Bit 3 */
#define  QUADSPI_CR_PRESCALER_4                  ((uint32_t)0x10000000)            /*!< Bit 4 */
#define  QUADSPI_CR_PRESCALER_5                  ((uint32_t)0x20000000)            /*!< Bit 5 */
#define  QUADSPI_CR_PRESCALER_6                  ((uint32_t)0x40000000)            /*!< Bit 6 */
#define  QUADSPI_CR_PRESCALER_7                  ((uint32_t)0x80000000)            /*!< Bit 7 */

/*****************  Bit definition for QUADSPI_DCR register  ******************/
#define  QUADSPI_DCR_CKMODE                      ((uint32_t)0x00000001)            /*!< Mode 0 / Mode 3 */
#define  QUADSPI_DCR_CSHT                        ((uint32_t)0x00000700)            /*!< CSHT[2:0]: ChipSelect High Time */
#define  QUADSPI_DCR_CSHT_0                      ((uint32_t)0x00000100)            /*!< Bit 0 */
#define  QUADSPI_DCR_CSHT_1                      ((uint32_t)0x00000200)            /*!< Bit 1 */
#define  QUADSPI_DCR_CSHT_2                      ((uint32_t)0x00000400)            /*!< Bit 2 */
#define  QUADSPI_DCR_FSIZE                       ((uint32_t)0x001F0000)            /*!< FSIZE[4:0]: Flash Size */
#define  QUADSPI_DCR_FSIZE_0                     ((uint32_t)0x00010000)            /*!< Bit 0 */
#define  QUADSPI_DCR_FSIZE_1                     ((uint32_t)0x00020000)            /*!< Bit 1 */
#define  QUADSPI_DCR_FSIZE_2                     ((uint32_t)0x00040000)            /*!< Bit 2 */
#define  QUADSPI_DCR_FSIZE_3                     ((uint32_t)0x00080000)            /*!< Bit 3 */
#define  QUADSPI_DCR_FSIZE_4                     ((uint32_t)0x00100000)            /*!< Bit 4 */

/******************  Bit definition for QUADSPI_SR register  *******************/
#define  QUADSPI_SR_TEF                          ((uint32_t)0x00000001)             /*!< Transfer Error Flag */
#define  QUADSPI_SR_TCF                          ((uint32_t)0x00000002)             /*!< Transfer Complete Flag */
#define  QUADSPI_SR_FTF                          ((uint32_t)0x00000004)             /*!< FIFO Threshlod Flag */
#define  QUADSPI_SR_SMF                          ((uint32_t)0x00000008)             /*!< Status Match Flag */
#define  QUADSPI_SR_TOF                          ((uint32_t)0x00000010)             /*!< Timeout Flag */
#define  QUADSPI_SR_BUSY                         ((uint32_t)0x00000020)             /*!< Busy */
#define  QUADSPI_SR_FLEVEL                       ((uint32_t)0x00001F00)             /*!< FIFO Threshlod Flag */
#define  QUADSPI_SR_FLEVEL_0                     ((uint32_t)0x00000100)             /*!< Bit 0 */
#define  QUADSPI_SR_FLEVEL_1                     ((uint32_t)0x00000200)             /*!< Bit 1 */
#define  QUADSPI_SR_FLEVEL_2                     ((uint32_t)0x00000400)             /*!< Bit 2 */
#define  QUADSPI_SR_FLEVEL_3                     ((uint32_t)0x00000800)             /*!< Bit 3 */
#define  QUADSPI_SR_FLEVEL_4                     ((uint32_t)0x00001000)             /*!< Bit 4 */

/******************  Bit definition for QUADSPI_FCR register  ******************/
#define  QUADSPI_FCR_CTEF                        ((uint32_t)0x00000001)             /*!< Clear Transfer Error Flag */
#define  QUADSPI_FCR_CTCF                        ((uint32_t)0x00000002)             /*!< Clear Transfer Complete Flag */
#define  QUADSPI_FCR_CSMF                        ((uint32_t)0x00000008)             /*!< Clear Status Match Flag */
#define  QUADSPI_FCR_CTOF                        ((uint32_t)0x00000010)             /*!< Clear Timeout Flag */

/******************  Bit definition for QUADSPI_DLR register  ******************/
#define  QUADSPI_DLR_DL                        ((uint32_t)0xFFFFFFFF)               /*!< DL[31:0]: Data Length */

/******************  Bit definition for QUADSPI_CCR register  ******************/
#define  QUADSPI_CCR_INSTRUCTION                  ((uint32_t)0x000000FF)            /*!< INSTRUCTION[7:0]: Instruction */
#define  QUADSPI_CCR_INSTRUCTION_0                ((uint32_t)0x00000001)            /*!< Bit 0 */
#define  QUADSPI_CCR_INSTRUCTION_1                ((uint32_t)0x00000002)            /*!< Bit 1 */
#define  QUADSPI_CCR_INSTRUCTION_2                ((uint32_t)0x00000004)            /*!< Bit 2 */
#define  QUADSPI_CCR_INSTRUCTION_3                ((uint32_t)0x00000008)            /*!< Bit 3 */
#define  QUADSPI_CCR_INSTRUCTION_4                ((uint32_t)0x00000010)            /*!< Bit 4 */
#define  QUADSPI_CCR_INSTRUCTION_5                ((uint32_t)0x00000020)            /*!< Bit 5 */
#define  QUADSPI_CCR_INSTRUCTION_6                ((uint32_t)0x00000040)            /*!< Bit 6 */
#define  QUADSPI_CCR_INSTRUCTION_7                ((uint32_t)0x00000080)            /*!< Bit 7 */
#define  QUADSPI_CCR_IMODE                        ((uint32_t)0x00000300)            /*!< IMODE[1:0]: Instruction Mode */
#define  QUADSPI_CCR_IMODE_0                      ((uint32_t)0x00000100)            /*!< Bit 0 */
#define  QUADSPI_CCR_IMODE_1                      ((uint32_t)0x00000200)            /*!< Bit 1 */
#define  QUADSPI_CCR_ADMODE                       ((uint32_t)0x00000C00)            /*!< ADMODE[1:0]: Address Mode */
#define  QUADSPI_CCR_ADMODE_0                     ((uint32_t)0x00000400)            /*!< Bit 0 */
#define  QUADSPI_CCR_ADMODE_1                     ((uint32_t)0x00000800)            /*!< Bit 1 */
#define  QUADSPI_CCR_ADSIZE                       ((uint32_t)0x00003000)            /*!< ADSIZE[1:0]: Address Size */
#define  QUADSPI_CCR_ADSIZE_0                     ((uint32_t)0x00001000)            /*!< Bit 0 */
#define  QUADSPI_CCR_ADSIZE_1                     ((uint32_t)0x00002000)            /*!< Bit 1 */
#define  QUADSPI_CCR_ABMODE                       ((uint32_t)0x0000C000)            /*!< ABMODE[1:0]: Alternate Bytes Mode */
#define  QUADSPI_CCR_ABMODE_0                     ((uint32_t)0x00004000)            /*!< Bit 0 */
#define  QUADSPI_CCR_ABMODE_1                     ((uint32_t)0x00008000)            /*!< Bit 1 */
#define  QUADSPI_CCR_ABSIZE                       ((uint32_t)0x00030000)            /*!< ABSIZE[1:0]: Instruction Mode */
#define  QUADSPI_CCR_ABSIZE_0                     ((uint32_t)0x00010000)            /*!< Bit 0 */
#define  QUADSPI_CCR_ABSIZE_1                     ((uint32_t)0x00020000)            /*!< Bit 1 */
#define  QUADSPI_CCR_DCYC                         ((uint32_t)0x007C0000)            /*!< DCYC[4:0]: Dummy Cycles */
#define  QUADSPI_CCR_DCYC_0                       ((uint32_t)0x00040000)            /*!< Bit 0 */
#define  QUADSPI_CCR_DCYC_1                       ((uint32_t)0x00080000)            /*!< Bit 1 */
#define  QUADSPI_CCR_DCYC_2                       ((uint32_t)0x00100000)            /*!< Bit 2 */
#define  QUADSPI_CCR_DCYC_3                       ((uint32_t)0x00200000)            /*!< Bit 3 */
#define  QUADSPI_CCR_DCYC_4                       ((uint32_t)0x00400000)            /*!< Bit 4 */
#define  QUADSPI_CCR_DMODE                        ((uint32_t)0x03000000)            /*!< DMODE[1:0]: Data Mode */
#define  QUADSPI_CCR_DMODE_0                      ((uint32_t)0x01000000)            /*!< Bit 0 */
#define  QUADSPI_CCR_DMODE_1                      ((uint32_t)0x02000000)            /*!< Bit 1 */
#define  QUADSPI_CCR_FMODE                        ((uint32_t)0x0C000000)            /*!< FMODE[1:0]: Functional Mode */
#define  QUADSPI_CCR_FMODE_0                      ((uint32_t)0x04000000)            /*!< Bit 0 */
#define  QUADSPI_CCR_FMODE_1                      ((uint32_t)0x08000000)            /*!< Bit 1 */
#define  QUADSPI_CCR_SIOO                         ((uint32_t)0x10000000)            /*!< SIOO: Send Instruction Only Once Mode */
#define  QUADSPI_CCR_DHHC                         ((uint32_t)0x40000000)            /*!< DHHC: DDR hold half cycle */
#define  QUADSPI_CCR_DDRM                         ((uint32_t)0x80000000)            /*!< DDRM: Double Data Rate Mode */

/******************  Bit definition for QUADSPI_AR register  *******************/
#define  QUADSPI_AR_ADDRESS                       ((uint32_t)0xFFFFFFFF)            /*!< ADDRESS[31:0]: Address */

/******************  Bit definition for QUADSPI_ABR register  ******************/
#define  QUADSPI_ABR_ALTERNATE                    ((uint32_t)0xFFFFFFFF)            /*!< ALTERNATE[31:0]: Alternate Bytes */

/******************  Bit definition for QUADSPI_DR register  *******************/
#define  QUADSPI_DR_DATA                          ((uint32_t)0xFFFFFFFF)            /*!< DATA[31:0]: Data */

/******************  Bit definition for QUADSPI_PSMKR register  ****************/
#define  QUADSPI_PSMKR_MASK                       ((uint32_t)0xFFFFFFFF)            /*!< MASK[31:0]: Status Mask */

/******************  Bit definition for QUADSPI_PSMAR register  ****************/
#define  QUADSPI_PSMAR_MATCH                      ((uint32_t)0xFFFFFFFF)            /*!< MATCH[31:0]: Status Match */

/******************  Bit definition for QUADSPI_PIR register  *****************/
#define  QUADSPI_PIR_INTERVAL                     ((uint32_t)0x0000FFFF)            /*!< INTERVAL[15:0]: Polling Interval */

/******************  Bit definition for QUADSPI_LPTR register  *****************/
#define  QUADSPI_LPTR_TIMEOUT                     ((uint32_t)0x0000FFFF)            /*!< TIMEOUT[15:0]: Timeout period */

/******************************************************************************/
/*                                                                            */
/*                                 SYSCFG                                     */
/*                                                                            */
/******************************************************************************/

/******************  Bit definition for SYSCFG_PMCR register  ******************/
#define SYSCFG_PMCR_I2C1_FMP               ((uint32_t)0x00000001) /*!< I2C1 Fast mode plus */
#define SYSCFG_PMCR_I2C2_FMP               ((uint32_t)0x00000002) /*!< I2C2 Fast mode plus */
#define SYSCFG_PMCR_I2C3_FMP               ((uint32_t)0x00000004) /*!< I2C3 Fast mode plus */
#define SYSCFG_PMCR_I2C4_FMP               ((uint32_t)0x00000008) /*!< I2C4 Fast mode plus */
#define SYSCFG_PMCR_I2C_PB6_FMP            ((uint32_t)0x00000010) /*!< I2C PB6 Fast mode plus */
#define SYSCFG_PMCR_I2C_PB7_FMP            ((uint32_t)0x00000020) /*!< I2C PB7 Fast mode plus */
#define SYSCFG_PMCR_I2C_PB8_FMP            ((uint32_t)0x00000040) /*!< I2C PB8 Fast mode plus */
#define SYSCFG_PMCR_I2C_PB9_FMP            ((uint32_t)0x00000080) /*!< I2C PB9 Fast mode plus */
#define SYSCFG_PMCR_BOOSTEN                ((uint32_t)0x00000100) /*!< I/O analog switch voltage booster enable */

#define SYCFG_PMCR_EPIS_SEL                ((uint32_t)0x00E00000) /*!< Ethernet PHY Interface Selection */
#define SYCFG_PMCR_EPIS_SEL_0              ((uint32_t)0x00200000) /*!< Bit 0 */
#define SYCFG_PMCR_EPIS_SEL_1              ((uint32_t)0x00400000) /*!< Bit 1 */
#define SYSCFG_PMCR_EPIS_SEL_2             ((uint32_t)0x00800000) /*!< Bit 2 */
#define SYSCFG_PMCR_PA0SO                  ((uint32_t)0x01000000) /*!< PA0 Switch Open */
#define SYSCFG_PMCR_PA1SO                  ((uint32_t)0x02000000) /*!< PA1 Switch Open */
#define SYSCFG_PMCR_PC2SO                  ((uint32_t)0x04000000) /*!< PC2 Switch Open */
#define SYSCFG_PMCR_PC3SO                  ((uint32_t)0x08000000) /*!< PC3 Switch Open */

/*****************  Bit definition for SYSCFG_EXTICR1 register  ***************/
#define SYSCFG_EXTICR1_EXTI0            ((uint16_t)0x0007) /*!<EXTI 0 configuration */
#define SYSCFG_EXTICR1_EXTI1            ((uint16_t)0x0070) /*!<EXTI 1 configuration */
#define SYSCFG_EXTICR1_EXTI2            ((uint16_t)0x0700) /*!<EXTI 2 configuration */
#define SYSCFG_EXTICR1_EXTI3            ((uint16_t)0x7000) /*!<EXTI 3 configuration */
/**
  * @brief   EXTI0 configuration
  */
#define SYSCFG_EXTICR1_EXTI0_PA         ((uint16_t)0x0000) /*!<PA[0] pin */
#define SYSCFG_EXTICR1_EXTI0_PB         ((uint16_t)0x0001) /*!<PB[0] pin */
#define SYSCFG_EXTICR1_EXTI0_PC         ((uint16_t)0x0002) /*!<PC[0] pin */
#define SYSCFG_EXTICR1_EXTI0_PD         ((uint16_t)0x0003) /*!<PD[0] pin */
#define SYSCFG_EXTICR1_EXTI0_PE         ((uint16_t)0x0004) /*!<PE[0] pin */
#define SYSCFG_EXTICR1_EXTI0_PF         ((uint16_t)0x0005) /*!<PF[0] pin */
#define SYSCFG_EXTICR1_EXTI0_PG         ((uint16_t)0x0006) /*!<PG[0] pin */
#define SYSCFG_EXTICR1_EXTI0_PH         ((uint16_t)0x0007) /*!<PH[0] pin */


/**
  * @brief   EXTI1 configuration
  */
#define SYSCFG_EXTICR1_EXTI1_PA         ((uint16_t)0x0000) /*!<PA[1] pin */
#define SYSCFG_EXTICR1_EXTI1_PB         ((uint16_t)0x0010) /*!<PB[1] pin */
#define SYSCFG_EXTICR1_EXTI1_PC         ((uint16_t)0x0020) /*!<PC[1] pin */
#define SYSCFG_EXTICR1_EXTI1_PD         ((uint16_t)0x0030) /*!<PD[1] pin */
#define SYSCFG_EXTICR1_EXTI1_PE         ((uint16_t)0x0040) /*!<PE[1] pin */
#define SYSCFG_EXTICR1_EXTI1_PF         ((uint16_t)0x0050) /*!<PF[1] pin */
#define SYSCFG_EXTICR1_EXTI1_PG         ((uint16_t)0x0060) /*!<PG[1] pin */
#define SYSCFG_EXTICR1_EXTI1_PH         ((uint16_t)0x0070) /*!<PH[1] pin */

/**
  * @brief   EXTI2 configuration
  */
#define SYSCFG_EXTICR1_EXTI2_PA         ((uint16_t)0x0000) /*!<PA[2] pin */
#define SYSCFG_EXTICR1_EXTI2_PB         ((uint16_t)0x0100) /*!<PB[2] pin */
#define SYSCFG_EXTICR1_EXTI2_PC         ((uint16_t)0x0200) /*!<PC[2] pin */
#define SYSCFG_EXTICR1_EXTI2_PD         ((uint16_t)0x0300) /*!<PD[2] pin */
#define SYSCFG_EXTICR1_EXTI2_PE         ((uint16_t)0x0400) /*!<PE[2] pin */
#define SYSCFG_EXTICR1_EXTI2_PF         ((uint16_t)0x0500) /*!<PF[2] pin */
#define SYSCFG_EXTICR1_EXTI2_PG         ((uint16_t)0x0600) /*!<PG[2] pin */


/**
  * @brief   EXTI3 configuration
  */
#define SYSCFG_EXTICR1_EXTI3_PA         ((uint16_t)0x0000) /*!<PA[3] pin */
#define SYSCFG_EXTICR1_EXTI3_PB         ((uint16_t)0x1000) /*!<PB[3] pin */
#define SYSCFG_EXTICR1_EXTI3_PC         ((uint16_t)0x2000) /*!<PC[3] pin */
#define SYSCFG_EXTICR1_EXTI3_PD         ((uint16_t)0x3000) /*!<PD[3] pin */
#define SYSCFG_EXTICR1_EXTI3_PE         ((uint16_t)0x4000) /*!<PE[3] pin */
#define SYSCFG_EXTICR1_EXTI3_PF         ((uint16_t)0x5000) /*!<PF[3] pin */
#define SYSCFG_EXTICR1_EXTI3_PG         ((uint16_t)0x6000) /*!<PG[3] pin */


/*****************  Bit definition for SYSCFG_EXTICR2 register  ***************/
#define SYSCFG_EXTICR2_EXTI4            ((uint16_t)0x0007) /*!<EXTI 4 configuration */
#define SYSCFG_EXTICR2_EXTI5            ((uint16_t)0x0070) /*!<EXTI 5 configuration */
#define SYSCFG_EXTICR2_EXTI6            ((uint16_t)0x0700) /*!<EXTI 6 configuration */
#define SYSCFG_EXTICR2_EXTI7            ((uint16_t)0x7000) /*!<EXTI 7 configuration */
/**
  * @brief   EXTI4 configuration
  */
#define SYSCFG_EXTICR2_EXTI4_PA         ((uint16_t)0x0000) /*!<PA[4] pin */
#define SYSCFG_EXTICR2_EXTI4_PB         ((uint16_t)0x0001) /*!<PB[4] pin */
#define SYSCFG_EXTICR2_EXTI4_PC         ((uint16_t)0x0002) /*!<PC[4] pin */
#define SYSCFG_EXTICR2_EXTI4_PD         ((uint16_t)0x0003) /*!<PD[4] pin */
#define SYSCFG_EXTICR2_EXTI4_PE         ((uint16_t)0x0004) /*!<PE[4] pin */
#define SYSCFG_EXTICR2_EXTI4_PF         ((uint16_t)0x0005) /*!<PF[4] pin */
#define SYSCFG_EXTICR2_EXTI4_PG         ((uint16_t)0x0006) /*!<PG[4] pin */

/**
  * @brief   EXTI5 configuration
  */
#define SYSCFG_EXTICR2_EXTI5_PA         ((uint16_t)0x0000) /*!<PA[5] pin */
#define SYSCFG_EXTICR2_EXTI5_PB         ((uint16_t)0x0010) /*!<PB[5] pin */
#define SYSCFG_EXTICR2_EXTI5_PC         ((uint16_t)0x0020) /*!<PC[5] pin */
#define SYSCFG_EXTICR2_EXTI5_PD         ((uint16_t)0x0030) /*!<PD[5] pin */
#define SYSCFG_EXTICR2_EXTI5_PE         ((uint16_t)0x0040) /*!<PE[5] pin */
#define SYSCFG_EXTICR2_EXTI5_PF         ((uint16_t)0x0050) /*!<PF[5] pin */
#define SYSCFG_EXTICR2_EXTI5_PG         ((uint16_t)0x0060) /*!<PG[5] pin */

/**
  * @brief   EXTI6 configuration
  */
#define SYSCFG_EXTICR2_EXTI6_PA         ((uint16_t)0x0000) /*!<PA[6] pin */
#define SYSCFG_EXTICR2_EXTI6_PB         ((uint16_t)0x0100) /*!<PB[6] pin */
#define SYSCFG_EXTICR2_EXTI6_PC         ((uint16_t)0x0200) /*!<PC[6] pin */
#define SYSCFG_EXTICR2_EXTI6_PD         ((uint16_t)0x0300) /*!<PD[6] pin */
#define SYSCFG_EXTICR2_EXTI6_PE         ((uint16_t)0x0400) /*!<PE[6] pin */
#define SYSCFG_EXTICR2_EXTI6_PF         ((uint16_t)0x0500) /*!<PF[6] pin */
#define SYSCFG_EXTICR2_EXTI6_PG         ((uint16_t)0x0600) /*!<PG[6] pin */

/**
  * @brief   EXTI7 configuration
  */
#define SYSCFG_EXTICR2_EXTI7_PA         ((uint16_t)0x0000) /*!<PA[7] pin */
#define SYSCFG_EXTICR2_EXTI7_PB         ((uint16_t)0x1000) /*!<PB[7] pin */
#define SYSCFG_EXTICR2_EXTI7_PC         ((uint16_t)0x2000) /*!<PC[7] pin */
#define SYSCFG_EXTICR2_EXTI7_PD         ((uint16_t)0x3000) /*!<PD[7] pin */
#define SYSCFG_EXTICR2_EXTI7_PE         ((uint16_t)0x4000) /*!<PE[7] pin */
#define SYSCFG_EXTICR2_EXTI7_PF         ((uint16_t)0x5000) /*!<PF[7] pin */
#define SYSCFG_EXTICR2_EXTI7_PG         ((uint16_t)0x6000) /*!<PG[7] pin */


/*****************  Bit definition for SYSCFG_EXTICR3 register  ***************/
#define SYSCFG_EXTICR3_EXTI8            ((uint16_t)0x0007) /*!<EXTI 8 configuration */
#define SYSCFG_EXTICR3_EXTI9            ((uint16_t)0x0070) /*!<EXTI 9 configuration */
#define SYSCFG_EXTICR3_EXTI10           ((uint16_t)0x0700) /*!<EXTI 10 configuration */
#define SYSCFG_EXTICR3_EXTI11           ((uint16_t)0x7000) /*!<EXTI 11 configuration */

/**
  * @brief   EXTI8 configuration
  */
#define SYSCFG_EXTICR3_EXTI8_PA         ((uint16_t)0x0000) /*!<PA[8] pin */
#define SYSCFG_EXTICR3_EXTI8_PB         ((uint16_t)0x0001) /*!<PB[8] pin */
#define SYSCFG_EXTICR3_EXTI8_PC         ((uint16_t)0x0002) /*!<PC[8] pin */
#define SYSCFG_EXTICR3_EXTI8_PD         ((uint16_t)0x0003) /*!<PD[8] pin */
#define SYSCFG_EXTICR3_EXTI8_PE         ((uint16_t)0x0004) /*!<PE[8] pin */
#define SYSCFG_EXTICR3_EXTI8_PF         ((uint16_t)0x0005) /*!<PF[8] pin */
#define SYSCFG_EXTICR3_EXTI8_PG         ((uint16_t)0x0006) /*!<PG[8] pin */

/**
  * @brief   EXTI9 configuration
  */
#define SYSCFG_EXTICR3_EXTI9_PA         ((uint16_t)0x0000) /*!<PA[9] pin */
#define SYSCFG_EXTICR3_EXTI9_PB         ((uint16_t)0x0010) /*!<PB[9] pin */
#define SYSCFG_EXTICR3_EXTI9_PC         ((uint16_t)0x0020) /*!<PC[9] pin */
#define SYSCFG_EXTICR3_EXTI9_PD         ((uint16_t)0x0030) /*!<PD[9] pin */
#define SYSCFG_EXTICR3_EXTI9_PE         ((uint16_t)0x0040) /*!<PE[9] pin */
#define SYSCFG_EXTICR3_EXTI9_PF         ((uint16_t)0x0050) /*!<PF[9] pin */
#define SYSCFG_EXTICR3_EXTI9_PG         ((uint16_t)0x0060) /*!<PG[9] pin */

/**
  * @brief   EXTI10 configuration
  */
#define SYSCFG_EXTICR3_EXTI10_PA        ((uint16_t)0x0000) /*!<PA[10] pin */
#define SYSCFG_EXTICR3_EXTI10_PB        ((uint16_t)0x0100) /*!<PB[10] pin */
#define SYSCFG_EXTICR3_EXTI10_PC        ((uint16_t)0x0200) /*!<PC[10] pin */
#define SYSCFG_EXTICR3_EXTI10_PD        ((uint16_t)0x0300) /*!<PD[10] pin */
#define SYSCFG_EXTICR3_EXTI10_PE        ((uint16_t)0x0400) /*!<PE[10] pin */
#define SYSCFG_EXTICR3_EXTI10_PF        ((uint16_t)0x0500) /*!<PF[10] pin */
#define SYSCFG_EXTICR3_EXTI10_PG        ((uint16_t)0x0600) /*!<PG[10] pin */

/**
  * @brief   EXTI11 configuration
  */
#define SYSCFG_EXTICR3_EXTI11_PA        ((uint16_t)0x0000) /*!<PA[11] pin */
#define SYSCFG_EXTICR3_EXTI11_PB        ((uint16_t)0x1000) /*!<PB[11] pin */
#define SYSCFG_EXTICR3_EXTI11_PC        ((uint16_t)0x2000) /*!<PC[11] pin */
#define SYSCFG_EXTICR3_EXTI11_PD        ((uint16_t)0x3000) /*!<PD[11] pin */
#define SYSCFG_EXTICR3_EXTI11_PE        ((uint16_t)0x4000) /*!<PE[11] pin */
#define SYSCFG_EXTICR3_EXTI11_PF        ((uint16_t)0x5000) /*!<PF[11] pin */
#define SYSCFG_EXTICR3_EXTI11_PG        ((uint16_t)0x6000) /*!<PG[11] pin */

/*****************  Bit definition for SYSCFG_EXTICR4 register  ***************/
#define SYSCFG_EXTICR4_EXTI12           ((uint16_t)0x0007) /*!<EXTI 12 configuration */
#define SYSCFG_EXTICR4_EXTI13           ((uint16_t)0x0070) /*!<EXTI 13 configuration */
#define SYSCFG_EXTICR4_EXTI14           ((uint16_t)0x0700) /*!<EXTI 14 configuration */
#define SYSCFG_EXTICR4_EXTI15           ((uint16_t)0x7000) /*!<EXTI 15 configuration */
/**
  * @brief   EXTI12 configuration
  */
#define SYSCFG_EXTICR4_EXTI12_PA        ((uint16_t)0x0000) /*!<PA[12] pin */
#define SYSCFG_EXTICR4_EXTI12_PB        ((uint16_t)0x0001) /*!<PB[12] pin */
#define SYSCFG_EXTICR4_EXTI12_PC        ((uint16_t)0x0002) /*!<PC[12] pin */
#define SYSCFG_EXTICR4_EXTI12_PD        ((uint16_t)0x0003) /*!<PD[12] pin */
#define SYSCFG_EXTICR4_EXTI12_PE        ((uint16_t)0x0004) /*!<PE[12] pin */
#define SYSCFG_EXTICR4_EXTI12_PF        ((uint16_t)0x0005) /*!<PF[12] pin */
#define SYSCFG_EXTICR4_EXTI12_PG        ((uint16_t)0x0006) /*!<PG[12] pin */

/**
  * @brief   EXTI13 configuration
  */
#define SYSCFG_EXTICR4_EXTI13_PA        ((uint16_t)0x0000) /*!<PA[13] pin */
#define SYSCFG_EXTICR4_EXTI13_PB        ((uint16_t)0x0010) /*!<PB[13] pin */
#define SYSCFG_EXTICR4_EXTI13_PC        ((uint16_t)0x0020) /*!<PC[13] pin */
#define SYSCFG_EXTICR4_EXTI13_PD        ((uint16_t)0x0030) /*!<PD[13] pin */
#define SYSCFG_EXTICR4_EXTI13_PE        ((uint16_t)0x0040) /*!<PE[13] pin */
#define SYSCFG_EXTICR4_EXTI13_PF        ((uint16_t)0x0050) /*!<PF[13] pin */
#define SYSCFG_EXTICR4_EXTI13_PG        ((uint16_t)0x0060) /*!<PG[13] pin */

/**
  * @brief   EXTI14 configuration
  */
#define SYSCFG_EXTICR4_EXTI14_PA        ((uint16_t)0x0000) /*!<PA[14] pin */
#define SYSCFG_EXTICR4_EXTI14_PB        ((uint16_t)0x0100) /*!<PB[14] pin */
#define SYSCFG_EXTICR4_EXTI14_PC        ((uint16_t)0x0200) /*!<PC[14] pin */
#define SYSCFG_EXTICR4_EXTI14_PD        ((uint16_t)0x0300) /*!<PD[14] pin */
#define SYSCFG_EXTICR4_EXTI14_PE        ((uint16_t)0x0400) /*!<PE[14] pin */
#define SYSCFG_EXTICR4_EXTI14_PF        ((uint16_t)0x0500) /*!<PF[14] pin */
#define SYSCFG_EXTICR4_EXTI14_PG        ((uint16_t)0x0600) /*!<PG[14] pin */

/**
  * @brief   EXTI15 configuration
  */
#define SYSCFG_EXTICR4_EXTI15_PA        ((uint16_t)0x0000) /*!<PA[15] pin */
#define SYSCFG_EXTICR4_EXTI15_PB        ((uint16_t)0x1000) /*!<PB[15] pin */
#define SYSCFG_EXTICR4_EXTI15_PC        ((uint16_t)0x2000) /*!<PC[15] pin */
#define SYSCFG_EXTICR4_EXTI15_PD        ((uint16_t)0x3000) /*!<PD[15] pin */
#define SYSCFG_EXTICR4_EXTI15_PE        ((uint16_t)0x4000) /*!<PE[15] pin */
#define SYSCFG_EXTICR4_EXTI15_PF        ((uint16_t)0x5000) /*!<PF[15] pin */
#define SYSCFG_EXTICR4_EXTI15_PG        ((uint16_t)0x6000) /*!<PG[15] pin */

/******************  Bit definition for SYSCFG_CCCSR register  ******************/
#define SYSCFG_CCCSR_EN                 ((uint32_t)0x00000001) /*!< I/O compensation cell enable */
#define SYSCFG_CCCSR_CS                 ((uint32_t)0x00000002) /*!< I/O compensation cell code selection */
#define SYSCFG_CCCSR_REDAY              ((uint32_t)0x00000100) /*!< I/O compensation cell ready flag */
#define SYSCFG_CCCSR_HSLV               ((uint32_t)0x00010000) /*!< High-speed at low-voltage */

/******************  Bit definition for SYSCFG_CCVR register  *******************/
#define SYSCFG_CCVR_NCV                 ((uint32_t)0x0000000F) /*!< NMOS compensation value */
#define SYSCFG_CCVR_PCV                 ((uint32_t)0x000000F0) /*!< PMOS compensation value */

/******************  Bit definition for SYSCFG_CCCR register  *******************/
#define SYSCFG_CCCR_NCC                 ((uint32_t)0x0000000F) /*!< NMOS compensation code */
#define SYSCFG_CCCR_PCC                 ((uint32_t)0x000000F0) /*!< PMOS compensation code */

/******************  Bit definition for SYSCFG_PKGR register  *******************/
#define SYSCFG_PKGR_PKG                 ((uint32_t)0x0000000F) /*!< Package type */

/******************  Bit definition for SYSCFG_UR0 register  *******************/
#define SYSCFG_UR0_BKS                 ((uint32_t)0x00000001) /*!< Bank Swap */
#define SYSCFG_UR0_RDP                 ((uint32_t)0x00FF0000) /*!< Readout protection */

/******************  Bit definition for SYSCFG_UR1 register  *******************/

#define SYSCFG_UR1_BCM7                 ((uint32_t)0x00010000) /*!< Boot Cortex-M7 */

/******************  Bit definition for SYSCFG_UR2 register  *******************/
#define SYSCFG_UR2_BORH                 ((uint32_t)0x00000003) /*!< Brown Out Reset High level */
#define SYSCFG_UR2_BCM7_ADD0            ((uint32_t)0xFFFF0000) /*!< Boot Cortex-M7 Address 0 */

/******************  Bit definition for SYSCFG_UR3 register  *******************/
#define SYSCFG_UR3_BCM7_ADD1            ((uint32_t)0x0000FFFF) /*!< Boot Cortex-M7 Address 1 */


/******************  Bit definition for SYSCFG_UR4 register  *******************/

#define SYSCFG_UR4_MEPAD_BANKA          ((uint32_t)0x00010000) /*!< Mass Erase Protected Area Disabled for bank A */

/******************  Bit definition for SYSCFG_UR5 register  *******************/
#define SYSCFG_UR5_MESAD_BANKA          ((uint32_t)0x00000001) /*!< Mass erase secured area disabled for bank A */
#define SYSCFG_UR5_WRPN_BANKA           ((uint32_t)0x00FF0000) /*!< Write protection for flash bank A */

/******************  Bit definition for SYSCFG_UR6 register  *******************/
#define SYSCFG_UR6_PABEG_BANKA          ((uint32_t)0x00000FFF) /*!< Protected area start address for bank A */
#define SYSCFG_UR6_PAEND_BANKA           ((uint32_t)0x0FFF0000) /*!< Protected area end address for bank A */

/******************  Bit definition for SYSCFG_UR7 register  *******************/
#define SYSCFG_UR7_SABEG_BANKA          ((uint32_t)0x00000FFF) /*!< Secured area start address for bank A */
#define SYSCFG_UR7_SAEND_BANKA           ((uint32_t)0x0FFF0000) /*!< Secured area end address for bank A */

/******************  Bit definition for SYSCFG_UR8 register  *******************/
#define SYSCFG_UR8_MEPAD_BANKB          ((uint32_t)0x00000001) /*!< Mass erase Protected area disabled for bank B */
#define SYSCFG_UR8_MESAD_BANKB          ((uint32_t)0x00010000) /*!< Mass Erase Secured Area Disabled for bank B */

/******************  Bit definition for SYSCFG_UR9 register  *******************/
#define SYSCFG_UR9_WRPN_BANKB           ((uint32_t)0x000000FF) /*!< Write protection for flash bank B */
#define SYSCFG_UR9_PABEG_BANKB          ((uint32_t)0x0FFF0000) /*!< Protected area start address for bank B */

/******************  Bit definition for SYSCFG_UR10 register  *******************/
#define SYSCFG_UR10_PAEND_BANKB           ((uint32_t)0x00000FFF) /*!< Protected area end address for bank B */
#define SYSCFG_UR10_SABEG_BANKB           ((uint32_t)0x0FFF0000) /*!< Secured area start address for bank B */

/******************  Bit definition for SYSCFG_UR11 register  *******************/
#define SYSCFG_UR11_SAEND_BANKB           ((uint32_t)0x00000FFF) /*!< Secured area end address for bank B */
#define SYSCFG_UR11_IWDG1M                ((uint32_t)0x00010000) /*!< Independent Watchdog 1 mode (SW or HW) */

/******************  Bit definition for SYSCFG_UR12 register  *******************/

#define SYSCFG_UR12_SECURE                ((uint32_t)0x00010000) /*!< Secure mode status */

/******************  Bit definition for SYSCFG_UR13 register  *******************/
#define SYSCFG_UR13_SDRS                   ((uint32_t)0x00000003) /*!< Secured DTCM RAM Size */
#define SYSCFG_UR13_D1SBRST                ((uint32_t)0x00010000) /*!< D1 Standby reset */

/******************  Bit definition for SYSCFG_UR14 register  *******************/
#define SYSCFG_UR14_D1STPRST               ((uint32_t)0x00000001) /*!< D1 Stop Reset */
#define SYSCFG_UR14_D2SBRST                ((uint32_t)0x00010000) /*!< D2 Standby Reset */

/******************  Bit definition for SYSCFG_UR15 register  *******************/
#define SYSCFG_UR15_D2STPRST               ((uint32_t)0x00000001) /*!< D2 Stop Reset */
#define SYSCFG_UR15_FZIWDGSTB              ((uint32_t)0x00010000) /*!< Freeze independent watchdogs in Standby mode */

/******************  Bit definition for SYSCFG_UR16 register  *******************/
#define SYSCFG_UR16_FZIWDGSTP              ((uint32_t)0x00000001) /*!< Freeze independent watchdogs in Stop mode */
#define SYSCFG_UR16_PKP                    ((uint32_t)0x00010000) /*!< Private key programmed */

/******************  Bit definition for SYSCFG_UR17 register  *******************/
#define SYSCFG_UR17_IOHSLV                 ((uint32_t)0x00000001) /*!< I/O high speed / low voltage */


/******************************************************************************/
/*                                                                            */
/*                                    TIM                                     */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for TIM_CR1 register  ********************/
#define  TIM_CR1_CEN                         ((uint16_t)0x0001)            /*!<Counter enable */
#define  TIM_CR1_UDIS                        ((uint16_t)0x0002)            /*!<Update disable */
#define  TIM_CR1_URS                         ((uint16_t)0x0004)            /*!<Update request source */
#define  TIM_CR1_OPM                         ((uint16_t)0x0008)            /*!<One pulse mode */
#define  TIM_CR1_DIR                         ((uint16_t)0x0010)            /*!<Direction */

#define  TIM_CR1_CMS                         ((uint16_t)0x0060)            /*!<CMS[1:0] bits (Center-aligned mode selection) */
#define  TIM_CR1_CMS_0                       ((uint16_t)0x0020)            /*!<Bit 0 */
#define  TIM_CR1_CMS_1                       ((uint16_t)0x0040)            /*!<Bit 1 */

#define  TIM_CR1_ARPE                        ((uint16_t)0x0080)            /*!<Auto-reload preload enable */

#define  TIM_CR1_CKD                         ((uint16_t)0x0300)            /*!<CKD[1:0] bits (clock division) */
#define  TIM_CR1_CKD_0                       ((uint16_t)0x0100)            /*!<Bit 0 */
#define  TIM_CR1_CKD_1                       ((uint16_t)0x0200)            /*!<Bit 1 */

#define  TIM_CR1_UIFREMAP                    ((uint16_t)0x0800)            /*!<Update interrupt flag remap */

/*******************  Bit definition for TIM_CR2 register  ********************/
#define  TIM_CR2_CCPC                        ((uint32_t)0x00000001)            /*!<Capture/Compare Preloaded Control */
#define  TIM_CR2_CCUS                        ((uint32_t)0x00000004)            /*!<Capture/Compare Control Update Selection */
#define  TIM_CR2_CCDS                        ((uint32_t)0x00000008)            /*!<Capture/Compare DMA Selection */

#define  TIM_CR2_MMS                         ((uint32_t)0x00000070)            /*!<MMS[2:0] bits (Master Mode Selection) */
#define  TIM_CR2_MMS_0                       ((uint32_t)0x00000010)            /*!<Bit 0 */
#define  TIM_CR2_MMS_1                       ((uint32_t)0x00000020)            /*!<Bit 1 */
#define  TIM_CR2_MMS_2                       ((uint32_t)0x00000040)            /*!<Bit 2 */

#define  TIM_CR2_TI1S                        ((uint32_t)0x00000080)            /*!<TI1 Selection */
#define  TIM_CR2_OIS1                        ((uint32_t)0x00000100)            /*!<Output Idle state 1 (OC1 output) */
#define  TIM_CR2_OIS1N                       ((uint32_t)0x00000200)            /*!<Output Idle state 1 (OC1N output) */
#define  TIM_CR2_OIS2                        ((uint32_t)0x00000400)            /*!<Output Idle state 2 (OC2 output) */
#define  TIM_CR2_OIS2N                       ((uint32_t)0x00000800)            /*!<Output Idle state 2 (OC2N output) */
#define  TIM_CR2_OIS3                        ((uint32_t)0x00001000)            /*!<Output Idle state 3 (OC3 output) */
#define  TIM_CR2_OIS3N                       ((uint32_t)0x00002000)            /*!<Output Idle state 3 (OC3N output) */
#define  TIM_CR2_OIS4                        ((uint32_t)0x00004000)            /*!<Output Idle state 4 (OC4 output) */
#define  TIM_CR2_OIS5                        ((uint32_t)0x00010000)            /*!<Output Idle state 4 (OC4 output) */
#define  TIM_CR2_OIS6                        ((uint32_t)0x00020000)            /*!<Output Idle state 4 (OC4 output) */

#define  TIM_CR2_MMS2                        ((uint32_t)0x00F00000)            /*!<MMS[2:0] bits (Master Mode Selection) */
#define  TIM_CR2_MMS2_0                      ((uint32_t)0x00100000)            /*!<Bit 0 */
#define  TIM_CR2_MMS2_1                      ((uint32_t)0x00200000)            /*!<Bit 1 */
#define  TIM_CR2_MMS2_2                      ((uint32_t)0x00400000)            /*!<Bit 2 */
#define  TIM_CR2_MMS2_3                      ((uint32_t)0x00800000)            /*!<Bit 2 */

/*******************  Bit definition for TIM_SMCR register  *******************/
#define  TIM_SMCR_SMS                        ((uint32_t)0x00010007)            /*!<SMS[2:0] bits (Slave mode selection) */
#define  TIM_SMCR_SMS_0                      ((uint32_t)0x00000001)            /*!<Bit 0 */
#define  TIM_SMCR_SMS_1                      ((uint32_t)0x00000002)            /*!<Bit 1 */
#define  TIM_SMCR_SMS_2                      ((uint32_t)0x00000004)            /*!<Bit 2 */
#define  TIM_SMCR_SMS_3                      ((uint32_t)0x00010000)            /*!<Bit 3 */

#define  TIM_SMCR_TS                         ((uint32_t)0x00300070)            /*!<TS[4:0] bits (Trigger selection) */
#define  TIM_SMCR_TS_0                       ((uint32_t)0x00000010)            /*!<Bit 0 */
#define  TIM_SMCR_TS_1                       ((uint32_t)0x00000020)            /*!<Bit 1 */
#define  TIM_SMCR_TS_2                       ((uint32_t)0x00000040)            /*!<Bit 2 */
#define  TIM_SMCR_TS_3                       ((uint32_t)0x00100000)            /*!<Bit 3 */
#define  TIM_SMCR_TS_4                       ((uint32_t)0x00200000)            /*!<Bit 4 */

#define  TIM_SMCR_MSM                        ((uint32_t)0x00000080)            /*!<Master/slave mode */

#define  TIM_SMCR_ETF                        ((uint32_t)0x00000F00)            /*!<ETF[3:0] bits (External trigger filter) */
#define  TIM_SMCR_ETF_0                      ((uint32_t)0x00000100)            /*!<Bit 0 */
#define  TIM_SMCR_ETF_1                      ((uint32_t)0x00000200)            /*!<Bit 1 */
#define  TIM_SMCR_ETF_2                      ((uint32_t)0x00000400)            /*!<Bit 2 */
#define  TIM_SMCR_ETF_3                      ((uint32_t)0x00000800)            /*!<Bit 3 */

#define  TIM_SMCR_ETPS                       ((uint32_t)0x00003000)            /*!<ETPS[1:0] bits (External trigger prescaler) */
#define  TIM_SMCR_ETPS_0                     ((uint32_t)0x00001000)            /*!<Bit 0 */
#define  TIM_SMCR_ETPS_1                     ((uint32_t)0x00002000)            /*!<Bit 1 */

#define  TIM_SMCR_ECE                        ((uint32_t)0x00004000)            /*!<External clock enable */
#define  TIM_SMCR_ETP                        ((uint32_t)0x00008000)            /*!<External trigger polarity */

/*******************  Bit definition for TIM_DIER register  *******************/
#define  TIM_DIER_UIE                        ((uint16_t)0x0001)            /*!<Update interrupt enable */
#define  TIM_DIER_CC1IE                      ((uint16_t)0x0002)            /*!<Capture/Compare 1 interrupt enable */
#define  TIM_DIER_CC2IE                      ((uint16_t)0x0004)            /*!<Capture/Compare 2 interrupt enable */
#define  TIM_DIER_CC3IE                      ((uint16_t)0x0008)            /*!<Capture/Compare 3 interrupt enable */
#define  TIM_DIER_CC4IE                      ((uint16_t)0x0010)            /*!<Capture/Compare 4 interrupt enable */
#define  TIM_DIER_COMIE                      ((uint16_t)0x0020)            /*!<COM interrupt enable */
#define  TIM_DIER_TIE                        ((uint16_t)0x0040)            /*!<Trigger interrupt enable */
#define  TIM_DIER_BIE                        ((uint16_t)0x0080)            /*!<Break interrupt enable */
#define  TIM_DIER_UDE                        ((uint16_t)0x0100)            /*!<Update DMA request enable */
#define  TIM_DIER_CC1DE                      ((uint16_t)0x0200)            /*!<Capture/Compare 1 DMA request enable */
#define  TIM_DIER_CC2DE                      ((uint16_t)0x0400)            /*!<Capture/Compare 2 DMA request enable */
#define  TIM_DIER_CC3DE                      ((uint16_t)0x0800)            /*!<Capture/Compare 3 DMA request enable */
#define  TIM_DIER_CC4DE                      ((uint16_t)0x1000)            /*!<Capture/Compare 4 DMA request enable */
#define  TIM_DIER_COMDE                      ((uint16_t)0x2000)            /*!<COM DMA request enable */
#define  TIM_DIER_TDE                        ((uint16_t)0x4000)            /*!<Trigger DMA request enable */

/********************  Bit definition for TIM_SR register  ********************/
#define  TIM_SR_UIF                          ((uint32_t)0x00000001)            /*!<Update interrupt Flag */
#define  TIM_SR_CC1IF                        ((uint32_t)0x00000002)            /*!<Capture/Compare 1 interrupt Flag */
#define  TIM_SR_CC2IF                        ((uint32_t)0x00000004)            /*!<Capture/Compare 2 interrupt Flag */
#define  TIM_SR_CC3IF                        ((uint32_t)0x00000008)            /*!<Capture/Compare 3 interrupt Flag */
#define  TIM_SR_CC4IF                        ((uint32_t)0x00000010)            /*!<Capture/Compare 4 interrupt Flag */
#define  TIM_SR_COMIF                        ((uint32_t)0x00000020)            /*!<COM interrupt Flag */
#define  TIM_SR_TIF                          ((uint32_t)0x00000040)            /*!<Trigger interrupt Flag */
#define  TIM_SR_BIF                          ((uint32_t)0x00000080)            /*!<Break interrupt Flag */
#define  TIM_SR_B2IF                         ((uint32_t)0x00000100)            /*!<Break2 interrupt Flag */
#define  TIM_SR_CC1OF                        ((uint32_t)0x00000200)            /*!<Capture/Compare 1 Overcapture Flag */
#define  TIM_SR_CC2OF                        ((uint32_t)0x00000400)            /*!<Capture/Compare 2 Overcapture Flag */
#define  TIM_SR_CC3OF                        ((uint32_t)0x00000800)            /*!<Capture/Compare 3 Overcapture Flag */
#define  TIM_SR_CC4OF                        ((uint32_t)0x00001000)            /*!<Capture/Compare 4 Overcapture Flag */
#define  TIM_SR_CC5IF                        ((uint32_t)0x00010000)            /*!<Capture/Compare 5 interrupt Flag */
#define  TIM_SR_CC6IF                        ((uint32_t)0x00020000)            /*!<Capture/Compare 6 interrupt Flag */
#define  TIM_SR_SBIF                         ((uint32_t)0x00002000)            /*!< System Break Flag */

/*******************  Bit definition for TIM_EGR register  ********************/
#define  TIM_EGR_UG                          ((uint16_t)0x0001)               /*!<Update Generation */
#define  TIM_EGR_CC1G                        ((uint16_t)0x0002)               /*!<Capture/Compare 1 Generation */
#define  TIM_EGR_CC2G                        ((uint16_t)0x0004)               /*!<Capture/Compare 2 Generation */
#define  TIM_EGR_CC3G                        ((uint16_t)0x0008)               /*!<Capture/Compare 3 Generation */
#define  TIM_EGR_CC4G                        ((uint16_t)0x0010)               /*!<Capture/Compare 4 Generation */
#define  TIM_EGR_COMG                        ((uint16_t)0x0020)               /*!<Capture/Compare Control Update Generation */
#define  TIM_EGR_TG                          ((uint16_t)0x0040)               /*!<Trigger Generation */
#define  TIM_EGR_BG                          ((uint16_t)0x0080)               /*!<Break Generation */
#define  TIM_EGR_B2G                         ((uint16_t)0x0100)               /*!<Break Generation */


/******************  Bit definition for TIM_CCMR1 register  *******************/
#define  TIM_CCMR1_CC1S                      ((uint32_t)0x00000003)            /*!<CC1S[1:0] bits (Capture/Compare 1 Selection) */
#define  TIM_CCMR1_CC1S_0                    ((uint32_t)0x00000001)            /*!<Bit 0 */
#define  TIM_CCMR1_CC1S_1                    ((uint32_t)0x00000002)            /*!<Bit 1 */

#define  TIM_CCMR1_OC1FE                     ((uint32_t)0x00000004)            /*!<Output Compare 1 Fast enable */
#define  TIM_CCMR1_OC1PE                     ((uint32_t)0x00000008)            /*!<Output Compare 1 Preload enable */

#define  TIM_CCMR1_OC1M                      ((uint32_t)0x00010070)            /*!<OC1M[2:0] bits (Output Compare 1 Mode) */
#define  TIM_CCMR1_OC1M_0                    ((uint32_t)0x00000010)            /*!<Bit 0 */
#define  TIM_CCMR1_OC1M_1                    ((uint32_t)0x00000020)            /*!<Bit 1 */
#define  TIM_CCMR1_OC1M_2                    ((uint32_t)0x00000040)            /*!<Bit 2 */
#define  TIM_CCMR1_OC1M_3                    ((uint32_t)0x00010000)            /*!<Bit 3 */

#define  TIM_CCMR1_OC1CE                     ((uint32_t)0x00000080)            /*!<Output Compare 1Clear Enable */

#define  TIM_CCMR1_CC2S                      ((uint32_t)0x00000300)            /*!<CC2S[1:0] bits (Capture/Compare 2 Selection) */
#define  TIM_CCMR1_CC2S_0                    ((uint32_t)0x00000100)            /*!<Bit 0 */
#define  TIM_CCMR1_CC2S_1                    ((uint32_t)0x00000200)            /*!<Bit 1 */

#define  TIM_CCMR1_OC2FE                     ((uint32_t)0x00000400)            /*!<Output Compare 2 Fast enable */
#define  TIM_CCMR1_OC2PE                     ((uint32_t)0x00000800)            /*!<Output Compare 2 Preload enable */

#define  TIM_CCMR1_OC2M                      ((uint32_t)0x01007000)            /*!<OC2M[2:0] bits (Output Compare 2 Mode) */
#define  TIM_CCMR1_OC2M_0                    ((uint32_t)0x00001000)            /*!<Bit 0 */
#define  TIM_CCMR1_OC2M_1                    ((uint32_t)0x00002000)            /*!<Bit 1 */
#define  TIM_CCMR1_OC2M_2                    ((uint32_t)0x00004000)            /*!<Bit 2 */
#define  TIM_CCMR1_OC2M_3                    ((uint32_t)0x01000000)            /*!<Bit 3 */

#define  TIM_CCMR1_OC2CE                     ((uint32_t)0x00008000)            /*!<Output Compare 2 Clear Enable */

/*----------------------------------------------------------------------------*/

#define  TIM_CCMR1_IC1PSC                    ((uint32_t)0x0000000C)            /*!<IC1PSC[1:0] bits (Input Capture 1 Prescaler) */
#define  TIM_CCMR1_IC1PSC_0                  ((uint32_t)0x00000004)            /*!<Bit 0 */
#define  TIM_CCMR1_IC1PSC_1                  ((uint32_t)0x00000008)            /*!<Bit 1 */

#define  TIM_CCMR1_IC1F                      ((uint32_t)0x000000F0)            /*!<IC1F[3:0] bits (Input Capture 1 Filter) */
#define  TIM_CCMR1_IC1F_0                    ((uint32_t)0x00000010)            /*!<Bit 0 */
#define  TIM_CCMR1_IC1F_1                    ((uint32_t)0x00000020)            /*!<Bit 1 */
#define  TIM_CCMR1_IC1F_2                    ((uint32_t)0x00000040)            /*!<Bit 2 */
#define  TIM_CCMR1_IC1F_3                    ((uint32_t)0x00000080)            /*!<Bit 3 */

#define  TIM_CCMR1_IC2PSC                    ((uint32_t)0x00000C00)            /*!<IC2PSC[1:0] bits (Input Capture 2 Prescaler) */
#define  TIM_CCMR1_IC2PSC_0                  ((uint32_t)0x00000400)            /*!<Bit 0 */
#define  TIM_CCMR1_IC2PSC_1                  ((uint32_t)0x00000800)            /*!<Bit 1 */

#define  TIM_CCMR1_IC2F                      ((uint32_t)0x0000F000)            /*!<IC2F[3:0] bits (Input Capture 2 Filter) */
#define  TIM_CCMR1_IC2F_0                    ((uint32_t)0x00001000)            /*!<Bit 0 */
#define  TIM_CCMR1_IC2F_1                    ((uint32_t)0x00002000)            /*!<Bit 1 */
#define  TIM_CCMR1_IC2F_2                    ((uint32_t)0x00004000)            /*!<Bit 2 */
#define  TIM_CCMR1_IC2F_3                    ((uint32_t)0x00008000)            /*!<Bit 3 */

/******************  Bit definition for TIM_CCMR2 register  *******************/
#define  TIM_CCMR2_CC3S                      ((uint32_t)0x00000003)            /*!<CC3S[1:0] bits (Capture/Compare 3 Selection) */
#define  TIM_CCMR2_CC3S_0                    ((uint32_t)0x00000001)            /*!<Bit 0 */
#define  TIM_CCMR2_CC3S_1                    ((uint32_t)0x00000002)            /*!<Bit 1 */

#define  TIM_CCMR2_OC3FE                     ((uint32_t)0x00000004)            /*!<Output Compare 3 Fast enable */
#define  TIM_CCMR2_OC3PE                     ((uint32_t)0x00000008)            /*!<Output Compare 3 Preload enable */

#define  TIM_CCMR2_OC3M                      ((uint32_t)0x00000070)            /*!<OC3M[2:0] bits (Output Compare 3 Mode) */
#define  TIM_CCMR2_OC3M_0                    ((uint32_t)0x00000010)            /*!<Bit 0 */
#define  TIM_CCMR2_OC3M_1                    ((uint32_t)0x00000020)            /*!<Bit 1 */
#define  TIM_CCMR2_OC3M_2                    ((uint32_t)0x00000040)            /*!<Bit 2 */
#define  TIM_CCMR2_OC3M_3                    ((uint32_t)0x00010000)            /*!<Bit 3 */

#define  TIM_CCMR2_OC3CE                     ((uint32_t)0x00000080)            /*!<Output Compare 3 Clear Enable */

#define  TIM_CCMR2_CC4S                      ((uint32_t)0x00000300)            /*!<CC4S[1:0] bits (Capture/Compare 4 Selection) */
#define  TIM_CCMR2_CC4S_0                    ((uint32_t)0x00000100)            /*!<Bit 0 */
#define  TIM_CCMR2_CC4S_1                    ((uint32_t)0x00000200)            /*!<Bit 1 */

#define  TIM_CCMR2_OC4FE                     ((uint32_t)0x00000400)            /*!<Output Compare 4 Fast enable */
#define  TIM_CCMR2_OC4PE                     ((uint32_t)0x00000800)            /*!<Output Compare 4 Preload enable */

#define  TIM_CCMR2_OC4M                      ((uint32_t)0x00007000)            /*!<OC4M[2:0] bits (Output Compare 4 Mode) */
#define  TIM_CCMR2_OC4M_0                    ((uint32_t)0x00001000)            /*!<Bit 0 */
#define  TIM_CCMR2_OC4M_1                    ((uint32_t)0x00002000)            /*!<Bit 1 */
#define  TIM_CCMR2_OC4M_2                    ((uint32_t)0x00004000)            /*!<Bit 2 */
#define  TIM_CCMR2_OC4M_3                    ((uint32_t)0x00100000)            /*!<Bit 3 */

#define  TIM_CCMR2_OC4CE                     ((uint32_t)0x00008000)            /*!<Output Compare 4 Clear Enable */

/*----------------------------------------------------------------------------*/

#define  TIM_CCMR2_IC3PSC                    ((uint16_t)0x0000000C)            /*!<IC3PSC[1:0] bits (Input Capture 3 Prescaler) */
#define  TIM_CCMR2_IC3PSC_0                  ((uint16_t)0x00000004)            /*!<Bit 0 */
#define  TIM_CCMR2_IC3PSC_1                  ((uint16_t)0x00000008)            /*!<Bit 1 */

#define  TIM_CCMR2_IC3F                      ((uint16_t)0x000000F0)            /*!<IC3F[3:0] bits (Input Capture 3 Filter) */
#define  TIM_CCMR2_IC3F_0                    ((uint16_t)0x00000010)            /*!<Bit 0 */
#define  TIM_CCMR2_IC3F_1                    ((uint16_t)0x00000020)            /*!<Bit 1 */
#define  TIM_CCMR2_IC3F_2                    ((uint16_t)0x00000040)            /*!<Bit 2 */
#define  TIM_CCMR2_IC3F_3                    ((uint16_t)0x00000080)            /*!<Bit 3 */

#define  TIM_CCMR2_IC4PSC                    ((uint16_t)0x00000C00)            /*!<IC4PSC[1:0] bits (Input Capture 4 Prescaler) */
#define  TIM_CCMR2_IC4PSC_0                  ((uint16_t)0x00000400)            /*!<Bit 0 */
#define  TIM_CCMR2_IC4PSC_1                  ((uint16_t)0x00000800)            /*!<Bit 1 */

#define  TIM_CCMR2_IC4F                      ((uint16_t)0x0000F000)            /*!<IC4F[3:0] bits (Input Capture 4 Filter) */
#define  TIM_CCMR2_IC4F_0                    ((uint16_t)0x00001000)            /*!<Bit 0 */
#define  TIM_CCMR2_IC4F_1                    ((uint16_t)0x00002000)            /*!<Bit 1 */
#define  TIM_CCMR2_IC4F_2                    ((uint16_t)0x00004000)            /*!<Bit 2 */
#define  TIM_CCMR2_IC4F_3                    ((uint16_t)0x00008000)            /*!<Bit 3 */

/*******************  Bit definition for TIM_CCER register  *******************/
#define  TIM_CCER_CC1E                       ((uint32_t)0x00000001)            /*!<Capture/Compare 1 output enable */
#define  TIM_CCER_CC1P                       ((uint32_t)0x00000002)            /*!<Capture/Compare 1 output Polarity */
#define  TIM_CCER_CC1NE                      ((uint32_t)0x00000004)            /*!<Capture/Compare 1 Complementary output enable */
#define  TIM_CCER_CC1NP                      ((uint32_t)0x00000008)            /*!<Capture/Compare 1 Complementary output Polarity */
#define  TIM_CCER_CC2E                       ((uint32_t)0x00000010)            /*!<Capture/Compare 2 output enable */
#define  TIM_CCER_CC2P                       ((uint32_t)0x00000020)            /*!<Capture/Compare 2 output Polarity */
#define  TIM_CCER_CC2NE                      ((uint32_t)0x00000040)            /*!<Capture/Compare 2 Complementary output enable */
#define  TIM_CCER_CC2NP                      ((uint32_t)0x00000080)            /*!<Capture/Compare 2 Complementary output Polarity */
#define  TIM_CCER_CC3E                       ((uint32_t)0x00000100)            /*!<Capture/Compare 3 output enable */
#define  TIM_CCER_CC3P                       ((uint32_t)0x00000200)            /*!<Capture/Compare 3 output Polarity */
#define  TIM_CCER_CC3NE                      ((uint32_t)0x00000400)            /*!<Capture/Compare 3 Complementary output enable */
#define  TIM_CCER_CC3NP                      ((uint32_t)0x00000800)            /*!<Capture/Compare 3 Complementary output Polarity */
#define  TIM_CCER_CC4E                       ((uint32_t)0x00001000)            /*!<Capture/Compare 4 output enable */
#define  TIM_CCER_CC4P                       ((uint32_t)0x00002000)            /*!<Capture/Compare 4 output Polarity */
#define  TIM_CCER_CC4NP                      ((uint32_t)0x00008000)            /*!<Capture/Compare 4 Complementary output Polarity */
#define  TIM_CCER_CC5E                       ((uint32_t)0x00010000)            /*!<Capture/Compare 5 output enable */
#define  TIM_CCER_CC5P                       ((uint32_t)0x00020000)            /*!<Capture/Compare 5 output Polarity */
#define  TIM_CCER_CC6E                       ((uint32_t)0x00100000)            /*!<Capture/Compare 6 output enable */
#define  TIM_CCER_CC6P                       ((uint32_t)0x00200000)            /*!<Capture/Compare 6 output Polarity */
/*******************  Bit definition for TIM_CNT register  ********************/
#define  TIM_CNT_CNT                         ((uint32_t)0xFFFFFFFF)            /*!<Counter Value */
#define  TIM_CNT_UIFCPY                      ((uint32_t)0x80000000)                                        /*!<Update interrupt flag copy */
/*******************  Bit definition for TIM_PSC register  ********************/
#define  TIM_PSC_PSC                         ((uint16_t)0xFFFF)            /*!<Prescaler Value */

/*******************  Bit definition for TIM_ARR register  ********************/
#define  TIM_ARR_ARR                         ((uint32_t)0xFFFFFFFF)            /*!<actual auto-reload Value */

/*******************  Bit definition for TIM_RCR register  ********************/
#define  TIM_RCR_REP                         ((uint8_t)0xFF)               /*!<Repetition Counter Value */

/*******************  Bit definition for TIM_CCR1 register  *******************/
#define  TIM_CCR1_CCR1                       ((uint16_t)0xFFFF)            /*!<Capture/Compare 1 Value */

/*******************  Bit definition for TIM_CCR2 register  *******************/
#define  TIM_CCR2_CCR2                       ((uint16_t)0xFFFF)            /*!<Capture/Compare 2 Value */

/*******************  Bit definition for TIM_CCR3 register  *******************/
#define  TIM_CCR3_CCR3                       ((uint16_t)0xFFFF)            /*!<Capture/Compare 3 Value */

/*******************  Bit definition for TIM_CCR4 register  *******************/
#define  TIM_CCR4_CCR4                       ((uint16_t)0xFFFF)            /*!<Capture/Compare 4 Value */

/*******************  Bit definition for TIM_CCR5 register  *******************/
#define  TIM_CCR5_CCR5                       ((uint32_t)0xFFFFFFFF)        /*!<Capture/Compare 5 Value */
#define  TIM_CCR5_GC5C1                      ((uint32_t)0x20000000)        /*!<Group Channel 5 and Channel 1 */
#define  TIM_CCR5_GC5C2                      ((uint32_t)0x40000000)        /*!<Group Channel 5 and Channel 2 */
#define  TIM_CCR5_GC5C3                      ((uint32_t)0x80000000)        /*!<Group Channel 5 and Channel 3 */

/*******************  Bit definition for TIM_CCR6 register  *******************/
#define  TIM_CCR6_CCR6                       ((uint16_t)0xFFFF)            /*!<Capture/Compare 6 Value */

/*******************  Bit definition for TIM_BDTR register  *******************/
#define  TIM_BDTR_DTG                        ((uint32_t)0x000000FF)            /*!<DTG[0:7] bits (Dead-Time Generator set-up) */
#define  TIM_BDTR_DTG_0                      ((uint32_t)0x00000001)            /*!<Bit 0 */
#define  TIM_BDTR_DTG_1                      ((uint32_t)0x00000002)            /*!<Bit 1 */
#define  TIM_BDTR_DTG_2                      ((uint32_t)0x00000004)            /*!<Bit 2 */
#define  TIM_BDTR_DTG_3                      ((uint32_t)0x00000008)            /*!<Bit 3 */
#define  TIM_BDTR_DTG_4                      ((uint32_t)0x00000010)            /*!<Bit 4 */
#define  TIM_BDTR_DTG_5                      ((uint32_t)0x00000020)            /*!<Bit 5 */
#define  TIM_BDTR_DTG_6                      ((uint32_t)0x00000040)            /*!<Bit 6 */
#define  TIM_BDTR_DTG_7                      ((uint32_t)0x00000080)            /*!<Bit 7 */

#define  TIM_BDTR_LOCK                       ((uint32_t)0x00000300)            /*!<LOCK[1:0] bits (Lock Configuration) */
#define  TIM_BDTR_LOCK_0                     ((uint32_t)0x00000100)            /*!<Bit 0 */
#define  TIM_BDTR_LOCK_1                     ((uint32_t)0x00000200)            /*!<Bit 1 */

#define  TIM_BDTR_OSSI                       ((uint32_t)0x00000400)            /*!<Off-State Selection for Idle mode */
#define  TIM_BDTR_OSSR                       ((uint32_t)0x00000800)            /*!<Off-State Selection for Run mode */
#define  TIM_BDTR_BKE                        ((uint32_t)0x00001000)            /*!<Break enable for Break1 */
#define  TIM_BDTR_BKP                        ((uint32_t)0x00002000)            /*!<Break Polarity for Break1 */
#define  TIM_BDTR_AOE                        ((uint32_t)0x00004000)            /*!<Automatic Output enable */
#define  TIM_BDTR_MOE                        ((uint32_t)0x00008000)            /*!<Main Output enable */

#define  TIM_BDTR_BKF                        ((uint32_t)0x000F0000)            /*!<Break Filter for Break1 */
#define  TIM_BDTR_BK2F                       ((uint32_t)0x00F00000)            /*!<Break Filter for Break2 */

#define  TIM_BDTR_BK2E                       ((uint32_t)0x01000000)            /*!<Break enable for Break2 */
#define  TIM_BDTR_BK2P                       ((uint32_t)0x02000000)            /*!<Break Polarity for Break2 */

/*******************  Bit definition for TIM_DCR register  ********************/
#define  TIM_DCR_DBA                         ((uint16_t)0x001F)            /*!<DBA[4:0] bits (DMA Base Address) */
#define  TIM_DCR_DBA_0                       ((uint16_t)0x0001)            /*!<Bit 0 */
#define  TIM_DCR_DBA_1                       ((uint16_t)0x0002)            /*!<Bit 1 */
#define  TIM_DCR_DBA_2                       ((uint16_t)0x0004)            /*!<Bit 2 */
#define  TIM_DCR_DBA_3                       ((uint16_t)0x0008)            /*!<Bit 3 */
#define  TIM_DCR_DBA_4                       ((uint16_t)0x0010)            /*!<Bit 4 */

#define  TIM_DCR_DBL                         ((uint16_t)0x1F00)            /*!<DBL[4:0] bits (DMA Burst Length) */
#define  TIM_DCR_DBL_0                       ((uint16_t)0x0100)            /*!<Bit 0 */
#define  TIM_DCR_DBL_1                       ((uint16_t)0x0200)            /*!<Bit 1 */
#define  TIM_DCR_DBL_2                       ((uint16_t)0x0400)            /*!<Bit 2 */
#define  TIM_DCR_DBL_3                       ((uint16_t)0x0800)            /*!<Bit 3 */
#define  TIM_DCR_DBL_4                       ((uint16_t)0x1000)            /*!<Bit 4 */

/*******************  Bit definition for TIM_DMAR register  *******************/
#define  TIM_DMAR_DMAB                       ((uint16_t)0xFFFF)            /*!<DMA register for burst accesses */

/*******************  Bit definition for TIM16_OR register  *********************/
#define TIM16_OR_TI1_RMP                     ((uint16_t)0x00C0)            /*!<TI1_RMP[1:0] bits (TIM16 Input 1 remap) */
#define TIM16_OR_TI1_RMP_0                   ((uint16_t)0x0040)            /*!<Bit 0 */
#define TIM16_OR_TI1_RMP_1                   ((uint16_t)0x0080)            /*!<Bit 1 */

/*******************  Bit definition for TIM1_OR register  *********************/
#define TIM1_OR_ETR_RMP                      ((uint16_t)0x000F)            /*!<ETR_RMP[3:0] bits (TIM1 ETR remap) */
#define TIM1_OR_ETR_RMP_0                    ((uint16_t)0x0001)            /*!<Bit 0 */
#define TIM1_OR_ETR_RMP_1                    ((uint16_t)0x0002)            /*!<Bit 1 */
#define TIM1_OR_ETR_RMP_2                    ((uint16_t)0x0004)            /*!<Bit 2 */
#define TIM1_OR_ETR_RMP_3                    ((uint16_t)0x0008)            /*!<Bit 3 */

/*******************  Bit definition for TIM8_OR register  *********************/
#define TIM8_OR_ETR_RMP                      ((uint16_t)0x000F)            /*!<ETR_RMP[3:0] bits (TIM8 ETR remap) */
#define TIM8_OR_ETR_RMP_0                    ((uint16_t)0x0001)            /*!<Bit 0 */
#define TIM8_OR_ETR_RMP_1                    ((uint16_t)0x0002)            /*!<Bit 1 */
#define TIM8_OR_ETR_RMP_2                    ((uint16_t)0x0004)            /*!<Bit 2 */
#define TIM8_OR_ETR_RMP_3                    ((uint16_t)0x0008)            /*!<Bit 3 */

/******************  Bit definition for TIM_CCMR3 register  *******************/
#define  TIM_CCMR3_OC5FE                     ((uint32_t)0x00000004)            /*!<Output Compare 5 Fast enable */
#define  TIM_CCMR3_OC5PE                     ((uint32_t)0x00000008)            /*!<Output Compare 5 Preload enable */

#define  TIM_CCMR3_OC5M                      ((uint32_t)0x00000070)            /*!<OC5M[2:0] bits (Output Compare 5 Mode) */
#define  TIM_CCMR3_OC5M_0                    ((uint32_t)0x00000010)            /*!<Bit 0 */
#define  TIM_CCMR3_OC5M_1                    ((uint32_t)0x00000020)            /*!<Bit 1 */
#define  TIM_CCMR3_OC5M_2                    ((uint32_t)0x00000040)            /*!<Bit 2 */
#define  TIM_CCMR3_OC5M_3                    ((uint32_t)0x00010000)            /*!<Bit 3 */

#define  TIM_CCMR3_OC5CE                     ((uint32_t)0x00000080)            /*!<Output Compare 5 Clear Enable */

#define  TIM_CCMR3_OC6FE                     ((uint32_t)0x00000400)            /*!<Output Compare 4 Fast enable */
#define  TIM_CCMR3_OC6PE                     ((uint32_t)0x00000800)            /*!<Output Compare 4 Preload enable */

#define  TIM_CCMR3_OC6M                      ((uint32_t)0x00007000)            /*!<OC4M[2:0] bits (Output Compare 4 Mode) */
#define  TIM_CCMR3_OC6M_0                    ((uint32_t)0x00001000)            /*!<Bit 0 */
#define  TIM_CCMR3_OC6M_1                    ((uint32_t)0x00002000)            /*!<Bit 1 */
#define  TIM_CCMR3_OC6M_2                    ((uint32_t)0x00004000)            /*!<Bit 2 */
#define  TIM_CCMR3_OC6M_3                    ((uint32_t)0x00100000)            /*!<Bit 3 */

#define  TIM_CCMR3_OC6CE                     ((uint32_t)0x00008000)            /*!<Output Compare 4 Clear Enable */
/*******************  Bit definition for TIM1_OR2 register  *********************/
#define TIM1_OR2_BKINE                        ((uint32_t)0x00000001)            /*!<BKINE Break input enable bit */
#define TIM1_OR2_BKCMP1E                      ((uint32_t)0x00000002)            /*!<BKCMP1E Break Compare1 Enable bit */
#define TIM1_OR2_BKCMP2E                      ((uint32_t)0x00000004)            /*!<BKCMP1E Break Compare2 Enable bit  */
#define TIM1_OR2_BKDFBK0E                     ((uint32_t)0x00000100)            /*!<BKDFBK0E Break input DFSDM Break 0 */
#define TIM1_OR2_BKINP                        ((uint32_t)0x00000200)            /*!<BRKINP Break input polarity */
#define TIM1_OR2_BKCMP1P                      ((uint32_t)0x00000400)            /*!<BKCMP1P Break COMP1 input polarity */ 
#define TIM1_OR2_BKCMP2P                      ((uint32_t)0x00000800)            /*!<BKCMP2P Break COMP2 input polarity */ 

#define TIM1_OR2_ETR_SEL                     ((uint32_t)0x0003C000)            /*!<ETR_SEL[3:0] bits (TIM1 ETR SEL) */
#define TIM1_OR2_ETR_SEL_0                   ((uint32_t)0x00004000)            /*!<Bit 14 */
#define TIM1_OR2_ETR_SEL_1                   ((uint32_t)0x00008000)            /*!<Bit 15 */
#define TIM1_OR2_ETR_SEL_2                   ((uint32_t)0x00010000)            /*!<Bit 16 */
#define TIM1_OR2_ETR_SEL_3                   ((uint32_t)0x00020000)            /*!<Bit 17 */

/*******************  Bit definition for TIM1_OR3 register  *********************/
#define TIM1_OR3_BK2INE                      ((uint32_t)0x00000001)            /*!<BK2INE Break input 2 enable bit */
#define TIM1_OR3_BK2CMP1E                    ((uint32_t)0x00000002)            /*!<BK2CMP1E Break2 Compare1 Enable bit */
#define TIM1_OR3_BK2CMP2E                    ((uint32_t)0x00000004)            /*!<BK2CMP1E Break2 Compare2 Enable bit  */
#define TIM1_OR3_BK2DFBK1E                   ((uint32_t)0x00000100)            /*!<BK2DFBK1E Break input2 DFSDM Break 1 */
#define TIM1_OR3_BK2INP                      ((uint32_t)0x00000200)            /*!<BRKINP Break2 input polarity */
#define TIM1_OR3_BK2CMP1P                    ((uint32_t)0x00000400)            /*!<BKCMP1P Break2 COMP1 input polarity */ 
#define TIM1_OR3_BK2CMP2P                    ((uint32_t)0x00000800)            /*!<BKCMP2P Break2 COMP2 input polarity */ 

/*******************  Bit definition for TIM1_TISEL register  *********************/
#define TIM1_TISEL_TI1SEL                     ((uint32_t)0x0000000F)            /*!<TI1SEL[3:0] bits (TIM1 TI1 SEL)*/
#define TIM1_TISEL_TI1SEL_0                   ((uint32_t)0x00000001)            /*!<Bit 0 */
#define TIM1_TISEL_TI1SEL_1                   ((uint32_t)0x00000002)            /*!<Bit 1 */
#define TIM1_TISEL_TI1SEL_2                   ((uint32_t)0x00000004)            /*!<Bit 2 */
#define TIM1_TISEL_TI1SEL_3                   ((uint32_t)0x00000008)            /*!<Bit 3 */

#define TIM1_TISEL_TI2SEL                     ((uint32_t)0x00000F00)            /*!<TI2SEL[3:0] bits (TIM1 TI2 SEL)*/
#define TIM1_TISEL_TI2SEL_0                   ((uint32_t)0x00000100)            /*!<Bit 8 */
#define TIM1_TISEL_TI2SEL_1                   ((uint32_t)0x00000200)            /*!<Bit 9 */
#define TIM1_TISEL_TI2SEL_2                   ((uint32_t)0x00000400)            /*!<Bit 10 */
#define TIM1_TISEL_TI2SEL_3                   ((uint32_t)0x00000800)            /*!<Bit 11 */

#define TIM1_TISEL_TI3SEL                     ((uint32_t)0x000F0000)            /*!<TI3SEL[3:0] bits (TIM1 TI3 SEL)*/
#define TIM1_TISEL_TI3SEL_0                   ((uint32_t)0x00010000)            /*!<Bit 16 */
#define TIM1_TISEL_TI3SEL_1                   ((uint32_t)0x00020000)            /*!<Bit 17 */
#define TIM1_TISEL_TI3SEL_2                   ((uint32_t)0x00040000)            /*!<Bit 18 */
#define TIM1_TISEL_TI3SEL_3                   ((uint32_t)0x00080000)            /*!<Bit 19 */

#define TIM1_TISEL_TI4SEL                     ((uint32_t)0x0F000000)            /*!<TI4SEL[3:0] bits (TIM1 TI4 SEL)*/
#define TIM1_TISEL_TI4SEL_0                   ((uint32_t)0x01000000)            /*!<Bit 20 */
#define TIM1_TISEL_TI4SEL_1                   ((uint32_t)0x02000000)            /*!<Bit 21 */
#define TIM1_TISEL_TI4SEL_2                   ((uint32_t)0x04000000)            /*!<Bit 22 */
#define TIM1_TISEL_TI4SEL_3                   ((uint32_t)0x08000000)            /*!<Bit 23 */

/*******************  Bit definition for TIM8_OR2 register  *********************/
#define TIM8_OR2_BKINE                        ((uint32_t)0x00000001)            /*!<BKINE Break input enable bit */
#define TIM8_OR2_BKCMP1E                      ((uint32_t)0x00000002)            /*!<BKCMP1E Break Compare1 Enable bit */
#define TIM8_OR2_BKCMP2E                      ((uint32_t)0x00000004)            /*!<BKCMP1E Break Compare2 Enable bit  */
#define TIM8_OR2_BKDFBK2E                     ((uint32_t)0x00000100)            /*!<BKDFBK0E Break input DFSDM Break 2 */
#define TIM8_OR2_BKINP                        ((uint32_t)0x00000200)            /*!<BRKINP Break input polarity */
#define TIM8_OR2_BKCMP1P                      ((uint32_t)0x00000400)            /*!<BKCMP1P Break COMP1 input polarity */ 
#define TIM8_OR2_BKCMP2P                      ((uint32_t)0x00000800)            /*!<BKCMP2P Break COMP2 input polarity */ 

#define TIM8_OR2_ETR_SEL                     ((uint32_t)0x0003C000)            /*!<ETR_SEL[3:0] bits (TIM8 ETR SEL) */
#define TIM8_OR2_ETR_SEL_0                   ((uint32_t)0x00004000)            /*!<Bit 14 */
#define TIM8_OR2_ETR_SEL_1                   ((uint32_t)0x00008000)            /*!<Bit 15 */
#define TIM8_OR2_ETR_SEL_2                   ((uint32_t)0x00010000)            /*!<Bit 16 */
#define TIM8_OR2_ETR_SEL_3                   ((uint32_t)0x00020000)            /*!<Bit 17 */
/*******************  Bit definition for TIM8_OR3 register  *********************/
#define TIM8_OR3_BK2INE                      ((uint32_t)0x00000001)            /*!<BK2INE Break input 2 enable bit */
#define TIM8_OR3_BK2CMP1E                    ((uint32_t)0x00000002)            /*!<BK2CMP1E Break2 Compare1 Enable bit */
#define TIM8_OR3_BK2CMP2E                    ((uint32_t)0x00000004)            /*!<BK2CMP1E Break2 Compare2 Enable bit  */
#define TIM8_OR3_BK2DFBK3E                   ((uint32_t)0x00000100)            /*!<BK2DFBK1E Break input2 DFSDM Break 3 */
#define TIM8_OR3_BK2INP                      ((uint32_t)0x00000200)            /*!<BRKINP Break2 input polarity */
#define TIM8_OR3_BK2CMP1P                    ((uint32_t)0x00000400)            /*!<BKCMP1P Break2 COMP1 input polarity */ 
#define TIM8_OR3_BK2CMP2P                    ((uint32_t)0x00000800)            /*!<BKCMP2P Break2 COMP2 input polarity */ 

/*******************  Bit definition for TIM8_TISEL register  *********************/
#define TIM8_TISEL_TI1SEL                     ((uint32_t)0x0000000F)            /*!<TI1SEL[3:0] bits (TIM8 TI1 SEL)*/
#define TIM8_TISEL_TI1SEL_0                   ((uint32_t)0x00000001)            /*!<Bit 0 */
#define TIM8_TISEL_TI1SEL_1                   ((uint32_t)0x00000002)            /*!<Bit 1 */
#define TIM8_TISEL_TI1SEL_2                   ((uint32_t)0x00000004)            /*!<Bit 2 */
#define TIM8_TISEL_TI1SEL_3                   ((uint32_t)0x00000008)            /*!<Bit 3 */

#define TIM8_TISEL_TI2SEL                     ((uint32_t)0x00000F00)            /*!<TI2SEL[3:0] bits (TIM8 TI2 SEL)*/
#define TIM8_TISEL_TI2SEL_0                   ((uint32_t)0x00000100)            /*!<Bit 8 */
#define TIM8_TISEL_TI2SEL_1                   ((uint32_t)0x00000200)            /*!<Bit 9 */
#define TIM8_TISEL_TI2SEL_2                   ((uint32_t)0x00000400)            /*!<Bit 10 */
#define TIM8_TISEL_TI2SEL_3                   ((uint32_t)0x00000800)            /*!<Bit 11 */

#define TIM8_TISEL_TI3SEL                     ((uint32_t)0x000F0000)            /*!<TI3SEL[3:0] bits (TIM8 TI3 SEL)*/
#define TIM8_TISEL_TI3SEL_0                   ((uint32_t)0x00010000)            /*!<Bit 16 */
#define TIM8_TISEL_TI3SEL_1                   ((uint32_t)0x00020000)            /*!<Bit 17 */
#define TIM8_TISEL_TI3SEL_2                   ((uint32_t)0x00040000)            /*!<Bit 18 */
#define TIM8_TISEL_TI3SEL_3                   ((uint32_t)0x00080000)            /*!<Bit 19 */

#define TIM8_TISEL_TI4SEL                     ((uint32_t)0x0F000000)            /*!<TI4SEL[3:0] bits (TIM8 TI4 SEL)*/
#define TIM8_TISEL_TI4SEL_0                   ((uint32_t)0x01000000)            /*!<Bit 20 */
#define TIM8_TISEL_TI4SEL_1                   ((uint32_t)0x02000000)            /*!<Bit 21 */
#define TIM8_TISEL_TI4SEL_2                   ((uint32_t)0x04000000)            /*!<Bit 22 */
#define TIM8_TISEL_TI4SEL_3                   ((uint32_t)0x08000000)            /*!<Bit 23 */

/*******************  Bit definition for TIM2_OR2 register  *********************/
#define TIM2_OR2_ETR_SEL                     ((uint32_t)0x0001C000)            /*!<ETR_SEL[3:0] bits (TIM2 ETR SEL) */
#define TIM2_OR2_ETR_SEL_0                   ((uint32_t)0x00004000)            /*!<Bit 14 */
#define TIM2_OR2_ETR_SEL_1                   ((uint32_t)0x00008000)            /*!<Bit 15 */
#define TIM2_OR2_ETR_SEL_2                   ((uint32_t)0x00010000)            /*!<Bit 16 */
#define TIM2_OR2_ETR_SEL_3                   ((uint32_t)0x00020000)            /*!<Bit 17 */

/*******************  Bit definition for TIM2_TISEL register  *********************/
#define TIM2_TISEL_TI1SEL                     ((uint32_t)0x0000000F)            /*!<TI1SEL[3:0] bits (TIM1 TI1 SEL)*/
#define TIM2_TISEL_TI1SEL_0                   ((uint32_t)0x00000001)            /*!<Bit 0 */
#define TIM2_TISEL_TI1SEL_1                   ((uint32_t)0x00000002)            /*!<Bit 1 */
#define TIM2_TISEL_TI1SEL_2                   ((uint32_t)0x00000004)            /*!<Bit 2 */
#define TIM2_TISEL_TI1SEL_3                   ((uint32_t)0x00000008)            /*!<Bit 3 */

#define TIM2_TISEL_TI2SEL                     ((uint32_t)0x00000F00)            /*!<TI2SEL[3:0] bits (TIM2 TI2 SEL)*/
#define TIM2_TISEL_TI2SEL_0                   ((uint32_t)0x00000100)            /*!<Bit 8 */
#define TIM2_TISEL_TI2SEL_1                   ((uint32_t)0x00000200)            /*!<Bit 9 */
#define TIM2_TISEL_TI2SEL_2                   ((uint32_t)0x00000400)            /*!<Bit 10 */
#define TIM2_TISEL_TI2SEL_3                   ((uint32_t)0x00000800)            /*!<Bit 11 */

#define TIM2_TISEL_TI3SEL                     ((uint32_t)0x000F0000)            /*!<TI3SEL[3:0] bits (TIM2 TI3 SEL)*/
#define TIM2_TISEL_TI3SEL_0                   ((uint32_t)0x00010000)            /*!<Bit 16 */
#define TIM2_TISEL_TI3SEL_1                   ((uint32_t)0x00020000)            /*!<Bit 17 */
#define TIM2_TISEL_TI3SEL_2                   ((uint32_t)0x00040000)            /*!<Bit 18 */
#define TIM2_TISEL_TI3SEL_3                   ((uint32_t)0x00080000)            /*!<Bit 19 */

#define TIM2_TISEL_TI4SEL                     ((uint32_t)0x0F000000)            /*!<TI4SEL[3:0] bits (TIM2 TI4 SEL)*/
#define TIM2_TISEL_TI4SEL_0                   ((uint32_t)0x01000000)            /*!<Bit 20 */
#define TIM2_TISEL_TI4SEL_1                   ((uint32_t)0x02000000)            /*!<Bit 21 */
#define TIM2_TISEL_TI4SEL_2                   ((uint32_t)0x04000000)            /*!<Bit 22 */
#define TIM2_TISEL_TI4SEL_3                   ((uint32_t)0x08000000)            /*!<Bit 23 */

/*******************  Bit definition for TIM3_OR2 register  *********************/
#define TIM3_OR2_ETR_SEL                     ((uint32_t)0x0001C000)            /*!<ETR_SEL[2:0] bits (TIM3 ETR SEL) */
#define TIM3_OR2_ETR_SEL_0                   ((uint32_t)0x00004000)            /*!<Bit 14 */
#define TIM3_OR2_ETR_SEL_1                   ((uint32_t)0x00008000)            /*!<Bit 15 */
#define TIM3_OR2_ETR_SEL_2                   ((uint32_t)0x00010000)            /*!<Bit 16 */
#define TIM3_OR2_ETR_SEL_3                   ((uint32_t)0x00020000)            /*!<Bit 17 */

/*******************  Bit definition for TIM3_TISEL register  *********************/
#define TIM3_TISEL_TI1SEL                     ((uint32_t)0x0000000F)            /*!<TI1SEL[3:0] bits (TIM3 TI1 SEL)*/
#define TIM3_TISEL_TI1SEL_0                   ((uint32_t)0x00000001)            /*!<Bit 0 */
#define TIM3_TISEL_TI1SEL_1                   ((uint32_t)0x00000002)            /*!<Bit 1 */
#define TIM3_TISEL_TI1SEL_2                   ((uint32_t)0x00000004)            /*!<Bit 2 */
#define TIM3_TISEL_TI1SEL_3                   ((uint32_t)0x00000008)            /*!<Bit 3 */

#define TIM3_TISEL_TI2SEL                     ((uint32_t)0x00000F00)            /*!<TI2SEL[3:0] bits (TIM3 TI2 SEL)*/
#define TIM3_TISEL_TI2SEL_0                   ((uint32_t)0x00000100)            /*!<Bit 8 */
#define TIM3_TISEL_TI2SEL_1                   ((uint32_t)0x00000200)            /*!<Bit 9 */
#define TIM3_TISEL_TI2SEL_2                   ((uint32_t)0x00000400)            /*!<Bit 10 */
#define TIM3_TISEL_TI2SEL_3                   ((uint32_t)0x00000800)            /*!<Bit 11 */

#define TIM3_TISEL_TI3SEL                     ((uint32_t)0x000F0000)            /*!<TI3SEL[3:0] bits (TIM3 TI3 SEL)*/
#define TIM3_TISEL_TI3SEL_0                   ((uint32_t)0x00010000)            /*!<Bit 16 */
#define TIM3_TISEL_TI3SEL_1                   ((uint32_t)0x00020000)            /*!<Bit 17 */
#define TIM3_TISEL_TI3SEL_2                   ((uint32_t)0x00040000)            /*!<Bit 18 */
#define TIM3_TISEL_TI3SEL_3                   ((uint32_t)0x00080000)            /*!<Bit 19 */

#define TIM3_TISEL_TI4SEL                     ((uint32_t)0x0F000000)            /*!<TI4SEL[3:0] bits (TIM3 TI4 SEL)*/
#define TIM3_TISEL_TI4SEL_0                   ((uint32_t)0x01000000)            /*!<Bit 20 */
#define TIM3_TISEL_TI4SEL_1                   ((uint32_t)0x02000000)            /*!<Bit 21 */
#define TIM3_TISEL_TI4SEL_2                   ((uint32_t)0x04000000)            /*!<Bit 22 */
#define TIM3_TISEL_TI4SEL_3                   ((uint32_t)0x08000000)            /*!<Bit 23 */

/*******************  Bit definition for TIM15_OR2 register  *********************/
#define TIM15_OR2_BKINE                        ((uint32_t)0x00000001)           /*!<BKINE Break input enable bit */
#define TIM15_OR2_BKCMP1E                      ((uint32_t)0x00000002)           /*!<BKCMP1E Break Compare1 Enable bit */
#define TIM15_OR2_BKCMP2E                      ((uint32_t)0x00000004)           /*!<BKCMP1E Break Compare2 Enable bit  */
#define TIM15_OR2_BKINP                        ((uint32_t)0x00000200)           /*!<BRKINP Break input polarity */
#define TIM15_OR2_BKCMP1P                      ((uint32_t)0x00000400)           /*!<BKCMP1P Break COMP1 input polarity */ 
#define TIM15_OR2_BKCMP2P                      ((uint32_t)0x00000800)           /*!<BKCMP2P Break COMP2 input polarity */ 

/*******************  Bit definition for TIM15_TISEL register  *********************/
#define TIM15_TISEL_TI1SEL                     ((uint32_t)0x0000000F)            /*!<TI1SEL[3:0] bits (TIM15 TI1 SEL)*/
#define TIM15_TISEL_TI1SEL_0                   ((uint32_t)0x00000001)            /*!<Bit 0 */
#define TIM15_TISEL_TI1SEL_1                   ((uint32_t)0x00000002)            /*!<Bit 1 */
#define TIM15_TISEL_TI1SEL_2                   ((uint32_t)0x00000004)            /*!<Bit 2 */
#define TIM15_TISEL_TI1SEL_3                   ((uint32_t)0x00000008)            /*!<Bit 3 */

#define TIM15_TISEL_TI2SEL                     ((uint32_t)0x00000F00)            /*!<TI2SEL[3:0] bits (TIM15 TI2 SEL)*/
#define TIM15_TISEL_TI2SEL_0                   ((uint32_t)0x00000100)            /*!<Bit 8 */
#define TIM15_TISEL_TI2SEL_1                   ((uint32_t)0x00000200)            /*!<Bit 9 */
#define TIM15_TISEL_TI2SEL_2                   ((uint32_t)0x00000400)            /*!<Bit 10 */
#define TIM15_TISEL_TI2SEL_3                   ((uint32_t)0x00000800)            /*!<Bit 11 */

/*******************  Bit definition for TIM16_OR2 register  *********************/
#define TIM16_OR2_BKINE                        ((uint32_t)0x00000001)            /*!<BKINE Break input enable bit */
#define TIM16_OR2_BKCMP1E                      ((uint32_t)0x00000002)            /*!<BKCMP1E Break Compare1 Enable bit */
#define TIM16_OR2_BKCMP2E                      ((uint32_t)0x00000004)            /*!<BKCMP1E Break Compare2 Enable bit  */
#define TIM16_OR2_BKINP                        ((uint32_t)0x00000200)            /*!<BRKINP Break input polarity */
#define TIM16_OR2_BKCMP1P                      ((uint32_t)0x00000400)            /*!<BKCMP1P Break COMP1 input polarity */ 
#define TIM16_OR2_BKCMP2P                      ((uint32_t)0x00000800)            /*!<BKCMP2P Break COMP2 input polarity */ 

/*******************  Bit definition for TIM16_TISEL register  *********************/
#define TIM16_TISEL_TI1SEL                     ((uint32_t)0x0000000F)            /*!<TI1SEL[3:0] bits (TIM16 TI1 SEL) */
#define TIM16_TISEL_TI1SEL_0                   ((uint32_t)0x00000001)            /*!<Bit 0 */
#define TIM16_TISEL_TI1SEL_1                   ((uint32_t)0x00000002)            /*!<Bit 1 */
#define TIM16_TISEL_TI1SEL_2                   ((uint32_t)0x00000004)            /*!<Bit 2 */
#define TIM16_TISEL_TI1SEL_3                   ((uint32_t)0x00000008)            /*!<Bit 3 */

/*******************  Bit definition for TIM17_OR2 register  *********************/
#define TIM17_OR2_BKINE                        ((uint32_t)0x00000001)            /*!<BKINE Break input enable bit */
#define TIM17_OR2_BKCMP1E                      ((uint32_t)0x00000002)            /*!<BKCMP1E Break Compare1 Enable bit */
#define TIM17_OR2_BKCMP2E                      ((uint32_t)0x00000004)            /*!<BKCMP1E Break Compare2 Enable bit  */
#define TIM17_OR2_BKINP                        ((uint32_t)0x00000200)            /*!<BRKINP Break input polarity */
#define TIM17_OR2_BKCMP1P                      ((uint32_t)0x00000400)            /*!<BKCMP1P Break COMP1 input polarity */ 
#define TIM17_OR2_BKCMP2P                      ((uint32_t)0x00000800)            /*!<BKCMP2P Break COMP2 input polarity */ 

/*******************  Bit definition for TIM17_TISEL register  *********************/
#define TIM17_TISEL_TI1SEL                     ((uint32_t)0x0000000F)            /*!<TI1SEL[3:0] bits (TIM17 TI1 SEL) */
#define TIM17_TISEL_TI1SEL_0                   ((uint32_t)0x00000001)            /*!<Bit 0 */
#define TIM17_TISEL_TI1SEL_1                   ((uint32_t)0x00000002)            /*!<Bit 1 */
#define TIM17_TISEL_TI1SEL_2                   ((uint32_t)0x00000004)            /*!<Bit 2 */
#define TIM17_TISEL_TI1SEL_3                   ((uint32_t)0x00000008)            /*!<Bit 3 */

/******************************************************************************/
/*                                                                            */
/*                         Low Power Timer (LPTTIM)                           */
/*                                                                            */
/******************************************************************************/
/******************  Bit definition for LPTIM_ISR register  *******************/
#define  LPTIM_ISR_CMPM                         ((uint32_t)0x00000001)            /*!< Compare match */
#define  LPTIM_ISR_ARRM                         ((uint32_t)0x00000002)            /*!< Autoreload match */
#define  LPTIM_ISR_EXTTRIG                      ((uint32_t)0x00000004)            /*!< External trigger edge event */
#define  LPTIM_ISR_CMPOK                        ((uint32_t)0x00000008)            /*!< Compare register update OK */
#define  LPTIM_ISR_ARROK                        ((uint32_t)0x00000010)            /*!< Autoreload register update OK */
#define  LPTIM_ISR_UP                           ((uint32_t)0x00000020)            /*!< Counter direction change down to up */
#define  LPTIM_ISR_DOWN                         ((uint32_t)0x00000040)            /*!< Counter direction change up to down */

/******************  Bit definition for LPTIM_ICR register  *******************/
#define  LPTIM_ICR_CMPMCF                       ((uint32_t)0x00000001)            /*!< Compare match Clear Flag */
#define  LPTIM_ICR_ARRMCF                       ((uint32_t)0x00000002)            /*!< Autoreload match Clear Flag */
#define  LPTIM_ICR_EXTTRIGCF                    ((uint32_t)0x00000004)            /*!< External trigger edge event Clear Flag */
#define  LPTIM_ICR_CMPOKCF                      ((uint32_t)0x00000008)            /*!< Compare register update OK Clear Flag */
#define  LPTIM_ICR_ARROKCF                      ((uint32_t)0x00000010)            /*!< Autoreload register update OK Clear Flag */
#define  LPTIM_ICR_UPCF                         ((uint32_t)0x00000020)            /*!< Counter direction change down to up Clear Flag */
#define  LPTIM_ICR_DOWNCF                       ((uint32_t)0x00000040)            /*!< Counter direction change up to down Clear Flag */

/******************  Bit definition for LPTIM_IER register ********************/
#define  LPTIM_IER_CMPMIE                       ((uint32_t)0x00000001)            /*!< Compare match Interrupt Enable */
#define  LPTIM_IER_ARRMIE                       ((uint32_t)0x00000002)            /*!< Autoreload match Interrupt Enable */
#define  LPTIM_IER_EXTTRIGIE                    ((uint32_t)0x00000004)            /*!< External trigger edge event Interrupt Enable */
#define  LPTIM_IER_CMPOKIE                      ((uint32_t)0x00000008)            /*!< Compare register update OK Interrupt Enable */
#define  LPTIM_IER_ARROKIE                      ((uint32_t)0x00000010)            /*!< Autoreload register update OK Interrupt Enable */
#define  LPTIM_IER_UPIE                         ((uint32_t)0x00000020)            /*!< Counter direction change down to up Interrupt Enable */
#define  LPTIM_IER_DOWNIE                       ((uint32_t)0x00000040)            /*!< Counter direction change up to down Interrupt Enable */

/******************  Bit definition for LPTIM_CFGR register *******************/
#define  LPTIM_CFGR_CKSEL                       ((uint32_t)0x00000001)             /*!< Clock selector */

#define  LPTIM_CFGR_CKPOL                       ((uint32_t)0x00000006)             /*!< CKPOL[1:0] bits (Clock polarity) */
#define  LPTIM_CFGR_CKPOL_0                     ((uint32_t)0x00000002)             /*!< Bit 0 */
#define  LPTIM_CFGR_CKPOL_1                     ((uint32_t)0x00000004)             /*!< Bit 1 */

#define  LPTIM_CFGR_CKFLT                       ((uint32_t)0x00000018)             /*!< CKFLT[1:0] bits (Configurable digital filter for external clock) */
#define  LPTIM_CFGR_CKFLT_0                     ((uint32_t)0x00000008)             /*!< Bit 0 */
#define  LPTIM_CFGR_CKFLT_1                     ((uint32_t)0x00000010)             /*!< Bit 1 */

#define  LPTIM_CFGR_TRGFLT                      ((uint32_t)0x000000C0)             /*!< TRGFLT[1:0] bits (Configurable digital filter for trigger) */
#define  LPTIM_CFGR_TRGFLT_0                    ((uint32_t)0x00000040)             /*!< Bit 0 */
#define  LPTIM_CFGR_TRGFLT_1                    ((uint32_t)0x00000080)             /*!< Bit 1 */

#define  LPTIM_CFGR_PRESC                       ((uint32_t)0x00000E00)             /*!< PRESC[2:0] bits (Clock prescaler) */
#define  LPTIM_CFGR_PRESC_0                     ((uint32_t)0x00000200)             /*!< Bit 0 */
#define  LPTIM_CFGR_PRESC_1                     ((uint32_t)0x00000400)             /*!< Bit 1 */
#define  LPTIM_CFGR_PRESC_2                     ((uint32_t)0x00000800)             /*!< Bit 2 */

#define  LPTIM_CFGR_TRIGSEL                     ((uint32_t)0x0000E000)             /*!< TRIGSEL[2:0]] bits (Trigger selector) */
#define  LPTIM_CFGR_TRIGSEL_0                   ((uint32_t)0x00002000)             /*!< Bit 0 */
#define  LPTIM_CFGR_TRIGSEL_1                   ((uint32_t)0x00004000)             /*!< Bit 1 */
#define  LPTIM_CFGR_TRIGSEL_2                   ((uint32_t)0x00008000)             /*!< Bit 2 */

#define  LPTIM_CFGR_TRIGEN                      ((uint32_t)0x00060000)             /*!< TRIGEN[1:0] bits (Trigger enable and polarity) */
#define  LPTIM_CFGR_TRIGEN_0                    ((uint32_t)0x00020000)             /*!< Bit 0 */
#define  LPTIM_CFGR_TRIGEN_1                    ((uint32_t)0x00040000)             /*!< Bit 1 */

#define  LPTIM_CFGR_TIMOUT                      ((uint32_t)0x00080000)             /*!< Timout enable */
#define  LPTIM_CFGR_WAVE                        ((uint32_t)0x00100000)             /*!< Waveform shape */
#define  LPTIM_CFGR_WAVPOL                      ((uint32_t)0x00200000)             /*!< Waveform shape polarity */
#define  LPTIM_CFGR_PRELOAD                     ((uint32_t)0x00400000)             /*!< Reg update mode */
#define  LPTIM_CFGR_COUNTMODE                   ((uint32_t)0x00800000)             /*!< Counter mode enable */
#define  LPTIM_CFGR_ENC                         ((uint32_t)0x01000000)             /*!< Encoder mode enable */

/******************  Bit definition for LPTIM_CR register  ********************/
#define  LPTIM_CR_ENABLE                        ((uint32_t)0x00000001)             /*!< LPTIMer enable */
#define  LPTIM_CR_SNGSTRT                       ((uint32_t)0x00080002)             /*!< Timer start in single mode */
#define  LPTIM_CR_CNTSTRT                       ((uint32_t)0x00000004)             /*!< Timer start in continuous mode */
#define  LPTIM_CR_COUNTRST                      ((uint32_t)0x00000008)             /*!< Timer Counter reset in synchronous mode*/
#define  LPTIM_CR_RSTARE                        ((uint32_t)0x00000010)             /*!< Timer Counter reset after read enable (asynchronously)*/


/******************  Bit definition for LPTIM_CMP register  *******************/
#define  LPTIM_CMP_CMP                          ((uint32_t)0x0000FFFF)             /*!< Compare register */

/******************  Bit definition for LPTIM_ARR register  *******************/
#define  LPTIM_ARR_ARR                          ((uint32_t)0x0000FFFF)             /*!< Auto reload register */

/******************  Bit definition for LPTIM_CNT register  *******************/
#define  LPTIM_CNT_CNT                          ((uint32_t)0x0000FFFF)             /*!< Counter register */

/******************  Bit definition for LPTIM_OR register  *******************/
#define  LPTIM_CFGR2_CFGR2                           ((uint32_t)0x000000FF)               /*!< LPTIMER_ CFGR2[7:0] bits (Remap selection) */
#define  LPTIM_CFGR2_IN1_SEL0                       ((uint32_t)0x00000001)               /*!< Bit 0 */
#define  LPTIM_CFGR2_IN1_SEL1                       ((uint32_t)0x00000002)               /*!< Bit 1 */
#define  LPTIM_CFGR2_IN1_SEL2                       ((uint32_t)0x00000004)               /*!< Bit 2 */
#define  LPTIM_CFGR2_IN1_SEL3                       ((uint32_t)0x00000008)               /*!< Bit 3 */
#define  LPTIM_CFGR2_IN2_SEL0                       ((uint32_t)0x00000010)               /*!< Bit 4 */
#define  LPTIM_CFGR2_IN2_SEL1                       ((uint32_t)0x00000020)               /*!< Bit 5 */
#define  LPTIM_CFGR2_IN2_SEL2                       ((uint32_t)0x00000040)               /*!< Bit 6 */
#define  LPTIM_CFGR2_IN2_SEL3                       ((uint32_t)0x00000080)               /*!< Bit 7 */

/******************************************************************************/
/*                                                                            */
/*                      Analog Comparators (COMP)                             */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for COMP_SR register  ********************/
#define  COMP_SR_C1VAL                         ((uint32_t)0x00000001)     
#define  COMP_SR_C2VAL                         ((uint32_t)0x00000002)    
#define  COMP_SR_C1IF                          ((uint32_t)0x00010000) 
#define  COMP_SR_C2IF                          ((uint32_t)0x00020000)    
/*******************  Bit definition for COMP_ICFR register  ********************/
#define  COMP_ICFR_C1IF                        ((uint32_t)0x00010000)     
#define  COMP_ICFR_C2IF                        ((uint32_t)0x00020000)     
/*******************  Bit definition for COMP_OR register  ********************/
#define  COMP_OR_AFOPA6                        ((uint32_t)0x00000001)     
#define  COMP_OR_AFOPA8                        ((uint32_t)0x00000002)     
#define  COMP_OR_AFOPB12                       ((uint32_t)0x00000004)    
#define  COMP_OR_AFOPE6                        ((uint32_t)0x00000008)     
#define  COMP_OR_AFOPE15                       ((uint32_t)0x00000010)     
#define  COMP_OR_AFOPG2                        ((uint32_t)0x00000020)     
#define  COMP_OR_AFOPG3                        ((uint32_t)0x00000040)    
#define  COMP_OR_AFOPG4                        ((uint32_t)0x00000080)     
#define  COMP_OR_AFOPI1                        ((uint32_t)0x00000100)  
#define  COMP_OR_AFOPI4                        ((uint32_t)0x00000200)     
#define  COMP_OR_AFOPK2                        ((uint32_t)0x00000400)  

/*!< ******************  Bit definition for COMP_CFGRx register  ********************/
#define  COMP_CFGRx_EN                         ((uint32_t)0x00000001)     /*!< COMPx enable bit                     */
#define  COMP_CFGRx_BRGEN                      ((uint32_t)0x00000002)     /*!< COMPx Scaler bridge enable           */
#define  COMP_CFGRx_SCALEN                     ((uint32_t)0x00000004)     /*!< COMPx Voltage scaler enable bit      */
#define  COMP_CFGRx_POLARITY                   ((uint32_t)0x00000008)     /*!< COMPx  polarity selection bit        */
#define  COMP_CFGRx_WINMODE                    ((uint32_t)0x00000010)     /*!< COMPx Windows mode selection bit     */
#define  COMP_CFGRx_ITEN                       ((uint32_t)0x00000040)     /*!< COMPx  interrupt enable              */
#define  COMP_CFGRx_HYST                       ((uint32_t)0x00000300)     /*!< COMPx  hysteresis selection bits     */
#define  COMP_CFGRx_HYST_0                     ((uint32_t)0x00000100)     /*!< COMPx  hysteresis selection bit 0    */
#define  COMP_CFGRx_HYST_1                     ((uint32_t)0x00000200)     /*!< COMPx  hysteresis selection bit 1    */
#define  COMP_CFGRx_PWRMODE                    ((uint32_t)0x00003000)     /*!< COMPx Power Mode of the comparator   */
#define  COMP_CFGRx_PWRMODE_0                  ((uint32_t)0x00001000)     /*!< COMPx  Power Mode selection bit 0    */
#define  COMP_CFGRx_PWRMODE_1                  ((uint32_t)0x00002000)     /*!< COMPx  Power Mode selection bit 1    */
#define  COMP_CFGRx_INMSEL                     ((uint32_t)0x00070000)     /*!< COMPx  input minus selection bit  */
#define  COMP_CFGRx_INMSEL_0                   ((uint32_t)0x00010000)     /*!< COMPx inverting input selection bit 0 */
#define  COMP_CFGRx_INMSEL_1                   ((uint32_t)0x00020000)     /*!< COMPx inverting input selection bit 1 */
#define  COMP_CFGRx_INMSEL_2                   ((uint32_t)0x00040000)     /*!< COMPx inverting input selection bit 2 */
#define  COMP_CFGRx_INPSEL                     ((uint32_t)0x00100000)     /*!< COMPx  input plus selection bit       */
#define  COMP_CFGRx_BLANKING                   ((uint32_t)0x0F000000)     /*!< COMPx  blanking source selection bits */
#define  COMP_CFGRx_BLANKING_0                 ((uint32_t)0x01000000)     /*!< COMPx  blanking source selection bit 0 */
#define  COMP_CFGRx_BLANKING_1                 ((uint32_t)0x02000000)     /*!< COMPx  blanking source selection bit 1 */
#define  COMP_CFGRx_BLANKING_2                 ((uint32_t)0x04000000)     /*!< COMPx  blanking source selection bit 2 */
#define  COMP_CFGRx_LOCK                       ((uint32_t)0x80000000)     /*!< COMPx Lock Bit                        */


/******************************************************************************/
/*                                                                            */
/*      Universal Synchronous Asynchronous Receiver Transmitter (USART)       */
/*                                                                            */
/******************************************************************************/
/******************  Bit definition for USART_CR1 register  *******************/
#define  USART_CR1_UE                        ((uint32_t)0x00000001)            /*!< USART Enable */
#define  USART_CR1_UESM                      ((uint32_t)0x00000002)            /*!< USART Enable in STOP Mode */
#define  USART_CR1_RE                        ((uint32_t)0x00000004)            /*!< Receiver Enable */
#define  USART_CR1_TE                        ((uint32_t)0x00000008)            /*!< Transmitter Enable */
#define  USART_CR1_IDLEIE                    ((uint32_t)0x00000010)            /*!< IDLE Interrupt Enable */
#define  USART_CR1_RXNEIE                    ((uint32_t)0x00000020)            /*!< RXNE Interrupt Enable */
#define  USART_CR1_TCIE                      ((uint32_t)0x00000040)            /*!< Transmission Complete Interrupt Enable */
#define  USART_CR1_TXEIE                     ((uint32_t)0x00000080)            /*!< TXE Interrupt Enable */
#define  USART_CR1_PEIE                      ((uint32_t)0x00000100)            /*!< PE Interrupt Enable */
#define  USART_CR1_PS                        ((uint32_t)0x00000200)            /*!< Parity Selection */
#define  USART_CR1_PCE                       ((uint32_t)0x00000400)            /*!< Parity Control Enable */
#define  USART_CR1_WAKE                      ((uint32_t)0x00000800)            /*!< Receiver Wakeup method */
#define  USART_CR1_M                         ((uint32_t)0x10001000)            /*!< Word length */
#define  USART_CR1_M0                        ((uint32_t)0x00001000)            /*!< Word length - Bit 0 */
#define  USART_CR1_MME                       ((uint32_t)0x00002000)            /*!< Mute Mode Enable */
#define  USART_CR1_CMIE                      ((uint32_t)0x00004000)            /*!< Character match interrupt enable */
#define  USART_CR1_OVER8                     ((uint32_t)0x00008000)            /*!< Oversampling by 8-bit or 16-bit mode */
#define  USART_CR1_DEDT                      ((uint32_t)0x001F0000)            /*!< DEDT[4:0] bits (Driver Enable Deassertion Time) */
#define  USART_CR1_DEDT_0                    ((uint32_t)0x00010000)            /*!< Bit 0 */
#define  USART_CR1_DEDT_1                    ((uint32_t)0x00020000)            /*!< Bit 1 */
#define  USART_CR1_DEDT_2                    ((uint32_t)0x00040000)            /*!< Bit 2 */
#define  USART_CR1_DEDT_3                    ((uint32_t)0x00080000)            /*!< Bit 3 */
#define  USART_CR1_DEDT_4                    ((uint32_t)0x00100000)            /*!< Bit 4 */
#define  USART_CR1_DEAT                      ((uint32_t)0x03E00000)            /*!< DEAT[4:0] bits (Driver Enable Assertion Time) */
#define  USART_CR1_DEAT_0                    ((uint32_t)0x00200000)            /*!< Bit 0 */
#define  USART_CR1_DEAT_1                    ((uint32_t)0x00400000)            /*!< Bit 1 */
#define  USART_CR1_DEAT_2                    ((uint32_t)0x00800000)            /*!< Bit 2 */
#define  USART_CR1_DEAT_3                    ((uint32_t)0x01000000)            /*!< Bit 3 */
#define  USART_CR1_DEAT_4                    ((uint32_t)0x02000000)            /*!< Bit 4 */
#define  USART_CR1_RTOIE                     ((uint32_t)0x04000000)            /*!< Receive Time Out interrupt enable */
#define  USART_CR1_EOBIE                     ((uint32_t)0x08000000)            /*!< End of Block interrupt enable */
#define  USART_CR1_M1                        ((uint32_t)0x10000000)            /*!< Word length - Bit 1 */
#define  USART_CR1_FIFOEN                    ((uint32_t)0x20000000)            /*!< FIFO mode enable */
#define  USART_CR1_TXFEIE                    ((uint32_t)0x40000000)            /*!< TXFIFO empty interrupt enable */
#define  USART_CR1_RXFFIE                    ((uint32_t)0x80000000)            /*!< RXFIFO Full interrupt enable */

/******************  Bit definition for USART_CR2 register  *******************/
#define  USART_CR2_SLVEN                     ((uint32_t)0x00000001)            /*!< Synchronous Slave mode Enable */
#define  USART_CR2_DIS_NSS                   ((uint32_t)0x00000008)            /*!< Negative Slave Select (NSS) pin management */
#define  USART_CR2_ADDM7                     ((uint32_t)0x00000010)            /*!< 7-bit or 4-bit Address Detection */
#define  USART_CR2_LBDL                      ((uint32_t)0x00000020)            /*!< LIN Break Detection Length */
#define  USART_CR2_LBDIE                     ((uint32_t)0x00000040)            /*!< LIN Break Detection Interrupt Enable */
#define  USART_CR2_LBCL                      ((uint32_t)0x00000100)            /*!< Last Bit Clock pulse */
#define  USART_CR2_CPHA                      ((uint32_t)0x00000200)            /*!< Clock Phase */
#define  USART_CR2_CPOL                      ((uint32_t)0x00000400)            /*!< Clock Polarity */
#define  USART_CR2_CLKEN                     ((uint32_t)0x00000800)            /*!< Clock Enable */
#define  USART_CR2_STOP                      ((uint32_t)0x00003000)            /*!< STOP[1:0] bits (STOP bits) */
#define  USART_CR2_STOP_0                    ((uint32_t)0x00001000)            /*!< Bit 0 */
#define  USART_CR2_STOP_1                    ((uint32_t)0x00002000)            /*!< Bit 1 */
#define  USART_CR2_LINEN                     ((uint32_t)0x00004000)            /*!< LIN mode enable */
#define  USART_CR2_SWAP                      ((uint32_t)0x00008000)            /*!< SWAP TX/RX pins */
#define  USART_CR2_RXINV                     ((uint32_t)0x00010000)            /*!< RX pin active level inversion */
#define  USART_CR2_TXINV                     ((uint32_t)0x00020000)            /*!< TX pin active level inversion */
#define  USART_CR2_DATAINV                   ((uint32_t)0x00040000)            /*!< Binary data inversion */
#define  USART_CR2_MSBFIRST                  ((uint32_t)0x00080000)            /*!< Most Significant Bit First */
#define  USART_CR2_ABREN                     ((uint32_t)0x00100000)            /*!< Auto Baud-Rate Enable*/
#define  USART_CR2_ABRMODE                   ((uint32_t)0x00600000)            /*!< ABRMOD[1:0] bits (Auto Baud-Rate Mode) */
#define  USART_CR2_ABRMODE_0                 ((uint32_t)0x00200000)            /*!< Bit 0 */
#define  USART_CR2_ABRMODE_1                 ((uint32_t)0x00400000)            /*!< Bit 1 */
#define  USART_CR2_RTOEN                     ((uint32_t)0x00800000)            /*!< Receiver Time-Out enable */
#define  USART_CR2_ADD                       ((uint32_t)0xFF000000)            /*!< Address of the USART node */

/******************  Bit definition for USART_CR3 register  *******************/
#define  USART_CR3_EIE                       ((uint32_t)0x00000001)            /*!< Error Interrupt Enable */
#define  USART_CR3_IREN                      ((uint32_t)0x00000002)            /*!< IrDA mode Enable */
#define  USART_CR3_IRLP                      ((uint32_t)0x00000004)            /*!< IrDA Low-Power */
#define  USART_CR3_HDSEL                     ((uint32_t)0x00000008)            /*!< Half-Duplex Selection */
#define  USART_CR3_NACK                      ((uint32_t)0x00000010)            /*!< SmartCard NACK enable */
#define  USART_CR3_SCEN                      ((uint32_t)0x00000020)            /*!< SmartCard mode enable */
#define  USART_CR3_DMAR                      ((uint32_t)0x00000040)            /*!< DMA Enable Receiver */
#define  USART_CR3_DMAT                      ((uint32_t)0x00000080)            /*!< DMA Enable Transmitter */
#define  USART_CR3_RTSE                      ((uint32_t)0x00000100)            /*!< RTS Enable */
#define  USART_CR3_CTSE                      ((uint32_t)0x00000200)            /*!< CTS Enable */
#define  USART_CR3_CTSIE                     ((uint32_t)0x00000400)            /*!< CTS Interrupt Enable */
#define  USART_CR3_ONEBIT                    ((uint32_t)0x00000800)            /*!< One sample bit method enable */
#define  USART_CR3_OVRDIS                    ((uint32_t)0x00001000)            /*!< Overrun Disable */
#define  USART_CR3_DDRE                      ((uint32_t)0x00002000)            /*!< DMA Disable on Reception Error */
#define  USART_CR3_DEM                       ((uint32_t)0x00004000)            /*!< Driver Enable Mode */
#define  USART_CR3_DEP                       ((uint32_t)0x00008000)            /*!< Driver Enable Polarity Selection */
#define  USART_CR3_SCARCNT                   ((uint32_t)0x000E0000)            /*!< SCARCNT[2:0] bits (SmartCard Auto-Retry Count) */
#define  USART_CR3_SCARCNT_0                 ((uint32_t)0x00020000)            /*!< Bit 0 */
#define  USART_CR3_SCARCNT_1                 ((uint32_t)0x00040000)            /*!< Bit 1 */
#define  USART_CR3_SCARCNT_2                 ((uint32_t)0x00080000)            /*!< Bit 2 */
#define  USART_CR3_WUS                       ((uint32_t)0x00300000)            /*!< WUS[1:0] bits (Wake UP Interrupt Flag Selection) */
#define  USART_CR3_WUS_0                     ((uint32_t)0x00100000)            /*!< Bit 0 */
#define  USART_CR3_WUS_1                     ((uint32_t)0x00200000)            /*!< Bit 1 */
#define  USART_CR3_WUFIE                     ((uint32_t)0x00400000)            /*!< Wake Up Interrupt Enable */
#define  USART_CR3_TXFTIE                    ((uint32_t)0x00800000)            /*!< TXFIFO threshold interrupt enable */ 
#define  USART_CR3_TCBGTIE                   ((uint32_t)0x01000000)            /*!< Transmission Complete before guard time, interrupt enable */
#define  USART_CR3_RXFTCFG                   ((uint32_t)0x0E000000)            /*!< RXFTCFG [2:0]Receive FIFO threshold configuration */
#define  USART_CR3_RXFTCFG_0                 ((uint32_t)0x02000000)            /*!< Bit 0 */
#define  USART_CR3_RXFTCFG_1                 ((uint32_t)0x04000000)            /*!< Bit 1 */
#define  USART_CR3_RXFTCFG_2                 ((uint32_t)0x08000000)            /*!< Bit 2 */
#define  USART_CR3_RXFTIE                    ((uint32_t)0x10000000)            /*!< RXFIFO threshold interrupt enable */
#define  USART_CR3_TXFTCFG                   ((uint32_t)0xE0000000)            /*!< TXFIFO [2:0] threshold configuration */
#define  USART_CR3_TXFTCFG_0                 ((uint32_t)0x20000000)            /*!< Bit 0 */
#define  USART_CR3_TXFTCFG_1                 ((uint32_t)0x40000000)            /*!< Bit 1 */
#define  USART_CR3_TXFTCFG_2                 ((uint32_t)0x80000000)            /*!< Bit 2 */

/******************  Bit definition for USART_BRR register  *******************/
#define  USART_BRR_DIV_FRACTION              ((uint32_t)0x0000000F)                /*!< Fraction of USARTDIV */
#define  USART_BRR_DIV_MANTISSA              ((uint32_t)0x0000FFF0)                /*!< Mantissa of USARTDIV */

/******************  Bit definition for USART_GTPR register  ******************/
#define  USART_GTPR_PSC                      ((uint32_t)0x000000FF)                /*!< PSC[7:0] bits (Prescaler value) */
#define  USART_GTPR_GT                       ((uint32_t)0x0000FF00)                /*!< GT[7:0] bits (Guard time value) */


/*******************  Bit definition for USART_RTOR register  *****************/
#define  USART_RTOR_RTO                      ((uint32_t)0x00FFFFFF)            /*!< Receiver Time Out Value */
#define  USART_RTOR_BLEN                     ((uint32_t)0xFF000000)            /*!< Block Length */

/*******************  Bit definition for USART_RQR register  ******************/
#define  USART_RQR_ABRRQ                    ((uint32_t)0x00000001)                /*!< Auto-Baud Rate Request */
#define  USART_RQR_SBKRQ                    ((uint32_t)0x00000002)                /*!< Send Break Request */
#define  USART_RQR_MMRQ                     ((uint32_t)0x00000004)                /*!< Mute Mode Request */
#define  USART_RQR_RXFRQ                    ((uint32_t)0x00000008)                /*!< Receive Data flush Request */
#define  USART_RQR_TXFRQ                    ((uint32_t)0x00000010)                /*!< Transmit data flush Request */

/*******************  Bit definition for USART_ISR register  ******************/
#define  USART_ISR_PE                        ((uint32_t)0x00000001)            /*!< Parity Error */
#define  USART_ISR_FE                        ((uint32_t)0x00000002)            /*!< Framing Error */
#define  USART_ISR_NE                        ((uint32_t)0x00000004)            /*!< Noise detected Flag */
#define  USART_ISR_ORE                       ((uint32_t)0x00000008)            /*!< OverRun Error */
#define  USART_ISR_IDLE                      ((uint32_t)0x00000010)            /*!< IDLE line detected */
#define  USART_ISR_RXNE                      ((uint32_t)0x00000020)            /*!< Read Data Register Not Empty */
#define  USART_ISR_TC                        ((uint32_t)0x00000040)            /*!< Transmission Complete */
#define  USART_ISR_TXE                       ((uint32_t)0x00000080)            /*!< Transmit Data Register Empty */
#define  USART_ISR_LBDF                      ((uint32_t)0x00000100)            /*!< LIN Break Detection Flag */
#define  USART_ISR_CTSIF                     ((uint32_t)0x00000200)            /*!< CTS interrupt flag */
#define  USART_ISR_CTS                       ((uint32_t)0x00000400)            /*!< CTS flag */
#define  USART_ISR_RTOF                      ((uint32_t)0x00000800)            /*!< Receiver Time Out */
#define  USART_ISR_EOBF                      ((uint32_t)0x00001000)            /*!< End Of Block Flag */
#define  USART_ISR_UDR                       ((uint32_t)0x00002000)            /*!< SPI slave underrun error flag */
#define  USART_ISR_ABRE                      ((uint32_t)0x00004000)            /*!< Auto-Baud Rate Error */
#define  USART_ISR_ABRF                      ((uint32_t)0x00008000)            /*!< Auto-Baud Rate Flag */
#define  USART_ISR_BUSY                      ((uint32_t)0x00010000)            /*!< Busy Flag */
#define  USART_ISR_CMF                       ((uint32_t)0x00020000)            /*!< Character Match Flag */
#define  USART_ISR_SBKF                      ((uint32_t)0x00040000)            /*!< Send Break Flag */
#define  USART_ISR_RWU                       ((uint32_t)0x00080000)            /*!< Receive Wake Up from mute mode Flag */
#define  USART_ISR_WUF                       ((uint32_t)0x00100000)            /*!< Wake Up from stop mode Flag */
#define  USART_ISR_TEACK                     ((uint32_t)0x00200000)            /*!< Transmit Enable Acknowledge Flag */
#define  USART_ISR_REACK                     ((uint32_t)0x00400000)            /*!< Receive Enable Acknowledge Flag */
#define  USART_ISR_TXFE                      ((uint32_t)0x00800000)            /*!< TXFIFO Empty */
#define  USART_ISR_RXFF                      ((uint32_t)0x01000000)            /*!< RXFIFO Full Flag */
#define  USART_ISR_TCBGT                     ((uint32_t)0x02000000)            /*!< Transmission complete before guard time Flag */
#define  USART_ISR_RXFT                      ((uint32_t)0x04000000)            /*!< RXFIFO threshold Flag */
#define  USART_ISR_TXFT                      ((uint32_t)0x08000000)            /*!< TXFIFO threshold Flag */

/*******************  Bit definition for USART_ICR register  ******************/
#define  USART_ICR_PECF                      ((uint32_t)0x00000001)            /*!< Parity Error Clear Flag */
#define  USART_ICR_FECF                      ((uint32_t)0x00000002)            /*!< Framing Error Clear Flag */
#define  USART_ICR_NCF                       ((uint32_t)0x00000004)            /*!< Noise detected Clear Flag */
#define  USART_ICR_ORECF                     ((uint32_t)0x00000008)            /*!< OverRun Error Clear Flag */
#define  USART_ICR_IDLECF                    ((uint32_t)0x00000010)            /*!< IDLE line detected Clear Flag */
#define  USART_ICR_TXFECF                    ((uint32_t)0x00000020)            /*!< TXFIFO empty clear flag */
#define  USART_ICR_TCCF                      ((uint32_t)0x00000040)            /*!< Transmission Complete Clear Flag */
#define  USART_ICR_TCBGT                     ((uint32_t)0x00000080)            /*!< Transmission complete before guard time Clear Flag */
#define  USART_ICR_LBDCF                     ((uint32_t)0x00000100)            /*!< LIN Break Detection Clear Flag */
#define  USART_ICR_CTSCF                     ((uint32_t)0x00000200)            /*!< CTS Interrupt Clear Flag */
#define  USART_ICR_RTOCF                     ((uint32_t)0x00000800)            /*!< Receiver Time Out Clear Flag */
#define  USART_ICR_EOBCF                     ((uint32_t)0x00001000)            /*!< End Of Block Clear Flag */
#define  USART_ICR_UDRCF                     ((uint32_t)0x00002000)            /*!< SPI slave underrun clear flag */
#define  USART_ICR_CMCF                      ((uint32_t)0x00020000)            /*!< Character Match Clear Flag */
#define  USART_ICR_WUCF                      ((uint32_t)0x00100000)            /*!< Wake Up from stop mode Clear Flag */

/*******************  Bit definition for USART_RDR register  ******************/
#define  USART_RDR_RDR                       ((uint32_t)0x000001FF)                /*!< RDR[8:0] bits (Receive Data value) */

/*******************  Bit definition for USART_TDR register  ******************/
#define  USART_TDR_TDR                       ((uint32_t)0x000001FF)                /*!< TDR[8:0] bits (Transmit Data value) */

/*******************  Bit definition for USART_PRESC register  ******************/
#define  USART_PRESC_PRESCALER              ((uint32_t)0x0000000F)                /*!< PRESCALER[3:0] bits (Clock prescaler) */

/******************************************************************************/
/*                                                                            */
/*           Single Wire Protocol Master Interface (SWPMI)                    */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for SWPMI_CR register   ********************/
#define  SWPMI_CR_RXDMA                      ((uint16_t)0x0001)            /*!<Reception DMA enable                                 */
#define  SWPMI_CR_TXDMA                      ((uint16_t)0x0002)            /*!<Transmission DMA enable                              */
#define  SWPMI_CR_RXMODE                     ((uint16_t)0x0004)            /*!<Reception buffering mode                             */
#define  SWPMI_CR_TXMODE                     ((uint16_t)0x0008)            /*!<Transmission buffering mode                          */
#define  SWPMI_CR_LPBK                       ((uint16_t)0x0010)            /*!<Loopback mode enable                                 */
#define  SWPMI_CR_SWPACT                     ((uint16_t)0x0020)            /*!<Single wire protocol master interface activate       */
#define  SWPMI_CR_DEACT                      ((uint16_t)0x0400)            /*!<Single wire protocol master interface deactivate     */
#define  SWPMI_CR_SWPEN                      ((uint16_t)0x0800)            /*!<Single wire protocol master transceiver enable       */

/*******************  Bit definition for SWPMI_BRR register  ********************/
#define  SWPMI_BRR_BR                        ((uint16_t)0x003F)            /*!<BR[5:0] bits (Bitrate prescaler) */

/*******************  Bit definition for SWPMI_ISR register  ********************/
#define  SWPMI_ISR_RXBFF                     ((uint16_t)0x0001)            /*!<Receive buffer full flag        */
#define  SWPMI_ISR_TXBEF                     ((uint16_t)0x0002)            /*!<Transmit buffer empty flag      */
#define  SWPMI_ISR_RXBERF                    ((uint16_t)0x0004)            /*!<Receive CRC error flag          */
#define  SWPMI_ISR_RXOVRF                    ((uint16_t)0x0008)            /*!<Receive overrun error flag      */
#define  SWPMI_ISR_TXUNRF                    ((uint16_t)0x0010)            /*!<Transmit underrun error flag    */
#define  SWPMI_ISR_RXNE                      ((uint16_t)0x0020)            /*!<Receive data register not empty */
#define  SWPMI_ISR_TXE                       ((uint16_t)0x0040)            /*!<Transmit data register empty    */
#define  SWPMI_ISR_TCF                       ((uint16_t)0x0080)            /*!<Transfer complete flag          */
#define  SWPMI_ISR_SRF                       ((uint16_t)0x0100)            /*!<Slave resume flag               */
#define  SWPMI_ISR_SUSP                      ((uint16_t)0x0200)            /*!<SUSPEND flag                    */
#define  SWPMI_ISR_DEACTF                    ((uint16_t)0x0400)            /*!<DEACTIVATED flag                */
#define  SWPMI_ISR_RDYF                      ((uint16_t)0x0800)            /*!<Transceiver ready flag          */

/*******************  Bit definition for SWPMI_ICR register  ********************/
#define  SWPMI_ICR_CRXBFF                    ((uint16_t)0x0001)            /*!<Clear receive buffer full flag       */
#define  SWPMI_ICR_CTXBEF                    ((uint16_t)0x0002)            /*!<Clear transmit buffer empty flag     */
#define  SWPMI_ICR_CRXBERF                   ((uint16_t)0x0004)            /*!<Clear receive CRC error flag         */
#define  SWPMI_ICR_CRXOVRF                   ((uint16_t)0x0008)            /*!<Clear receive overrun error flag     */
#define  SWPMI_ICR_CTXUNRF                   ((uint16_t)0x0010)            /*!<Clear transmit underrun error flag   */
#define  SWPMI_ICR_CTCF                      ((uint16_t)0x0080)            /*!<Clear transfer complete flag         */
#define  SWPMI_ICR_CSRF                      ((uint16_t)0x0100)            /*!<Clear slave resume flag              */
#define  SWPMI_ICR_CRDYF                     ((uint16_t)0x0800)            /*!<Clear transceiver ready flag         */

/*******************  Bit definition for SWPMI_IER register  ********************/
#define  SWPMI_IER_RXBFIE                  ((uint16_t)0x0001)            /*!<Receive buffer full interrupt enable        */
#define  SWPMI_IER_TXBEIE                  ((uint16_t)0x0002)            /*!<Transmit buffer empty interrupt enable      */
#define  SWPMI_IER_RXBERIE                 ((uint16_t)0x0004)            /*!<Receive CRC error interrupt enable          */
#define  SWPMI_IER_RXOVRIE                 ((uint16_t)0x0008)            /*!<Receive overrun error interrupt enable      */
#define  SWPMI_IER_TXUNRIE                 ((uint16_t)0x0010)            /*!<Transmit underrun error interrupt enable    */
#define  SWPMI_IER_RIE                     ((uint16_t)0x0020)            /*!<Receive interrupt enable                    */
#define  SWPMI_IER_TIE                     ((uint16_t)0x0040)            /*!<Transmit interrupt enable                   */
#define  SWPMI_IER_TCIE                    ((uint16_t)0x0080)            /*!<Transmit complete interrupt enable          */
#define  SWPMI_IER_SRIE                    ((uint16_t)0x0100)            /*!<Slave resume interrupt enable               */
#define  SWPMI_IER_RDYIE                   ((uint16_t)0x0800)            /*!<Transceiver ready interrupt enable          */

/*******************  Bit definition for SWPMI_RFL register  ********************/
#define  SWPMI_RFL_RFL                     ((uint16_t)0x001F)            /*!<RFL[4:0] bits (Receive Frame length) */
#define  SWPMI_RFL_RFL_0_1                 ((uint16_t)0x0003)            /*!<RFL[1:0] bits (number of relevant bytes for the last SWPMI_RDR register read.) */

/*******************  Bit definition for SWPMI_TDR register  ********************/
#define  SWPMI_TDR_TD                      ((uint32_t)0xFFFFFFFF)        /*!<Transmit Data Register         */

/*******************  Bit definition for SWPMI_RDR register  ********************/
#define  SWPMI_RDR_RD                      ((uint32_t)0xFFFFFFFF)        /*!<Recive Data Register           */


/*******************  Bit definition for SWPMI_OR register  ********************/
#define  SWPMI_OR_TBYP                     ((uint16_t)0x0001)             /*!<SWP Transceiver Bypass */
#define  SWPMI_OR_CLASS                    ((uint16_t)0x0002)             /*!<SWP CLASS selection */

/******************************************************************************/
/*                                                                            */
/*                            Window WATCHDOG                                 */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for WWDG_CR register  ********************/
#define  WWDG_CR_T                           ((uint8_t)0x7F)               /*!<T[6:0] bits (7-Bit counter (MSB to LSB)) */
#define  WWDG_CR_T0                          ((uint8_t)0x01)               /*!<Bit 0 */
#define  WWDG_CR_T1                          ((uint8_t)0x02)               /*!<Bit 1 */
#define  WWDG_CR_T2                          ((uint8_t)0x04)               /*!<Bit 2 */
#define  WWDG_CR_T3                          ((uint8_t)0x08)               /*!<Bit 3 */
#define  WWDG_CR_T4                          ((uint8_t)0x10)               /*!<Bit 4 */
#define  WWDG_CR_T5                          ((uint8_t)0x20)               /*!<Bit 5 */
#define  WWDG_CR_T6                          ((uint8_t)0x40)               /*!<Bit 6 */

#define  WWDG_CR_WDGA                        ((uint8_t)0x80)               /*!<Activation bit */

/*******************  Bit definition for WWDG_CFR register  *******************/
#define  WWDG_CFR_W                          ((uint16_t)0x007F)            /*!<W[6:0] bits (7-bit window value) */
#define  WWDG_CFR_W0                         ((uint16_t)0x0001)            /*!<Bit 0 */
#define  WWDG_CFR_W1                         ((uint16_t)0x0002)            /*!<Bit 1 */
#define  WWDG_CFR_W2                         ((uint16_t)0x0004)            /*!<Bit 2 */
#define  WWDG_CFR_W3                         ((uint16_t)0x0008)            /*!<Bit 3 */
#define  WWDG_CFR_W4                         ((uint16_t)0x0010)            /*!<Bit 4 */
#define  WWDG_CFR_W5                         ((uint16_t)0x0020)            /*!<Bit 5 */
#define  WWDG_CFR_W6                         ((uint16_t)0x0040)            /*!<Bit 6 */

#define  WWDG_CFR_EWI                        ((uint16_t)0x0200)            /*!<Early Wakeup Interrupt */

#define  WWDG_CFR_WDGTB                      ((uint16_t)0x3800)            /*!<WDGTB[1:0] bits (Timer Base) */
#define  WWDG_CFR_WDGTB0                     ((uint16_t)0x0800)            /*!<Bit 0 */
#define  WWDG_CFR_WDGTB1                     ((uint16_t)0x1000)            /*!<Bit 1 */
#define  WWDG_CFR_WDGTB2                     ((uint16_t)0x2000)

/*******************  Bit definition for WWDG_SR register  ********************/
#define  WWDG_SR_EWIF                        ((uint8_t)0x01)               /*!<Early Wakeup Interrupt Flag */


/******************************************************************************/
/*                                                                            */
/*                                DBG                                         */
/*                                                                            */
/******************************************************************************/

/********************  Bit definition for DBGMCU_IDCODE register  *************/
#define  DBGMCU_IDCODE_DEV_ID                ((uint32_t)0x00000FFF)
#define  DBGMCU_IDCODE_REV_ID                ((uint32_t)0xFFFF0000)

/********************  Bit definition for DBGMCU_CR register  *****************/
#define  DBGMCU_CR_DBG_SLEEPD1                 ((uint32_t)0x00000001)
#define  DBGMCU_CR_DBG_STOPD1                  ((uint32_t)0x00000002)
#define  DBGMCU_CR_DBG_STANDBYD1               ((uint32_t)0x00000004)
#define  DBGMCU_CR_DBG_SLEEPD2                 ((uint32_t)0x00000008)
#define  DBGMCU_CR_DBG_STOPD2                  ((uint32_t)0x00000010)
#define  DBGMCU_CR_DBG_STANDBYD2               ((uint32_t)0x00000020)
#define  DBGMCU_CR_DBG_STOPD3                  ((uint32_t)0x00000080)
#define  DBGMCU_CR_DBG_STANDBYD3               ((uint32_t)0x00000100)
#define  DBGMCU_CR_DBG_TRACECKEN               ((uint32_t)0x00100000)
#define  DBGMCU_CR_DBG_CKD1EN                  ((uint32_t)0x00200000)
#define  DBGMCU_CR_DBG_CKD3EN                  ((uint32_t)0x00400000)


/********************  Bit definition for D1AHB1FZ1 register  ************/
#define  DBGMCU_D1AHB1FZ1_DBG_MDMA            ((uint32_t)0x00000001)
#define  DBGMCU_D1AHB1FZ1_DBG_DMA2D           ((uint32_t)0x00000010)
/********************  Bit definition for D1AHB1FZ2 register  ************/
#define  DBGMCU_D1AHB1FZ2_DBG_MDMA            ((uint32_t)0x00000001)
#define  DBGMCU_D1AHB1FZ2_DBG_DMA2D           ((uint32_t)0x00000010)
/********************  Bit definition for D2AHB1FZ1 register  ************/
#define  DBGMCU_D2AHB1FZ1_DBG_GPDMA1          ((uint32_t)0x00000001)
#define  DBGMCU_D2AHB1FZ1_DBG_GPDMA2          ((uint32_t)0x00000002)
/********************  Bit definition for D2AHB1FZ2 register  ************/
#define  DBGMCU_D2AHB1FZ2_DBG_GPDMA1          ((uint32_t)0x00000001)
#define  DBGMCU_D2AHB1FZ2_DBG_GPDMA2          ((uint32_t)0x00000002)
/********************  Bit definition for D3AHB1FZ1 register  ************/
#define  DBGMCU_D3AHB1FZ1_DBG_BDMA            ((uint32_t)0x00200000)
/********************  Bit definition for D3AHB1FZ2 register  ************/
#define  DBGMCU_D3AHB1FZ2_DBG_BDMA            ((uint32_t)0x00200000)
/********************  Bit definition for D1APB1FZ1 register  ************/
#define  DBGMCU_D1APB1FZ1_DBG_WWDG1          ((uint32_t)0x00000040)
/********************  Bit definition for D1APB1FZ2 register  ************/
#define  DBGMCU_D1APB1FZ2_DBG_WWDG1          ((uint32_t)0x00000040)
/********************  Bit definition for D2APB1LFZ1 register  ************/
#define  DBGMCU_D2APB1LFZ1_DBG_TIM2          ((uint32_t)0x00000001)
#define  DBGMCU_D2APB1LFZ1_DBG_TIM3          ((uint32_t)0x00000002)
#define  DBGMCU_D2APB1LFZ1_DBG_TIM4          ((uint32_t)0x00000004)
#define  DBGMCU_D2APB1LFZ1_DBG_TIM5          ((uint32_t)0x00000008)
#define  DBGMCU_D2APB1LFZ1_DBG_TIM6          ((uint32_t)0x00000010)
#define  DBGMCU_D2APB1LFZ1_DBG_TIM7          ((uint32_t)0x00000020)
#define  DBGMCU_D2APB1LFZ1_DBG_TIM12         ((uint32_t)0x00000040)
#define  DBGMCU_D2APB1LFZ1_DBG_TIM13         ((uint32_t)0x00000080)
#define  DBGMCU_D2APB1LFZ1_DBG_TIM14         ((uint32_t)0x00000100)
#define  DBGMCU_D2APB1LFZ1_DBG_LPTIM1        ((uint32_t)0x00000200)


#define  DBGMCU_D2APB1LFZ1_DBG_I2C1          ((uint32_t)0x00200000)
#define  DBGMCU_D2APB1LFZ1_DBG_I2C2          ((uint32_t)0x00400000)
#define  DBGMCU_D2APB1LFZ1_DBG_I2C3          ((uint32_t)0x00800000)

/********************  Bit definition for D2APB1LFZ2 register  ************/
#define  DBGMCU_D2APB1LFZ2_DBG_TIM2          ((uint32_t)0x00000001)
#define  DBGMCU_D2APB1LFZ2_DBG_TIM3          ((uint32_t)0x00000002)
#define  DBGMCU_D2APB1LFZ2_DBG_TIM4          ((uint32_t)0x00000004)
#define  DBGMCU_D2APB1LFZ2_DBG_TIM5          ((uint32_t)0x00000008)
#define  DBGMCU_D2APB1LFZ2_DBG_TIM6          ((uint32_t)0x00000010)
#define  DBGMCU_D2APB1LFZ2_DBG_TIM7          ((uint32_t)0x00000020)
#define  DBGMCU_D2APB1LFZ2_DBG_TIM12         ((uint32_t)0x00000040)
#define  DBGMCU_D2APB1LFZ2_DBG_TIM13         ((uint32_t)0x00000080)
#define  DBGMCU_D2APB1LFZ2_DBG_TIM14         ((uint32_t)0x00000100)
#define  DBGMCU_D2APB1LFZ2_DBG_LPTIM1        ((uint32_t)0x00000200)


#define  DBGMCU_D2APB1LFZ2_DBG_I2C1          ((uint32_t)0x00200000)
#define  DBGMCU_D2APB1LFZ2_DBG_I2C2          ((uint32_t)0x00400000)
#define  DBGMCU_D2APB1LFZ2_DBG_I2C3          ((uint32_t)0x00800000)

/********************  Bit definition for D2APB1HFZ1 register  ************/
#define  DBGMCU_D2APB1HFZ1_DBG_FDCAN          ((uint32_t)0x00000100)
/********************  Bit definition for D2APB1HFZ2 register  ************/
#define  DBGMCU_D2APB1HFZ2_DBG_FDCAN          ((uint32_t)0x00000100)

/********************  Bit definition for D2APB2FZ1 register  ************/
#define  DBGMCU_D2APB2FZ1_DBG_TIM1             ((uint32_t)0x00000001)
#define  DBGMCU_D2APB2FZ1_DBG_TIM8             ((uint32_t)0x00000002)
#define  DBGMCU_D2APB2FZ1_DBG_TIM15            ((uint32_t)0x00010000)
#define  DBGMCU_D2APB2FZ1_DBG_TIM16            ((uint32_t)0x00020000)
#define  DBGMCU_D2APB2FZ1_DBG_TIM17            ((uint32_t)0x00040000)
#define  DBGMCU_D2APB2FZ1_DBG_HRTIM            ((uint32_t)0x20000000)
/********************  Bit definition for D2APB2FZ2 register  ************/
#define  DBGMCU_D2APB2FZ2_DBG_TIM1             ((uint32_t)0x00000001)
#define  DBGMCU_D2APB2FZ2_DBG_TIM8             ((uint32_t)0x00000002)
#define  DBGMCU_D2APB2FZ2_DBG_TIM15            ((uint32_t)0x00010000)
#define  DBGMCU_D2APB2FZ2_DBG_TIM16            ((uint32_t)0x00020000)
#define  DBGMCU_D2APB2FZ2_DBG_TIM17            ((uint32_t)0x00040000)
#define  DBGMCU_D2APB2FZ2_DBG_HRTIM            ((uint32_t)0x20000000)

/********************  Bit definition for D3APB1FZ1 register  ************/
#define  DBGMCU_D3APB1FZ1_DBG_I2C4             ((uint32_t)0x00000080)
#define  DBGMCU_D3APB1FZ1_DBG_LPTIM2           ((uint32_t)0x00000200)
#define  DBGMCU_D3APB1FZ1_DBG_LPTIM3           ((uint32_t)0x00000400)
#define  DBGMCU_D3APB1FZ1_DBG_LPTIM4           ((uint32_t)0x00000800)
#define  DBGMCU_D3APB1FZ1_DBG_LPTIM5           ((uint32_t)0x00001000)
#define  DBGMCU_D3APB1FZ1_DBG_RTC              ((uint32_t)0x00010000)
#define  DBGMCU_D3APB1FZ1_DBG_IWDG1            ((uint32_t)0x00040000)


/********************  Bit definition for D3APB1FZ2 register  ************/
#define  DBGMCU_D3APB1FZ2_DBG_I2C4             ((uint32_t)0x00000080)
#define  DBGMCU_D3APB1FZ2_DBG_LPTIM2           ((uint32_t)0x00000200)
#define  DBGMCU_D3APB1FZ2_DBG_LPTIM3           ((uint32_t)0x00000400)
#define  DBGMCU_D3APB1FZ2_DBG_LPTIM4           ((uint32_t)0x00000800)
#define  DBGMCU_D3APB1FZ2_DBG_LPTIM5           ((uint32_t)0x00001000)
#define  DBGMCU_D3APB1FZ2_DBG_RTC              ((uint32_t)0x00010000)
#define  DBGMCU_D3APB1FZ2_DBG_IWDG1            ((uint32_t)0x00040000)

/******************************************************************************/
/*                                                                            */
/*                        High Resolution Timer (HRTIM)                       */
/*                                                                            */
/******************************************************************************/
/******************** Master Timer control register ***************************/
#define HRTIM_MCR_CK_PSC     ((uint32_t)0x00000007)   /*!< Prescaler mask */
#define HRTIM_MCR_CK_PSC_0   ((uint32_t)0x00000001)   /*!< Prescaler bit 0 */ 
#define HRTIM_MCR_CK_PSC_1   ((uint32_t)0x00000002)   /*!< Prescaler bit 1 */ 
#define HRTIM_MCR_CK_PSC_2   ((uint32_t)0x00000004)   /*!< Prescaler bit 2 */ 

#define HRTIM_MCR_CONT       ((uint32_t)0x00000008)   /*!< Continuous mode */
#define HRTIM_MCR_RETRIG     ((uint32_t)0x00000010)   /*!< Rettrigreable mode */
#define HRTIM_MCR_HALF       ((uint32_t)0x00000020)   /*!< Half mode */

#define HRTIM_MCR_SYNC_IN    ((uint32_t)0x00000300)   /*!< Synchronization input master */
#define HRTIM_MCR_SYNC_IN_0  ((uint32_t)0x00000100)   /*!< Synchronization input bit 0 */
#define HRTIM_MCR_SYNC_IN_1  ((uint32_t)0x00000200)   /*!< Synchronization input bit 1 */
#define HRTIM_MCR_SYNCRSTM   ((uint32_t)0x00000400)   /*!< Synchronization reset master */
#define HRTIM_MCR_SYNCSTRTM  ((uint32_t)0x00000800)   /*!< Synchronization start master */
#define HRTIM_MCR_SYNC_OUT   ((uint32_t)0x00003000)   /*!< Synchronization output master */
#define HRTIM_MCR_SYNC_OUT_0 ((uint32_t)0x00001000)   /*!< Synchronization output bit 0 */
#define HRTIM_MCR_SYNC_OUT_1 ((uint32_t)0x00002000)   /*!< Synchronization output bit 1 */
#define HRTIM_MCR_SYNC_SRC   ((uint32_t)0x0000C000)   /*!< Synchronization source */
#define HRTIM_MCR_SYNC_SRC_0 ((uint32_t)0x00004000)   /*!< Synchronization source bit 0 */
#define HRTIM_MCR_SYNC_SRC_1 ((uint32_t)0x00008000)   /*!< Synchronization source bit 1 */

#define HRTIM_MCR_MCEN       ((uint32_t)0x00010000)   /*!< Master counter enable */
#define HRTIM_MCR_TACEN      ((uint32_t)0x00020000)   /*!< Timer A counter enable */
#define HRTIM_MCR_TBCEN      ((uint32_t)0x00040000)   /*!< Timer B counter enable */
#define HRTIM_MCR_TCCEN      ((uint32_t)0x00080000)   /*!< Timer C counter enable */
#define HRTIM_MCR_TDCEN      ((uint32_t)0x00100000)   /*!< Timer D counter enable */
#define HRTIM_MCR_TECEN      ((uint32_t)0x00200000)   /*!< Timer E counter enable */

#define HRTIM_MCR_DACSYNC    ((uint32_t)0x06000000)   /*!< DAC sychronization mask */
#define HRTIM_MCR_DACSYNC_0  ((uint32_t)0x02000000)   /*!< DAC sychronization bit 0 */
#define HRTIM_MCR_DACSYNC_1  ((uint32_t)0x04000000)   /*!< DAC sychronization bit 1 */

#define HRTIM_MCR_PREEN      ((uint32_t)0x08000000)   /*!< Master preload enable */
#define HRTIM_MCR_MREPU      ((uint32_t)0x20000000)   /*!< Master repetition update */

#define HRTIM_MCR_BRSTDMA    ((uint32_t)0xC0000000)   /*!< Burst DMA update */
#define HRTIM_MCR_BRSTDMA_0  ((uint32_t)0x40000000)   /*!< Burst DMA update bit 0*/
#define HRTIM_MCR_BRSTDMA_1  ((uint32_t)0x80000000)   /*!< Burst DMA update bit 1 */

/******************** Master Timer Interrupt status register ******************/
#define HRTIM_MISR_MCMP1    ((uint32_t)0x00000001)  /*!< Master compare 1 interrupt flag */
#define HRTIM_MISR_MCMP2    ((uint32_t)0x00000002)  /*!< Master compare 2 interrupt flag */
#define HRTIM_MISR_MCMP3    ((uint32_t)0x00000004)  /*!< Master compare 3 interrupt flag */
#define HRTIM_MISR_MCMP4    ((uint32_t)0x00000008)  /*!< Master compare 4 interrupt flag */
#define HRTIM_MISR_MREP     ((uint32_t)0x00000010)  /*!< Master Repetition interrupt flag */
#define HRTIM_MISR_SYNC     ((uint32_t)0x00000020)  /*!< Synchronization input interrupt flag */
#define HRTIM_MISR_MUPD     ((uint32_t)0x00000040)  /*!< Master update interrupt flag */

/******************** Master Timer Interrupt clear register *******************/
#define HRTIM_MICR_MCMP1    ((uint32_t)0x00000001)  /*!< Master compare 1 interrupt flag clear */
#define HRTIM_MICR_MCMP2    ((uint32_t)0x00000002)  /*!< Master compare 2 interrupt flag clear */
#define HRTIM_MICR_MCMP3    ((uint32_t)0x00000004)  /*!< Master compare 3 interrupt flag clear */
#define HRTIM_MICR_MCMP4    ((uint32_t)0x00000008)  /*!< Master compare 4 interrupt flag clear */
#define HRTIM_MICR_MREP     ((uint32_t)0x00000010)  /*!< Master Repetition interrupt flag clear */
#define HRTIM_MICR_SYNC     ((uint32_t)0x00000020)  /*!< Synchronization input interrupt flag clear */
#define HRTIM_MICR_MUPD     ((uint32_t)0x00000040)  /*!< Master update interrupt flag clear */

/******************** Master Timer DMA/Interrupt enable register **************/
#define HRTIM_MDIER_MCMP1IE    ((uint32_t)0x00000001)  /*!< Master compare 1 interrupt enable */
#define HRTIM_MDIER_MCMP2IE    ((uint32_t)0x00000002)  /*!< Master compare 2 interrupt enable */
#define HRTIM_MDIER_MCMP3IE    ((uint32_t)0x00000004)  /*!< Master compare 3 interrupt enable */
#define HRTIM_MDIER_MCMP4IE    ((uint32_t)0x00000008)  /*!< Master compare 4 interrupt enable */
#define HRTIM_MDIER_MREPIE     ((uint32_t)0x00000010)  /*!< Master Repetition interrupt enable */
#define HRTIM_MDIER_SYNCIE     ((uint32_t)0x00000020)  /*!< Synchronization input interrupt enable */
#define HRTIM_MDIER_MUPDIE     ((uint32_t)0x00000040)  /*!< Master update interrupt enable */

#define HRTIM_MDIER_MCMP1DE    ((uint32_t)0x00010000)  /*!< Master compare 1 DMA enable */
#define HRTIM_MDIER_MCMP2DE    ((uint32_t)0x00020000)  /*!< Master compare 2 DMA enable */
#define HRTIM_MDIER_MCMP3DE    ((uint32_t)0x00040000)  /*!< Master compare 3 DMA enable */
#define HRTIM_MDIER_MCMP4DE    ((uint32_t)0x00080000)  /*!< Master compare 4 DMA enable */
#define HRTIM_MDIER_MREPDE     ((uint32_t)0x00100000)  /*!< Master Repetition DMA enable */
#define HRTIM_MDIER_SYNCDE     ((uint32_t)0x00200000)  /*!< Synchronization input DMA enable */
#define HRTIM_MDIER_MUPDDE     ((uint32_t)0x00400000)  /*!< Master update DMA enable */

/*******************  Bit definition for HRTIM_MCNTR register  ****************/
#define  HRTIM_MCNTR_MCNTR     ((uint32_t)0xFFFFFFFF)       /*!<Counter Value */

/*******************  Bit definition for HRTIM_MPER register  *****************/
#define  HRTIM_MPER_MPER      ((uint32_t)0xFFFFFFFF)        /*!< Period Value */

/*******************  Bit definition for HRTIM_MREP register  *****************/
#define  HRTIM_MREP_MREP     ((uint32_t)0xFFFFFFFF)        /*!<Repetition Value */

/*******************  Bit definition for HRTIM_MCMP1R register  *****************/
#define  HRTIM_MCMP1R_MCMP1R     ((uint32_t)0xFFFFFFFF)     /*!<Compare Value */

/*******************  Bit definition for HRTIM_MCMP2R register  *****************/
#define  HRTIM_MCMP1R_MCMP2R     ((uint32_t)0xFFFFFFFF)     /*!<Compare Value */

/*******************  Bit definition for HRTIM_MCMP3R register  *****************/
#define  HRTIM_MCMP1R_MCMP3R     ((uint32_t)0xFFFFFFFF)     /*!<Compare Value */

/*******************  Bit definition for HRTIM_MCMP4R register  *****************/
#define  HRTIM_MCMP1R_MCMP4R     ((uint32_t)0xFFFFFFFF)     /*!<Compare Value */

/******************** Slave control register **********************************/
#define HRTIM_TIMCR_CK_PSC      ((uint32_t)0x00000007) /*!< Slave prescaler mask*/
#define HRTIM_TIMCR_CK_PSC_0    ((uint32_t)0x00000001) /*!< prescaler bit 0 */
#define HRTIM_TIMCR_CK_PSC_1    ((uint32_t)0x00000002) /*!< prescaler bit 1 */
#define HRTIM_TIMCR_CK_PSC_2    ((uint32_t)0x00000004) /*!< prescaler bit 2 */

#define HRTIM_TIMCR_CONT        ((uint32_t)0x00000008) /*!< Slave continuous mode */
#define HRTIM_TIMCR_RETRIG      ((uint32_t)0x00000010) /*!< Slave Retrigreable mode */
#define HRTIM_TIMCR_HALF        ((uint32_t)0x00000020) /*!< Slave Half mode */
#define HRTIM_TIMCR_PSHPLL      ((uint32_t)0x00000040) /*!< Slave push-pull mode */

#define HRTIM_TIMCR_SYNCRST     ((uint32_t)0x00000400) /*!< Slave synchronization resets */
#define HRTIM_TIMCR_SYNCSTRT    ((uint32_t)0x00000800) /*!< Slave synchronization starts */

#define HRTIM_TIMCR_DELCMP2     ((uint32_t)0x00003000) /*!< Slave delayed compartor 2 mode mask */
#define HRTIM_TIMCR_DELCMP2_0   ((uint32_t)0x00001000) /*!< Slave delayed compartor 2 bit 0 */
#define HRTIM_TIMCR_DELCMP2_1   ((uint32_t)0x00002000) /*!< Slave delayed compartor 2 bit 1 */
#define HRTIM_TIMCR_DELCMP4     ((uint32_t)0x0000C000) /*!< Slave delayed compartor 4 mode mask */
#define HRTIM_TIMCR_DELCMP4_0   ((uint32_t)0x00004000) /*!< Slave delayed compartor 4 bit 0 */
#define HRTIM_TIMCR_DELCMP4_1   ((uint32_t)0x00008000) /*!< Slave delayed compartor 4 bit 1 */

#define HRTIM_TIMCR_TREPU       ((uint32_t)0x00020000) /*!< Slave repetition update */
#define HRTIM_TIMCR_TRSTU       ((uint32_t)0x00040000) /*!< Slave reset update */
#define HRTIM_TIMCR_TAU         ((uint32_t)0x00080000) /*!< Slave Timer A update reserved for TIM A */
#define HRTIM_TIMCR_TBU         ((uint32_t)0x00100000) /*!< Slave Timer B update reserved for TIM B */
#define HRTIM_TIMCR_TCU         ((uint32_t)0x00200000) /*!< Slave Timer C update reserved for TIM C */
#define HRTIM_TIMCR_TDU         ((uint32_t)0x00400000) /*!< Slave Timer D update reserved for TIM D */
#define HRTIM_TIMCR_TEU         ((uint32_t)0x00800000) /*!< Slave Timer E update reserved for TIM E */
#define HRTIM_TIMCR_MSTU        ((uint32_t)0x01000000) /*!< Master Update */

#define HRTIM_TIMCR_DACSYNC    ((uint32_t)0x06000000)   /*!< DAC sychronization mask */
#define HRTIM_TIMCR_DACSYNC_0  ((uint32_t)0x02000000)   /*!< DAC sychronization bit 0 */
#define HRTIM_TIMCR_DACSYNC_1  ((uint32_t)0x04000000)   /*!< DAC sychronization bit 1 */
#define HRTIM_TIMCR_PREEN      ((uint32_t)0x08000000)   /*!< Slave preload enable */

#define HRTIM_TIMCR_UPDGAT     ((uint32_t)0xF0000000)   /*!< Slave update gating mask */
#define HRTIM_TIMCR_UPDGAT_0   ((uint32_t)0x10000000)   /*!< Update gating bit 0 */
#define HRTIM_TIMCR_UPDGAT_1   ((uint32_t)0x20000000)   /*!< Update gating bit 1 */
#define HRTIM_TIMCR_UPDGAT_2   ((uint32_t)0x40000000)   /*!< Update gating bit 2 */
#define HRTIM_TIMCR_UPDGAT_3   ((uint32_t)0x80000000)   /*!< Update gating bit 3 */

/******************** Slave Interrupt status register **************************/
#define HRTIM_TIMISR_CMP1       ((uint32_t)0x00000001)   /*!< Slave compare 1 interrupt flag */
#define HRTIM_TIMISR_CMP2       ((uint32_t)0x00000002)   /*!< Slave compare 2 interrupt flag */
#define HRTIM_TIMISR_CMP3       ((uint32_t)0x00000004)   /*!< Slave compare 3 interrupt flag */
#define HRTIM_TIMISR_CMP4       ((uint32_t)0x00000008)   /*!< Slave compare 4 interrupt flag */
#define HRTIM_TIMISR_REP        ((uint32_t)0x00000010)   /*!< Slave repetition interrupt flag */
#define HRTIM_TIMISR_UPD        ((uint32_t)0x00000040)   /*!< Slave update interrupt flag */
#define HRTIM_TIMISR_CPT1       ((uint32_t)0x00000080)   /*!< Slave capture 1 interrupt flag */
#define HRTIM_TIMISR_CPT2       ((uint32_t)0x00000100)   /*!< Slave capture 2 interrupt flag */
#define HRTIM_TIMISR_SET1       ((uint32_t)0x00000200)   /*!< Slave output 1 set interrupt flag */
#define HRTIM_TIMISR_RST1       ((uint32_t)0x00000400)   /*!< Slave output 1 reset interrupt flag */
#define HRTIM_TIMISR_SET2       ((uint32_t)0x00000800)   /*!< Slave output 2 set interrupt flag */
#define HRTIM_TIMISR_RST2       ((uint32_t)0x00001000)   /*!< Slave output 2 reset interrupt flag */
#define HRTIM_TIMISR_RST        ((uint32_t)0x00002000)   /*!< Slave reset interrupt flag */
#define HRTIM_TIMISR_DLYPRT     ((uint32_t)0x00004000)   /*!< Slave output 1 delay protection interrupt flag */
#define HRTIM_TIMISR_CPPSTAT    ((uint32_t)0x00010000)   /*!< Slave current push-pull flag */
#define HRTIM_TIMISR_IPPSTAT    ((uint32_t)0x00020000)   /*!< Slave idle push-pull flag */
#define HRTIM_TIMISR_O1STAT     ((uint32_t)0x00040000)   /*!< Slave output 1 state flag */
#define HRTIM_TIMISR_O2STAT     ((uint32_t)0x00080000)   /*!< Slave output 2 state flag */
#define HRTIM_TIMISR_O1CPY      ((uint32_t)0x00100000)   /*!< Slave output 1 copy flag */
#define HRTIM_TIMISR_O2CPY      ((uint32_t)0x00200000)   /*!< Slave output 2 copy flag */

/******************** Slave Interrupt clear register **************************/
#define HRTIM_TIMICR_CMP1C       ((uint32_t)0x00000001)   /*!< Slave compare 1 clear flag */
#define HRTIM_TIMICR_CMP2C       ((uint32_t)0x00000002)   /*!< Slave compare 2 clear flag */
#define HRTIM_TIMICR_CMP3C       ((uint32_t)0x00000004)   /*!< Slave compare 3 clear flag */
#define HRTIM_TIMICR_CMP4C       ((uint32_t)0x00000008)   /*!< Slave compare 4 clear flag */
#define HRTIM_TIMICR_REPC        ((uint32_t)0x00000010)   /*!< Slave repetition clear flag */
#define HRTIM_TIMICR_UPDC        ((uint32_t)0x00000040)   /*!< Slave update clear flag */
#define HRTIM_TIMICR_CPT1C       ((uint32_t)0x00000080)   /*!< Slave capture 1 clear flag */
#define HRTIM_TIMICR_CPT2C       ((uint32_t)0x00000100)   /*!< Slave capture 2 clear flag */
#define HRTIM_TIMICR_SET1C       ((uint32_t)0x00000200)   /*!< Slave output 1 set clear flag */
#define HRTIM_TIMICR_RST1C       ((uint32_t)0x00000400)   /*!< Slave output 1 reset clear flag */
#define HRTIM_TIMICR_SET2C       ((uint32_t)0x00000800)   /*!< Slave output 2 set clear flag */
#define HRTIM_TIMICR_RST2C       ((uint32_t)0x00001000)   /*!< Slave output 2 reset clear flag */
#define HRTIM_TIMICR_RSTC        ((uint32_t)0x00002000)   /*!< Slave reset clear flag */
#define HRTIM_TIMICR_DLYPRT1C    ((uint32_t)0x00004000)   /*!< Slave output 1 delay protection clear flag */
#define HRTIM_TIMICR_DLYPRT2C    ((uint32_t)0x00008000)   /*!< Slave output 2 delay protection clear flag */

/******************** Slave DMA/Interrupt enable register *********************/
#define HRTIM_TIMDIER_CMP1IE       ((uint32_t)0x00000001)   /*!< Slave compare 1 interrupt enable */
#define HRTIM_TIMDIER_CMP2IE       ((uint32_t)0x00000002)   /*!< Slave compare 2 interrupt enable */
#define HRTIM_TIMDIER_CMP3IE       ((uint32_t)0x00000004)   /*!< Slave compare 3 interrupt enable */
#define HRTIM_TIMDIER_CMP4IE       ((uint32_t)0x00000008)   /*!< Slave compare 4 interrupt enable */
#define HRTIM_TIMDIER_REPIE        ((uint32_t)0x00000010)   /*!< Slave repetition interrupt enable */
#define HRTIM_TIMDIER_UPDIE        ((uint32_t)0x00000040)   /*!< Slave update interrupt enable */
#define HRTIM_TIMDIER_CPT1IE       ((uint32_t)0x00000080)   /*!< Slave capture 1 interrupt enable */
#define HRTIM_TIMDIER_CPT2IE       ((uint32_t)0x00000100)   /*!< Slave capture 2 interrupt enable */
#define HRTIM_TIMDIER_SET1IE       ((uint32_t)0x00000200)   /*!< Slave output 1 set interrupt enable */
#define HRTIM_TIMDIER_RST1IE       ((uint32_t)0x00000400)   /*!< Slave output 1 reset interrupt enable */
#define HRTIM_TIMDIER_SET2IE       ((uint32_t)0x00000800)   /*!< Slave output 2 set interrupt enable */
#define HRTIM_TIMDIER_RST2IE       ((uint32_t)0x00001000)   /*!< Slave output 2 reset interrupt enable */
#define HRTIM_TIMDIER_RSTIE        ((uint32_t)0x00002000)   /*!< Slave reset interrupt enable */
#define HRTIM_TIMDIER_DLYPRTIE     ((uint32_t)0x00004000)   /*!< Slave delay protection interrupt enable */

#define HRTIM_TIMDIER_CMP1DE       ((uint32_t)0x00010000)   /*!< Slave compare 1 request enable */
#define HRTIM_TIMDIER_CMP2DE       ((uint32_t)0x00020000)   /*!< Slave compare 2 request enable */
#define HRTIM_TIMDIER_CMP3DE       ((uint32_t)0x00040000)   /*!< Slave compare 3 request enable */
#define HRTIM_TIMDIER_CMP4DE       ((uint32_t)0x00080000)   /*!< Slave compare 4 request enable */
#define HRTIM_TIMDIER_REPDE        ((uint32_t)0x00100000)   /*!< Slave repetition request enable */
#define HRTIM_TIMDIER_UPDDE        ((uint32_t)0x00400000)   /*!< Slave update request enable */
#define HRTIM_TIMDIER_CPT1DE       ((uint32_t)0x00800000)   /*!< Slave capture 1 request enable */
#define HRTIM_TIMDIER_CPT2DE       ((uint32_t)0x01000000)   /*!< Slave capture 2 request enable */
#define HRTIM_TIMDIER_SET1DE       ((uint32_t)0x02000000)   /*!< Slave output 1 set request enable */
#define HRTIM_TIMDIER_RST1DE       ((uint32_t)0x04000000)   /*!< Slave output 1 reset request enable */
#define HRTIM_TIMDIER_SET2DE       ((uint32_t)0x08000000)   /*!< Slave output 2 set request enable */
#define HRTIM_TIMDIER_RST2DE       ((uint32_t)0x10000000)   /*!< Slave output 2 reset request enable */
#define HRTIM_TIMDIER_RSTDE        ((uint32_t)0x20000000)   /*!< Slave reset request enable */
#define HRTIM_TIMDIER_DLYPRTDE     ((uint32_t)0x40000000)   /*!< Slavedelay protection request enable */

/******************  Bit definition for HRTIM_CNTR register  ****************/
#define  HRTIM_CNTR_CNTR      ((uint32_t)0xFFFFFFFF)       /*!< Counter Value */

/*******************  Bit definition for HRTIM_PER register  *****************/
#define  HRTIM_PER_PER       ((uint32_t)0xFFFFFFFF)        /*!< Period Value */

/*******************  Bit definition for HRTIM_REP register  *****************/
#define  HRTIM_REP_REP      ((uint32_t)0xFFFFFFFF)        /*!< Repetition Value */

/*******************  Bit definition for HRTIM_CMP1R register  *****************/
#define  HRTIM_CMP1R_CMP1R     ((uint32_t)0xFFFFFFFF)     /*!< Compare Value */

/*******************  Bit definition for HRTIM_CMP1CR register  *****************/
#define  HRTIM_CMP1CR_CMP1CR     ((uint32_t)0xFFFFFFFF)     /*!< Compare Value */

/*******************  Bit definition for HRTIM_CMP2R register  *****************/
#define  HRTIM_CMP2R_CMP2R     ((uint32_t)0xFFFFFFFF)     /*!< Compare Value */

/*******************  Bit definition for HRTIM_CMP3R register  *****************/
#define  HRTIM_CMP3R_CMP3R     ((uint32_t)0xFFFFFFFF)     /*!< Compare Value */

/*******************  Bit definition for HRTIM_CMP4R register  *****************/
#define  HRTIM_CMP4R_CMP4R     ((uint32_t)0xFFFFFFFF)     /*!< Compare Value */

/*******************  Bit definition for HRTIM_CPT1R register  ****************/
#define  HRTIM_CPT1R_CPT1R     ((uint32_t)0xFFFFFFFF)     /*!< Capture Value */

/*******************  Bit definition for HRTIM_CPT2R register  ****************/
#define  HRTIM_CPT2R_CPT2R     ((uint32_t)0xFFFFFFFF)     /*!< Capture Value */

/******************** Bit definition for Slave Deadtime register **************/
#define HRTIM_DTR_DTR           ((uint32_t)0x000001FF)    /*!< Dead time rising value */
#define HRTIM_DTR_DTR_0         ((uint32_t)0x00000001)    /*!< Dead time rising bit 0 */
#define HRTIM_DTR_DTR_1         ((uint32_t)0x00000002)    /*!< Dead time rising bit 1 */
#define HRTIM_DTR_DTR_2         ((uint32_t)0x00000004)    /*!< Dead time rising bit 2 */
#define HRTIM_DTR_DTR_3         ((uint32_t)0x00000008)    /*!< Dead time rising bit 3 */
#define HRTIM_DTR_DTR_4         ((uint32_t)0x00000010)    /*!< Dead time rising bit 4 */
#define HRTIM_DTR_DTR_5         ((uint32_t)0x00000020)    /*!< Dead time rising bit 5 */
#define HRTIM_DTR_DTR_6         ((uint32_t)0x00000040)    /*!< Dead time rising bit 6 */
#define HRTIM_DTR_DTR_7         ((uint32_t)0x00000080)    /*!< Dead time rising bit 7 */
#define HRTIM_DTR_DTR_8         ((uint32_t)0x00000100)    /*!< Dead time rising bit 8 */
#define HRTIM_DTR_SDTR          ((uint32_t)0x00000200)    /*!< Sign dead time rising value */
#define HRTIM_DTR_DTPRSC        ((uint32_t)0x00001C00)    /*!< Dead time prescaler */
#define HRTIM_DTR_DTPRSC_0      ((uint32_t)0x00000400)    /*!< Dead time prescaler bit 0 */
#define HRTIM_DTR_DTPRSC_1      ((uint32_t)0x00000800)    /*!< Dead time prescaler bit 1 */
#define HRTIM_DTR_DTPRSC_2      ((uint32_t)0x00001000)    /*!< Dead time prescaler bit 2 */
#define HRTIM_DTR_DTRSLK        ((uint32_t)0x00004000)    /*!< Dead time rising sign lock */
#define HRTIM_DTR_DTRLK         ((uint32_t)0x00008000)    /*!< Dead time rising lock */
#define HRTIM_DTR_DTF           ((uint32_t)0x01FF0000)    /*!< Dead time falling value */
#define HRTIM_DTR_DTF_0         ((uint32_t)0x00010000)    /*!< Dead time falling bit 0 */
#define HRTIM_DTR_DTF_1         ((uint32_t)0x00020000)    /*!< Dead time falling bit 1 */
#define HRTIM_DTR_DTF_2         ((uint32_t)0x00040000)    /*!< Dead time falling bit 2 */
#define HRTIM_DTR_DTF_3         ((uint32_t)0x00080000)    /*!< Dead time falling bit 3 */
#define HRTIM_DTR_DTF_4         ((uint32_t)0x00100000)    /*!< Dead time falling bit 4 */
#define HRTIM_DTR_DTF_5         ((uint32_t)0x00200000)    /*!< Dead time falling bit 5 */
#define HRTIM_DTR_DTF_6         ((uint32_t)0x00400000)    /*!< Dead time falling bit 6 */
#define HRTIM_DTR_DTF_7         ((uint32_t)0x00800000)    /*!< Dead time falling bit 7 */
#define HRTIM_DTR_DTF_8         ((uint32_t)0x01000000)    /*!< Dead time falling bit 8 */
#define HRTIM_DTR_SDTF          ((uint32_t)0x02000000)    /*!< Sign dead time falling value */
#define HRTIM_DTR_DTFSLK        ((uint32_t)0x40000000)    /*!< Dead time falling sign lock */
#define HRTIM_DTR_DTFLK         ((uint32_t)0x80000000)    /*!< Dead time falling lock */

/**** Bit definition for Slave Output 1 set register **************************/
#define HRTIM_SET1R_SST         ((uint32_t)0x00000001)    /*!< software set trigger */
#define HRTIM_SET1R_RESYNC      ((uint32_t)0x00000002)    /*!< Timer A resynchronization */
#define HRTIM_SET1R_PER         ((uint32_t)0x00000004)    /*!< Timer A period */
#define HRTIM_SET1R_CMP1        ((uint32_t)0x00000008)    /*!< Timer A compare 1 */
#define HRTIM_SET1R_CMP2        ((uint32_t)0x00000010)    /*!< Timer A compare 2 */
#define HRTIM_SET1R_CMP3        ((uint32_t)0x00000020)    /*!< Timer A compare 3 */
#define HRTIM_SET1R_CMP4        ((uint32_t)0x00000040)    /*!< Timer A compare 4 */

#define HRTIM_SET1R_MSTPER      ((uint32_t)0x00000080)    /*!< Master period */
#define HRTIM_SET1R_MSTCMP1     ((uint32_t)0x00000100)    /*!< Master compare 1 */
#define HRTIM_SET1R_MSTCMP2     ((uint32_t)0x00000200)    /*!< Master compare 2 */
#define HRTIM_SET1R_MSTCMP3     ((uint32_t)0x00000400)    /*!< Master compare 3 */
#define HRTIM_SET1R_MSTCMP4     ((uint32_t)0x00000800)    /*!< Master compare 4 */

#define HRTIM_SET1R_TIMEVNT1   ((uint32_t)0x00001000)    /*!< Timer event 1 */
#define HRTIM_SET1R_TIMEVNT2   ((uint32_t)0x00002000)    /*!< Timer event 2 */
#define HRTIM_SET1R_TIMEVNT3   ((uint32_t)0x00004000)    /*!< Timer event 3 */
#define HRTIM_SET1R_TIMEVNT4   ((uint32_t)0x00008000)    /*!< Timer event 4 */
#define HRTIM_SET1R_TIMEVNT5   ((uint32_t)0x00010000)    /*!< Timer event 5 */
#define HRTIM_SET1R_TIMEVNT6   ((uint32_t)0x00020000)    /*!< Timer event 6 */
#define HRTIM_SET1R_TIMEVNT7   ((uint32_t)0x00040000)    /*!< Timer event 7 */
#define HRTIM_SET1R_TIMEVNT8   ((uint32_t)0x00080000)    /*!< Timer event 8 */
#define HRTIM_SET1R_TIMEVNT9   ((uint32_t)0x00100000)    /*!< Timer event 9 */

#define HRTIM_SET1R_EXTVNT1   ((uint32_t)0x00200000)    /*!< External event 1 */
#define HRTIM_SET1R_EXTVNT2   ((uint32_t)0x00400000)    /*!< External event 2 */
#define HRTIM_SET1R_EXTVNT3   ((uint32_t)0x00800000)    /*!< External event 3 */
#define HRTIM_SET1R_EXTVNT4   ((uint32_t)0x01000000)    /*!< External event 4 */
#define HRTIM_SET1R_EXTVNT5   ((uint32_t)0x02000000)    /*!< External event 5 */
#define HRTIM_SET1R_EXTVNT6   ((uint32_t)0x04000000)    /*!< External event 6 */
#define HRTIM_SET1R_EXTVNT7   ((uint32_t)0x08000000)    /*!< External event 7 */
#define HRTIM_SET1R_EXTVNT8   ((uint32_t)0x10000000)    /*!< External event 8 */
#define HRTIM_SET1R_EXTVNT9   ((uint32_t)0x20000000)    /*!< External event 9 */
#define HRTIM_SET1R_EXTVNT10  ((uint32_t)0x40000000)    /*!< External event 10 */

#define HRTIM_SET1R_UPDATE    ((uint32_t)0x80000000)    /*!< Register update (transfer preload to active) */

/**** Bit definition for Slave Output 1 reset register ************************/
#define HRTIM_RST1R_SRT         ((uint32_t)0x00000001)    /*!< software reset trigger */
#define HRTIM_RST1R_RESYNC      ((uint32_t)0x00000002)    /*!< Timer A resynchronization */
#define HRTIM_RST1R_PER         ((uint32_t)0x00000004)    /*!< Timer A period */
#define HRTIM_RST1R_CMP1        ((uint32_t)0x00000008)    /*!< Timer A compare 1 */
#define HRTIM_RST1R_CMP2        ((uint32_t)0x00000010)    /*!< Timer A compare 2 */
#define HRTIM_RST1R_CMP3        ((uint32_t)0x00000020)    /*!< Timer A compare 3 */
#define HRTIM_RST1R_CMP4        ((uint32_t)0x00000040)    /*!< Timer A compare 4 */

#define HRTIM_RST1R_MSTPER      ((uint32_t)0x00000080)    /*!< Master period */
#define HRTIM_RST1R_MSTCMP1     ((uint32_t)0x00000100)    /*!< Master compare 1 */
#define HRTIM_RST1R_MSTCMP2     ((uint32_t)0x00000200)    /*!< Master compare 2 */
#define HRTIM_RST1R_MSTCMP3     ((uint32_t)0x00000400)    /*!< Master compare 3 */
#define HRTIM_RST1R_MSTCMP4     ((uint32_t)0x00000800)    /*!< Master compare 4 */

#define HRTIM_RST1R_TIMEVNT1   ((uint32_t)0x00001000)    /*!< Timer event 1 */
#define HRTIM_RST1R_TIMEVNT2   ((uint32_t)0x00002000)    /*!< Timer event 2 */
#define HRTIM_RST1R_TIMEVNT3   ((uint32_t)0x00004000)    /*!< Timer event 3 */
#define HRTIM_RST1R_TIMEVNT4   ((uint32_t)0x00008000)    /*!< Timer event 4 */
#define HRTIM_RST1R_TIMEVNT5   ((uint32_t)0x00010000)    /*!< Timer event 5 */
#define HRTIM_RST1R_TIMEVNT6   ((uint32_t)0x00020000)    /*!< Timer event 6 */
#define HRTIM_RST1R_TIMEVNT7   ((uint32_t)0x00040000)    /*!< Timer event 7 */
#define HRTIM_RST1R_TIMEVNT8   ((uint32_t)0x00080000)    /*!< Timer event 8 */
#define HRTIM_RST1R_TIMEVNT9   ((uint32_t)0x00100000)    /*!< Timer event 9 */

#define HRTIM_RST1R_EXTVNT1   ((uint32_t)0x00200000)    /*!< External event 1 */
#define HRTIM_RST1R_EXTVNT2   ((uint32_t)0x00400000)    /*!< External event 2 */
#define HRTIM_RST1R_EXTVNT3   ((uint32_t)0x00800000)    /*!< External event 3 */
#define HRTIM_RST1R_EXTVNT4   ((uint32_t)0x01000000)    /*!< External event 4 */
#define HRTIM_RST1R_EXTVNT5   ((uint32_t)0x02000000)    /*!< External event 5 */
#define HRTIM_RST1R_EXTVNT6   ((uint32_t)0x04000000)    /*!< External event 6 */
#define HRTIM_RST1R_EXTVNT7   ((uint32_t)0x08000000)    /*!< External event 7 */
#define HRTIM_RST1R_EXTVNT8   ((uint32_t)0x10000000)    /*!< External event 8 */
#define HRTIM_RST1R_EXTVNT9   ((uint32_t)0x20000000)    /*!< External event 9 */
#define HRTIM_RST1R_EXTVNT10  ((uint32_t)0x40000000)    /*!< External event 10 */

#define HRTIM_RST1R_UPDATE    ((uint32_t)0x80000000)    /*!< Register update (transfer preload to active) */


/**** Bit definition for Slave Output 2 set register **************************/
#define HRTIM_SET2R_SST         ((uint32_t)0x00000001)    /*!< software set trigger */
#define HRTIM_SET2R_RESYNC      ((uint32_t)0x00000002)    /*!< Timer A resynchronization */
#define HRTIM_SET2R_PER         ((uint32_t)0x00000004)    /*!< Timer A period */
#define HRTIM_SET2R_CMP1        ((uint32_t)0x00000008)    /*!< Timer A compare 1 */
#define HRTIM_SET2R_CMP2        ((uint32_t)0x00000010)    /*!< Timer A compare 2 */
#define HRTIM_SET2R_CMP3        ((uint32_t)0x00000020)    /*!< Timer A compare 3 */
#define HRTIM_SET2R_CMP4        ((uint32_t)0x00000040)    /*!< Timer A compare 4 */

#define HRTIM_SET2R_MSTPER      ((uint32_t)0x00000080)    /*!< Master period */
#define HRTIM_SET2R_MSTCMP1     ((uint32_t)0x00000100)    /*!< Master compare 1 */
#define HRTIM_SET2R_MSTCMP2     ((uint32_t)0x00000200)    /*!< Master compare 2 */
#define HRTIM_SET2R_MSTCMP3     ((uint32_t)0x00000400)    /*!< Master compare 3 */
#define HRTIM_SET2R_MSTCMP4     ((uint32_t)0x00000800)    /*!< Master compare 4 */

#define HRTIM_SET2R_TIMEVNT1   ((uint32_t)0x00001000)    /*!< Timer event 1 */
#define HRTIM_SET2R_TIMEVNT2   ((uint32_t)0x00002000)    /*!< Timer event 2 */
#define HRTIM_SET2R_TIMEVNT3   ((uint32_t)0x00004000)    /*!< Timer event 3 */
#define HRTIM_SET2R_TIMEVNT4   ((uint32_t)0x00008000)    /*!< Timer event 4 */
#define HRTIM_SET2R_TIMEVNT5   ((uint32_t)0x00010000)    /*!< Timer event 5 */
#define HRTIM_SET2R_TIMEVNT6   ((uint32_t)0x00020000)    /*!< Timer event 6 */
#define HRTIM_SET2R_TIMEVNT7   ((uint32_t)0x00040000)    /*!< Timer event 7 */
#define HRTIM_SET2R_TIMEVNT8   ((uint32_t)0x00080000)    /*!< Timer event 8 */
#define HRTIM_SET2R_TIMEVNT9   ((uint32_t)0x00100000)    /*!< Timer event 9 */

#define HRTIM_SET2R_EXTVNT1   ((uint32_t)0x00200000)    /*!< External event 1 */
#define HRTIM_SET2R_EXTVNT2   ((uint32_t)0x00400000)    /*!< External event 2 */
#define HRTIM_SET2R_EXTVNT3   ((uint32_t)0x00800000)    /*!< External event 3 */
#define HRTIM_SET2R_EXTVNT4   ((uint32_t)0x01000000)    /*!< External event 4 */
#define HRTIM_SET2R_EXTVNT5   ((uint32_t)0x02000000)    /*!< External event 5 */
#define HRTIM_SET2R_EXTVNT6   ((uint32_t)0x04000000)    /*!< External event 6 */
#define HRTIM_SET2R_EXTVNT7   ((uint32_t)0x08000000)    /*!< External event 7 */
#define HRTIM_SET2R_EXTVNT8   ((uint32_t)0x10000000)    /*!< External event 8 */
#define HRTIM_SET2R_EXTVNT9   ((uint32_t)0x20000000)    /*!< External event 9 */
#define HRTIM_SET2R_EXTVNT10  ((uint32_t)0x40000000)    /*!< External event 10 */

#define HRTIM_SET2R_UPDATE    ((uint32_t)0x80000000)    /*!< Register update (transfer preload to active) */

/**** Bit definition for Slave Output 2 reset register ************************/
#define HRTIM_RST2R_SRT         ((uint32_t)0x00000001)    /*!< software reset trigger */
#define HRTIM_RST2R_RESYNC      ((uint32_t)0x00000002)    /*!< Timer A resynchronization */
#define HRTIM_RST2R_PER         ((uint32_t)0x00000004)    /*!< Timer A period */
#define HRTIM_RST2R_CMP1        ((uint32_t)0x00000008)    /*!< Timer A compare 1 */
#define HRTIM_RST2R_CMP2        ((uint32_t)0x00000010)    /*!< Timer A compare 2 */
#define HRTIM_RST2R_CMP3        ((uint32_t)0x00000020)    /*!< Timer A compare 3 */
#define HRTIM_RST2R_CMP4        ((uint32_t)0x00000040)    /*!< Timer A compare 4 */

#define HRTIM_RST2R_MSTPER      ((uint32_t)0x00000080)    /*!< Master period */
#define HRTIM_RST2R_MSTCMP1     ((uint32_t)0x00000100)    /*!< Master compare 1 */
#define HRTIM_RST2R_MSTCMP2     ((uint32_t)0x00000200)    /*!< Master compare 2 */
#define HRTIM_RST2R_MSTCMP3     ((uint32_t)0x00000400)    /*!< Master compare 3 */
#define HRTIM_RST2R_MSTCMP4     ((uint32_t)0x00000800)    /*!< Master compare 4 */

#define HRTIM_RST2R_TIMEVNT1   ((uint32_t)0x00001000)    /*!< Timer event 1 */
#define HRTIM_RST2R_TIMEVNT2   ((uint32_t)0x00002000)    /*!< Timer event 2 */
#define HRTIM_RST2R_TIMEVNT3   ((uint32_t)0x00004000)    /*!< Timer event 3 */
#define HRTIM_RST2R_TIMEVNT4   ((uint32_t)0x00008000)    /*!< Timer event 4 */
#define HRTIM_RST2R_TIMEVNT5   ((uint32_t)0x00010000)    /*!< Timer event 5 */
#define HRTIM_RST2R_TIMEVNT6   ((uint32_t)0x00020000)    /*!< Timer event 6 */
#define HRTIM_RST2R_TIMEVNT7   ((uint32_t)0x00040000)    /*!< Timer event 7 */
#define HRTIM_RST2R_TIMEVNT8   ((uint32_t)0x00080000)    /*!< Timer event 8 */
#define HRTIM_RST2R_TIMEVNT9   ((uint32_t)0x00100000)    /*!< Timer event 9 */

#define HRTIM_RST2R_EXTVNT1   ((uint32_t)0x00200000)    /*!< External event 1 */
#define HRTIM_RST2R_EXTVNT2   ((uint32_t)0x00400000)    /*!< External event 2 */
#define HRTIM_RST2R_EXTVNT3   ((uint32_t)0x00800000)    /*!< External event 3 */
#define HRTIM_RST2R_EXTVNT4   ((uint32_t)0x01000000)    /*!< External event 4 */
#define HRTIM_RST2R_EXTVNT5   ((uint32_t)0x02000000)    /*!< External event 5 */
#define HRTIM_RST2R_EXTVNT6   ((uint32_t)0x04000000)    /*!< External event 6 */
#define HRTIM_RST2R_EXTVNT7   ((uint32_t)0x08000000)    /*!< External event 7 */
#define HRTIM_RST2R_EXTVNT8   ((uint32_t)0x10000000)    /*!< External event 8 */
#define HRTIM_RST2R_EXTVNT9   ((uint32_t)0x20000000)    /*!< External event 9 */
#define HRTIM_RST2R_EXTVNT10  ((uint32_t)0x40000000)    /*!< External event 10 */

#define HRTIM_RST2R_UPDATE    ((uint32_t)0x80000000)    /*!< Register update (transfer preload to active) */

/**** Bit definition for Slave external event filtering  register 1 ***********/
#define HRTIM_EEFR1_EE1LTCH    ((uint32_t)0x00000001)    /*!< External Event 1 latch */
#define HRTIM_EEFR1_EE1FLTR    ((uint32_t)0x0000001E)    /*!< External Event 1 filter mask */
#define HRTIM_EEFR1_EE1FLTR_0  ((uint32_t)0x00000002)    /*!< External Event 1 bit 0  */
#define HRTIM_EEFR1_EE1FLTR_1  ((uint32_t)0x00000004)    /*!< External Event 1 bit 1*/
#define HRTIM_EEFR1_EE1FLTR_2  ((uint32_t)0x00000008)    /*!< External Event 1 bit 2 */
#define HRTIM_EEFR1_EE1FLTR_3  ((uint32_t)0x00000010)    /*!< External Event 1 bit 3 */

#define HRTIM_EEFR1_EE2LTCH    ((uint32_t)0x00000040)    /*!< External Event 2 latch */
#define HRTIM_EEFR1_EE2FLTR    ((uint32_t)0x00000780)    /*!< External Event 2 filter mask */
#define HRTIM_EEFR1_EE2FLTR_0  ((uint32_t)0x00000080)    /*!< External Event 2 bit 0  */
#define HRTIM_EEFR1_EE2FLTR_1  ((uint32_t)0x00000100)    /*!< External Event 2 bit 1*/
#define HRTIM_EEFR1_EE2FLTR_2  ((uint32_t)0x00000200)    /*!< External Event 2 bit 2 */
#define HRTIM_EEFR1_EE2FLTR_3  ((uint32_t)0x00000400)    /*!< External Event 2 bit 3 */

#define HRTIM_EEFR1_EE3LTCH    ((uint32_t)0x00001000)    /*!< External Event 3 latch */
#define HRTIM_EEFR1_EE3FLTR    ((uint32_t)0x0001E000)    /*!< External Event 3 filter mask */
#define HRTIM_EEFR1_EE3FLTR_0  ((uint32_t)0x00002000)    /*!< External Event 3 bit 0  */
#define HRTIM_EEFR1_EE3FLTR_1  ((uint32_t)0x00004000)    /*!< External Event 3 bit 1*/
#define HRTIM_EEFR1_EE3FLTR_2  ((uint32_t)0x00008000)    /*!< External Event 3 bit 2 */
#define HRTIM_EEFR1_EE3FLTR_3  ((uint32_t)0x00010000)    /*!< External Event 3 bit 3 */

#define HRTIM_EEFR1_EE4LTCH    ((uint32_t)0x00040000)    /*!< External Event 4 latch */
#define HRTIM_EEFR1_EE4FLTR    ((uint32_t)0x00780000)    /*!< External Event 4 filter mask */
#define HRTIM_EEFR1_EE4FLTR_0  ((uint32_t)0x00080000)    /*!< External Event 4 bit 0  */
#define HRTIM_EEFR1_EE4FLTR_1  ((uint32_t)0x00100000)    /*!< External Event 4 bit 1*/
#define HRTIM_EEFR1_EE4FLTR_2  ((uint32_t)0x00200000)    /*!< External Event 4 bit 2 */
#define HRTIM_EEFR1_EE4FLTR_3  ((uint32_t)0x00400000)    /*!< External Event 4 bit 3 */

#define HRTIM_EEFR1_EE5LTCH    ((uint32_t)0x01000000)   /*!< External Event 5 latch */
#define HRTIM_EEFR1_EE5FLTR    ((uint32_t)0x1E000000)    /*!< External Event 5 filter mask */
#define HRTIM_EEFR1_EE5FLTR_0  ((uint32_t)0x02000000)    /*!< External Event 5 bit 0  */
#define HRTIM_EEFR1_EE5FLTR_1  ((uint32_t)0x04000000)    /*!< External Event 5 bit 1*/
#define HRTIM_EEFR1_EE5FLTR_2  ((uint32_t)0x08000000)    /*!< External Event 5 bit 2 */
#define HRTIM_EEFR1_EE5FLTR_3  ((uint32_t)0x10000000)    /*!< External Event 5 bit 3 */

/**** Bit definition for Slave external event filtering  register 2 ***********/
#define HRTIM_EEFR2_EE6LTCH    ((uint32_t)0x00000001)    /*!< External Event 6 latch */
#define HRTIM_EEFR2_EE6FLTR    ((uint32_t)0x0000001E)    /*!< External Event 6 filter mask */
#define HRTIM_EEFR2_EE6FLTR_0  ((uint32_t)0x00000002)    /*!< External Event 6 bit 0  */
#define HRTIM_EEFR2_EE6FLTR_1  ((uint32_t)0x00000004)    /*!< External Event 6 bit 1*/
#define HRTIM_EEFR2_EE6FLTR_2  ((uint32_t)0x00000008)    /*!< External Event 6 bit 2 */
#define HRTIM_EEFR2_EE6FLTR_3  ((uint32_t)0x00000010)    /*!< External Event 6 bit 3 */

#define HRTIM_EEFR2_EE7LTCH    ((uint32_t)0x00000040)    /*!< External Event 7 latch */
#define HRTIM_EEFR2_EE7FLTR    ((uint32_t)0x00000780)    /*!< External Event 7 filter mask */
#define HRTIM_EEFR2_EE7FLTR_0  ((uint32_t)0x00000080)    /*!< External Event 7 bit 0  */
#define HRTIM_EEFR2_EE7FLTR_1  ((uint32_t)0x00000100)    /*!< External Event 7 bit 1*/
#define HRTIM_EEFR2_EE7FLTR_2  ((uint32_t)0x00000200)    /*!< External Event 7 bit 2 */
#define HRTIM_EEFR2_EE7FLTR_3  ((uint32_t)0x00000400)    /*!< External Event 7 bit 3 */

#define HRTIM_EEFR2_EE8LTCH    ((uint32_t)0x00001000)    /*!< External Event 8 latch */
#define HRTIM_EEFR2_EE8FLTR    ((uint32_t)0x0001E000)    /*!< External Event 8 filter mask */
#define HRTIM_EEFR2_EE8FLTR_0  ((uint32_t)0x00002000)    /*!< External Event 8 bit 0  */
#define HRTIM_EEFR2_EE8FLTR_1  ((uint32_t)0x00004000)    /*!< External Event 8 bit 1*/
#define HRTIM_EEFR2_EE8FLTR_2  ((uint32_t)0x00008000)    /*!< External Event 8 bit 2 */
#define HRTIM_EEFR2_EE8FLTR_3  ((uint32_t)0x00010000)    /*!< External Event 8 bit 3 */

#define HRTIM_EEFR2_EE9LTCH    ((uint32_t)0x00040000)    /*!< External Event 9 latch */
#define HRTIM_EEFR2_EE9FLTR    ((uint32_t)0x00780000)    /*!< External Event 9 filter mask */
#define HRTIM_EEFR2_EE9FLTR_0  ((uint32_t)0x00080000)    /*!< External Event 9 bit 0  */
#define HRTIM_EEFR2_EE9FLTR_1  ((uint32_t)0x00100000)    /*!< External Event 9 bit 1*/
#define HRTIM_EEFR2_EE9FLTR_2  ((uint32_t)0x00200000)    /*!< External Event 9 bit 2 */
#define HRTIM_EEFR2_EE9FLTR_3  ((uint32_t)0x00400000)    /*!< External Event 9 bit 3 */

#define HRTIM_EEFR2_EE10LTCH    ((uint32_t)0x01000000)   /*!< External Event 10 latch */
#define HRTIM_EEFR2_EE10FLTR    ((uint32_t)0x1E000000)    /*!< External Event 10 filter mask */
#define HRTIM_EEFR2_EE10FLTR_0  ((uint32_t)0x02000000)    /*!< External Event 10 bit 0  */
#define HRTIM_EEFR2_EE10FLTR_1  ((uint32_t)0x04000000)    /*!< External Event 10 bit 1*/
#define HRTIM_EEFR2_EE10FLTR_2  ((uint32_t)0x08000000)    /*!< External Event 10 bit 2 */
#define HRTIM_EEFR2_EE10FLTR_3  ((uint32_t)0x10000000)    /*!< External Event 10 bit 3 */

/**** Bit definition for Slave Timer reset register ***************************/
#define HRTIM_RSTR_UPDATE     ((uint32_t)0x00000002)   /*!< Timer update */
#define HRTIM_RSTR_CMP2       ((uint32_t)0x00000004)   /*!< Timer compare2 */
#define HRTIM_RSTR_CMP4       ((uint32_t)0x00000008)   /*!< Timer compare4 */

#define HRTIM_RSTR_MSTPER     ((uint32_t)0x00000010)   /*!< Master period */
#define HRTIM_RSTR_MSTCMP1    ((uint32_t)0x00000020)   /*!< Master compare1 */
#define HRTIM_RSTR_MSTCMP2    ((uint32_t)0x00000040)   /*!< Master compare2 */
#define HRTIM_RSTR_MSTCMP3    ((uint32_t)0x00000080)   /*!< Master compare3 */
#define HRTIM_RSTR_MSTCMP4    ((uint32_t)0x00000100)   /*!< Master compare4 */

#define HRTIM_RSTR_EXTEVNT1   ((uint32_t)0x00000200)   /*!< External event 1 */
#define HRTIM_RSTR_EXTEVNT2   ((uint32_t)0x00000400)   /*!< External event 2 */
#define HRTIM_RSTR_EXTEVNT3   ((uint32_t)0x00000800)   /*!< External event 3 */
#define HRTIM_RSTR_EXTEVNT4   ((uint32_t)0x00001000)   /*!< External event 4 */
#define HRTIM_RSTR_EXTEVNT5   ((uint32_t)0x00002000)   /*!< External event 5 */
#define HRTIM_RSTR_EXTEVNT6   ((uint32_t)0x00004000)   /*!< External event 6 */
#define HRTIM_RSTR_EXTEVNT7   ((uint32_t)0x00008000)   /*!< External event 7 */
#define HRTIM_RSTR_EXTEVNT8   ((uint32_t)0x00010000)   /*!< External event 8 */
#define HRTIM_RSTR_EXTEVNT9   ((uint32_t)0x00020000)   /*!< External event 9 */
#define HRTIM_RSTR_EXTEVNT10  ((uint32_t)0x00040000)   /*!< External event 10 */

#define HRTIM_RSTR_TIMBCMP1   ((uint32_t)0x00080000)   /*!< Timer B compare 1 */
#define HRTIM_RSTR_TIMBCMP2   ((uint32_t)0x00100000)   /*!< Timer B compare 2 */
#define HRTIM_RSTR_TIMBCMP4   ((uint32_t)0x00200000)   /*!< Timer B compare 4 */

#define HRTIM_RSTR_TIMCCMP1   ((uint32_t)0x00400000)   /*!< Timer C compare 1 */
#define HRTIM_RSTR_TIMCCMP2   ((uint32_t)0x00800000)   /*!< Timer C compare 2 */
#define HRTIM_RSTR_TIMCCMP4   ((uint32_t)0x01000000)   /*!< Timer C compare 4 */

#define HRTIM_RSTR_TIMDCMP1   ((uint32_t)0x02000000)   /*!< Timer D compare 1 */
#define HRTIM_RSTR_TIMDCMP2   ((uint32_t)0x04000000)   /*!< Timer D compare 2 */
#define HRTIM_RSTR_TIMDCMP4   ((uint32_t)0x08000000)   /*!< Timer D compare 4 */

#define HRTIM_RSTR_TIMECMP1   ((uint32_t)0x10000000)   /*!< Timer E compare 1 */
#define HRTIM_RSTR_TIMECMP2   ((uint32_t)0x20000000)   /*!< Timer E compare 2 */
#define HRTIM_RSTR_TIMECMP4   ((uint32_t)0x40000000)   /*!< Timer E compare 4 */

/**** Bit definition for Slave Timer Chopper register *************************/
#define HRTIM_CHPR_CARFRQ    ((uint32_t)0x0000000F)   /*!< Timer carrier frequency value */
#define HRTIM_CHPR_CARFRQ_0  ((uint32_t)0x00000001)   /*!< Timer carrier frequency value bit 0 */
#define HRTIM_CHPR_CARFRQ_1  ((uint32_t)0x00000002)   /*!< Timer carrier frequency value bit 1 */
#define HRTIM_CHPR_CARFRQ_2  ((uint32_t)0x00000004)   /*!< Timer carrier frequency value bit 2 */
#define HRTIM_CHPR_CARFRQ_3  ((uint32_t)0x00000008)   /*!< Timer carrier frequency value bit 3 */

#define HRTIM_CHPR_CARDTY    ((uint32_t)0x00000070)   /*!< Timer chopper duty cycle value */
#define HRTIM_CHPR_CARDTY_0  ((uint32_t)0x00000010)   /*!< Timer chopper duty cycle value bit 0 */
#define HRTIM_CHPR_CARDTY_1  ((uint32_t)0x00000020)   /*!< Timer chopper duty cycle value bit 1 */
#define HRTIM_CHPR_CARDTY_2  ((uint32_t)0x00000040)   /*!< Timer chopper duty cycle value bit 2 */

#define HRTIM_CHPR_STRPW     ((uint32_t)0x00000780)   /*!< Timer start pulse width value */
#define HRTIM_CHPR_STRPW_0   ((uint32_t)0x00000080)   /*!< Timer start pulse width value bit 0 */
#define HRTIM_CHPR_STRPW_1   ((uint32_t)0x00000100)   /*!< Timer start pulse width value bit 1 */
#define HRTIM_CHPR_STRPW_2   ((uint32_t)0x00000200)   /*!< Timer start pulse width value bit 2 */
#define HRTIM_CHPR_STRPW_3   ((uint32_t)0x00000400)   /*!< Timer start pulse width value bit 3 */

/**** Bit definition for Slave Timer Capture 1 control register ***************/
#define HRTIM_CPT1CR_SWCPT       ((uint32_t)0x00000001)   /*!< Software capture */
#define HRTIM_CPT1CR_UPDCPT      ((uint32_t)0x00000002)   /*!< Update capture */
#define HRTIM_CPT1CR_EXEV1CPT    ((uint32_t)0x00000004)   /*!< External event 1 capture */
#define HRTIM_CPT1CR_EXEV2CPT    ((uint32_t)0x00000008)   /*!< External event 2 capture */
#define HRTIM_CPT1CR_EXEV3CPT    ((uint32_t)0x00000010)   /*!< External event 3 capture */
#define HRTIM_CPT1CR_EXEV4CPT    ((uint32_t)0x00000020)   /*!< External event 4 capture */
#define HRTIM_CPT1CR_EXEV5CPT    ((uint32_t)0x00000040)   /*!< External event 5 capture */
#define HRTIM_CPT1CR_EXEV6CPT    ((uint32_t)0x00000080)   /*!< External event 6 capture */
#define HRTIM_CPT1CR_EXEV7CPT    ((uint32_t)0x00000100)   /*!< External event 7 capture */
#define HRTIM_CPT1CR_EXEV8CPT    ((uint32_t)0x00000200)   /*!< External event 8 capture */
#define HRTIM_CPT1CR_EXEV9CPT    ((uint32_t)0x00000400)   /*!< External event 9 capture */
#define HRTIM_CPT1CR_EXEV10CPT   ((uint32_t)0x00000800)   /*!< External event 10 capture */

#define HRTIM_CPT1CR_TA1SET      ((uint32_t)0x00001000)   /*!< Timer A output 1 set */
#define HRTIM_CPT1CR_TA1RST      ((uint32_t)0x00002000)   /*!< Timer A output 1 reset */
#define HRTIM_CPT1CR_TIMACMP1    ((uint32_t)0x00004000)   /*!< Timer A compare 1 */
#define HRTIM_CPT1CR_TIMACMP2    ((uint32_t)0x00008000)   /*!< Timer A compare 2 */

#define HRTIM_CPT1CR_TB1SET      ((uint32_t)0x00010000)   /*!< Timer B output 1 set */
#define HRTIM_CPT1CR_TB1RST      ((uint32_t)0x00020000)   /*!< Timer B output 1 reset */
#define HRTIM_CPT1CR_TIMBCMP1    ((uint32_t)0x00040000)   /*!< Timer B compare 1 */
#define HRTIM_CPT1CR_TIMBCMP2    ((uint32_t)0x00080000)   /*!< Timer B compare 2 */

#define HRTIM_CPT1CR_TC1SET      ((uint32_t)0x00100000)   /*!< Timer C output 1 set */
#define HRTIM_CPT1CR_TC1RST      ((uint32_t)0x00200000)   /*!< Timer C output 1 reset */
#define HRTIM_CPT1CR_TIMCCMP1    ((uint32_t)0x00400000)   /*!< Timer C compare 1 */
#define HRTIM_CPT1CR_TIMCCMP2    ((uint32_t)0x00800000)   /*!< Timer C compare 2 */

#define HRTIM_CPT1CR_TD1SET      ((uint32_t)0x01000000)   /*!< Timer D output 1 set */
#define HRTIM_CPT1CR_TD1RST      ((uint32_t)0x02000000)   /*!< Timer D output 1 reset */
#define HRTIM_CPT1CR_TIMDCMP1    ((uint32_t)0x04000000)   /*!< Timer D compare 1 */
#define HRTIM_CPT1CR_TIMDCMP2    ((uint32_t)0x08000000)   /*!< Timer D compare 2 */

#define HRTIM_CPT1CR_TE1SET      ((uint32_t)0x10000000)   /*!< Timer E output 1 set */
#define HRTIM_CPT1CR_TE1RST      ((uint32_t)0x20000000)   /*!< Timer E output 1 reset */
#define HRTIM_CPT1CR_TIMECMP1    ((uint32_t)0x40000000)   /*!< Timer E compare 1 */
#define HRTIM_CPT1CR_TIMECMP2    ((uint32_t)0x80000000)   /*!< Timer E compare 2 */

/**** Bit definition for Slave Timer Capture 2 control register ***************/
#define HRTIM_CPT2CR_SWCPT       ((uint32_t)0x00000001)   /*!< Software capture */
#define HRTIM_CPT2CR_UPDCPT      ((uint32_t)0x00000002)   /*!< Update capture */
#define HRTIM_CPT2CR_EXEV1CPT    ((uint32_t)0x00000004)   /*!< External event 1 capture */
#define HRTIM_CPT2CR_EXEV2CPT    ((uint32_t)0x00000008)   /*!< External event 2 capture */
#define HRTIM_CPT2CR_EXEV3CPT    ((uint32_t)0x00000010)   /*!< External event 3 capture */
#define HRTIM_CPT2CR_EXEV4CPT    ((uint32_t)0x00000020)   /*!< External event 4 capture */
#define HRTIM_CPT2CR_EXEV5CPT    ((uint32_t)0x00000040)   /*!< External event 5 capture */
#define HRTIM_CPT2CR_EXEV6CPT    ((uint32_t)0x00000080)   /*!< External event 6 capture */
#define HRTIM_CPT2CR_EXEV7CPT    ((uint32_t)0x00000100)   /*!< External event 7 capture */
#define HRTIM_CPT2CR_EXEV8CPT    ((uint32_t)0x00000200)   /*!< External event 8 capture */
#define HRTIM_CPT2CR_EXEV9CPT    ((uint32_t)0x00000400)   /*!< External event 9 capture */
#define HRTIM_CPT2CR_EXEV10CPT   ((uint32_t)0x00000800)   /*!< External event 10 capture */

#define HRTIM_CPT2CR_TA1SET      ((uint32_t)0x00001000)   /*!< Timer A output 1 set */
#define HRTIM_CPT2CR_TA1RST      ((uint32_t)0x00002000)   /*!< Timer A output 1 reset */
#define HRTIM_CPT2CR_TIMACMP1    ((uint32_t)0x00004000)   /*!< Timer A compare 1 */
#define HRTIM_CPT2CR_TIMACMP2    ((uint32_t)0x00008000)   /*!< Timer A compare 2 */

#define HRTIM_CPT2CR_TB1SET      ((uint32_t)0x00010000)   /*!< Timer B output 1 set */
#define HRTIM_CPT2CR_TB1RST      ((uint32_t)0x00020000)   /*!< Timer B output 1 reset */
#define HRTIM_CPT2CR_TIMBCMP1    ((uint32_t)0x00040000)   /*!< Timer B compare 1 */
#define HRTIM_CPT2CR_TIMBCMP2    ((uint32_t)0x00080000)   /*!< Timer B compare 2 */

#define HRTIM_CPT2CR_TC1SET      ((uint32_t)0x00100000)   /*!< Timer C output 1 set */
#define HRTIM_CPT2CR_TC1RST      ((uint32_t)0x00200000)   /*!< Timer C output 1 reset */
#define HRTIM_CPT2CR_TIMCCMP1    ((uint32_t)0x00400000)   /*!< Timer C compare 1 */
#define HRTIM_CPT2CR_TIMCCMP2    ((uint32_t)0x00800000)   /*!< Timer C compare 2 */

#define HRTIM_CPT2CR_TD1SET      ((uint32_t)0x01000000)   /*!< Timer D output 1 set */
#define HRTIM_CPT2CR_TD1RST      ((uint32_t)0x02000000)   /*!< Timer D output 1 reset */
#define HRTIM_CPT2CR_TIMDCMP1    ((uint32_t)0x04000000)   /*!< Timer D compare 1 */
#define HRTIM_CPT2CR_TIMDCMP2    ((uint32_t)0x08000000)   /*!< Timer D compare 2 */

#define HRTIM_CPT2CR_TE1SET      ((uint32_t)0x10000000)   /*!< Timer E output 1 set */
#define HRTIM_CPT2CR_TE1RST      ((uint32_t)0x20000000)   /*!< Timer E output 1 reset */
#define HRTIM_CPT2CR_TIMECMP1    ((uint32_t)0x40000000)   /*!< Timer E compare 1 */
#define HRTIM_CPT2CR_TIMECMP2    ((uint32_t)0x80000000)   /*!< Timer E compare 2 */

/**** Bit definition for Slave Timer Output register **************************/
#define HRTIM_OUTR_POL1       ((uint32_t)0x00000002)    /*!< Slave output 1 polarity */
#define HRTIM_OUTR_IDLM1      ((uint32_t)0x00000004)   /*!< Slave output 1 idle mode */
#define HRTIM_OUTR_IDLES1     ((uint32_t)0x00000008)   /*!< Slave output 1 idle state */
#define HRTIM_OUTR_FAULT1     ((uint32_t)0x00000030)   /*!< Slave output 1 fault state */
#define HRTIM_OUTR_FAULT1_0   ((uint32_t)0x00000010)   /*!< Slave output 1 fault state bit 0 */
#define HRTIM_OUTR_FAULT1_1   ((uint32_t)0x00000020)   /*!< Slave output 1 fault state bit 1 */
#define HRTIM_OUTR_CHP1       ((uint32_t)0x00000040)   /*!< Slave output 1 chopper enable */
#define HRTIM_OUTR_DIDL1      ((uint32_t)0x00000080)   /*!< Slave output 1 dead time idle */

#define HRTIM_OUTR_DTEN      ((uint32_t)0x00000100)   /*!< Slave output deadtime enable */
#define HRTIM_OUTR_DLYPRTEN  ((uint32_t)0x00000200)   /*!< Slave output delay protection enable */
#define HRTIM_OUTR_DLYPRT    ((uint32_t)0x00001C00)   /*!< Slave output delay protection */
#define HRTIM_OUTR_DLYPRT_0  ((uint32_t)0x00000400)   /*!< Slave output delay protection bit 0 */
#define HRTIM_OUTR_DLYPRT_1  ((uint32_t)0x00000800)   /*!< Slave output delay protection bit 1 */
#define HRTIM_OUTR_DLYPRT_2  ((uint32_t)0x00001000)   /*!< Slave output delay protection bit 2 */

#define HRTIM_OUTR_POL2      ((uint32_t)0x00020000)   /*!< Slave output 2 polarity */
#define HRTIM_OUTR_IDLM2     ((uint32_t)0x00040000)   /*!< Slave output 2 idle mode */
#define HRTIM_OUTR_IDLES2    ((uint32_t)0x00080000)   /*!< Slave output 2 idle state */
#define HRTIM_OUTR_FAULT2    ((uint32_t)0x00300000)   /*!< Slave output 2 fault state */
#define HRTIM_OUTR_FAULT2_0  ((uint32_t)0x00100000)   /*!< Slave output 2 fault state bit 0 */
#define HRTIM_OUTR_FAULT2_1  ((uint32_t)0x00200000)   /*!< Slave output 2 fault state bit 1 */
#define HRTIM_OUTR_CHP2      ((uint32_t)0x00400000)   /*!< Slave output 2 chopper enable */
#define HRTIM_OUTR_DIDL2     ((uint32_t)0x00800000)   /*!< Slave output 2 dead time idle */

/**** Bit definition for Slave Timer Fault register ***************************/
#define HRTIM_FLTR_FLT1EN     ((uint32_t)0x00000001)   /*!< Fault 1 enable */
#define HRTIM_FLTR_FLT2EN     ((uint32_t)0x00000002)   /*!< Fault 2 enable */
#define HRTIM_FLTR_FLT3EN     ((uint32_t)0x00000004)   /*!< Fault 3 enable */
#define HRTIM_FLTR_FLT4EN     ((uint32_t)0x00000008)   /*!< Fault 4 enable */
#define HRTIM_FLTR_FLT5EN     ((uint32_t)0x00000010)   /*!< Fault 5 enable */
#define HRTIM_FLTR_FLTLCK     ((uint32_t)0x80000000)   /*!< Fault sources lock */

/**** Bit definition for Common HRTIM Timer control register 1 ****************/
#define HRTIM_CR1_MUDIS       ((uint32_t)0x00000001)   /*!< Master update disable*/
#define HRTIM_CR1_TAUDIS      ((uint32_t)0x00000002)   /*!< Timer A update disable*/
#define HRTIM_CR1_TBUDIS      ((uint32_t)0x00000004)   /*!< Timer B update disable*/
#define HRTIM_CR1_TCUDIS      ((uint32_t)0x00000008)   /*!< Timer C update disable*/
#define HRTIM_CR1_TDUDIS      ((uint32_t)0x00000010)   /*!< Timer D update disable*/
#define HRTIM_CR1_TEUDIS      ((uint32_t)0x00000020)   /*!< Timer E update disable*/
#define HRTIM_CR1_ADC1USRC    ((uint32_t)0x00070000)   /*!< ADC Trigger 1 update source */
#define HRTIM_CR1_ADC1USRC_0  ((uint32_t)0x00010000)   /*!< ADC Trigger 1 update source bit 0 */
#define HRTIM_CR1_ADC1USRC_1  ((uint32_t)0x00020000)   /*!< ADC Trigger 1 update source bit 1 */
#define HRTIM_CR1_ADC1USRC_2  ((uint32_t)0x00040000)   /*!< ADC Trigger 1 update source bit 2 */
#define HRTIM_CR1_ADC2USRC    ((uint32_t)0x00380000)   /*!< ADC Trigger 2 update source */
#define HRTIM_CR1_ADC2USRC_0  ((uint32_t)0x00080000)   /*!< ADC Trigger 2 update source bit 0 */
#define HRTIM_CR1_ADC2USRC_1  ((uint32_t)0x00100000)   /*!< ADC Trigger 2 update source bit 1 */
#define HRTIM_CR1_ADC2USRC_2  ((uint32_t)0x00200000)   /*!< ADC Trigger 2 update source bit 2 */
#define HRTIM_CR1_ADC3USRC    ((uint32_t)0x01C00000)   /*!< ADC Trigger 3 update source */
#define HRTIM_CR1_ADC3USRC_0  ((uint32_t)0x00400000)   /*!< ADC Trigger 3 update source bit 0 */
#define HRTIM_CR1_ADC3USRC_1  ((uint32_t)0x00800000)   /*!< ADC Trigger 3 update source bit 1 */
#define HRTIM_CR1_ADC3USRC_2  ((uint32_t)0x01000000)   /*!< ADC Trigger 3 update source bit 2 */
#define HRTIM_CR1_ADC4USRC    ((uint32_t)0x0E000000)   /*!< ADC Trigger 4 update source */
#define HRTIM_CR1_ADC4USRC_0  ((uint32_t)0x02000000)   /*!< ADC Trigger 4 update source bit 0 */
#define HRTIM_CR1_ADC4USRC_1  ((uint32_t)0x04000000)   /*!< ADC Trigger 4 update source bit 1 */
#define HRTIM_CR1_ADC4USRC_2  ((uint32_t)0x0800000)   /*!< ADC Trigger 4 update source bit 2 */

/**** Bit definition for Common HRTIM Timer control register 2 ****************/
#define HRTIM_CR2_MSWU   ((uint32_t)0x00000001)        /*!< Master software update */
#define HRTIM_CR2_TASWU  ((uint32_t)0x00000002)        /*!< Timer A software update */
#define HRTIM_CR2_TBSWU  ((uint32_t)0x00000004)        /*!< Timer B software update */
#define HRTIM_CR2_TCSWU  ((uint32_t)0x00000008)        /*!< Timer C software update */
#define HRTIM_CR2_TDSWU  ((uint32_t)0x00000010)        /*!< Timer D software update */
#define HRTIM_CR2_TESWU  ((uint32_t)0x00000020)        /*!< Timer E software update */
#define HRTIM_CR2_MRST   ((uint32_t)0x00000100)        /*!< Master count software reset */
#define HRTIM_CR2_TARST  ((uint32_t)0x00000200)        /*!< Timer A count software reset */
#define HRTIM_CR2_TBRST  ((uint32_t)0x00000400)        /*!< Timer B count software reset */
#define HRTIM_CR2_TCRST  ((uint32_t)0x00000800)        /*!< Timer C count software reset */
#define HRTIM_CR2_TDRST  ((uint32_t)0x00001000)        /*!< Timer D count software reset */
#define HRTIM_CR2_TERST  ((uint32_t)0x00002000)        /*!< Timer E count software reset */

/**** Bit definition for Common HRTIM Timer interrupt status register *********/
#define HRTIM_ISR_FLT1    ((uint32_t)0x00000001)   /*!< Fault 1 interrupt flag */
#define HRTIM_ISR_FLT2    ((uint32_t)0x00000002)   /*!< Fault 2 interrupt flag */
#define HRTIM_ISR_FLT3    ((uint32_t)0x00000004)   /*!< Fault 3 interrupt flag */
#define HRTIM_ISR_FLT4    ((uint32_t)0x00000008)   /*!< Fault 4 interrupt flag */
#define HRTIM_ISR_FLT5    ((uint32_t)0x00000010)   /*!< Fault 5 interrupt flag */
#define HRTIM_ISR_SYSFLT  ((uint32_t)0x00000020)   /*!< System Fault interrupt flag */
#define HRTIM_ISR_DLLRDY  ((uint32_t)0x00010000)   /*!< DLL ready interrupt flag */
#define HRTIM_ISR_BMPER   ((uint32_t)0x00020000)   /*!<  Burst mode period interrupt flag */

/**** Bit definition for Common HRTIM Timer interrupt clear register **********/
#define HRTIM_ICR_FLT1C    ((uint32_t)0x00000001)   /*!< Fault 1 interrupt flag clear */
#define HRTIM_ICR_FLT2C    ((uint32_t)0x00000002)   /*!< Fault 2 interrupt flag clear */
#define HRTIM_ICR_FLT3C    ((uint32_t)0x00000004)   /*!< Fault 3 interrupt flag clear */
#define HRTIM_ICR_FLT4C    ((uint32_t)0x00000008)   /*!< Fault 4 interrupt flag clear */
#define HRTIM_ICR_FLT5C    ((uint32_t)0x00000010)   /*!< Fault 5 interrupt flag clear */
#define HRTIM_ICR_SYSFLTC  ((uint32_t)0x00000020)   /*!< System Fault interrupt flag clear */
#define HRTIM_ICR_DLLRDYC  ((uint32_t)0x00010000)   /*!< DLL ready interrupt flag clear */
#define HRTIM_ICR_BMPERC   ((uint32_t)0x00020000)   /*!<  Burst mode period interrupt flag clear */

/**** Bit definition for Common HRTIM Timer interrupt enable register *********/
#define HRTIM_IER_FLT1    ((uint32_t)0x00000001)   /*!< Fault 1 interrupt enable */
#define HRTIM_IER_FLT2    ((uint32_t)0x00000002)   /*!< Fault 2 interrupt enable */
#define HRTIM_IER_FLT3    ((uint32_t)0x00000004)   /*!< Fault 3 interrupt enable */
#define HRTIM_IER_FLT4    ((uint32_t)0x00000008)   /*!< Fault 4 interrupt enable */
#define HRTIM_IER_FLT5    ((uint32_t)0x00000010)   /*!< Fault 5 interrupt enable */
#define HRTIM_IER_SYSFLT  ((uint32_t)0x00000020)   /*!< System Fault interrupt enable */
#define HRTIM_IER_DLLRDY  ((uint32_t)0x00010000)   /*!< DLL ready interrupt enable */
#define HRTIM_IER_BMPER   ((uint32_t)0x00020000)   /*!<  Burst mode period interrupt enable */

/**** Bit definition for Common HRTIM Timer output enable register ************/
#define HRTIM_OENR_TA1OEN    ((uint32_t)0x00000001)   /*!< Timer A Output 1 enable */
#define HRTIM_OENR_TA2OEN    ((uint32_t)0x00000002)   /*!< Timer A Output 2 enable */
#define HRTIM_OENR_TB1OEN    ((uint32_t)0x00000004)   /*!< Timer B Output 1 enable */
#define HRTIM_OENR_TB2OEN    ((uint32_t)0x00000008)   /*!< Timer B Output 2 enable */
#define HRTIM_OENR_TC1OEN    ((uint32_t)0x00000010)   /*!< Timer C Output 1 enable */
#define HRTIM_OENR_TC2OEN    ((uint32_t)0x00000020)   /*!< Timer C Output 2 enable */
#define HRTIM_OENR_TD1OEN    ((uint32_t)0x00000040)   /*!< Timer D Output 1 enable */
#define HRTIM_OENR_TD2OEN    ((uint32_t)0x00000080)   /*!< Timer D Output 2 enable */
#define HRTIM_OENR_TE1OEN    ((uint32_t)0x00000100)   /*!< Timer E Output 1 enable */
#define HRTIM_OENR_TE2OEN    ((uint32_t)0x00000200)   /*!< Timer E Output 2 enable */

/**** Bit definition for Common HRTIM Timer output disable register ***********/
#define HRTIM_ODISR_TA1ODIS    ((uint32_t)0x00000001)   /*!< Timer A Output 1 disable */
#define HRTIM_ODISR_TA2ODIS    ((uint32_t)0x00000002)   /*!< Timer A Output 2 disable */
#define HRTIM_ODISR_TB1ODIS    ((uint32_t)0x00000004)   /*!< Timer B Output 1 disable */
#define HRTIM_ODISR_TB2ODIS    ((uint32_t)0x00000008)   /*!< Timer B Output 2 disable */
#define HRTIM_ODISR_TC1ODIS    ((uint32_t)0x00000010)   /*!< Timer C Output 1 disable */
#define HRTIM_ODISR_TC2ODIS    ((uint32_t)0x00000020)   /*!< Timer C Output 2 disable */
#define HRTIM_ODISR_TD1ODIS    ((uint32_t)0x00000040)   /*!< Timer D Output 1 disable */
#define HRTIM_ODISR_TD2ODIS    ((uint32_t)0x00000080)   /*!< Timer D Output 2 disable */
#define HRTIM_ODISR_TE1ODIS    ((uint32_t)0x00000100)   /*!< Timer E Output 1 disable */
#define HRTIM_ODISR_TE2ODIS    ((uint32_t)0x00000200)   /*!< Timer E Output 2 disable */

/**** Bit definition for Common HRTIM Timer output disable status register *****/
#define HRTIM_ODSR_TA1ODS    ((uint32_t)0x00000001)   /*!< Timer A Output 1 disable status */
#define HRTIM_ODSR_TA2ODS    ((uint32_t)0x00000002)   /*!< Timer A Output 2 disable status */
#define HRTIM_ODSR_TB1ODS    ((uint32_t)0x00000004)   /*!< Timer B Output 1 disable status */
#define HRTIM_ODSR_TB2ODS    ((uint32_t)0x00000008)   /*!< Timer B Output 2 disable status */
#define HRTIM_ODSR_TC1ODS    ((uint32_t)0x00000010)   /*!< Timer C Output 1 disable status */
#define HRTIM_ODSR_TC2ODS    ((uint32_t)0x00000020)   /*!< Timer C Output 2 disable status */
#define HRTIM_ODSR_TD1ODS    ((uint32_t)0x00000040)   /*!< Timer D Output 1 disable status */
#define HRTIM_ODSR_TD2ODS    ((uint32_t)0x00000080)   /*!< Timer D Output 2 disable status */
#define HRTIM_ODSR_TE1ODS    ((uint32_t)0x00000100)   /*!< Timer E Output 1 disable status */
#define HRTIM_ODSR_TE2ODS    ((uint32_t)0x00000200)   /*!< Timer E Output 2 disable status */

/**** Bit definition for Common HRTIM Timer Burst mode control register ********/
#define HRTIM_BMCR_BME       ((uint32_t)0x00000001)    /*!< Burst mode enbale */
#define HRTIM_BMCR_BMOM      ((uint32_t)0x00000002)    /*!< Burst mode operating mode */
#define HRTIM_BMCR_BMCLK     ((uint32_t)0x0000003C)    /*!< Burst mode clock source */
#define HRTIM_BMCR_BMCLK_0   ((uint32_t)0x00000004)    /*!< Burst mode clock source bit 0 */
#define HRTIM_BMCR_BMCLK_1   ((uint32_t)0x00000008)    /*!< Burst mode clock source bit 1 */
#define HRTIM_BMCR_BMCLK_2   ((uint32_t)0x00000010)    /*!< Burst mode clock source bit 2 */
#define HRTIM_BMCR_BMCLK_3   ((uint32_t)0x00000020)    /*!< Burst mode clock source bit 3 */
#define HRTIM_BMCR_BMPRSC    ((uint32_t)0x000003C0)    /*!< Burst mode prescaler */
#define HRTIM_BMCR_BMPRSC_0  ((uint32_t)0x00000040)    /*!< Burst mode prescaler bit 0 */
#define HRTIM_BMCR_BMPRSC_1  ((uint32_t)0x00000080)    /*!< Burst mode prescaler bit 1 */
#define HRTIM_BMCR_BMPRSC_2  ((uint32_t)0x00000100)    /*!< Burst mode prescaler bit 2 */
#define HRTIM_BMCR_BMPRSC_3  ((uint32_t)0x00000200)    /*!< Burst mode prescaler bit 3 */
#define HRTIM_BMCR_BMPREN    ((uint32_t)0x00000400)    /*!< Burst mode Preload bit */
#define HRTIM_BMCR_MTBM      ((uint32_t)0x00010000)    /*!< Master Timer Burst mode */
#define HRTIM_BMCR_TABM      ((uint32_t)0x00020000)    /*!< Timer A Burst mode */
#define HRTIM_BMCR_TBBM      ((uint32_t)0x00040000)    /*!< Timer B Burst mode */
#define HRTIM_BMCR_TCBM      ((uint32_t)0x00080000)    /*!< Timer C Burst mode */
#define HRTIM_BMCR_TDBM      ((uint32_t)0x00100000)    /*!< Timer D Burst mode */
#define HRTIM_BMCR_TEBM      ((uint32_t)0x00200000)    /*!< Timer E Burst mode */
#define HRTIM_BMCR_BMSTAT    ((uint32_t)0x80000000)    /*!< Burst mode status */

/**** Bit definition for Common HRTIM Timer Burst mode Trigger register *******/
#define HRTIM_BMTRGR_SW       ((uint32_t)0x00000001)    /*!< Software start */
#define HRTIM_BMTRGR_MSTRST   ((uint32_t)0x00000002)    /*!<  Master reset */
#define HRTIM_BMTRGR_MSTREP   ((uint32_t)0x00000004)    /*!<  Master repetition */
#define HRTIM_BMTRGR_MSTCMP1  ((uint32_t)0x00000008)    /*!<  Master compare 1 */
#define HRTIM_BMTRGR_MSTCMP2  ((uint32_t)0x00000010)    /*!< Master compare 2  */
#define HRTIM_BMTRGR_MSTCMP3  ((uint32_t)0x00000020)    /*!< Master compare 3 */
#define HRTIM_BMTRGR_MSTCMP4  ((uint32_t)0x00000040)    /*!< Master compare 4 */
#define HRTIM_BMTRGR_TARST    ((uint32_t)0x00000080)    /*!< Timer A reset  */
#define HRTIM_BMTRGR_TAREP    ((uint32_t)0x00000100)    /*!< Timer A repetition  */
#define HRTIM_BMTRGR_TACMP1   ((uint32_t)0x00000200)    /*!< Timer A compare 1  */
#define HRTIM_BMTRGR_TACMP2   ((uint32_t)0x00000400)    /*!< Timer A compare 2  */
#define HRTIM_BMTRGR_TBRST    ((uint32_t)0x00000800)    /*!< Timer B reset  */
#define HRTIM_BMTRGR_TBREP    ((uint32_t)0x00001000)    /*!< Timer B repetition  */
#define HRTIM_BMTRGR_TBCMP1   ((uint32_t)0x00002000)    /*!< Timer B compare 1 */
#define HRTIM_BMTRGR_TBCMP2   ((uint32_t)0x00004000)    /*!< Timer B compare 2 */
#define HRTIM_BMTRGR_TCRST    ((uint32_t)0x00008000)    /*!< Timer C reset  */
#define HRTIM_BMTRGR_TCREP    ((uint32_t)0x00010000)    /*!< Timer C repetition */
#define HRTIM_BMTRGR_TCCMP1   ((uint32_t)0x00020000)    /*!< Timer C compare 1 */
#define HRTIM_BMTRGR_TCCMP2   ((uint32_t)0x00040000)    /*!< Timer C compare 2 */
#define HRTIM_BMTRGR_TDRST    ((uint32_t)0x00080000)    /*!< Timer D reset  */
#define HRTIM_BMTRGR_TDREP    ((uint32_t)0x00100000)    /*!< Timer D repetition  */
#define HRTIM_BMTRGR_TDCMP1   ((uint32_t)0x00200000)    /*!< Timer D compare 1 */
#define HRTIM_BMTRGR_TDCMP2   ((uint32_t)0x00400000)    /*!< Timer D compare 2 */
#define HRTIM_BMTRGR_TERST    ((uint32_t)0x00800000)    /*!< Timer E reset  */
#define HRTIM_BMTRGR_TEREP    ((uint32_t)0x01000000)    /*!< Timer E repetition  */
#define HRTIM_BMTRGR_TECMP1   ((uint32_t)0x02000000)    /*!< Timer E compare 1 */
#define HRTIM_BMTRGR_TECMP2   ((uint32_t)0x04000000)    /*!< Timer E compare 2 */
#define HRTIM_BMTRGR_TAEEV7   ((uint32_t)0x08000000)    /*!< Timer A period following External Event7  */
#define HRTIM_BMTRGR_TDEEV8   ((uint32_t)0x10000000)    /*!< Timer D period following External Event8  */
#define HRTIM_BMTRGR_EEV7     ((uint32_t)0x20000000)    /*!< External Event 7 */
#define HRTIM_BMTRGR_EEV8     ((uint32_t)0x40000000)    /*!< External Event 8 */
#define HRTIM_BMTRGR_OCHPEV   ((uint32_t)0x80000000)    /*!< on-chip Event */

/*******************  Bit definition for HRTIM_BMCMPR register  ***************/
#define  HRTIM_BMCMPR_BMCMPR     ((uint32_t)0x0000FFFF)     /*!<!<Burst Compare Value */

/*******************  Bit definition for HRTIM_BMPER register  ****************/
#define  HRTIM_BMPER_BMPER     ((uint32_t)0x0000FFFF)     /*!<!<Burst period Value */

/*******************  Bit definition for HRTIM_EECR1 register  ****************/
#define HRTIM_EECR1_EE1SRC    ((uint32_t)0x00000003)    /*!< External event 1 source */
#define HRTIM_EECR1_EE1SRC_0  ((uint32_t)0x00000001)    /*!< External event 1 source bit 0 */
#define HRTIM_EECR1_EE1SRC_1  ((uint32_t)0x00000002)    /*!< External event 1 source bit 1 */
#define HRTIM_EECR1_EE1POL    ((uint32_t)0x00000004)    /*!< External event 1 Polarity */
#define HRTIM_EECR1_EE1SNS    ((uint32_t)0x00000018)    /*!< External event 1 sensitivity */
#define HRTIM_EECR1_EE1SNS_0  ((uint32_t)0x00000008)    /*!< External event 1 sensitivity bit 0 */
#define HRTIM_EECR1_EE1SNS_1  ((uint32_t)0x00000010)    /*!< External event 1 sensitivity bit 1 */
#define HRTIM_EECR1_EE1FAST   ((uint32_t)0x00000020)    /*!< External event 1 Fast mode */

#define HRTIM_EECR1_EE2SRC    ((uint32_t)0x000000C0)    /*!< External event 2 source */
#define HRTIM_EECR1_EE2SRC_0  ((uint32_t)0x00000040)    /*!< External event 2 source bit 0 */
#define HRTIM_EECR1_EE2SRC_1  ((uint32_t)0x00000080)    /*!< External event 2 source bit 1 */
#define HRTIM_EECR1_EE2POL    ((uint32_t)0x00000100)    /*!< External event 2 Polarity */
#define HRTIM_EECR1_EE2SNS    ((uint32_t)0x00000600)    /*!< External event 2 sensitivity */
#define HRTIM_EECR1_EE2SNS_0  ((uint32_t)0x00000200)    /*!< External event 2 sensitivity bit 0 */
#define HRTIM_EECR1_EE2SNS_1  ((uint32_t)0x00000400)    /*!< External event 2 sensitivity bit 1 */
#define HRTIM_EECR1_EE2FAST   ((uint32_t)0x00000800)    /*!< External event 2 Fast mode */

#define HRTIM_EECR1_EE3SRC    ((uint32_t)0x00003000)    /*!< External event 3 source */
#define HRTIM_EECR1_EE3SRC_0  ((uint32_t)0x00001000)    /*!< External event 3 source bit 0 */
#define HRTIM_EECR1_EE3SRC_1  ((uint32_t)0x00002000)    /*!< External event 3 source bit 1 */
#define HRTIM_EECR1_EE3POL    ((uint32_t)0x00004000)    /*!< External event 3 Polarity */
#define HRTIM_EECR1_EE3SNS    ((uint32_t)0x00018000)    /*!< External event 3 sensitivity */
#define HRTIM_EECR1_EE3SNS_0  ((uint32_t)0x00008000)    /*!< External event 3 sensitivity bit 0 */
#define HRTIM_EECR1_EE3SNS_1  ((uint32_t)0x00010000)    /*!< External event 3 sensitivity bit 1 */
#define HRTIM_EECR1_EE3FAST   ((uint32_t)0x00020000)    /*!< External event 3 Fast mode */

#define HRTIM_EECR1_EE4SRC    ((uint32_t)0x000C0000)    /*!< External event 4 source */
#define HRTIM_EECR1_EE4SRC_0  ((uint32_t)0x00040000)    /*!< External event 4 source bit 0 */
#define HRTIM_EECR1_EE4SRC_1  ((uint32_t)0x00080000)    /*!< External event 4 source bit 1 */
#define HRTIM_EECR1_EE4POL    ((uint32_t)0x00100000)    /*!< External event 4 Polarity */
#define HRTIM_EECR1_EE4SNS    ((uint32_t)0x00600000)    /*!< External event 4 sensitivity */
#define HRTIM_EECR1_EE4SNS_0  ((uint32_t)0x00200000)    /*!< External event 4 sensitivity bit 0 */
#define HRTIM_EECR1_EE4SNS_1  ((uint32_t)0x00400000)    /*!< External event 4 sensitivity bit 1 */
#define HRTIM_EECR1_EE4FAST   ((uint32_t)0x00800000)    /*!< External event 4 Fast mode */

#define HRTIM_EECR1_EE5SRC    ((uint32_t)0x03000000)    /*!< External event 5 source */
#define HRTIM_EECR1_EE5SRC_0  ((uint32_t)0x01000000)    /*!< External event 5 source bit 0 */
#define HRTIM_EECR1_EE5SRC_1  ((uint32_t)0x02000000)    /*!< External event 5 source bit 1 */
#define HRTIM_EECR1_EE5POL    ((uint32_t)0x04000000)    /*!< External event 5 Polarity */
#define HRTIM_EECR1_EE5SNS    ((uint32_t)0x18000000)    /*!< External event 5 sensitivity */
#define HRTIM_EECR1_EE5SNS_0  ((uint32_t)0x08000000)    /*!< External event 5 sensitivity bit 0 */
#define HRTIM_EECR1_EE5SNS_1  ((uint32_t)0x10000000)    /*!< External event 5 sensitivity bit 1 */
#define HRTIM_EECR1_EE5FAST   ((uint32_t)0x20000000)    /*!< External event 5 Fast mode */

/*******************  Bit definition for HRTIM_EECR2 register  ****************/
#define HRTIM_EECR2_EE6SRC    ((uint32_t)0x00000003)    /*!< External event 6 source */
#define HRTIM_EECR2_EE6SRC_0  ((uint32_t)0x00000001)    /*!< External event 6 source bit 0 */
#define HRTIM_EECR2_EE6SRC_1  ((uint32_t)0x00000002)    /*!< External event 6 source bit 1 */
#define HRTIM_EECR2_EE6POL    ((uint32_t)0x00000004)    /*!< External event 6 Polarity */
#define HRTIM_EECR2_EE6SNS    ((uint32_t)0x00000018)    /*!< External event 6 sensitivity */
#define HRTIM_EECR2_EE6SNS_0  ((uint32_t)0x00000008)    /*!< External event 6 sensitivity bit 0 */
#define HRTIM_EECR2_EE6SNS_1  ((uint32_t)0x00000010)    /*!< External event 6 sensitivity bit 1 */

#define HRTIM_EECR2_EE7SRC    ((uint32_t)0x000000C0)    /*!< External event 7 source */
#define HRTIM_EECR2_EE7SRC_0  ((uint32_t)0x00000040)    /*!< External event 7 source bit 0 */
#define HRTIM_EECR2_EE7SRC_1  ((uint32_t)0x00000080)    /*!< External event 7 source bit 1 */
#define HRTIM_EECR2_EE7POL    ((uint32_t)0x00000100)    /*!< External event 7 Polarity */
#define HRTIM_EECR2_EE7SNS    ((uint32_t)0x00000600)    /*!< External event 7 sensitivity */
#define HRTIM_EECR2_EE7SNS_0  ((uint32_t)0x00000200)    /*!< External event 7 sensitivity bit 0 */
#define HRTIM_EECR2_EE7SNS_1  ((uint32_t)0x00000400)    /*!< External event 7 sensitivity bit 1 */

#define HRTIM_EECR2_EE8SRC    ((uint32_t)0x00003000)    /*!< External event 8 source */
#define HRTIM_EECR2_EE8SRC_0  ((uint32_t)0x00001000)    /*!< External event 8 source bit 0 */
#define HRTIM_EECR2_EE8SRC_1  ((uint32_t)0x00002000)    /*!< External event 8 source bit 1 */
#define HRTIM_EECR2_EE8POL    ((uint32_t)0x00004000)    /*!< External event 8 Polarity */
#define HRTIM_EECR2_EE8SNS    ((uint32_t)0x00018000)    /*!< External event 8 sensitivity */
#define HRTIM_EECR2_EE8SNS_0  ((uint32_t)0x00008000)    /*!< External event 8 sensitivity bit 0 */
#define HRTIM_EECR2_EE8SNS_1  ((uint32_t)0x00010000)    /*!< External event 8 sensitivity bit 1 */

#define HRTIM_EECR2_EE9SRC    ((uint32_t)0x000C0000)    /*!< External event 9 source */
#define HRTIM_EECR2_EE9SRC_0  ((uint32_t)0x00040000)    /*!< External event 9 source bit 0 */
#define HRTIM_EECR2_EE9SRC_1  ((uint32_t)0x00080000)    /*!< External event 9 source bit 1 */
#define HRTIM_EECR2_EE9POL    ((uint32_t)0x00100000)    /*!< External event 9 Polarity */
#define HRTIM_EECR2_EE9SNS    ((uint32_t)0x00600000)    /*!< External event 9 sensitivity */
#define HRTIM_EECR2_EE9SNS_0  ((uint32_t)0x00200000)    /*!< External event 9 sensitivity bit 0 */
#define HRTIM_EECR2_EE9SNS_1  ((uint32_t)0x00400000)    /*!< External event 9 sensitivity bit 1 */

#define HRTIM_EECR2_EE10SRC    ((uint32_t)0x03000000)    /*!< External event 10 source */
#define HRTIM_EECR2_EE10SRC_0  ((uint32_t)0x01000000)    /*!< External event 10 source bit 0 */
#define HRTIM_EECR2_EE10SRC_1  ((uint32_t)0x02000000)    /*!< External event 10 source bit 1 */
#define HRTIM_EECR2_EE10POL    ((uint32_t)0x04000000)    /*!< External event 10 Polarity */
#define HRTIM_EECR2_EE10SNS    ((uint32_t)0x18000000)    /*!< External event 10 sensitivity */
#define HRTIM_EECR2_EE10SNS_0  ((uint32_t)0x08000000)    /*!< External event 10 sensitivity bit 0 */
#define HRTIM_EECR2_EE10SNS_1  ((uint32_t)0x10000000)    /*!< External event 10 sensitivity bit 1 */

/*******************  Bit definition for HRTIM_EECR3 register  ****************/
#define HRTIM_EECR3_EE6F    ((uint32_t)0x0000000F)    /*!< External event 6 filter */
#define HRTIM_EECR3_EE6F_0  ((uint32_t)0x00000001)    /*!< External event 6 filter bit 0 */
#define HRTIM_EECR3_EE6F_1  ((uint32_t)0x00000002)    /*!< External event 6 filter bit 1  */
#define HRTIM_EECR3_EE6F_2  ((uint32_t)0x00000004)    /*!< External event 6 filter bit 2   */
#define HRTIM_EECR3_EE6F_3  ((uint32_t)0x00000008)    /*!< External event 6 filter bit 3   */
#define HRTIM_EECR3_EE7F    ((uint32_t)0x000003C0)    /*!< External event 7 filter */
#define HRTIM_EECR3_EE7F_0  ((uint32_t)0x00000040)    /*!< External event 7 filter bit 0  */
#define HRTIM_EECR3_EE7F_1  ((uint32_t)0x00000080)    /*!< External event 7 filter bit 1  */
#define HRTIM_EECR3_EE7F_2  ((uint32_t)0x00000100)    /*!< External event 7 filter bit 2  */
#define HRTIM_EECR3_EE7F_3  ((uint32_t)0x00000200)    /*!< External event 7 filter bit 3  */
#define HRTIM_EECR3_EE8F    ((uint32_t)0x0000F000)    /*!< External event 8 filter */
#define HRTIM_EECR3_EE8F_0  ((uint32_t)0x00001000)    /*!< External event 8 filter bit 0 */
#define HRTIM_EECR3_EE8F_1  ((uint32_t)0x00002000)    /*!< External event 8 filter bit 1 */
#define HRTIM_EECR3_EE8F_2  ((uint32_t)0x00004000)    /*!< External event 8 filter bit 2 */
#define HRTIM_EECR3_EE8F_3  ((uint32_t)0x00008000)    /*!< External event 8 filter bit 3 */
#define HRTIM_EECR3_EE9F    ((uint32_t)0x003C0000)    /*!< External event 9 filter */
#define HRTIM_EECR3_EE9F_0  ((uint32_t)0x00040000)    /*!< External event 9 filter bit 0 */
#define HRTIM_EECR3_EE9F_1  ((uint32_t)0x00080000)    /*!< External event 9 filter bit 1 */
#define HRTIM_EECR3_EE9F_2  ((uint32_t)0x00100000)    /*!< External event 9 filter bit 2 */
#define HRTIM_EECR3_EE9F_3  ((uint32_t)0x00200000)    /*!< External event 9 filter bit 3 */
#define HRTIM_EECR3_EE10F   ((uint32_t)0x0F000000)    /*!< External event 10 filter */
#define HRTIM_EECR3_EE10F_0 ((uint32_t)0x01000000)    /*!< External event 10 filter bit 0 */
#define HRTIM_EECR3_EE10F_1 ((uint32_t)0x02000000)    /*!< External event 10 filter bit 1 */
#define HRTIM_EECR3_EE10F_2 ((uint32_t)0x04000000)    /*!< External event 10 filter bit 2 */
#define HRTIM_EECR3_EE10F_3 ((uint32_t)0x08000000)    /*!< External event 10 filter bit 3 */
#define HRTIM_EECR3_EEVSD   ((uint32_t)0xC0000000)    /*!< External event sampling clock division */
#define HRTIM_EECR3_EEVSD_0 ((uint32_t)0x40000000)    /*!< External event sampling clock division bit 0 */
#define HRTIM_EECR3_EEVSD_1 ((uint32_t)0x80000000)    /*!< External event sampling clock division bit 1 */

/*******************  Bit definition for HRTIM_ADC1R register  ****************/
#define HRTIM_ADC1R_AD1MC1     ((uint32_t)0x00000001)    /*!< ADC Trigger 1 on master compare 1 */
#define HRTIM_ADC1R_AD1MC2     ((uint32_t)0x00000002)    /*!< ADC Trigger 1 on master compare 2 */
#define HRTIM_ADC1R_AD1MC3     ((uint32_t)0x00000004)    /*!< ADC Trigger 1 on master compare 3 */
#define HRTIM_ADC1R_AD1MC4     ((uint32_t)0x00000008)    /*!< ADC Trigger 1 on master compare 4 */
#define HRTIM_ADC1R_AD1MPER    ((uint32_t)0x00000010)    /*!< ADC Trigger 1 on master period */
#define HRTIM_ADC1R_AD1EEV1    ((uint32_t)0x00000020)    /*!< ADC Trigger 1 on external event 1 */
#define HRTIM_ADC1R_AD1EEV2    ((uint32_t)0x00000040)    /*!< ADC Trigger 1 on external event 2 */
#define HRTIM_ADC1R_AD1EEV3    ((uint32_t)0x00000080)    /*!< ADC Trigger 1 on external event 3 */
#define HRTIM_ADC1R_AD1EEV4    ((uint32_t)0x00000100)    /*!< ADC Trigger 1 on external event 4 */
#define HRTIM_ADC1R_AD1EEV5    ((uint32_t)0x00000200)    /*!< ADC Trigger 1 on external event 5 */
#define HRTIM_ADC1R_AD1TAC2    ((uint32_t)0x00000400)    /*!< ADC Trigger 1 on Timer A compare 2 */
#define HRTIM_ADC1R_AD1TAC3    ((uint32_t)0x00000800)    /*!< ADC Trigger 1 on Timer A compare 3 */
#define HRTIM_ADC1R_AD1TAC4    ((uint32_t)0x00001000)    /*!< ADC Trigger 1 on Timer A compare 4 */
#define HRTIM_ADC1R_AD1TAPER   ((uint32_t)0x00002000)    /*!< ADC Trigger 1 on Timer A period */
#define HRTIM_ADC1R_AD1TARST   ((uint32_t)0x00004000)    /*!< ADC Trigger 1 on Timer A reset */
#define HRTIM_ADC1R_AD1TBC2    ((uint32_t)0x00008000)    /*!< ADC Trigger 1 on Timer B compare 2 */
#define HRTIM_ADC1R_AD1TBC3    ((uint32_t)0x00010000)    /*!< ADC Trigger 1 on Timer B compare 3 */
#define HRTIM_ADC1R_AD1TBC4    ((uint32_t)0x00020000)    /*!< ADC Trigger 1 on Timer B compare 4 */
#define HRTIM_ADC1R_AD1TBPER   ((uint32_t)0x00040000)    /*!< ADC Trigger 1 on Timer B period */
#define HRTIM_ADC1R_AD1TBRST   ((uint32_t)0x00080000)    /*!< ADC Trigger 1 on Timer B reset */
#define HRTIM_ADC1R_AD1TCC2    ((uint32_t)0x00100000)    /*!< ADC Trigger 1 on Timer C compare 2 */
#define HRTIM_ADC1R_AD1TCC3    ((uint32_t)0x00200000)    /*!< ADC Trigger 1 on Timer C compare 3 */
#define HRTIM_ADC1R_AD1TCC4    ((uint32_t)0x00400000)    /*!< ADC Trigger 1 on Timer C compare 4 */
#define HRTIM_ADC1R_AD1TCPER   ((uint32_t)0x00800000)    /*!< ADC Trigger 1 on Timer C period */
#define HRTIM_ADC1R_AD1TDC2    ((uint32_t)0x01000000)    /*!< ADC Trigger 1 on Timer D compare 2 */
#define HRTIM_ADC1R_AD1TDC3    ((uint32_t)0x02000000)    /*!< ADC Trigger 1 on Timer D compare 3 */
#define HRTIM_ADC1R_AD1TDC4    ((uint32_t)0x04000000)    /*!< ADC Trigger 1 on Timer D compare 4 */
#define HRTIM_ADC1R_AD1TDPER   ((uint32_t)0x08000000)    /*!< ADC Trigger 1 on Timer D period */
#define HRTIM_ADC1R_AD1TEC2    ((uint32_t)0x10000000)    /*!< ADC Trigger 1 on Timer E compare 2 */
#define HRTIM_ADC1R_AD1TEC3    ((uint32_t)0x20000000)    /*!< ADC Trigger 1 on Timer E compare 3 */
#define HRTIM_ADC1R_AD1TEC4    ((uint32_t)0x40000000)    /*!< ADC Trigger 1 on Timer E compare 4 */
#define HRTIM_ADC1R_AD1TEPER   ((uint32_t)0x80000000)    /*!< ADC Trigger 1 on Timer E period */

/*******************  Bit definition for HRTIM_ADC2R register  ****************/
#define HRTIM_ADC2R_AD2MC1      ((uint32_t)0x00000001)    /*!< ADC Trigger 2 on master compare 1 */
#define HRTIM_ADC2R_AD2MC2      ((uint32_t)0x00000002)    /*!< ADC Trigger 2 on master compare 2 */
#define HRTIM_ADC2R_AD2MC3      ((uint32_t)0x00000004)    /*!< ADC Trigger 2 on master compare 3 */
#define HRTIM_ADC2R_AD2MC4      ((uint32_t)0x00000008)    /*!< ADC Trigger 2 on master compare 4 */
#define HRTIM_ADC2R_AD2MPER     ((uint32_t)0x00000010)    /*!< ADC Trigger 2 on master period */
#define HRTIM_ADC2R_AD2EEV6     ((uint32_t)0x00000020)    /*!< ADC Trigger 2 on external event 6 */
#define HRTIM_ADC2R_AD2EEV7     ((uint32_t)0x00000040)    /*!< ADC Trigger 2 on external event 7 */
#define HRTIM_ADC2R_AD2EEV8     ((uint32_t)0x00000080)    /*!< ADC Trigger 2 on external event 8 */
#define HRTIM_ADC2R_AD2EEV9     ((uint32_t)0x00000100)    /*!< ADC Trigger 2 on external event 9 */
#define HRTIM_ADC2R_AD2EEV10    ((uint32_t)0x00000200)    /*!< ADC Trigger 2 on external event 10 */
#define HRTIM_ADC2R_AD2TAC2     ((uint32_t)0x00000400)    /*!< ADC Trigger 2 on Timer A compare 2 */
#define HRTIM_ADC2R_AD2TAC3     ((uint32_t)0x00000800)    /*!< ADC Trigger 2 on Timer A compare 3 */
#define HRTIM_ADC2R_AD2TAC4     ((uint32_t)0x00001000)    /*!< ADC Trigger 2 on Timer A compare 4*/
#define HRTIM_ADC2R_AD2TAPER    ((uint32_t)0x00002000)    /*!< ADC Trigger 2 on Timer A period */
#define HRTIM_ADC2R_AD2TBC2     ((uint32_t)0x00004000)    /*!< ADC Trigger 2 on Timer B compare 2 */
#define HRTIM_ADC2R_AD2TBC3     ((uint32_t)0x00008000)    /*!< ADC Trigger 2 on Timer B compare 3 */
#define HRTIM_ADC2R_AD2TBC4     ((uint32_t)0x00010000)    /*!< ADC Trigger 2 on Timer B compare 4 */
#define HRTIM_ADC2R_AD2TBPER    ((uint32_t)0x00020000)    /*!< ADC Trigger 2 on Timer B period */
#define HRTIM_ADC2R_AD2TCC2     ((uint32_t)0x00040000)    /*!< ADC Trigger 2 on Timer C compare 2 */
#define HRTIM_ADC2R_AD2TCC3     ((uint32_t)0x00080000)    /*!< ADC Trigger 2 on Timer C compare 3 */
#define HRTIM_ADC2R_AD2TCC4     ((uint32_t)0x00100000)    /*!< ADC Trigger 2 on Timer C compare 4 */
#define HRTIM_ADC2R_AD2TCPER    ((uint32_t)0x00200000)    /*!< ADC Trigger 2 on Timer C period */
#define HRTIM_ADC2R_AD2TCRST    ((uint32_t)0x00400000)    /*!< ADC Trigger 2 on Timer C reset */
#define HRTIM_ADC2R_AD2TDC2     ((uint32_t)0x00800000)    /*!< ADC Trigger 2 on Timer D compare 2 */
#define HRTIM_ADC2R_AD2TDC3     ((uint32_t)0x01000000)    /*!< ADC Trigger 2 on Timer D compare 3 */
#define HRTIM_ADC2R_AD2TDC4     ((uint32_t)0x02000000)    /*!< ADC Trigger 2 on Timer D compare 4*/
#define HRTIM_ADC2R_AD2TDPER    ((uint32_t)0x04000000)    /*!< ADC Trigger 2 on Timer D period */
#define HRTIM_ADC2R_AD2TDRST    ((uint32_t)0x08000000)    /*!< ADC Trigger 2 on Timer D reset */
#define HRTIM_ADC2R_AD2TEC2     ((uint32_t)0x10000000)    /*!< ADC Trigger 2 on Timer E compare 2 */
#define HRTIM_ADC2R_AD2TEC3     ((uint32_t)0x20000000)    /*!< ADC Trigger 2 on Timer E compare 3 */
#define HRTIM_ADC2R_AD2TEC4     ((uint32_t)0x40000000)    /*!< ADC Trigger 2 on Timer E compare 4 */
#define HRTIM_ADC2R_AD2TERST    ((uint32_t)0x80000000)    /*!< ADC Trigger 2 on Timer E reset */

/*******************  Bit definition for HRTIM_ADC3R register  ****************/
#define HRTIM_ADC3R_AD3MC1     ((uint32_t)0x00000001)    /*!< ADC Trigger 3 on master compare 1 */
#define HRTIM_ADC3R_AD3MC2     ((uint32_t)0x00000002)    /*!< ADC Trigger 3 on master compare 2 */
#define HRTIM_ADC3R_AD3MC3     ((uint32_t)0x00000004)    /*!< ADC Trigger 3 on master compare 3 */
#define HRTIM_ADC3R_AD3MC4     ((uint32_t)0x00000008)    /*!< ADC Trigger 3 on master compare 4 */
#define HRTIM_ADC3R_AD3MPER    ((uint32_t)0x00000010)    /*!< ADC Trigger 3 on master period */
#define HRTIM_ADC3R_AD3EEV1    ((uint32_t)0x00000020)    /*!< ADC Trigger 3 on external event 1 */
#define HRTIM_ADC3R_AD3EEV2    ((uint32_t)0x00000040)    /*!< ADC Trigger 3 on external event 2 */
#define HRTIM_ADC3R_AD3EEV3    ((uint32_t)0x00000080)    /*!< ADC Trigger 3 on external event 3 */
#define HRTIM_ADC3R_AD3EEV4    ((uint32_t)0x00000100)    /*!< ADC Trigger 3 on external event 4 */
#define HRTIM_ADC3R_AD3EEV5    ((uint32_t)0x00000200)    /*!< ADC Trigger 3 on external event 5 */
#define HRTIM_ADC3R_AD3TAC2    ((uint32_t)0x00000400)    /*!< ADC Trigger 3 on Timer A compare 2 */
#define HRTIM_ADC3R_AD3TAC3    ((uint32_t)0x00000800)    /*!< ADC Trigger 3 on Timer A compare 3 */
#define HRTIM_ADC3R_AD3TAC4    ((uint32_t)0x00001000)    /*!< ADC Trigger 3 on Timer A compare 4 */
#define HRTIM_ADC3R_AD3TAPER   ((uint32_t)0x00002000)    /*!< ADC Trigger 3 on Timer A period */
#define HRTIM_ADC3R_AD3TARST   ((uint32_t)0x00004000)    /*!< ADC Trigger 3 on Timer A reset */
#define HRTIM_ADC3R_AD3TBC2    ((uint32_t)0x00008000)    /*!< ADC Trigger 3 on Timer B compare 2 */
#define HRTIM_ADC3R_AD3TBC3    ((uint32_t)0x00010000)    /*!< ADC Trigger 3 on Timer B compare 3 */
#define HRTIM_ADC3R_AD3TBC4    ((uint32_t)0x00020000)    /*!< ADC Trigger 3 on Timer B compare 4 */
#define HRTIM_ADC3R_AD3TBPER   ((uint32_t)0x00040000)    /*!< ADC Trigger 3 on Timer B period */
#define HRTIM_ADC3R_AD3TBRST   ((uint32_t)0x00080000)    /*!< ADC Trigger 3 on Timer B reset */
#define HRTIM_ADC3R_AD3TCC2    ((uint32_t)0x00100000)    /*!< ADC Trigger 3 on Timer C compare 2 */
#define HRTIM_ADC3R_AD3TCC3    ((uint32_t)0x00200000)    /*!< ADC Trigger 3 on Timer C compare 3 */
#define HRTIM_ADC3R_AD3TCC4    ((uint32_t)0x00400000)    /*!< ADC Trigger 3 on Timer C compare 4 */
#define HRTIM_ADC3R_AD3TCPER   ((uint32_t)0x00800000)    /*!< ADC Trigger 3 on Timer C period */
#define HRTIM_ADC3R_AD3TDC2    ((uint32_t)0x01000000)    /*!< ADC Trigger 3 on Timer D compare 2 */
#define HRTIM_ADC3R_AD3TDC3    ((uint32_t)0x02000000)    /*!< ADC Trigger 3 on Timer D compare 3 */
#define HRTIM_ADC3R_AD3TDC4    ((uint32_t)0x04000000)    /*!< ADC Trigger 3 on Timer D compare 4 */
#define HRTIM_ADC3R_AD3TDPER   ((uint32_t)0x08000000)    /*!< ADC Trigger 3 on Timer D period */
#define HRTIM_ADC3R_AD3TEC2    ((uint32_t)0x10000000)    /*!< ADC Trigger 3 on Timer E compare 2 */
#define HRTIM_ADC3R_AD3TEC3    ((uint32_t)0x20000000)    /*!< ADC Trigger 3 on Timer E compare 3 */
#define HRTIM_ADC3R_AD3TEC4    ((uint32_t)0x40000000)    /*!< ADC Trigger 3 on Timer E compare 4 */
#define HRTIM_ADC3R_AD3TEPER   ((uint32_t)0x80000000)    /*!< ADC Trigger 3 on Timer E period */

/*******************  Bit definition for HRTIM_ADC4R register  ****************/
#define HRTIM_ADC4R_AD4MC1      ((uint32_t)0x00000001)    /*!< ADC Trigger 4 on master compare 1 */
#define HRTIM_ADC4R_AD4MC2      ((uint32_t)0x00000002)    /*!< ADC Trigger 4 on master compare 2 */
#define HRTIM_ADC4R_AD4MC3      ((uint32_t)0x00000004)    /*!< ADC Trigger 4 on master compare 3 */
#define HRTIM_ADC4R_AD4MC4      ((uint32_t)0x00000008)    /*!< ADC Trigger 4 on master compare 4 */
#define HRTIM_ADC4R_AD4MPER     ((uint32_t)0x00000010)    /*!< ADC Trigger 4 on master period */
#define HRTIM_ADC4R_AD4EEV6     ((uint32_t)0x00000020)    /*!< ADC Trigger 4 on external event 6 */
#define HRTIM_ADC4R_AD4EEV7     ((uint32_t)0x00000040)    /*!< ADC Trigger 4 on external event 7 */
#define HRTIM_ADC4R_AD4EEV8     ((uint32_t)0x00000080)    /*!< ADC Trigger 4 on external event 8 */
#define HRTIM_ADC4R_AD4EEV9     ((uint32_t)0x00000100)    /*!< ADC Trigger 4 on external event 9 */
#define HRTIM_ADC4R_AD4EEV10    ((uint32_t)0x00000200)    /*!< ADC Trigger 4 on external event 10 */
#define HRTIM_ADC4R_AD4TAC2     ((uint32_t)0x00000400)    /*!< ADC Trigger 4 on Timer A compare 2 */
#define HRTIM_ADC4R_AD4TAC3     ((uint32_t)0x00000800)    /*!< ADC Trigger 4 on Timer A compare 3 */
#define HRTIM_ADC4R_AD4TAC4     ((uint32_t)0x00001000)    /*!< ADC Trigger 4 on Timer A compare 4*/
#define HRTIM_ADC4R_AD4TAPER    ((uint32_t)0x00002000)    /*!< ADC Trigger 4 on Timer A period */
#define HRTIM_ADC4R_AD4TBC2     ((uint32_t)0x00004000)    /*!< ADC Trigger 4 on Timer B compare 2 */
#define HRTIM_ADC4R_AD4TBC3     ((uint32_t)0x00008000)    /*!< ADC Trigger 4 on Timer B compare 3 */
#define HRTIM_ADC4R_AD4TBC4     ((uint32_t)0x00010000)    /*!< ADC Trigger 4 on Timer B compare 4 */
#define HRTIM_ADC4R_AD4TBPER    ((uint32_t)0x00020000)    /*!< ADC Trigger 4 on Timer B period */
#define HRTIM_ADC4R_AD4TCC2     ((uint32_t)0x00040000)    /*!< ADC Trigger 4 on Timer C compare 2 */
#define HRTIM_ADC4R_AD4TCC3     ((uint32_t)0x00080000)    /*!< ADC Trigger 4 on Timer C compare 3 */
#define HRTIM_ADC4R_AD4TCC4     ((uint32_t)0x00100000)    /*!< ADC Trigger 4 on Timer C compare 4 */
#define HRTIM_ADC4R_AD4TCPER    ((uint32_t)0x00200000)    /*!< ADC Trigger 4 on Timer C period */
#define HRTIM_ADC4R_AD4TCRST    ((uint32_t)0x00400000)    /*!< ADC Trigger 4 on Timer C reset */
#define HRTIM_ADC4R_AD4TDC2     ((uint32_t)0x00800000)    /*!< ADC Trigger 4 on Timer D compare 2 */
#define HRTIM_ADC4R_AD4TDC3     ((uint32_t)0x01000000)    /*!< ADC Trigger 4 on Timer D compare 3 */
#define HRTIM_ADC4R_AD4TDC4     ((uint32_t)0x02000000)    /*!< ADC Trigger 4 on Timer D compare 4*/
#define HRTIM_ADC4R_AD4TDPER    ((uint32_t)0x04000000)    /*!< ADC Trigger 4 on Timer D period */
#define HRTIM_ADC4R_AD4TDRST    ((uint32_t)0x08000000)    /*!< ADC Trigger 4 on Timer D reset */
#define HRTIM_ADC4R_AD4TEC2     ((uint32_t)0x10000000)    /*!< ADC Trigger 4 on Timer E compare 2 */
#define HRTIM_ADC4R_AD4TEC3     ((uint32_t)0x20000000)    /*!< ADC Trigger 4 on Timer E compare 3 */
#define HRTIM_ADC4R_AD4TEC4     ((uint32_t)0x40000000)    /*!< ADC Trigger 4 on Timer E compare 4 */
#define HRTIM_ADC4R_AD4TERST    ((uint32_t)0x80000000)    /*!< ADC Trigger 4 on Timer E reset */

/*******************  Bit definition for HRTIM_DLLCR register  ****************/
#define HRTIM_DLLCR_CAL         ((uint32_t)0x00000001)    /*!< DLL calibration start */ 
#define HRTIM_DLLCR_CALEN       ((uint32_t)0x00000002)    /*!< DLL calibration enable */  
#define HRTIM_DLLCR_CALRTE      ((uint32_t)0x0000000C)    /*!< DLL calibration rate */
#define HRTIM_DLLCR_CALRTE_0    ((uint32_t)0x00000004)    /*!< DLL calibration rate bit 0 */
#define HRTIM_DLLCR_CALRTE_1    ((uint32_t)0x00000008)    /*!< DLL calibration rate bit 1 */  

/*******************  Bit definition for HRTIM_FLTINR1 register  ***************/  
#define HRTIM_FLTINR1_FLT1E      ((uint32_t)0x00000001)    /*!< Fault 1 enable */ 
#define HRTIM_FLTINR1_FLT1P      ((uint32_t)0x00000002)    /*!< Fault 1 polarity */
#define HRTIM_FLTINR1_FLT1SRC    ((uint32_t)0x00000004)    /*!< Fault 1 source */
#define HRTIM_FLTINR1_FLT1F      ((uint32_t)0x00000078)    /*!< Fault 1 filter */
#define HRTIM_FLTINR1_FLT1F_0    ((uint32_t)0x00000008)    /*!< Fault 1 filter bit 0 */
#define HRTIM_FLTINR1_FLT1F_1    ((uint32_t)0x00000010)    /*!< Fault 1 filter bit 1 */
#define HRTIM_FLTINR1_FLT1F_2    ((uint32_t)0x00000020)    /*!< Fault 1 filter bit 2 */
#define HRTIM_FLTINR1_FLT1F_3    ((uint32_t)0x00000040)    /*!< Fault 1 filter bit 3 */
#define HRTIM_FLTINR1_FLT1LCK    ((uint32_t)0x00000080)    /*!< Fault 1 lock */ 

#define HRTIM_FLTINR1_FLT2E      ((uint32_t)0x00000100)    /*!< Fault 2 enable */ 
#define HRTIM_FLTINR1_FLT2P      ((uint32_t)0x00000200)    /*!< Fault 2 polarity */
#define HRTIM_FLTINR1_FLT2SRC    ((uint32_t)0x00000400)    /*!< Fault 2 source */
#define HRTIM_FLTINR1_FLT2F      ((uint32_t)0x00007800)    /*!< Fault 2 filter */
#define HRTIM_FLTINR1_FLT2F_0    ((uint32_t)0x00000800)    /*!< Fault 2 filter bit 0 */
#define HRTIM_FLTINR1_FLT2F_1    ((uint32_t)0x00001000)    /*!< Fault 2 filter bit 1 */
#define HRTIM_FLTINR1_FLT2F_2    ((uint32_t)0x00002000)    /*!< Fault 2 filter bit 2 */
#define HRTIM_FLTINR1_FLT2F_3    ((uint32_t)0x00004000)    /*!< Fault 2 filter bit 3 */
#define HRTIM_FLTINR1_FLT2LCK    ((uint32_t)0x00008000)    /*!< Fault 2 lock */ 

#define HRTIM_FLTINR1_FLT3E      ((uint32_t)0x00010000)    /*!< Fault 3 enable */ 
#define HRTIM_FLTINR1_FLT3P      ((uint32_t)0x00020000)    /*!< Fault 3 polarity */
#define HRTIM_FLTINR1_FLT3SRC    ((uint32_t)0x00040000)    /*!< Fault 3 source */
#define HRTIM_FLTINR1_FLT3F      ((uint32_t)0x00780000)    /*!< Fault 3 filter */
#define HRTIM_FLTINR1_FLT3F_0    ((uint32_t)0x00080000)    /*!< Fault 3 filter bit 0 */
#define HRTIM_FLTINR1_FLT3F_1    ((uint32_t)0x00100000)    /*!< Fault 3 filter bit 1 */
#define HRTIM_FLTINR1_FLT3F_2    ((uint32_t)0x00200000)    /*!< Fault 3 filter bit 2 */
#define HRTIM_FLTINR1_FLT3F_3    ((uint32_t)0x00400000)    /*!< Fault 3 filter bit 3 */
#define HRTIM_FLTINR1_FLT3LCK    ((uint32_t)0x00800000)    /*!< Fault 3 lock */ 

#define HRTIM_FLTINR1_FLT4E      ((uint32_t)0x01000000)    /*!< Fault 4 enable */ 
#define HRTIM_FLTINR1_FLT4P      ((uint32_t)0x02000000)    /*!< Fault 4 polarity */
#define HRTIM_FLTINR1_FLT4SRC    ((uint32_t)0x04000000)    /*!< Fault 4 source */
#define HRTIM_FLTINR1_FLT4F      ((uint32_t)0x78000000)    /*!< Fault 4 filter */
#define HRTIM_FLTINR1_FLT4F_0    ((uint32_t)0x08000000)    /*!< Fault 4 filter bit 0 */
#define HRTIM_FLTINR1_FLT4F_1    ((uint32_t)0x10000000)    /*!< Fault 4 filter bit 1 */
#define HRTIM_FLTINR1_FLT4F_2    ((uint32_t)0x20000000)    /*!< Fault 4 filter bit 2 */
#define HRTIM_FLTINR1_FLT4F_3    ((uint32_t)0x40000000)    /*!< Fault 4 filter bit 3 */
#define HRTIM_FLTINR1_FLT4LCK    ((uint32_t)0x80000000)    /*!< Fault 4 lock */

/*******************  Bit definition for HRTIM_FLTINR2 register  ***************/  
#define HRTIM_FLTINR2_FLT5E      ((uint32_t)0x00000001)    /*!< Fault 5 enable */ 
#define HRTIM_FLTINR2_FLT5P      ((uint32_t)0x00000002)    /*!< Fault 5 polarity */
#define HRTIM_FLTINR2_FLT5SRC    ((uint32_t)0x00000004)    /*!< Fault 5 source */
#define HRTIM_FLTINR2_FLT5F      ((uint32_t)0x00000078)    /*!< Fault 5 filter */
#define HRTIM_FLTINR2_FLT5F_0    ((uint32_t)0x00000008)    /*!< Fault 5 filter bit 0 */
#define HRTIM_FLTINR2_FLT5F_1    ((uint32_t)0x00000010)    /*!< Fault 5 filter bit 1 */
#define HRTIM_FLTINR2_FLT5F_2    ((uint32_t)0x00000020)    /*!< Fault 5 filter bit 2 */
#define HRTIM_FLTINR2_FLT5F_3    ((uint32_t)0x00000040)    /*!< Fault 5 filter bit 3 */
#define HRTIM_FLTINR2_FLT5LCK    ((uint32_t)0x00000080)    /*!< Fault 5 lock */
#define HRTIM_FLTINR2_FLTSD     ((uint32_t)0x03000000)     /*!< Fault sampling clock division */
#define HRTIM_FLTINR2_FLTSD_0   ((uint32_t)0x01000000)     /*!< Fault sampling clock division bit 0 */
#define HRTIM_FLTINR2_FLTSD_1   ((uint32_t)0x02000000)     /*!< Fault sampling clock division bit 1 */

/*******************  Bit definition for HRTIM_BDMUPR register  ***************/  
#define HRTIM_BDMUPR_MCR      ((uint32_t)0x00000001)    /*!< MCR register update enable */ 
#define HRTIM_BDMUPR_MICR     ((uint32_t)0x00000002)    /*!< MICR register update enable */ 
#define HRTIM_BDMUPR_MDIER    ((uint32_t)0x00000004)    /*!< MDIER register update enable */ 
#define HRTIM_BDMUPR_MCNT     ((uint32_t)0x00000008)    /*!< MCNT register update enable */ 
#define HRTIM_BDMUPR_MPER     ((uint32_t)0x00000010)    /*!< MPER register update enable */ 
#define HRTIM_BDMUPR_MREP     ((uint32_t)0x00000020)    /*!< MREP register update enable */ 
#define HRTIM_BDMUPR_MCMP1    ((uint32_t)0x00000040)    /*!< MCMP1 register update enable */ 
#define HRTIM_BDMUPR_MCMP2    ((uint32_t)0x00000080)    /*!< MCMP2 register update enable */ 
#define HRTIM_BDMUPR_MCMP3    ((uint32_t)0x00000100)    /*!< MCMP3 register update enable */ 
#define HRTIM_BDMUPR_MCMP4    ((uint32_t)0x00000200)    /*!< MPCMP4 register update enable */ 

/*******************  Bit definition for HRTIM_BDTUPR register  ***************/  
#define HRTIM_BDTUPR_TIMCR      ((uint32_t)0x00000001)    /*!<  TIMCR register update enable */ 
#define HRTIM_BDTUPR_TIMICR     ((uint32_t)0x00000002)    /*!<  TIMICR register update enable */ 
#define HRTIM_BDTUPR_TIMDIER    ((uint32_t)0x00000004)    /*!<  TIMDIER register update enable */ 
#define HRTIM_BDTUPR_TIMCNT     ((uint32_t)0x00000008)    /*!<  TIMCNT register update enable */ 
#define HRTIM_BDTUPR_TIMPER     ((uint32_t)0x00000010)    /*!<  TIMPER register update enable */ 
#define HRTIM_BDTUPR_TIMREP     ((uint32_t)0x00000020)    /*!<  TIMREP register update enable */ 
#define HRTIM_BDTUPR_TIMCMP1    ((uint32_t)0x00000040)    /*!<  TIMCMP1 register update enable */ 
#define HRTIM_BDTUPR_TIMCMP2    ((uint32_t)0x00000080)    /*!<  TIMCMP2 register update enable */ 
#define HRTIM_BDTUPR_TIMCMP3    ((uint32_t)0x00000100)    /*!<  TIMCMP3 register update enable */ 
#define HRTIM_BDTUPR_TIMCMP4    ((uint32_t)0x00000200)    /*!<  TIMCMP4 register update enable */ 
#define HRTIM_BDTUPR_TIMDTR     ((uint32_t)0x00000400)    /*!<  TIMDTR register update enable */ 
#define HRTIM_BDTUPR_TIMSET1R   ((uint32_t)0x00000800)    /*!<  TIMSET1R register update enable */ 
#define HRTIM_BDTUPR_TIMRST1R   ((uint32_t)0x00001000)    /*!<  TIMRST1R register update enable */ 
#define HRTIM_BDTUPR_TIMSET2R   ((uint32_t)0x00002000)    /*!<  TIMSET2R register update enable */ 
#define HRTIM_BDTUPR_TIMRST2R   ((uint32_t)0x00004000)    /*!<  TIMRST2R register update enable */ 
#define HRTIM_BDTUPR_TIMEEFR1   ((uint32_t)0x00008000)    /*!<  TIMEEFR1 register update enable */ 
#define HRTIM_BDTUPR_TIMEEFR2   ((uint32_t)0x00010000)    /*!<  TIMEEFR2 register update enable */ 
#define HRTIM_BDTUPR_TIMRSTR    ((uint32_t)0x00020000)    /*!<  TIMRSTR register update enable */ 
#define HRTIM_BDTUPR_TIMCHPR    ((uint32_t)0x00040000)    /*!<  TIMCHPR register update enable */ 
#define HRTIM_BDTUPR_TIMOUTR    ((uint32_t)0x00080000)    /*!<  TIMOUTR register update enable */ 
#define HRTIM_BDTUPR_TIMFLTR    ((uint32_t)0x00100000)    /*!<  TIMFLTR register update enable */ 

/*******************  Bit definition for HRTIM_BDMADR register  ***************/  
#define HRTIM_BDMADR_BDMADR      ((uint32_t)0xFFFFFFFF)    /*!<  Burst DMA Data register */

/******************************************************************************/
/*                                                                            */
/*                                MDIOS                                        */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for MDIOS_CR register  *******************/
#define MDIOS_CR_EN               ((uint32_t)0x00000001)    /*!<  MDIOS slave peripheral enable */
#define MDIOS_CR_WRIE             ((uint32_t)0x00000002)    /*!<  MDIOS slave register write interrupt enable. */ 
#define MDIOS_CR_RDIE             ((uint32_t)0x00000004)    /*!<  MDIOS slave register read interrupt enable. */
#define MDIOS_CR_EIE              ((uint32_t)0x00000008)    /*!<  MDIOS slave register error interrupt enable. */
#define MDIOS_CR_DPC              ((uint32_t)0x00000080)    /*!<  MDIOS slave disable preamble check. */
#define MDIOS_CR_PORT_ADDRESS     ((uint32_t)0x00001F00)    /*!<  MDIOS slave port address mask. */
#define MDIOS_CR_PORT_ADDRESS_0   ((uint32_t)0x00000100)    /*!<  MDIOS slave port address bit 0. */
#define MDIOS_CR_PORT_ADDRESS_1   ((uint32_t)0x00000200)    /*!<  MDIOS slave port address bit 1. */
#define MDIOS_CR_PORT_ADDRESS_2   ((uint32_t)0x00000400)    /*!<  MDIOS slave port address bit 2. */
#define MDIOS_CR_PORT_ADDRESS_3   ((uint32_t)0x00000800)    /*!<  MDIOS slave port address bit 3. */
#define MDIOS_CR_PORT_ADDRESS_4   ((uint32_t)0x00001000)    /*!<  MDIOS slave port address bit 4. */

/********************  Bit definition for MDIOS_SR register  *******************/
#define MDIOS_SR_PERF             ((uint32_t)0x00000001)    /*!<  MDIOS slave turnaround error flag*/
#define MDIOS_SR_SERF             ((uint32_t)0x00000002)    /*!<  MDIOS slave start error flag */
#define MDIOS_SR_TERF             ((uint32_t)0x00000004)    /*!<  MDIOS slave preamble error flag */

/********************  Bit definition for MDIOS_CLRFR register  *******************/
#define MDIOS_SR_CPERF             ((uint32_t)0x00000001)    /*!<  MDIOS slave Clear the turnaround error flag */
#define MDIOS_SR_CSERF             ((uint32_t)0x00000002)    /*!<  MDIOS slave Clear the start error flag */
#define MDIOS_SR_CTERF             ((uint32_t)0x00000004)    /*!<  MDIOS slave Clear the preamble error flag */

/******************************************************************************/
/*                                                                            */
/*                                       USB_OTG                              */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition forUSB_OTG_GOTGCTL register  ********************/
#define USB_OTG_GOTGCTL_SRQSCS                  ((uint32_t)0x00000001)         /*!< Session request success */
#define USB_OTG_GOTGCTL_SRQ                     ((uint32_t)0x00000002)         /*!< Session request */
#define USB_OTG_GOTGCTL_VBVALOEN                ((uint32_t)0x00000004)         /*!< VBUS valid override enable */
#define USB_OTG_GOTGCTL_VBVALOVAL               ((uint32_t)0x00000008)         /*!< VBUS valid override value */
#define USB_OTG_GOTGCTL_AVALOEN                 ((uint32_t)0x00000010)         /*!< A-peripheral session valid override enable */
#define USB_OTG_GOTGCTL_AVALOVAL                ((uint32_t)0x00000020)         /*!< A-peripheral session valid override value */
#define USB_OTG_GOTGCTL_BVALOEN                 ((uint32_t)0x00000040)         /*!< B-peripheral session valid override enable */
#define USB_OTG_GOTGCTL_BVALOVAL                ((uint32_t)0x00000080)         /*!< B-peripheral session valid override value  */
#define USB_OTG_GOTGCTL_HNGSCS                  ((uint32_t)0x00000100)         /*!< Host set HNP enable */
#define USB_OTG_GOTGCTL_HNPRQ                   ((uint32_t)0x00000200)         /*!< HNP request */
#define USB_OTG_GOTGCTL_HSHNPEN                 ((uint32_t)0x00000400)         /*!< Host set HNP enable */
#define USB_OTG_GOTGCTL_DHNPEN                  ((uint32_t)0x00000800)         /*!< Device HNP enabled */
#define USB_OTG_GOTGCTL_EHEN                    ((uint32_t)0x00001000)         /*!< Embedded host enable */
#define USB_OTG_GOTGCTL_CIDSTS                  ((uint32_t)0x00010000)         /*!< Connector ID status */
#define USB_OTG_GOTGCTL_DBCT                    ((uint32_t)0x00020000)         /*!< Long/short debounce time */
#define USB_OTG_GOTGCTL_ASVLD                   ((uint32_t)0x00040000)         /*!< A-session valid  */
#define USB_OTG_GOTGCTL_BSESVLD                 ((uint32_t)0x00080000)         /*!< B-session valid */
#define USB_OTG_GOTGCTL_OTGVER                  ((uint32_t)0x00100000)         /*!< OTG version  */

/********************  Bit definition forUSB_OTG_HCFG register  ********************/

#define USB_OTG_HCFG_FSLSPCS                 ((uint32_t)0x00000003)            /*!< FS/LS PHY clock select  */
#define USB_OTG_HCFG_FSLSPCS_0               ((uint32_t)0x00000001)            /*!<Bit 0 */
#define USB_OTG_HCFG_FSLSPCS_1               ((uint32_t)0x00000002)            /*!<Bit 1 */
#define USB_OTG_HCFG_FSLSS                   ((uint32_t)0x00000004)            /*!< FS- and LS-only support */

/********************  Bit definition forUSB_OTG_DCFG register  ********************/

#define USB_OTG_DCFG_DSPD                    ((uint32_t)0x00000003)            /*!< Device speed */
#define USB_OTG_DCFG_DSPD_0                  ((uint32_t)0x00000001)            /*!<Bit 0 */
#define USB_OTG_DCFG_DSPD_1                  ((uint32_t)0x00000002)            /*!<Bit 1 */
#define USB_OTG_DCFG_NZLSOHSK                ((uint32_t)0x00000004)            /*!< Nonzero-length status OUT handshake */

#define USB_OTG_DCFG_DAD                     ((uint32_t)0x000007F0)            /*!< Device address */
#define USB_OTG_DCFG_DAD_0                   ((uint32_t)0x00000010)            /*!<Bit 0 */
#define USB_OTG_DCFG_DAD_1                   ((uint32_t)0x00000020)            /*!<Bit 1 */
#define USB_OTG_DCFG_DAD_2                   ((uint32_t)0x00000040)            /*!<Bit 2 */
#define USB_OTG_DCFG_DAD_3                   ((uint32_t)0x00000080)            /*!<Bit 3 */
#define USB_OTG_DCFG_DAD_4                   ((uint32_t)0x00000100)            /*!<Bit 4 */
#define USB_OTG_DCFG_DAD_5                   ((uint32_t)0x00000200)            /*!<Bit 5 */
#define USB_OTG_DCFG_DAD_6                   ((uint32_t)0x00000400)            /*!<Bit 6 */

#define USB_OTG_DCFG_PFIVL                   ((uint32_t)0x00001800)            /*!< Periodic (micro)frame interval */
#define USB_OTG_DCFG_PFIVL_0                 ((uint32_t)0x00000800)            /*!<Bit 0 */
#define USB_OTG_DCFG_PFIVL_1                 ((uint32_t)0x00001000)            /*!<Bit 1 */

#define USB_OTG_DCFG_PERSCHIVL               ((uint32_t)0x03000000)            /*!< Periodic scheduling interval */
#define USB_OTG_DCFG_PERSCHIVL_0             ((uint32_t)0x01000000)            /*!<Bit 0 */
#define USB_OTG_DCFG_PERSCHIVL_1             ((uint32_t)0x02000000)            /*!<Bit 1 */

/********************  Bit definition forUSB_OTG_PCGCR register  ********************/
#define USB_OTG_PCGCR_STPPCLK                 ((uint32_t)0x00000001)            /*!< Stop PHY clock */
#define USB_OTG_PCGCR_GATEHCLK                ((uint32_t)0x00000002)            /*!< Gate HCLK */
#define USB_OTG_PCGCR_PHYSUSP                 ((uint32_t)0x00000010)            /*!< PHY suspended */

/********************  Bit definition forUSB_OTG_GOTGINT register  ********************/
#define USB_OTG_GOTGINT_SEDET                   ((uint32_t)0x00000004)          /*!< Session end detected                   */
#define USB_OTG_GOTGINT_SRSSCHG                 ((uint32_t)0x00000100)          /*!< Session request success status change  */
#define USB_OTG_GOTGINT_HNSSCHG                 ((uint32_t)0x00000200)          /*!< Host negotiation success status change */
#define USB_OTG_GOTGINT_HNGDET                  ((uint32_t)0x00020000)          /*!< Host negotiation detected              */
#define USB_OTG_GOTGINT_ADTOCHG                 ((uint32_t)0x00040000)          /*!< A-device timeout change                */
#define USB_OTG_GOTGINT_DBCDNE                  ((uint32_t)0x00080000)          /*!< Debounce done                          */

/********************  Bit definition forUSB_OTG_DCTL register  ********************/
#define USB_OTG_DCTL_RWUSIG                  ((uint32_t)0x00000001)            /*!< Remote wakeup signaling */
#define USB_OTG_DCTL_SDIS                    ((uint32_t)0x00000002)            /*!< Soft disconnect         */
#define USB_OTG_DCTL_GINSTS                  ((uint32_t)0x00000004)            /*!< Global IN NAK status    */
#define USB_OTG_DCTL_GONSTS                  ((uint32_t)0x00000008)            /*!< Global OUT NAK status   */

#define USB_OTG_DCTL_TCTL                    ((uint32_t)0x00000070)            /*!< Test control */
#define USB_OTG_DCTL_TCTL_0                  ((uint32_t)0x00000010)            /*!<Bit 0 */
#define USB_OTG_DCTL_TCTL_1                  ((uint32_t)0x00000020)            /*!<Bit 1 */
#define USB_OTG_DCTL_TCTL_2                  ((uint32_t)0x00000040)            /*!<Bit 2 */
#define USB_OTG_DCTL_SGINAK                  ((uint32_t)0x00000080)            /*!< Set global IN NAK         */
#define USB_OTG_DCTL_CGINAK                  ((uint32_t)0x00000100)            /*!< Clear global IN NAK       */
#define USB_OTG_DCTL_SGONAK                  ((uint32_t)0x00000200)            /*!< Set global OUT NAK        */
#define USB_OTG_DCTL_CGONAK                  ((uint32_t)0x00000400)            /*!< Clear global OUT NAK      */
#define USB_OTG_DCTL_POPRGDNE                ((uint32_t)0x00000800)            /*!< Power-on programming done */

/********************  Bit definition forUSB_OTG_HFIR register  ********************/
#define USB_OTG_HFIR_FRIVL                   ((uint32_t)0x0000FFFF)            /*!< Frame interval */

/********************  Bit definition forUSB_OTG_HFNUM register  ********************/
#define USB_OTG_HFNUM_FRNUM                   ((uint32_t)0x0000FFFF)            /*!< Frame number         */
#define USB_OTG_HFNUM_FTREM                   ((uint32_t)0xFFFF0000)            /*!< Frame time remaining */

/********************  Bit definition forUSB_OTG_DSTS register  ********************/
#define USB_OTG_DSTS_SUSPSTS                 ((uint32_t)0x00000001)            /*!< Suspend status   */

#define USB_OTG_DSTS_ENUMSPD                 ((uint32_t)0x00000006)            /*!< Enumerated speed */
#define USB_OTG_DSTS_ENUMSPD_0               ((uint32_t)0x00000002)            /*!<Bit 0 */
#define USB_OTG_DSTS_ENUMSPD_1               ((uint32_t)0x00000004)            /*!<Bit 1 */
#define USB_OTG_DSTS_EERR                    ((uint32_t)0x00000008)            /*!< Erratic error     */
#define USB_OTG_DSTS_FNSOF                   ((uint32_t)0x003FFF00)            /*!< Frame number of the received SOF */

/********************  Bit definition forUSB_OTG_GAHBCFG register  ********************/
#define USB_OTG_GAHBCFG_GINT                    ((uint32_t)0x00000001)            /*!< Global interrupt mask */

#define USB_OTG_GAHBCFG_HBSTLEN                 ((uint32_t)0x0000001E)            /*!< Burst length/type */
#define USB_OTG_GAHBCFG_HBSTLEN_0               ((uint32_t)0x00000002)            /*!<Bit 0 */
#define USB_OTG_GAHBCFG_HBSTLEN_1               ((uint32_t)0x00000004)            /*!<Bit 1 */
#define USB_OTG_GAHBCFG_HBSTLEN_2               ((uint32_t)0x00000008)            /*!<Bit 2 */
#define USB_OTG_GAHBCFG_HBSTLEN_3               ((uint32_t)0x00000010)            /*!<Bit 3 */
#define USB_OTG_GAHBCFG_DMAEN                   ((uint32_t)0x00000020)            /*!< DMA enable */
#define USB_OTG_GAHBCFG_TXFELVL                 ((uint32_t)0x00000080)            /*!< TxFIFO empty level */
#define USB_OTG_GAHBCFG_PTXFELVL                ((uint32_t)0x00000100)            /*!< Periodic TxFIFO empty level */

/********************  Bit definition forUSB_OTG_GUSBCFG register  ********************/

#define USB_OTG_GUSBCFG_TOCAL                   ((uint32_t)0x00000007)            /*!< FS timeout calibration */
#define USB_OTG_GUSBCFG_TOCAL_0                 ((uint32_t)0x00000001)            /*!<Bit 0 */
#define USB_OTG_GUSBCFG_TOCAL_1                 ((uint32_t)0x00000002)            /*!<Bit 1 */
#define USB_OTG_GUSBCFG_TOCAL_2                 ((uint32_t)0x00000004)            /*!<Bit 2 */
#define USB_OTG_GUSBCFG_PHYSEL                  ((uint32_t)0x00000040)            /*!< USB 2.0 high-speed ULPI PHY or USB 1.1 full-speed serial transceiver select */
#define USB_OTG_GUSBCFG_SRPCAP                  ((uint32_t)0x00000100)            /*!< SRP-capable */
#define USB_OTG_GUSBCFG_HNPCAP                  ((uint32_t)0x00000200)            /*!< HNP-capable */

#define USB_OTG_GUSBCFG_TRDT                    ((uint32_t)0x00003C00)            /*!< USB turnaround time */
#define USB_OTG_GUSBCFG_TRDT_0                  ((uint32_t)0x00000400)            /*!<Bit 0 */
#define USB_OTG_GUSBCFG_TRDT_1                  ((uint32_t)0x00000800)            /*!<Bit 1 */
#define USB_OTG_GUSBCFG_TRDT_2                  ((uint32_t)0x00001000)            /*!<Bit 2 */
#define USB_OTG_GUSBCFG_TRDT_3                  ((uint32_t)0x00002000)            /*!<Bit 3 */
#define USB_OTG_GUSBCFG_PHYLPCS                 ((uint32_t)0x00008000)            /*!< PHY Low-power clock select */
#define USB_OTG_GUSBCFG_ULPIFSLS                ((uint32_t)0x00020000)            /*!< ULPI FS/LS select               */
#define USB_OTG_GUSBCFG_ULPIAR                  ((uint32_t)0x00040000)            /*!< ULPI Auto-resume                */
#define USB_OTG_GUSBCFG_ULPICSM                 ((uint32_t)0x00080000)            /*!< ULPI Clock SuspendM             */
#define USB_OTG_GUSBCFG_ULPIEVBUSD              ((uint32_t)0x00100000)            /*!< ULPI External VBUS Drive        */
#define USB_OTG_GUSBCFG_ULPIEVBUSI              ((uint32_t)0x00200000)            /*!< ULPI external VBUS indicator    */
#define USB_OTG_GUSBCFG_TSDPS                   ((uint32_t)0x00400000)            /*!< TermSel DLine pulsing selection */
#define USB_OTG_GUSBCFG_PCCI                    ((uint32_t)0x00800000)            /*!< Indicator complement            */
#define USB_OTG_GUSBCFG_PTCI                    ((uint32_t)0x01000000)            /*!< Indicator pass through          */
#define USB_OTG_GUSBCFG_ULPIIPD                 ((uint32_t)0x02000000)            /*!< ULPI interface protect disable  */
#define USB_OTG_GUSBCFG_FHMOD                   ((uint32_t)0x20000000)            /*!< Forced host mode                */
#define USB_OTG_GUSBCFG_FDMOD                   ((uint32_t)0x40000000)            /*!< Forced peripheral mode          */
#define USB_OTG_GUSBCFG_CTXPKT                  ((uint32_t)0x80000000)            /*!< Corrupt Tx packet               */

/********************  Bit definition forUSB_OTG_GRSTCTL register  ********************/
#define USB_OTG_GRSTCTL_CSRST                   ((uint32_t)0x00000001)            /*!< Core soft reset          */
#define USB_OTG_GRSTCTL_HSRST                   ((uint32_t)0x00000002)            /*!< HCLK soft reset          */
#define USB_OTG_GRSTCTL_FCRST                   ((uint32_t)0x00000004)            /*!< Host frame counter reset */
#define USB_OTG_GRSTCTL_RXFFLSH                 ((uint32_t)0x00000010)            /*!< RxFIFO flush             */
#define USB_OTG_GRSTCTL_TXFFLSH                 ((uint32_t)0x00000020)            /*!< TxFIFO flush             */

#define USB_OTG_GRSTCTL_TXFNUM                  ((uint32_t)0x000007C0)            /*!< TxFIFO number */
#define USB_OTG_GRSTCTL_TXFNUM_0                ((uint32_t)0x00000040)            /*!<Bit 0 */
#define USB_OTG_GRSTCTL_TXFNUM_1                ((uint32_t)0x00000080)            /*!<Bit 1 */
#define USB_OTG_GRSTCTL_TXFNUM_2                ((uint32_t)0x00000100)            /*!<Bit 2 */
#define USB_OTG_GRSTCTL_TXFNUM_3                ((uint32_t)0x00000200)            /*!<Bit 3 */
#define USB_OTG_GRSTCTL_TXFNUM_4                ((uint32_t)0x00000400)            /*!<Bit 4 */
#define USB_OTG_GRSTCTL_DMAREQ                  ((uint32_t)0x40000000)            /*!< DMA request signal */
#define USB_OTG_GRSTCTL_AHBIDL                  ((uint32_t)0x80000000)            /*!< AHB master idle */

/********************  Bit definition forUSB_OTG_DIEPMSK register  ********************/
#define USB_OTG_DIEPMSK_XFRCM                   ((uint32_t)0x00000001)            /*!< Transfer completed interrupt mask                 */
#define USB_OTG_DIEPMSK_EPDM                    ((uint32_t)0x00000002)            /*!< Endpoint disabled interrupt mask                  */
#define USB_OTG_DIEPMSK_TOM                     ((uint32_t)0x00000008)            /*!< Timeout condition mask (nonisochronous endpoints) */
#define USB_OTG_DIEPMSK_ITTXFEMSK               ((uint32_t)0x00000010)            /*!< IN token received when TxFIFO empty mask          */
#define USB_OTG_DIEPMSK_INEPNMM                 ((uint32_t)0x00000020)            /*!< IN token received with EP mismatch mask           */
#define USB_OTG_DIEPMSK_INEPNEM                 ((uint32_t)0x00000040)            /*!< IN endpoint NAK effective mask                    */
#define USB_OTG_DIEPMSK_TXFURM                  ((uint32_t)0x00000100)            /*!< FIFO underrun mask                                */
#define USB_OTG_DIEPMSK_BIM                     ((uint32_t)0x00000200)            /*!< BNA interrupt mask                                */

/********************  Bit definition forUSB_OTG_HPTXSTS register  ********************/
#define USB_OTG_HPTXSTS_PTXFSAVL                ((uint32_t)0x0000FFFF)            /*!< Periodic transmit data FIFO space available     */

#define USB_OTG_HPTXSTS_PTXQSAV                 ((uint32_t)0x00FF0000)            /*!< Periodic transmit request queue space available */
#define USB_OTG_HPTXSTS_PTXQSAV_0               ((uint32_t)0x00010000)            /*!<Bit 0 */
#define USB_OTG_HPTXSTS_PTXQSAV_1               ((uint32_t)0x00020000)            /*!<Bit 1 */
#define USB_OTG_HPTXSTS_PTXQSAV_2               ((uint32_t)0x00040000)            /*!<Bit 2 */
#define USB_OTG_HPTXSTS_PTXQSAV_3               ((uint32_t)0x00080000)            /*!<Bit 3 */
#define USB_OTG_HPTXSTS_PTXQSAV_4               ((uint32_t)0x00100000)            /*!<Bit 4 */
#define USB_OTG_HPTXSTS_PTXQSAV_5               ((uint32_t)0x00200000)            /*!<Bit 5 */
#define USB_OTG_HPTXSTS_PTXQSAV_6               ((uint32_t)0x00400000)            /*!<Bit 6 */
#define USB_OTG_HPTXSTS_PTXQSAV_7               ((uint32_t)0x00800000)            /*!<Bit 7 */

#define USB_OTG_HPTXSTS_PTXQTOP                 ((uint32_t)0xFF000000)            /*!< Top of the periodic transmit request queue */
#define USB_OTG_HPTXSTS_PTXQTOP_0               ((uint32_t)0x01000000)            /*!<Bit 0 */
#define USB_OTG_HPTXSTS_PTXQTOP_1               ((uint32_t)0x02000000)            /*!<Bit 1 */
#define USB_OTG_HPTXSTS_PTXQTOP_2               ((uint32_t)0x04000000)            /*!<Bit 2 */
#define USB_OTG_HPTXSTS_PTXQTOP_3               ((uint32_t)0x08000000)            /*!<Bit 3 */
#define USB_OTG_HPTXSTS_PTXQTOP_4               ((uint32_t)0x10000000)            /*!<Bit 4 */
#define USB_OTG_HPTXSTS_PTXQTOP_5               ((uint32_t)0x20000000)            /*!<Bit 5 */
#define USB_OTG_HPTXSTS_PTXQTOP_6               ((uint32_t)0x40000000)            /*!<Bit 6 */
#define USB_OTG_HPTXSTS_PTXQTOP_7               ((uint32_t)0x80000000)            /*!<Bit 7 */

/********************  Bit definition forUSB_OTG_HAINT register  ********************/
#define USB_OTG_HAINT_HAINT                   ((uint32_t)0x0000FFFF)            /*!< Channel interrupts */

/********************  Bit definition forUSB_OTG_DOEPMSK register  ********************/
#define USB_OTG_DOEPMSK_XFRCM                   ((uint32_t)0x00000001)            /*!< Transfer completed interrupt mask */
#define USB_OTG_DOEPMSK_EPDM                    ((uint32_t)0x00000002)            /*!< Endpoint disabled interrupt mask               */
#define USB_OTG_DOEPMSK_STUPM                   ((uint32_t)0x00000008)            /*!< SETUP phase done mask                          */
#define USB_OTG_DOEPMSK_OTEPDM                  ((uint32_t)0x00000010)            /*!< OUT token received when endpoint disabled mask */
#define USB_OTG_DOEPMSK_B2BSTUP                 ((uint32_t)0x00000040)            /*!< Back-to-back SETUP packets received mask       */
#define USB_OTG_DOEPMSK_OPEM                    ((uint32_t)0x00000100)            /*!< OUT packet error mask                          */
#define USB_OTG_DOEPMSK_BOIM                    ((uint32_t)0x00000200)            /*!< BNA interrupt mask                             */

/********************  Bit definition forUSB_OTG_GINTSTS register  ********************/
#define USB_OTG_GINTSTS_CMOD                    ((uint32_t)0x00000001)            /*!< Current mode of operation                      */
#define USB_OTG_GINTSTS_MMIS                    ((uint32_t)0x00000002)            /*!< Mode mismatch interrupt                        */
#define USB_OTG_GINTSTS_OTGINT                  ((uint32_t)0x00000004)            /*!< OTG interrupt                                  */
#define USB_OTG_GINTSTS_SOF                     ((uint32_t)0x00000008)            /*!< Start of frame                                 */
#define USB_OTG_GINTSTS_RXFLVL                  ((uint32_t)0x00000010)            /*!< RxFIFO nonempty                                */
#define USB_OTG_GINTSTS_NPTXFE                  ((uint32_t)0x00000020)            /*!< Nonperiodic TxFIFO empty                       */
#define USB_OTG_GINTSTS_GINAKEFF                ((uint32_t)0x00000040)            /*!< Global IN nonperiodic NAK effective            */
#define USB_OTG_GINTSTS_BOUTNAKEFF              ((uint32_t)0x00000080)            /*!< Global OUT NAK effective                       */
#define USB_OTG_GINTSTS_ESUSP                   ((uint32_t)0x00000400)            /*!< Early suspend                                  */
#define USB_OTG_GINTSTS_USBSUSP                 ((uint32_t)0x00000800)            /*!< USB suspend                                    */
#define USB_OTG_GINTSTS_USBRST                  ((uint32_t)0x00001000)            /*!< USB reset                                      */
#define USB_OTG_GINTSTS_ENUMDNE                 ((uint32_t)0x00002000)            /*!< Enumeration done                               */
#define USB_OTG_GINTSTS_ISOODRP                 ((uint32_t)0x00004000)            /*!< Isochronous OUT packet dropped interrupt       */
#define USB_OTG_GINTSTS_EOPF                    ((uint32_t)0x00008000)            /*!< End of periodic frame interrupt                */
#define USB_OTG_GINTSTS_IEPINT                  ((uint32_t)0x00040000)            /*!< IN endpoint interrupt                          */
#define USB_OTG_GINTSTS_OEPINT                  ((uint32_t)0x00080000)            /*!< OUT endpoint interrupt                         */
#define USB_OTG_GINTSTS_IISOIXFR                ((uint32_t)0x00100000)            /*!< Incomplete isochronous IN transfer             */
#define USB_OTG_GINTSTS_PXFR_INCOMPISOOUT       ((uint32_t)0x00200000)            /*!< Incomplete periodic transfer                   */
#define USB_OTG_GINTSTS_DATAFSUSP               ((uint32_t)0x00400000)            /*!< Data fetch suspended                           */
#define USB_OTG_GINTSTS_RSTDET                  ((uint32_t)0x00800000)            /*!< Reset detected interrupt                       */
#define USB_OTG_GINTSTS_HPRTINT                 ((uint32_t)0x01000000)            /*!< Host port interrupt                            */
#define USB_OTG_GINTSTS_HCINT                   ((uint32_t)0x02000000)            /*!< Host channels interrupt                        */
#define USB_OTG_GINTSTS_PTXFE                   ((uint32_t)0x04000000)            /*!< Periodic TxFIFO empty                          */
#define USB_OTG_GINTSTS_LPMINT                  ((uint32_t)0x08000000)            /*!< LPM interrupt                                  */
#define USB_OTG_GINTSTS_CIDSCHG                 ((uint32_t)0x10000000)            /*!< Connector ID status change                     */
#define USB_OTG_GINTSTS_DISCINT                 ((uint32_t)0x20000000)            /*!< Disconnect detected interrupt                  */
#define USB_OTG_GINTSTS_SRQINT                  ((uint32_t)0x40000000)            /*!< Session request/new session detected interrupt */
#define USB_OTG_GINTSTS_WKUINT                  ((uint32_t)0x80000000)            /*!< Resume/remote wakeup detected interrupt        */

/********************  Bit definition forUSB_OTG_GINTMSK register  ********************/
#define USB_OTG_GINTMSK_MMISM                   ((uint32_t)0x00000002)            /*!< Mode mismatch interrupt mask                        */
#define USB_OTG_GINTMSK_OTGINT                  ((uint32_t)0x00000004)            /*!< OTG interrupt mask                                  */
#define USB_OTG_GINTMSK_SOFM                    ((uint32_t)0x00000008)            /*!< Start of frame mask                                 */
#define USB_OTG_GINTMSK_RXFLVLM                 ((uint32_t)0x00000010)            /*!< Receive FIFO nonempty mask                          */
#define USB_OTG_GINTMSK_NPTXFEM                 ((uint32_t)0x00000020)            /*!< Nonperiodic TxFIFO empty mask                       */
#define USB_OTG_GINTMSK_GINAKEFFM               ((uint32_t)0x00000040)            /*!< Global nonperiodic IN NAK effective mask            */
#define USB_OTG_GINTMSK_GONAKEFFM               ((uint32_t)0x00000080)            /*!< Global OUT NAK effective mask                       */
#define USB_OTG_GINTMSK_ESUSPM                  ((uint32_t)0x00000400)            /*!< Early suspend mask                                  */
#define USB_OTG_GINTMSK_USBSUSPM                ((uint32_t)0x00000800)            /*!< USB suspend mask                                    */
#define USB_OTG_GINTMSK_USBRST                  ((uint32_t)0x00001000)            /*!< USB reset mask                                      */
#define USB_OTG_GINTMSK_ENUMDNEM                ((uint32_t)0x00002000)            /*!< Enumeration done mask                               */
#define USB_OTG_GINTMSK_ISOODRPM                ((uint32_t)0x00004000)            /*!< Isochronous OUT packet dropped interrupt mask       */
#define USB_OTG_GINTMSK_EOPFM                   ((uint32_t)0x00008000)            /*!< End of periodic frame interrupt mask                */
#define USB_OTG_GINTMSK_EPMISM                  ((uint32_t)0x00020000)            /*!< Endpoint mismatch interrupt mask                    */
#define USB_OTG_GINTMSK_IEPINT                  ((uint32_t)0x00040000)            /*!< IN endpoints interrupt mask                         */
#define USB_OTG_GINTMSK_OEPINT                  ((uint32_t)0x00080000)            /*!< OUT endpoints interrupt mask                        */
#define USB_OTG_GINTMSK_IISOIXFRM               ((uint32_t)0x00100000)            /*!< Incomplete isochronous IN transfer mask             */
#define USB_OTG_GINTMSK_PXFRM_IISOOXFRM         ((uint32_t)0x00200000)            /*!< Incomplete periodic transfer mask                   */
#define USB_OTG_GINTMSK_FSUSPM                  ((uint32_t)0x00400000)            /*!< Data fetch suspended mask                           */
#define USB_OTG_GINTMSK_RSTDEM                  ((uint32_t)0x00800000)            /*!< Reset detected interrupt mask                      */
#define USB_OTG_GINTMSK_PRTIM                   ((uint32_t)0x01000000)            /*!< Host port interrupt mask                            */
#define USB_OTG_GINTMSK_HCIM                    ((uint32_t)0x02000000)            /*!< Host channels interrupt mask                        */
#define USB_OTG_GINTMSK_PTXFEM                  ((uint32_t)0x04000000)            /*!< Periodic TxFIFO empty mask                          */
#define USB_OTG_GINTMSK_LPMINTM                 ((uint32_t)0x08000000)            /*!< LPM interrupt Mask                                  */
#define USB_OTG_GINTMSK_CIDSCHGM                ((uint32_t)0x10000000)            /*!< Connector ID status change mask                     */
#define USB_OTG_GINTMSK_DISCINT                 ((uint32_t)0x20000000)            /*!< Disconnect detected interrupt mask                  */
#define USB_OTG_GINTMSK_SRQIM                   ((uint32_t)0x40000000)            /*!< Session request/new session detected interrupt mask */
#define USB_OTG_GINTMSK_WUIM                    ((uint32_t)0x80000000)            /*!< Resume/remote wakeup detected interrupt mask        */

/********************  Bit definition forUSB_OTG_DAINT register  ********************/
#define USB_OTG_DAINT_IEPINT                  ((uint32_t)0x0000FFFF)            /*!< IN endpoint interrupt bits  */
#define USB_OTG_DAINT_OEPINT                  ((uint32_t)0xFFFF0000)            /*!< OUT endpoint interrupt bits */

/********************  Bit definition forUSB_OTG_HAINTMSK register  ********************/
#define USB_OTG_HAINTMSK_HAINTM                  ((uint32_t)0x0000FFFF)            /*!< Channel interrupt mask */

/********************  Bit definition for USB_OTG_GRXSTSP register  ********************/
#define USB_OTG_GRXSTSP_EPNUM                    ((uint32_t)0x0000000F)            /*!< IN EP interrupt mask bits  */
#define USB_OTG_GRXSTSP_BCNT                     ((uint32_t)0x00007FF0)            /*!< OUT EP interrupt mask bits */
#define USB_OTG_GRXSTSP_DPID                     ((uint32_t)0x00018000)            /*!< OUT EP interrupt mask bits */
#define USB_OTG_GRXSTSP_PKTSTS                   ((uint32_t)0x001E0000)            /*!< OUT EP interrupt mask bits */

/********************  Bit definition forUSB_OTG_DAINTMSK register  ********************/
#define USB_OTG_DAINTMSK_IEPM                    ((uint32_t)0x0000FFFF)            /*!< IN EP interrupt mask bits */
#define USB_OTG_DAINTMSK_OEPM                    ((uint32_t)0xFFFF0000)            /*!< OUT EP interrupt mask bits */

/********************  Bit definition for OTG register  ********************/

#define USB_OTG_CHNUM                   ((uint32_t)0x0000000F)            /*!< Channel number */
#define USB_OTG_CHNUM_0                 ((uint32_t)0x00000001)            /*!<Bit 0 */
#define USB_OTG_CHNUM_1                 ((uint32_t)0x00000002)            /*!<Bit 1 */
#define USB_OTG_CHNUM_2                 ((uint32_t)0x00000004)            /*!<Bit 2 */
#define USB_OTG_CHNUM_3                 ((uint32_t)0x00000008)            /*!<Bit 3 */
#define USB_OTG_BCNT                    ((uint32_t)0x00007FF0)            /*!< Byte count */

#define USB_OTG_DPID                    ((uint32_t)0x00018000)            /*!< Data PID */
#define USB_OTG_DPID_0                  ((uint32_t)0x00008000)            /*!<Bit 0 */
#define USB_OTG_DPID_1                  ((uint32_t)0x00010000)            /*!<Bit 1 */

#define USB_OTG_PKTSTS                  ((uint32_t)0x001E0000)            /*!< Packet status */
#define USB_OTG_PKTSTS_0                ((uint32_t)0x00020000)            /*!<Bit 0 */
#define USB_OTG_PKTSTS_1                ((uint32_t)0x00040000)            /*!<Bit 1 */
#define USB_OTG_PKTSTS_2                ((uint32_t)0x00080000)            /*!<Bit 2 */
#define USB_OTG_PKTSTS_3                ((uint32_t)0x00100000)            /*!<Bit 3 */

#define USB_OTG_EPNUM                   ((uint32_t)0x0000000F)            /*!< Endpoint number */
#define USB_OTG_EPNUM_0                 ((uint32_t)0x00000001)            /*!<Bit 0 */
#define USB_OTG_EPNUM_1                 ((uint32_t)0x00000002)            /*!<Bit 1 */
#define USB_OTG_EPNUM_2                 ((uint32_t)0x00000004)            /*!<Bit 2 */
#define USB_OTG_EPNUM_3                 ((uint32_t)0x00000008)            /*!<Bit 3 */

#define USB_OTG_FRMNUM                  ((uint32_t)0x01E00000)            /*!< Frame number */
#define USB_OTG_FRMNUM_0                ((uint32_t)0x00200000)            /*!<Bit 0 */
#define USB_OTG_FRMNUM_1                ((uint32_t)0x00400000)            /*!<Bit 1 */
#define USB_OTG_FRMNUM_2                ((uint32_t)0x00800000)            /*!<Bit 2 */
#define USB_OTG_FRMNUM_3                ((uint32_t)0x01000000)            /*!<Bit 3 */

/********************  Bit definition for OTG register  ********************/

#define USB_OTG_CHNUM                   ((uint32_t)0x0000000F)            /*!< Channel number */
#define USB_OTG_CHNUM_0                 ((uint32_t)0x00000001)            /*!<Bit 0 */
#define USB_OTG_CHNUM_1                 ((uint32_t)0x00000002)            /*!<Bit 1 */
#define USB_OTG_CHNUM_2                 ((uint32_t)0x00000004)            /*!<Bit 2 */
#define USB_OTG_CHNUM_3                 ((uint32_t)0x00000008)            /*!<Bit 3 */
#define USB_OTG_BCNT                    ((uint32_t)0x00007FF0)            /*!< Byte count */

#define USB_OTG_DPID                    ((uint32_t)0x00018000)            /*!< Data PID */
#define USB_OTG_DPID_0                  ((uint32_t)0x00008000)            /*!<Bit 0 */
#define USB_OTG_DPID_1                  ((uint32_t)0x00010000)            /*!<Bit 1 */

#define USB_OTG_PKTSTS                  ((uint32_t)0x001E0000)            /*!< Packet status */
#define USB_OTG_PKTSTS_0                ((uint32_t)0x00020000)            /*!<Bit 0 */
#define USB_OTG_PKTSTS_1                ((uint32_t)0x00040000)            /*!<Bit 1 */
#define USB_OTG_PKTSTS_2                ((uint32_t)0x00080000)            /*!<Bit 2 */
#define USB_OTG_PKTSTS_3                ((uint32_t)0x00100000)            /*!<Bit 3 */

#define USB_OTG_EPNUM                   ((uint32_t)0x0000000F)            /*!< Endpoint number */
#define USB_OTG_EPNUM_0                 ((uint32_t)0x00000001)            /*!<Bit 0 */
#define USB_OTG_EPNUM_1                 ((uint32_t)0x00000002)            /*!<Bit 1 */
#define USB_OTG_EPNUM_2                 ((uint32_t)0x00000004)            /*!<Bit 2 */
#define USB_OTG_EPNUM_3                 ((uint32_t)0x00000008)            /*!<Bit 3 */

#define USB_OTG_FRMNUM                  ((uint32_t)0x01E00000)            /*!< Frame number */
#define USB_OTG_FRMNUM_0                ((uint32_t)0x00200000)            /*!<Bit 0 */
#define USB_OTG_FRMNUM_1                ((uint32_t)0x00400000)            /*!<Bit 1 */
#define USB_OTG_FRMNUM_2                ((uint32_t)0x00800000)            /*!<Bit 2 */
#define USB_OTG_FRMNUM_3                ((uint32_t)0x01000000)            /*!<Bit 3 */

/********************  Bit definition forUSB_OTG_GRXFSIZ register  ********************/
#define USB_OTG_GRXFSIZ_RXFD            ((uint32_t)0x0000FFFF)            /*!< RxFIFO depth */

/********************  Bit definition forUSB_OTG_DVBUSDIS register  ********************/
#define USB_OTG_DVBUSDIS_VBUSDT         ((uint32_t)0x0000FFFF)            /*!< Device VBUS discharge time */

/********************  Bit definition for OTG register  ********************/
#define USB_OTG_NPTXFSA                 ((uint32_t)0x0000FFFF)            /*!< Nonperiodic transmit RAM start address */
#define USB_OTG_NPTXFD                  ((uint32_t)0xFFFF0000)            /*!< Nonperiodic TxFIFO depth               */
#define USB_OTG_TX0FSA                  ((uint32_t)0x0000FFFF)            /*!< Endpoint 0 transmit RAM start address  */
#define USB_OTG_TX0FD                   ((uint32_t)0xFFFF0000)            /*!< Endpoint 0 TxFIFO depth                */

/********************  Bit definition forUSB_OTG_DVBUSPULSE register  ********************/
#define USB_OTG_DVBUSPULSE_DVBUSP                  ((uint32_t)0x00000FFF)            /*!< Device VBUS pulsing time */

/********************  Bit definition forUSB_OTG_GNPTXSTS register  ********************/
#define USB_OTG_GNPTXSTS_NPTXFSAV                ((uint32_t)0x0000FFFF)            /*!< Nonperiodic TxFIFO space available */

#define USB_OTG_GNPTXSTS_NPTQXSAV                ((uint32_t)0x00FF0000)            /*!< Nonperiodic transmit request queue space available */
#define USB_OTG_GNPTXSTS_NPTQXSAV_0              ((uint32_t)0x00010000)            /*!<Bit 0 */
#define USB_OTG_GNPTXSTS_NPTQXSAV_1              ((uint32_t)0x00020000)            /*!<Bit 1 */
#define USB_OTG_GNPTXSTS_NPTQXSAV_2              ((uint32_t)0x00040000)            /*!<Bit 2 */
#define USB_OTG_GNPTXSTS_NPTQXSAV_3              ((uint32_t)0x00080000)            /*!<Bit 3 */
#define USB_OTG_GNPTXSTS_NPTQXSAV_4              ((uint32_t)0x00100000)            /*!<Bit 4 */
#define USB_OTG_GNPTXSTS_NPTQXSAV_5              ((uint32_t)0x00200000)            /*!<Bit 5 */
#define USB_OTG_GNPTXSTS_NPTQXSAV_6              ((uint32_t)0x00400000)            /*!<Bit 6 */
#define USB_OTG_GNPTXSTS_NPTQXSAV_7              ((uint32_t)0x00800000)            /*!<Bit 7 */

#define USB_OTG_GNPTXSTS_NPTXQTOP                ((uint32_t)0x7F000000)            /*!< Top of the nonperiodic transmit request queue */
#define USB_OTG_GNPTXSTS_NPTXQTOP_0              ((uint32_t)0x01000000)            /*!<Bit 0 */
#define USB_OTG_GNPTXSTS_NPTXQTOP_1              ((uint32_t)0x02000000)            /*!<Bit 1 */
#define USB_OTG_GNPTXSTS_NPTXQTOP_2              ((uint32_t)0x04000000)            /*!<Bit 2 */
#define USB_OTG_GNPTXSTS_NPTXQTOP_3              ((uint32_t)0x08000000)            /*!<Bit 3 */
#define USB_OTG_GNPTXSTS_NPTXQTOP_4              ((uint32_t)0x10000000)            /*!<Bit 4 */
#define USB_OTG_GNPTXSTS_NPTXQTOP_5              ((uint32_t)0x20000000)            /*!<Bit 5 */
#define USB_OTG_GNPTXSTS_NPTXQTOP_6              ((uint32_t)0x40000000)            /*!<Bit 6 */

/********************  Bit definition forUSB_OTG_DTHRCTL register  ********************/
#define USB_OTG_DTHRCTL_NONISOTHREN             ((uint32_t)0x00000001)            /*!< Nonisochronous IN endpoints threshold enable */
#define USB_OTG_DTHRCTL_ISOTHREN                ((uint32_t)0x00000002)            /*!< ISO IN endpoint threshold enable */

#define USB_OTG_DTHRCTL_TXTHRLEN                ((uint32_t)0x000007FC)            /*!< Transmit threshold length */
#define USB_OTG_DTHRCTL_TXTHRLEN_0              ((uint32_t)0x00000004)            /*!<Bit 0 */
#define USB_OTG_DTHRCTL_TXTHRLEN_1              ((uint32_t)0x00000008)            /*!<Bit 1 */
#define USB_OTG_DTHRCTL_TXTHRLEN_2              ((uint32_t)0x00000010)            /*!<Bit 2 */
#define USB_OTG_DTHRCTL_TXTHRLEN_3              ((uint32_t)0x00000020)            /*!<Bit 3 */
#define USB_OTG_DTHRCTL_TXTHRLEN_4              ((uint32_t)0x00000040)            /*!<Bit 4 */
#define USB_OTG_DTHRCTL_TXTHRLEN_5              ((uint32_t)0x00000080)            /*!<Bit 5 */
#define USB_OTG_DTHRCTL_TXTHRLEN_6              ((uint32_t)0x00000100)            /*!<Bit 6 */
#define USB_OTG_DTHRCTL_TXTHRLEN_7              ((uint32_t)0x00000200)            /*!<Bit 7 */
#define USB_OTG_DTHRCTL_TXTHRLEN_8              ((uint32_t)0x00000400)            /*!<Bit 8 */
#define USB_OTG_DTHRCTL_RXTHREN                 ((uint32_t)0x00010000)            /*!< Receive threshold enable */

#define USB_OTG_DTHRCTL_RXTHRLEN                ((uint32_t)0x03FE0000)            /*!< Receive threshold length */
#define USB_OTG_DTHRCTL_RXTHRLEN_0              ((uint32_t)0x00020000)            /*!<Bit 0 */
#define USB_OTG_DTHRCTL_RXTHRLEN_1              ((uint32_t)0x00040000)            /*!<Bit 1 */
#define USB_OTG_DTHRCTL_RXTHRLEN_2              ((uint32_t)0x00080000)            /*!<Bit 2 */
#define USB_OTG_DTHRCTL_RXTHRLEN_3              ((uint32_t)0x00100000)            /*!<Bit 3 */
#define USB_OTG_DTHRCTL_RXTHRLEN_4              ((uint32_t)0x00200000)            /*!<Bit 4 */
#define USB_OTG_DTHRCTL_RXTHRLEN_5              ((uint32_t)0x00400000)            /*!<Bit 5 */
#define USB_OTG_DTHRCTL_RXTHRLEN_6              ((uint32_t)0x00800000)            /*!<Bit 6 */
#define USB_OTG_DTHRCTL_RXTHRLEN_7              ((uint32_t)0x01000000)            /*!<Bit 7 */
#define USB_OTG_DTHRCTL_RXTHRLEN_8              ((uint32_t)0x02000000)            /*!<Bit 8 */
#define USB_OTG_DTHRCTL_ARPEN                   ((uint32_t)0x08000000)            /*!< Arbiter parking enable */

/********************  Bit definition forUSB_OTG_DIEPEMPMSK register  ********************/
#define USB_OTG_DIEPEMPMSK_INEPTXFEM               ((uint32_t)0x0000FFFF)            /*!< IN EP Tx FIFO empty interrupt mask bits */

/********************  Bit definition forUSB_OTG_DEACHINT register  ********************/
#define USB_OTG_DEACHINT_IEP1INT                 ((uint32_t)0x00000002)            /*!< IN endpoint 1interrupt bit   */
#define USB_OTG_DEACHINT_OEP1INT                 ((uint32_t)0x00020000)            /*!< OUT endpoint 1 interrupt bit */

/********************  Bit definition forUSB_OTG_GCCFG register  ********************/
#define USB_OTG_GCCFG_DCDET                  ((uint32_t)0x00000001U)            /*!< Data contact detection (DCD) status */
#define USB_OTG_GCCFG_PDET                   ((uint32_t)0x00000002U)            /*!< Primary detection (PD) status */
#define USB_OTG_GCCFG_SDET                   ((uint32_t)0x00000004U)            /*!< Secondary detection (SD) status */
#define USB_OTG_GCCFG_PS2DET                 ((uint32_t)0x00000008U)            /*!< DM pull-up detection status */
#define USB_OTG_GCCFG_PWRDWN                 ((uint32_t)0x00010000U)            /*!< Power down */
#define USB_OTG_GCCFG_BCDEN                  ((uint32_t)0x00020000U)            /*!< Battery charging detector (BCD) enable */
#define USB_OTG_GCCFG_DCDEN                  ((uint32_t)0x00040000U)            /*!< Data contact detection (DCD) mode enable*/
#define USB_OTG_GCCFG_PDEN                   ((uint32_t)0x00080000U)            /*!< Primary detection (PD) mode enable*/
#define USB_OTG_GCCFG_SDEN                   ((uint32_t)0x00100000U)            /*!< Secondary detection (SD) mode enable */
#define USB_OTG_GCCFG_VBDEN                  ((uint32_t)0x00200000U)            /*!< Secondary detection (SD) mode enable */

/********************  Bit definition forUSB_OTG_GPWRDN) register  ********************/
#define USB_OTG_GPWRDN_ADPMEN                 ((uint32_t)0x00000001)             /*!< ADP module enable */
#define USB_OTG_GPWRDN_ADPIF                  ((uint32_t)0x00800000)             /*!< ADP Interrupt flag */

/********************  Bit definition forUSB_OTG_DEACHINTMSK register  ********************/
#define USB_OTG_DEACHINTMSK_IEP1INTM                ((uint32_t)0x00000002)            /*!< IN Endpoint 1 interrupt mask bit  */
#define USB_OTG_DEACHINTMSK_OEP1INTM                ((uint32_t)0x00020000)            /*!< OUT Endpoint 1 interrupt mask bit */

/********************  Bit definition forUSB_OTG_CID register  ********************/
#define USB_OTG_CID_PRODUCT_ID              ((uint32_t)0xFFFFFFFF)            /*!< Product ID field */

/********************  Bit definition for USB_OTG_GLPMCFG register  ********************/
#define  USB_OTG_GLPMCFG_LPMEN               ((uint32_t)0x00000001)            /*!< LPM support enable                                     */
#define  USB_OTG_GLPMCFG_LPMACK              ((uint32_t)0x00000002)            /*!< LPM Token acknowledge enable                           */
#define  USB_OTG_GLPMCFG_BESL                ((uint32_t)0x0000003C)            /*!< BESL value received with last ACKed LPM Token          */
#define  USB_OTG_GLPMCFG_REMWAKE             ((uint32_t)0x00000040)            /*!< bRemoteWake value received with last ACKed LPM Token   */
#define  USB_OTG_GLPMCFG_L1SSEN              ((uint32_t)0x00000080)            /*!< L1 shallow sleep enable                                */
#define  USB_OTG_GLPMCFG_BESLTHRS            ((uint32_t)0x00000F00)            /*!< BESL threshold                                         */
#define  USB_OTG_GLPMCFG_L1DSEN              ((uint32_t)0x00001000)            /*!< L1 deep sleep enable                                   */
#define  USB_OTG_GLPMCFG_LPMRSP              ((uint32_t)0x00006000)            /*!< LPM response                                           */
#define  USB_OTG_GLPMCFG_SLPSTS              ((uint32_t)0x00008000)            /*!< Port sleep status                                      */
#define  USB_OTG_GLPMCFG_L1RSMOK             ((uint32_t)0x00010000)            /*!< Sleep State Resume OK                                  */
#define  USB_OTG_GLPMCFG_LPMCHIDX            ((uint32_t)0x001E0000)            /*!< LPM Channel Index                                      */
#define  USB_OTG_GLPMCFG_LPMRCNT             ((uint32_t)0x00E00000)            /*!< LPM retry count                                        */
#define  USB_OTG_GLPMCFG_SNDLPM              ((uint32_t)0x01000000)            /*!< Send LPM transaction                                   */
#define  USB_OTG_GLPMCFG_LPMRCNTSTS          ((uint32_t)0x0E000000)            /*!< LPM retry count status                                 */
#define  USB_OTG_GLPMCFG_ENBESL              ((uint32_t)0x10000000)            /*!< Enable best effort service latency                     */

/********************  Bit definition forUSB_OTG_DIEPEACHMSK1 register  ********************/
#define USB_OTG_DIEPEACHMSK1_XFRCM                   ((uint32_t)0x00000001)            /*!< Transfer completed interrupt mask                 */
#define USB_OTG_DIEPEACHMSK1_EPDM                    ((uint32_t)0x00000002)            /*!< Endpoint disabled interrupt mask                  */
#define USB_OTG_DIEPEACHMSK1_TOM                     ((uint32_t)0x00000008)            /*!< Timeout condition mask (nonisochronous endpoints) */
#define USB_OTG_DIEPEACHMSK1_ITTXFEMSK               ((uint32_t)0x00000010)            /*!< IN token received when TxFIFO empty mask          */
#define USB_OTG_DIEPEACHMSK1_INEPNMM                 ((uint32_t)0x00000020)            /*!< IN token received with EP mismatch mask           */
#define USB_OTG_DIEPEACHMSK1_INEPNEM                 ((uint32_t)0x00000040)            /*!< IN endpoint NAK effective mask                    */
#define USB_OTG_DIEPEACHMSK1_TXFURM                  ((uint32_t)0x00000100)            /*!< FIFO underrun mask */
#define USB_OTG_DIEPEACHMSK1_BIM                     ((uint32_t)0x00000200)            /*!< BNA interrupt mask */
#define USB_OTG_DIEPEACHMSK1_NAKM                    ((uint32_t)0x00002000)            /*!< NAK interrupt mask */

/********************  Bit definition forUSB_OTG_HPRT register  ********************/
#define USB_OTG_HPRT_PCSTS                   ((uint32_t)0x00000001)            /*!< Port connect status        */
#define USB_OTG_HPRT_PCDET                   ((uint32_t)0x00000002)            /*!< Port connect detected      */
#define USB_OTG_HPRT_PENA                    ((uint32_t)0x00000004)            /*!< Port enable                */
#define USB_OTG_HPRT_PENCHNG                 ((uint32_t)0x00000008)            /*!< Port enable/disable change */
#define USB_OTG_HPRT_POCA                    ((uint32_t)0x00000010)            /*!< Port overcurrent active    */
#define USB_OTG_HPRT_POCCHNG                 ((uint32_t)0x00000020)            /*!< Port overcurrent change    */
#define USB_OTG_HPRT_PRES                    ((uint32_t)0x00000040)            /*!< Port resume   */
#define USB_OTG_HPRT_PSUSP                   ((uint32_t)0x00000080)            /*!< Port suspend  */
#define USB_OTG_HPRT_PRST                    ((uint32_t)0x00000100)            /*!< Port reset    */

#define USB_OTG_HPRT_PLSTS                   ((uint32_t)0x00000C00)            /*!< Port line status */
#define USB_OTG_HPRT_PLSTS_0                 ((uint32_t)0x00000400)            /*!<Bit 0 */
#define USB_OTG_HPRT_PLSTS_1                 ((uint32_t)0x00000800)            /*!<Bit 1 */
#define USB_OTG_HPRT_PPWR                    ((uint32_t)0x00001000)            /*!< Port power */

#define USB_OTG_HPRT_PTCTL                   ((uint32_t)0x0001E000)            /*!< Port test control */
#define USB_OTG_HPRT_PTCTL_0                 ((uint32_t)0x00002000)            /*!<Bit 0 */
#define USB_OTG_HPRT_PTCTL_1                 ((uint32_t)0x00004000)            /*!<Bit 1 */
#define USB_OTG_HPRT_PTCTL_2                 ((uint32_t)0x00008000)            /*!<Bit 2 */
#define USB_OTG_HPRT_PTCTL_3                 ((uint32_t)0x00010000)            /*!<Bit 3 */

#define USB_OTG_HPRT_PSPD                    ((uint32_t)0x00060000)            /*!< Port speed */
#define USB_OTG_HPRT_PSPD_0                  ((uint32_t)0x00020000)            /*!<Bit 0 */
#define USB_OTG_HPRT_PSPD_1                  ((uint32_t)0x00040000)            /*!<Bit 1 */

/********************  Bit definition forUSB_OTG_DOEPEACHMSK1 register  ********************/
#define USB_OTG_DOEPEACHMSK1_XFRCM                   ((uint32_t)0x00000001)            /*!< Transfer completed interrupt mask */
#define USB_OTG_DOEPEACHMSK1_EPDM                    ((uint32_t)0x00000002)            /*!< Endpoint disabled interrupt mask */
#define USB_OTG_DOEPEACHMSK1_TOM                     ((uint32_t)0x00000008)            /*!< Timeout condition mask */
#define USB_OTG_DOEPEACHMSK1_ITTXFEMSK               ((uint32_t)0x00000010)            /*!< IN token received when TxFIFO empty mask */
#define USB_OTG_DOEPEACHMSK1_INEPNMM                 ((uint32_t)0x00000020)            /*!< IN token received with EP mismatch mask */
#define USB_OTG_DOEPEACHMSK1_INEPNEM                 ((uint32_t)0x00000040)            /*!< IN endpoint NAK effective mask */
#define USB_OTG_DOEPEACHMSK1_TXFURM                  ((uint32_t)0x00000100)            /*!< OUT packet error mask */
#define USB_OTG_DOEPEACHMSK1_BIM                     ((uint32_t)0x00000200)            /*!< BNA interrupt mask */
#define USB_OTG_DOEPEACHMSK1_BERRM                   ((uint32_t)0x00001000)            /*!< Bubble error interrupt mask */
#define USB_OTG_DOEPEACHMSK1_NAKM                    ((uint32_t)0x00002000)            /*!< NAK interrupt mask */
#define USB_OTG_DOEPEACHMSK1_NYETM                   ((uint32_t)0x00004000)            /*!< NYET interrupt mask */

/********************  Bit definition forUSB_OTG_HPTXFSIZ register  ********************/
#define USB_OTG_HPTXFSIZ_PTXSA                   ((uint32_t)0x0000FFFF)            /*!< Host periodic TxFIFO start address */
#define USB_OTG_HPTXFSIZ_PTXFD                   ((uint32_t)0xFFFF0000)            /*!< Host periodic TxFIFO depth */

/********************  Bit definition forUSB_OTG_DIEPCTL register  ********************/
#define USB_OTG_DIEPCTL_MPSIZ                   ((uint32_t)0x000007FF)            /*!< Maximum packet size */
#define USB_OTG_DIEPCTL_USBAEP                  ((uint32_t)0x00008000)            /*!< USB active endpoint */
#define USB_OTG_DIEPCTL_EONUM_DPID              ((uint32_t)0x00010000)            /*!< Even/odd frame */
#define USB_OTG_DIEPCTL_NAKSTS                  ((uint32_t)0x00020000)            /*!< NAK status */

#define USB_OTG_DIEPCTL_EPTYP                   ((uint32_t)0x000C0000)            /*!< Endpoint type */
#define USB_OTG_DIEPCTL_EPTYP_0                 ((uint32_t)0x00040000)            /*!<Bit 0 */
#define USB_OTG_DIEPCTL_EPTYP_1                 ((uint32_t)0x00080000)            /*!<Bit 1 */
#define USB_OTG_DIEPCTL_STALL                   ((uint32_t)0x00200000)            /*!< STALL handshake */

#define USB_OTG_DIEPCTL_TXFNUM                  ((uint32_t)0x03C00000)            /*!< TxFIFO number */
#define USB_OTG_DIEPCTL_TXFNUM_0                ((uint32_t)0x00400000)            /*!<Bit 0 */
#define USB_OTG_DIEPCTL_TXFNUM_1                ((uint32_t)0x00800000)            /*!<Bit 1 */
#define USB_OTG_DIEPCTL_TXFNUM_2                ((uint32_t)0x01000000)            /*!<Bit 2 */
#define USB_OTG_DIEPCTL_TXFNUM_3                ((uint32_t)0x02000000)            /*!<Bit 3 */
#define USB_OTG_DIEPCTL_CNAK                    ((uint32_t)0x04000000)            /*!< Clear NAK */
#define USB_OTG_DIEPCTL_SNAK                    ((uint32_t)0x08000000)            /*!< Set NAK */
#define USB_OTG_DIEPCTL_SD0PID_SEVNFRM          ((uint32_t)0x10000000)            /*!< Set DATA0 PID */
#define USB_OTG_DIEPCTL_SODDFRM                 ((uint32_t)0x20000000)            /*!< Set odd frame */
#define USB_OTG_DIEPCTL_EPDIS                   ((uint32_t)0x40000000)            /*!< Endpoint disable */
#define USB_OTG_DIEPCTL_EPENA                   ((uint32_t)0x80000000)            /*!< Endpoint enable */

/********************  Bit definition forUSB_OTG_HCCHAR register  ********************/
#define USB_OTG_HCCHAR_MPSIZ                   ((uint32_t)0x000007FF)            /*!< Maximum packet size */

#define USB_OTG_HCCHAR_EPNUM                   ((uint32_t)0x00007800)            /*!< Endpoint number */
#define USB_OTG_HCCHAR_EPNUM_0                 ((uint32_t)0x00000800)            /*!<Bit 0 */
#define USB_OTG_HCCHAR_EPNUM_1                 ((uint32_t)0x00001000)            /*!<Bit 1 */
#define USB_OTG_HCCHAR_EPNUM_2                 ((uint32_t)0x00002000)            /*!<Bit 2 */
#define USB_OTG_HCCHAR_EPNUM_3                 ((uint32_t)0x00004000)            /*!<Bit 3 */
#define USB_OTG_HCCHAR_EPDIR                   ((uint32_t)0x00008000)            /*!< Endpoint direction */
#define USB_OTG_HCCHAR_LSDEV                   ((uint32_t)0x00020000)            /*!< Low-speed device */

#define USB_OTG_HCCHAR_EPTYP                   ((uint32_t)0x000C0000)            /*!< Endpoint type */
#define USB_OTG_HCCHAR_EPTYP_0                 ((uint32_t)0x00040000)            /*!<Bit 0 */
#define USB_OTG_HCCHAR_EPTYP_1                 ((uint32_t)0x00080000)            /*!<Bit 1 */

#define USB_OTG_HCCHAR_MC                      ((uint32_t)0x00300000)            /*!< Multi Count (MC) / Error Count (EC) */
#define USB_OTG_HCCHAR_MC_0                    ((uint32_t)0x00100000)            /*!<Bit 0 */
#define USB_OTG_HCCHAR_MC_1                    ((uint32_t)0x00200000)            /*!<Bit 1 */

#define USB_OTG_HCCHAR_DAD                     ((uint32_t)0x1FC00000)            /*!< Device address */
#define USB_OTG_HCCHAR_DAD_0                   ((uint32_t)0x00400000)            /*!<Bit 0 */
#define USB_OTG_HCCHAR_DAD_1                   ((uint32_t)0x00800000)            /*!<Bit 1 */
#define USB_OTG_HCCHAR_DAD_2                   ((uint32_t)0x01000000)            /*!<Bit 2 */
#define USB_OTG_HCCHAR_DAD_3                   ((uint32_t)0x02000000)            /*!<Bit 3 */
#define USB_OTG_HCCHAR_DAD_4                   ((uint32_t)0x04000000)            /*!<Bit 4 */
#define USB_OTG_HCCHAR_DAD_5                   ((uint32_t)0x08000000)            /*!<Bit 5 */
#define USB_OTG_HCCHAR_DAD_6                   ((uint32_t)0x10000000)            /*!<Bit 6 */
#define USB_OTG_HCCHAR_ODDFRM                  ((uint32_t)0x20000000)            /*!< Odd frame */
#define USB_OTG_HCCHAR_CHDIS                   ((uint32_t)0x40000000)            /*!< Channel disable */
#define USB_OTG_HCCHAR_CHENA                   ((uint32_t)0x80000000)            /*!< Channel enable */

/********************  Bit definition forUSB_OTG_HCSPLT register  ********************/

#define USB_OTG_HCSPLT_PRTADDR                 ((uint32_t)0x0000007F)            /*!< Port address */
#define USB_OTG_HCSPLT_PRTADDR_0               ((uint32_t)0x00000001)            /*!<Bit 0 */
#define USB_OTG_HCSPLT_PRTADDR_1               ((uint32_t)0x00000002)            /*!<Bit 1 */
#define USB_OTG_HCSPLT_PRTADDR_2               ((uint32_t)0x00000004)            /*!<Bit 2 */
#define USB_OTG_HCSPLT_PRTADDR_3               ((uint32_t)0x00000008)            /*!<Bit 3 */
#define USB_OTG_HCSPLT_PRTADDR_4               ((uint32_t)0x00000010)            /*!<Bit 4 */
#define USB_OTG_HCSPLT_PRTADDR_5               ((uint32_t)0x00000020)            /*!<Bit 5 */
#define USB_OTG_HCSPLT_PRTADDR_6               ((uint32_t)0x00000040)            /*!<Bit 6 */

#define USB_OTG_HCSPLT_HUBADDR                 ((uint32_t)0x00003F80)            /*!< Hub address */
#define USB_OTG_HCSPLT_HUBADDR_0               ((uint32_t)0x00000080)            /*!<Bit 0 */
#define USB_OTG_HCSPLT_HUBADDR_1               ((uint32_t)0x00000100)            /*!<Bit 1 */
#define USB_OTG_HCSPLT_HUBADDR_2               ((uint32_t)0x00000200)            /*!<Bit 2 */
#define USB_OTG_HCSPLT_HUBADDR_3               ((uint32_t)0x00000400)            /*!<Bit 3 */
#define USB_OTG_HCSPLT_HUBADDR_4               ((uint32_t)0x00000800)            /*!<Bit 4 */
#define USB_OTG_HCSPLT_HUBADDR_5               ((uint32_t)0x00001000)            /*!<Bit 5 */
#define USB_OTG_HCSPLT_HUBADDR_6               ((uint32_t)0x00002000)            /*!<Bit 6 */

#define USB_OTG_HCSPLT_XACTPOS                 ((uint32_t)0x0000C000)            /*!< XACTPOS */
#define USB_OTG_HCSPLT_XACTPOS_0               ((uint32_t)0x00004000)            /*!<Bit 0 */
#define USB_OTG_HCSPLT_XACTPOS_1               ((uint32_t)0x00008000)            /*!<Bit 1 */
#define USB_OTG_HCSPLT_COMPLSPLT               ((uint32_t)0x00010000)            /*!< Do complete split */
#define USB_OTG_HCSPLT_SPLITEN                 ((uint32_t)0x80000000)            /*!< Split enable */

/********************  Bit definition forUSB_OTG_HCINT register  ********************/
#define USB_OTG_HCINT_XFRC                    ((uint32_t)0x00000001)            /*!< Transfer completed */
#define USB_OTG_HCINT_CHH                     ((uint32_t)0x00000002)            /*!< Channel halted */
#define USB_OTG_HCINT_AHBERR                  ((uint32_t)0x00000004)            /*!< AHB error */
#define USB_OTG_HCINT_STALL                   ((uint32_t)0x00000008)            /*!< STALL response received interrupt */
#define USB_OTG_HCINT_NAK                     ((uint32_t)0x00000010)            /*!< NAK response received interrupt */
#define USB_OTG_HCINT_ACK                     ((uint32_t)0x00000020)            /*!< ACK response received/transmitted interrupt */
#define USB_OTG_HCINT_NYET                    ((uint32_t)0x00000040)            /*!< Response received interrupt */
#define USB_OTG_HCINT_TXERR                   ((uint32_t)0x00000080)            /*!< Transaction error */
#define USB_OTG_HCINT_BBERR                   ((uint32_t)0x00000100)            /*!< Babble error */
#define USB_OTG_HCINT_FRMOR                   ((uint32_t)0x00000200)            /*!< Frame overrun */
#define USB_OTG_HCINT_DTERR                   ((uint32_t)0x00000400)            /*!< Data toggle error */

/********************  Bit definition forUSB_OTG_DIEPINT register  ********************/
#define USB_OTG_DIEPINT_XFRC                    ((uint32_t)0x00000001)            /*!< Transfer completed interrupt */
#define USB_OTG_DIEPINT_EPDISD                  ((uint32_t)0x00000002)            /*!< Endpoint disabled interrupt */
#define USB_OTG_DIEPINT_TOC                     ((uint32_t)0x00000008)            /*!< Timeout condition */
#define USB_OTG_DIEPINT_ITTXFE                  ((uint32_t)0x00000010)            /*!< IN token received when TxFIFO is empty */
#define USB_OTG_DIEPINT_INEPNE                  ((uint32_t)0x00000040)            /*!< IN endpoint NAK effective */
#define USB_OTG_DIEPINT_TXFE                    ((uint32_t)0x00000080)            /*!< Transmit FIFO empty */
#define USB_OTG_DIEPINT_TXFIFOUDRN              ((uint32_t)0x00000100)            /*!< Transmit Fifo Underrun */
#define USB_OTG_DIEPINT_BNA                     ((uint32_t)0x00000200)            /*!< Buffer not available interrupt */
#define USB_OTG_DIEPINT_PKTDRPSTS               ((uint32_t)0x00000800)            /*!< Packet dropped status */
#define USB_OTG_DIEPINT_BERR                    ((uint32_t)0x00001000)            /*!< Babble error interrupt */
#define USB_OTG_DIEPINT_NAK                     ((uint32_t)0x00002000)            /*!< NAK interrupt */

/********************  Bit definition forUSB_OTG_HCINTMSK register  ********************/
#define USB_OTG_HCINTMSK_XFRCM                   ((uint32_t)0x00000001)            /*!< Transfer completed mask */
#define USB_OTG_HCINTMSK_CHHM                    ((uint32_t)0x00000002)            /*!< Channel halted mask */
#define USB_OTG_HCINTMSK_AHBERR                  ((uint32_t)0x00000004)            /*!< AHB error */
#define USB_OTG_HCINTMSK_STALLM                  ((uint32_t)0x00000008)            /*!< STALL response received interrupt mask */
#define USB_OTG_HCINTMSK_NAKM                    ((uint32_t)0x00000010)            /*!< NAK response received interrupt mask */
#define USB_OTG_HCINTMSK_ACKM                    ((uint32_t)0x00000020)            /*!< ACK response received/transmitted interrupt mask */
#define USB_OTG_HCINTMSK_NYET                    ((uint32_t)0x00000040)            /*!< response received interrupt mask */
#define USB_OTG_HCINTMSK_TXERRM                  ((uint32_t)0x00000080)            /*!< Transaction error mask */
#define USB_OTG_HCINTMSK_BBERRM                  ((uint32_t)0x00000100)            /*!< Babble error mask */
#define USB_OTG_HCINTMSK_FRMORM                  ((uint32_t)0x00000200)            /*!< Frame overrun mask */
#define USB_OTG_HCINTMSK_DTERRM                  ((uint32_t)0x00000400)            /*!< Data toggle error mask */

/********************  Bit definition for USB_OTG_DIEPTSIZ register  ********************/

#define USB_OTG_DIEPTSIZ_XFRSIZ                  ((uint32_t)0x0007FFFF)            /*!< Transfer size */
#define USB_OTG_DIEPTSIZ_PKTCNT                  ((uint32_t)0x1FF80000)            /*!< Packet count */
#define USB_OTG_DIEPTSIZ_MULCNT                  ((uint32_t)0x60000000)            /*!< Packet count */
/********************  Bit definition forUSB_OTG_HCTSIZ register  ********************/
#define USB_OTG_HCTSIZ_XFRSIZ                    ((uint32_t)0x0007FFFF)            /*!< Transfer size */
#define USB_OTG_HCTSIZ_PKTCNT                    ((uint32_t)0x1FF80000)            /*!< Packet count */
#define USB_OTG_HCTSIZ_DOPING                    ((uint32_t)0x80000000)            /*!< Do PING */
#define USB_OTG_HCTSIZ_DPID                      ((uint32_t)0x60000000)            /*!< Data PID */
#define USB_OTG_HCTSIZ_DPID_0                    ((uint32_t)0x20000000)            /*!<Bit 0 */
#define USB_OTG_HCTSIZ_DPID_1                    ((uint32_t)0x40000000)            /*!<Bit 1 */

/********************  Bit definition forUSB_OTG_DIEPDMA register  ********************/
#define USB_OTG_DIEPDMA_DMAADDR                  ((uint32_t)0xFFFFFFFF)            /*!< DMA address */

/********************  Bit definition forUSB_OTG_HCDMA register  ********************/
#define USB_OTG_HCDMA_DMAADDR                    ((uint32_t)0xFFFFFFFF)            /*!< DMA address */

/********************  Bit definition forUSB_OTG_DTXFSTS register  ********************/
#define USB_OTG_DTXFSTS_INEPTFSAV                ((uint32_t)0x0000FFFF)            /*!< IN endpoint TxFIFO space available */

/********************  Bit definition forUSB_OTG_DIEPTXF register  ********************/
#define USB_OTG_DIEPTXF_INEPTXSA                 ((uint32_t)0x0000FFFF)            /*!< IN endpoint FIFOx transmit RAM start address */
#define USB_OTG_DIEPTXF_INEPTXFD                 ((uint32_t)0xFFFF0000)            /*!< IN endpoint TxFIFO depth */

/********************  Bit definition forUSB_OTG_DOEPCTL register  ********************/

#define USB_OTG_DOEPCTL_MPSIZ                     ((uint32_t)0x000007FF)            /*!< Maximum packet size */          /*!<Bit 1 */
#define USB_OTG_DOEPCTL_USBAEP                    ((uint32_t)0x00008000)            /*!< USB active endpoint */
#define USB_OTG_DOEPCTL_NAKSTS                    ((uint32_t)0x00020000)            /*!< NAK status */
#define USB_OTG_DOEPCTL_SD0PID_SEVNFRM            ((uint32_t)0x10000000)            /*!< Set DATA0 PID */
#define USB_OTG_DOEPCTL_SODDFRM                   ((uint32_t)0x20000000)            /*!< Set odd frame */
#define USB_OTG_DOEPCTL_EPTYP                     ((uint32_t)0x000C0000)            /*!< Endpoint type */
#define USB_OTG_DOEPCTL_EPTYP_0                   ((uint32_t)0x00040000)            /*!<Bit 0 */
#define USB_OTG_DOEPCTL_EPTYP_1                   ((uint32_t)0x00080000)            /*!<Bit 1 */
#define USB_OTG_DOEPCTL_SNPM                      ((uint32_t)0x00100000)            /*!< Snoop mode */
#define USB_OTG_DOEPCTL_STALL                     ((uint32_t)0x00200000)            /*!< STALL handshake */
#define USB_OTG_DOEPCTL_CNAK                      ((uint32_t)0x04000000)            /*!< Clear NAK */
#define USB_OTG_DOEPCTL_SNAK                      ((uint32_t)0x08000000)            /*!< Set NAK */
#define USB_OTG_DOEPCTL_EPDIS                     ((uint32_t)0x40000000)            /*!< Endpoint disable */
#define USB_OTG_DOEPCTL_EPENA                     ((uint32_t)0x80000000)            /*!< Endpoint enable */

/********************  Bit definition forUSB_OTG_DOEPINT register  ********************/
#define USB_OTG_DOEPINT_XFRC                    ((uint32_t)0x00000001)            /*!< Transfer completed interrupt */
#define USB_OTG_DOEPINT_EPDISD                  ((uint32_t)0x00000002)            /*!< Endpoint disabled interrupt */
#define USB_OTG_DOEPINT_STUP                    ((uint32_t)0x00000008)            /*!< SETUP phase done */
#define USB_OTG_DOEPINT_OTEPDIS                 ((uint32_t)0x00000010)            /*!< OUT token received when endpoint disabled */
#define USB_OTG_DOEPINT_B2BSTUP                 ((uint32_t)0x00000040)            /*!< Back-to-back SETUP packets received */
#define USB_OTG_DOEPINT_NYET                    ((uint32_t)0x00004000)            /*!< NYET interrupt */

/********************  Bit definition forUSB_OTG_DOEPTSIZ register  ********************/

#define USB_OTG_DOEPTSIZ_XFRSIZ                  ((uint32_t)0x0007FFFF)            /*!< Transfer size */
#define USB_OTG_DOEPTSIZ_PKTCNT                  ((uint32_t)0x1FF80000)            /*!< Packet count */

#define USB_OTG_DOEPTSIZ_STUPCNT                 ((uint32_t)0x60000000)            /*!< SETUP packet count */
#define USB_OTG_DOEPTSIZ_STUPCNT_0               ((uint32_t)0x20000000)            /*!<Bit 0 */
#define USB_OTG_DOEPTSIZ_STUPCNT_1               ((uint32_t)0x40000000)            /*!<Bit 1 */

/********************  Bit definition for PCGCCTL register  ********************/
#define USB_OTG_PCGCCTL_STOPCLK                 ((uint32_t)0x00000001)            /*!< SETUP packet count */
#define USB_OTG_PCGCCTL_GATECLK                 ((uint32_t)0x00000002)            /*!<Bit 0 */
#define USB_OTG_PCGCCTL_PHYSUSP                 ((uint32_t)0x00000010)            /*!<Bit 1 */

/**
  * @}
  */

/**
  * @}
  */

/** @addtogroup Exported_macros
  * @{
  */

/******************************* ADC Instances ********************************/
#define IS_ADC_ALL_INSTANCE(INSTANCE) (((INSTANCE) == ADC1) || \
                                       ((INSTANCE) == ADC2) || \
                                       ((INSTANCE) == ADC3))

#define IS_ADC_MULTIMODE_MASTER_INSTANCE(INSTANCE) ((INSTANCE) == ADC1)

#define IS_ADC_COMMON_INSTANCE(INSTANCE) ((INSTANCE) == ADC123_COMMON)

/******************************** COMP Instances ******************************/
#define IS_COMP_ALL_INSTANCE(INSTANCE) (((INSTANCE) == COMP1) || \
                                       ((INSTANCE) == COMP2))

#define IS_COMP_COMMON_INSTANCE(INSTANCE) ((INSTANCE) == COMP12_COMMON)
/******************** COMP Instances with window mode capability **************/
#define IS_COMP_WINDOWMODE_INSTANCE(INSTANCE) ((INSTANCE) == COMP2) 

/******************************* CRC Instances ********************************/
#define IS_CRC_ALL_INSTANCE(INSTANCE) ((INSTANCE) == CRC)

/******************************* DAC Instances ********************************/
#define IS_DAC_ALL_INSTANCE(INSTANCE) ((INSTANCE) == DAC1)

/******************************* DCMI Instances *******************************/
#define IS_DCMI_ALL_INSTANCE(__INSTANCE__) ((__INSTANCE__) == DCMI)

/****************************** DFSDM Instances *******************************/
#define IS_DFSDM_FILTER_ALL_INSTANCE(INSTANCE) (((INSTANCE) == DFSDM1_Filter0) || \
                                         ((INSTANCE) == DFSDM1_Filter1) || \
                                         ((INSTANCE) == DFSDM1_Filter2) || \
                                         ((INSTANCE) == DFSDM1_Filter3))

#define IS_DFSDM_CHANNEL_ALL_INSTANCE(INSTANCE) (((INSTANCE) == DFSDM1_Channel0) || \
                                                 ((INSTANCE) == DFSDM1_Channel1) || \
                                                 ((INSTANCE) == DFSDM1_Channel2) || \
                                                 ((INSTANCE) == DFSDM1_Channel3) || \
                                                 ((INSTANCE) == DFSDM1_Channel4) || \
                                                 ((INSTANCE) == DFSDM1_Channel5) || \
                                                 ((INSTANCE) == DFSDM1_Channel6) || \
                                                 ((INSTANCE) == DFSDM1_Channel7))

/******************************** DMA Instances *******************************/
#define IS_DMA_STREAM_ALL_INSTANCE(INSTANCE) (((INSTANCE) == DMA1_Stream0) || \
                                             ((INSTANCE) == DMA1_Stream1) || \
                                             ((INSTANCE) == DMA1_Stream2) || \
                                             ((INSTANCE) == DMA1_Stream3) || \
                                             ((INSTANCE) == DMA1_Stream4) || \
                                             ((INSTANCE) == DMA1_Stream5) || \
                                             ((INSTANCE) == DMA1_Stream6) || \
                                             ((INSTANCE) == DMA1_Stream7) || \
                                             ((INSTANCE) == DMA2_Stream0) || \
                                             ((INSTANCE) == DMA2_Stream1) || \
                                             ((INSTANCE) == DMA2_Stream2) || \
                                             ((INSTANCE) == DMA2_Stream3) || \
                                             ((INSTANCE) == DMA2_Stream4) || \
                                             ((INSTANCE) == DMA2_Stream5) || \
                                             ((INSTANCE) == DMA2_Stream6) || \
                                             ((INSTANCE) == DMA2_Stream7) || \
                                             ((INSTANCE) == BDMA_Channel0) || \
                                             ((INSTANCE) == BDMA_Channel1) || \
                                             ((INSTANCE) == BDMA_Channel2) || \
                                             ((INSTANCE) == BDMA_Channel3) || \
                                             ((INSTANCE) == BDMA_Channel4) || \
                                             ((INSTANCE) == BDMA_Channel5) || \
                                             ((INSTANCE) == BDMA_Channel6) || \
                                             ((INSTANCE) == BDMA_Channel7))

/******************************** DMA Request Generator Instances **************/
#define IS_DMA_REQUEST_GEN_ALL_INSTANCE(INSTANCE) (((INSTANCE) == DMAMUX1_RequestGenerator0) || \
                                                   ((INSTANCE) == DMAMUX1_RequestGenerator1) || \
                                                   ((INSTANCE) == DMAMUX1_RequestGenerator2) || \
                                                   ((INSTANCE) == DMAMUX1_RequestGenerator3) || \
                                                   ((INSTANCE) == DMAMUX2_RequestGenerator0) || \
                                                   ((INSTANCE) == DMAMUX2_RequestGenerator1) || \
                                                   ((INSTANCE) == DMAMUX2_RequestGenerator2) || \
                                                   ((INSTANCE) == DMAMUX2_RequestGenerator3))

/******************************* DMA2D Instances *******************************/
#define IS_DMA2D_ALL_INSTANCE(__INSTANCE__) ((__INSTANCE__) == DMA2D)

/******************************** MDMA Request Generator Instances **************/
#define IS_MDMA_STREAM_ALL_INSTANCE(INSTANCE) (((INSTANCE) == MDMA_Channel0) || \
                                               ((INSTANCE) == MDMA_Channel1) || \
                                               ((INSTANCE) == MDMA_Channel2) || \
                                               ((INSTANCE) == MDMA_Channel3) || \
                                               ((INSTANCE) == MDMA_Channel4) || \
                                               ((INSTANCE) == MDMA_Channel5) || \
                                               ((INSTANCE) == MDMA_Channel6) || \
                                               ((INSTANCE) == MDMA_Channel7) || \
                                               ((INSTANCE) == MDMA_Channel8) || \
                                               ((INSTANCE) == MDMA_Channel9)  || \
                                               ((INSTANCE) == MDMA_Channel10) || \
                                               ((INSTANCE) == MDMA_Channel11) || \
                                               ((INSTANCE) == MDMA_Channel12) || \
                                               ((INSTANCE) == MDMA_Channel13) || \
                                               ((INSTANCE) == MDMA_Channel14) || \
                                               ((INSTANCE) == MDMA_Channel15) || \
                                               ((INSTANCE) == MDMA_Channel16))
/******************************* QUADSPI Instances *******************************/
#define IS_QSPI_ALL_INSTANCE(__INSTANCE__) ((__INSTANCE__) == QUADSPI)

/******************************* GPIO Instances *******************************/
#define IS_GPIO_ALL_INSTANCE(INSTANCE) (((INSTANCE) == GPIOA) || \
                                        ((INSTANCE) == GPIOB) || \
                                        ((INSTANCE) == GPIOC) || \
                                        ((INSTANCE) == GPIOD) || \
                                        ((INSTANCE) == GPIOE) || \
                                        ((INSTANCE) == GPIOF) || \
                                        ((INSTANCE) == GPIOG) || \
                                        ((INSTANCE) == GPIOH) || \
                                        ((INSTANCE) == GPIOI) || \
                                        ((INSTANCE) == GPIOJ) || \
                                        ((INSTANCE) == GPIOK))

/**************************** GPIO Lock Instances *****************************/
/* On L4, all GPIO Bank support the Lock mechanism */
#define IS_GPIO_LOCK_INSTANCE(INSTANCE) IS_GPIO_ALL_INSTANCE(INSTANCE)

/******************************** HSEM Instances *******************************/
#define IS_HSEM_ALL_INSTANCE(INSTANCE) ((INSTANCE) == HSEM)

/******************************** I2C Instances *******************************/
#define IS_I2C_ALL_INSTANCE(INSTANCE) (((INSTANCE) == I2C1) || \
                                       ((INSTANCE) == I2C2) || \
                                       ((INSTANCE) == I2C3) || \
                                       ((INSTANCE) == I2C4))
/************** I2C Instances : wakeup capability from stop modes *************/
#define IS_I2C_WAKEUP_FROMSTOP_INSTANCE(INSTANCE) IS_I2C_ALL_INSTANCE(INSTANCE)

/****************************** SMBUS Instances *******************************/
#define IS_SMBUS_ALL_INSTANCE(INSTANCE) (((INSTANCE) == I2C1) || \
                                         ((INSTANCE) == I2C2) || \
                                         ((INSTANCE) == I2C3) || \
                                         ((INSTANCE) == I2C4))
/******************************** I2S Instances *******************************/
#define IS_I2S_INSTANCE(INSTANCE)  ((INSTANCE) == SPI2)

/****************************** LTDC Instances ********************************/
#define IS_LTDC_ALL_INSTANCE(INSTANCE)  ((INSTANCE) == LTDC)

/******************************* RNG Instances ********************************/
#define IS_RNG_ALL_INSTANCE(INSTANCE)  ((INSTANCE) == RNG)

/****************************** RTC Instances *********************************/
#define IS_RTC_ALL_INSTANCE(INSTANCE)  ((INSTANCE) == RTC)

/******************************** SMBUS Instances *****************************/
#define IS_SMBUS_INSTANCE(INSTANCE)  ((INSTANCE) == I2C1)

/******************************** SPI Instances *******************************/
#define IS_SPI_ALL_INSTANCE(INSTANCE) (((INSTANCE) == SPI1) || \
                                       ((INSTANCE) == SPI2))

/******************************** SWPMI Instances *****************************/
#define IS_SWPMI_INSTANCE(INSTANCE)  ((INSTANCE) == SWPMI1)

/****************** LPTIM Instances : All supported instances *****************/
#define IS_LPTIM_INSTANCE(INSTANCE)     (((INSTANCE) == LPTIM1) || \
                                         ((INSTANCE) == LPTIM2) || \
                                         ((INSTANCE) == LPTIM3) ||\
                                         ((INSTANCE) == LPTIM4) ||\
                                         ((INSTANCE) == LPTIM5))

/****************** TIM Instances : All supported instances *******************/
#define IS_TIM_INSTANCE(INSTANCE)       (((INSTANCE) == TIM1)   || \
                                         ((INSTANCE) == TIM2)   || \
                                         ((INSTANCE) == TIM3)   || \
                                         ((INSTANCE) == TIM4)   || \
                                         ((INSTANCE) == TIM5)   || \
                                         ((INSTANCE) == TIM6)   || \
                                         ((INSTANCE) == TIM7)   || \
                                         ((INSTANCE) == TIM8)   || \
                                         ((INSTANCE) == TIM12)  || \
                                         ((INSTANCE) == TIM13)  || \
                                         ((INSTANCE) == TIM14)  || \
                                         ((INSTANCE) == TIM15)  || \
                                         ((INSTANCE) == TIM16)  || \
                                         ((INSTANCE) == TIM17))
/************* TIM Instances : at least 1 capture/compare channel *************/
#define IS_TIM_CC1_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                         ((INSTANCE) == TIM2)   || \
                                         ((INSTANCE) == TIM3)   || \
                                         ((INSTANCE) == TIM4)   || \
                                         ((INSTANCE) == TIM5)   || \
                                         ((INSTANCE) == TIM8)   || \
                                         ((INSTANCE) == TIM12)  || \
                                         ((INSTANCE) == TIM13)  || \
                                         ((INSTANCE) == TIM14)  || \
                                         ((INSTANCE) == TIM15)  || \
                                         ((INSTANCE) == TIM16)  || \
                                         ((INSTANCE) == TIM17))	
/************ TIM Instances : at least 2 capture/compare channels *************/
#define IS_TIM_CC2_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                         ((INSTANCE) == TIM2)   || \
                                         ((INSTANCE) == TIM3)   || \
                                         ((INSTANCE) == TIM4)   || \
                                         ((INSTANCE) == TIM5)   || \
                                         ((INSTANCE) == TIM8)   || \
                                         ((INSTANCE) == TIM12)   || \
                                         ((INSTANCE) == TIM15))                                          
/************ TIM Instances : at least 3 capture/compare channels *************/
#define IS_TIM_CC3_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                         ((INSTANCE) == TIM2)   || \
                                         ((INSTANCE) == TIM3)   || \
                                         ((INSTANCE) == TIM4)   || \
                                         ((INSTANCE) == TIM5)   || \
                                         ((INSTANCE) == TIM8))

/************ TIM Instances : at least 4 capture/compare channels *************/
#define IS_TIM_CC4_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                         ((INSTANCE) == TIM2)   || \
                                         ((INSTANCE) == TIM3)   || \
                                         ((INSTANCE) == TIM4)   || \
                                         ((INSTANCE) == TIM5)   || \
                                         ((INSTANCE) == TIM8))
/************ TIM Instances : at least 5 capture/compare channels *************/
#define IS_TIM_CC5_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                         ((INSTANCE) == TIM8))
/************ TIM Instances : at least 6 capture/compare channels *************/
#define IS_TIM_CC6_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                         ((INSTANCE) == TIM8))                                                                                  
                                         
/******************** TIM Instances : Advanced-control timers *****************/

/******************* TIM Instances : Timer input XOR function *****************/
#define IS_TIM_XOR_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                         ((INSTANCE) == TIM2)   || \
                                         ((INSTANCE) == TIM3)   || \
                                         ((INSTANCE) == TIM4)   || \
                                         ((INSTANCE) == TIM5)   || \
                                         ((INSTANCE) == TIM8))
/****************** TIM Instances : DMA requests generation (UDE) *************/
#define IS_TIM_DMA_INSTANCE(INSTANCE)     (((INSTANCE) == TIM1)   || \
                                           ((INSTANCE) == TIM2)   || \
                                           ((INSTANCE) == TIM3)   || \
                                           ((INSTANCE) == TIM4)   || \
                                           ((INSTANCE) == TIM5)   || \
                                           ((INSTANCE) == TIM6)   || \
                                           ((INSTANCE) == TIM7)   || \
                                           ((INSTANCE) == TIM8)   || \
                                           ((INSTANCE) == TIM15)  || \
                                           ((INSTANCE) == TIM16)  || \
                                           ((INSTANCE) == TIM17))

/************ TIM Instances : DMA requests generation (CCxDE) *****************/
#define IS_TIM_DMA_CC_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                            ((INSTANCE) == TIM2)   || \
                                            ((INSTANCE) == TIM3)   || \
                                            ((INSTANCE) == TIM4)   || \
                                            ((INSTANCE) == TIM5)   || \
                                            ((INSTANCE) == TIM8)   || \
                                            ((INSTANCE) == TIM15)  || \
                                            ((INSTANCE) == TIM16)  || \
                                            ((INSTANCE) == TIM17))

/************ TIM Instances : DMA requests generation (COMDE) *****************/
#define IS_TIM_CCDMA_INSTANCE(INSTANCE)    (((INSTANCE) == TIM1)   || \
                                            ((INSTANCE) == TIM2)   || \
                                            ((INSTANCE) == TIM3)   || \
                                            ((INSTANCE) == TIM4)   || \
                                            ((INSTANCE) == TIM5)   || \
                                            ((INSTANCE) == TIM8)   || \
                                            ((INSTANCE) == TIM15)) 

/******************** TIM Instances : DMA burst feature ***********************/
#define IS_TIM_DMABURST_INSTANCE(INSTANCE) (((INSTANCE) == TIM1)   || \
                                            ((INSTANCE) == TIM2)   || \
                                            ((INSTANCE) == TIM3)   || \
                                            ((INSTANCE) == TIM4)   || \
                                            ((INSTANCE) == TIM5)   || \
                                            ((INSTANCE) == TIM8)) 
                                                
/***************** TIM Instances : external trigger reamp input availabe *******/
#define IS_TIM_ETR_INSTANCE(INSTANCE)     (((INSTANCE) == TIM1)   || \
                                           ((INSTANCE) == TIM2)   || \
                                           ((INSTANCE) == TIM3)   || \
                                           ((INSTANCE) == TIM4)   || \
                                           ((INSTANCE) == TIM5)   || \
                                           ((INSTANCE) == TIM8))    
                                                                                                                                                                
/***************** TIM Instances : external trigger reamp input availabe *******/
#define IS_TIM_ETRSEL_INSTANCE(INSTANCE)     (((INSTANCE) == TIM1)   || \
                                              ((INSTANCE) == TIM2)   || \
                                              ((INSTANCE) == TIM3)   || \
                                              ((INSTANCE) == TIM5)   || \
                                              ((INSTANCE) == TIM8))
                                              
/****** TIM Instances : master mode available (TIMx_CR2.MMS available )********/
#define IS_TIM_MASTER_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                            ((INSTANCE) == TIM2)   || \
                                            ((INSTANCE) == TIM3)   || \
                                            ((INSTANCE) == TIM4)   || \
                                            ((INSTANCE) == TIM5)   || \
                                            ((INSTANCE) == TIM6)   || \
                                            ((INSTANCE) == TIM7)   || \
                                            ((INSTANCE) == TIM8)   || \
                                            ((INSTANCE) == TIM15))
/****** TIM Instances : Salve mode available (TIMx_SMCR.TS available )*********/
#define IS_TIM_SLAVE_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                           ((INSTANCE) == TIM2)   || \
                                           ((INSTANCE) == TIM3)   || \
                                           ((INSTANCE) == TIM4)   || \
                                           ((INSTANCE) == TIM5)   || \
                                           ((INSTANCE) == TIM8)   || \
                                           ((INSTANCE) == TIM12))                                            

/****** TIM Instances : TRGO2 available (TIMx_CR2.MMS2 available )*********/
#define IS_TIM_TRGO2_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                           ((INSTANCE) == TIM8))

/****** TIM Instances : TISEL available (TIMx_TISEL available )*********/                                           
#define IS_TIM_TISEL_INSTANCE(INSTANCE)  (((INSTANCE) == TIM1)   || \
                                          ((INSTANCE) == TIM2)   || \
                                          ((INSTANCE) == TIM3)   || \
                                          ((INSTANCE) == TIM4)   || \
                                          ((INSTANCE) == TIM5)   || \
                                          ((INSTANCE) == TIM8)   || \
                                          ((INSTANCE) == TIM15)  || \
                                          ((INSTANCE) == TIM16)  || \
                                          ((INSTANCE) == TIM17)) 

/****************** TIM Instances : supporting commutation event *************/
#define IS_TIM_COMMUTATION_EVENT_INSTANCE(INSTANCE) (((INSTANCE) == TIM1)    || \
                                                     ((INSTANCE) == TIM8)    || \
                                                     ((INSTANCE) == TIM15)   || \
                                                     ((INSTANCE) == TIM16)   || \
                                                     ((INSTANCE) == TIM17))

                                         
/****** TIM Instances : TIM_CCR5_GC5C available (TIMx_CCR5.GC5C available )*********/
#define IS_TIM_COMBINED3PHASEPWM_INSTANCE(INSTANCE)   (((INSTANCE) == TIM1)   || \
                                                       ((INSTANCE) == TIM8))
/******************* TIM Instances : output(s) available **********************/
#define IS_TIM_CCX_INSTANCE(INSTANCE, CHANNEL) \
    ((((INSTANCE) == TIM1) &&                  \
     (((CHANNEL) == TIM_CHANNEL_1) ||          \
      ((CHANNEL) == TIM_CHANNEL_2) ||          \
      ((CHANNEL) == TIM_CHANNEL_3) ||          \
      ((CHANNEL) == TIM_CHANNEL_4)))           \
     ||                                        \
     (((INSTANCE) == TIM2) &&                  \
     (((CHANNEL) == TIM_CHANNEL_1) ||          \
      ((CHANNEL) == TIM_CHANNEL_2) ||          \
      ((CHANNEL) == TIM_CHANNEL_3) ||          \
      ((CHANNEL) == TIM_CHANNEL_4)))           \
  ||                                           \
      (((INSTANCE) == TIM3) &&                 \
      (((CHANNEL) == TIM_CHANNEL_1)||          \
      ((CHANNEL) == TIM_CHANNEL_2) ||          \
      ((CHANNEL) == TIM_CHANNEL_3) ||          \
      ((CHANNEL) == TIM_CHANNEL_4)))           \
  ||                                           \
      (((INSTANCE) == TIM4) &&                 \
      (((CHANNEL) == TIM_CHANNEL_1) ||         \
      ((CHANNEL) == TIM_CHANNEL_2) ||          \
      ((CHANNEL) == TIM_CHANNEL_3) ||          \
      ((CHANNEL) == TIM_CHANNEL_4)))           \
  ||                                           \
      (((INSTANCE) == TIM5) &&                 \
      (((CHANNEL) == TIM_CHANNEL_1) ||         \
      ((CHANNEL) == TIM_CHANNEL_2) ||          \
      ((CHANNEL) == TIM_CHANNEL_3) ||          \
      ((CHANNEL) == TIM_CHANNEL_4)))           \
  ||                                           \
      (((INSTANCE) == TIM8) &&                 \
      (((CHANNEL) == TIM_CHANNEL_1) ||         \
      ((CHANNEL) == TIM_CHANNEL_2) ||          \
      ((CHANNEL) == TIM_CHANNEL_3) ||          \
      ((CHANNEL) == TIM_CHANNEL_4)))           \
  ||                                           \
     (((INSTANCE) == TIM13) &&                 \
     (((CHANNEL) == TIM_CHANNEL_1)))           \
  ||                                           \
     (((INSTANCE) == TIM14) &&                 \
     (((CHANNEL) == TIM_CHANNEL_1)))           \
  ||                                           \
     (((INSTANCE) == TIM15) &&                 \
     (((CHANNEL) == TIM_CHANNEL_1) ||          \
     ((CHANNEL) == TIM_CHANNEL_2)))            \
  ||                                           \
     (((INSTANCE) == TIM16) &&                 \
     (((CHANNEL) == TIM_CHANNEL_1)))           \
  ||                                           \
     (((INSTANCE) == TIM17) &&                 \
     (((CHANNEL) == TIM_CHANNEL_1))))

/****************** TIM Instances : supporting the break function *************/
#define IS_TIM_BREAK_INSTANCE(INSTANCE)\
      (((INSTANCE) == TIM1)    || \
      ((INSTANCE) == TIM8)     || \
       ((INSTANCE) == TIM15)   || \
       ((INSTANCE) == TIM16)   || \
       ((INSTANCE) == TIM17))
/****************** TIM Instances : supporting complementary output(s) ********/
#define IS_TIM_CCXN_INSTANCE(INSTANCE, CHANNEL) \
   ((((INSTANCE) == TIM1) &&                    \
     (((CHANNEL) == TIM_CHANNEL_1) ||           \
      ((CHANNEL) == TIM_CHANNEL_2) ||           \
      ((CHANNEL) == TIM_CHANNEL_3)))            \
 ||                                             \
      (((INSTANCE) == TIM8) &&                  \
      (((CHANNEL) == TIM_CHANNEL_1) ||          \
      ((CHANNEL) == TIM_CHANNEL_2) ||           \
      ((CHANNEL) == TIM_CHANNEL_3)))            \
    ||                                          \
    (((INSTANCE) == TIM15) &&                   \
      ((CHANNEL) == TIM_CHANNEL_1))             \
    ||                                          \
    (((INSTANCE) == TIM16) &&                   \
     ((CHANNEL) == TIM_CHANNEL_1))              \
    ||                                          \
    (((INSTANCE) == TIM17) &&                   \
     ((CHANNEL) == TIM_CHANNEL_1)))

/****************** TIM Instances : supporting counting mode selection ********/
#define IS_TIM_COUNTER_MODE_SELECT_INSTANCE(INSTANCE)\
  (((INSTANCE) == TIM1)    || \
   ((INSTANCE) == TIM2)    || \
   ((INSTANCE) == TIM3)    || \
   ((INSTANCE) == TIM4)    || \
   ((INSTANCE) == TIM5)    || \
   ((INSTANCE) == TIM8))
 
/****************** TIM Instances : supporting repetition counter *************/
#define IS_TIM_REPETITION_COUNTER_INSTANCE(INSTANCE)\
  (((INSTANCE) == TIM1)    || \
   ((INSTANCE) == TIM8)    || \
   ((INSTANCE) == TIM15)   || \
   ((INSTANCE) == TIM16)   || \
   ((INSTANCE) == TIM17))

/****************** TIM Instances : supporting clock division *****************/
#define IS_TIM_CLOCK_DIVISION_INSTANCE(INSTANCE)\
  (((INSTANCE) == TIM1)    || \
   ((INSTANCE) == TIM2)    || \
   ((INSTANCE) == TIM3)    || \
   ((INSTANCE) == TIM4)    || \
   ((INSTANCE) == TIM5)    || \
   ((INSTANCE) == TIM8)    || \
   ((INSTANCE) == TIM15)   || \
   ((INSTANCE) == TIM16)   || \
   ((INSTANCE) == TIM17))
/****************** TIM Instances : supporting external clock mode 1 for ETRF input */
#define IS_TIM_CLOCKSOURCE_ETRMODE1_INSTANCE(INSTANCE)\
  (((INSTANCE) == TIM1)    || \
   ((INSTANCE) == TIM2)    || \
   ((INSTANCE) == TIM3)    || \
   ((INSTANCE) == TIM4)    || \
   ((INSTANCE) == TIM5)    || \
   ((INSTANCE) == TIM8))

/****************** TIM Instances : supporting external clock mode 2 **********/
#define IS_TIM_CLOCKSOURCE_ETRMODE2_INSTANCE(INSTANCE)\
 (((INSTANCE) == TIM1)     || \
   ((INSTANCE) == TIM2)    || \
   ((INSTANCE) == TIM3)    || \
   ((INSTANCE) == TIM4)    || \
   ((INSTANCE) == TIM5)    || \
   ((INSTANCE) == TIM8))
/****************** TIM Instances : supporting external clock mode 1 for TIX inputs*/
#define IS_TIM_CLOCKSOURCE_TIX_INSTANCE(INSTANCE)\
  (((INSTANCE) == TIM1)    || \
   ((INSTANCE) == TIM2)    || \
   ((INSTANCE) == TIM3)    || \
   ((INSTANCE) == TIM4)    || \
   ((INSTANCE) == TIM5)    || \
   ((INSTANCE) == TIM8)    || \
   ((INSTANCE) == TIM15))

/****************** TIM Instances : supporting internal trigger inputs(ITRX) *******/
#define IS_TIM_CLOCKSOURCE_ITRX_INSTANCE(INSTANCE)\
  (((INSTANCE) == TIM1)    || \
   ((INSTANCE) == TIM2)    || \
   ((INSTANCE) == TIM3)    || \
   ((INSTANCE) == TIM4)    || \
   ((INSTANCE) == TIM5)    || \
   ((INSTANCE) == TIM8)    || \
   ((INSTANCE) == TIM15))

/****************** TIM Instances : supporting OCxREF clear *******************/
#define IS_TIM_OCXREF_CLEAR_INSTANCE(INSTANCE)\
  (((INSTANCE) == TIM1)    || \
   ((INSTANCE) == TIM2)    || \
   ((INSTANCE) == TIM3))
/****************** TIM Instances : TIM_32B_COUNTER ***************************/  
#define IS_TIM_32B_COUNTER_INSTANCE(INSTANCE)\
  (((INSTANCE) == TIM2)    || \
   ((INSTANCE) == TIM5))

/****************** TIM Instances : TIM_BKIN2 ***************************/   
#define IS_TIM_BKIN2_INSTANCE(INSTANCE)\
  (((INSTANCE) == TIM1)    || \
   ((INSTANCE) == TIM8))
/****************************** HRTIM Instances *******************************/
#define IS_HRTIM_ALL_INSTANCE(INSTANCE) (((INSTANCE) == HRTIM1))
/******************** USART Instances : Synchronous mode **********************/
#define IS_USART_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                     ((INSTANCE) == USART2) || \
                                     ((INSTANCE) == USART3) || \
                                     ((INSTANCE) == USART6))

/******************** UART Instances : Asynchronous mode **********************/
#define IS_UART_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                    ((INSTANCE) == USART2) || \
                                    ((INSTANCE) == USART3) || \
                                    ((INSTANCE) == UART4)  || \
                                    ((INSTANCE) == UART5)  || \
                                    ((INSTANCE) == USART6) || \
                                    ((INSTANCE) == UART7)  || \
                                    ((INSTANCE) == UART8))

/****************** UART Instances : Auto Baud Rate detection *****************/
#define IS_USART_AUTOBAUDRATE_DETECTION_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                                            ((INSTANCE) == USART2) || \
                                                            ((INSTANCE) == USART3) || \
                                                            ((INSTANCE) == UART4)  || \
                                                            ((INSTANCE) == UART5)  || \
                                                            ((INSTANCE) == USART6) || \
                                                            ((INSTANCE) == UART7)  || \
                                                            ((INSTANCE) == UART8))

/*********************** UART Instances : Driver Enable ***********************/
#define IS_UART_DRIVER_ENABLE_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                                  ((INSTANCE) == USART2) || \
                                                  ((INSTANCE) == USART3) || \
                                                  ((INSTANCE) == UART4)  || \
                                                  ((INSTANCE) == UART5)  || \
                                                  ((INSTANCE) == USART6) || \
                                                  ((INSTANCE) == UART7)  || \
                                                  ((INSTANCE) == UART8)  || \
                                                  ((INSTANCE) == LPUART1))

/********************* UART Instances : Half-Duplex mode **********************/
#define IS_UART_HALFDUPLEX_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                               ((INSTANCE) == USART2) || \
                                               ((INSTANCE) == USART3) || \
                                               ((INSTANCE) == UART4)  || \
                                               ((INSTANCE) == UART5)  || \
                                               ((INSTANCE) == USART6) || \
                                               ((INSTANCE) == UART7)  || \
                                               ((INSTANCE) == UART8)  || \
                                               ((INSTANCE) == LPUART1))

/******************* UART Instances : Hardware Flow control *******************/
#define IS_UART_HWFLOW_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                           ((INSTANCE) == USART2) || \
                                           ((INSTANCE) == USART3) || \
                                           ((INSTANCE) == UART4)  || \
                                           ((INSTANCE) == UART5)  || \
                                           ((INSTANCE) == USART6) || \
                                           ((INSTANCE) == UART7)  || \
                                           ((INSTANCE) == UART8)  || \
                                           ((INSTANCE) == LPUART1))

/************************* UART Instances : LIN mode **************************/
#define IS_UART_LIN_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                        ((INSTANCE) == USART2) || \
                                        ((INSTANCE) == USART3) || \
                                        ((INSTANCE) == UART4)  || \
                                        ((INSTANCE) == UART5)  || \
                                        ((INSTANCE) == USART6) || \
                                        ((INSTANCE) == UART7)  || \
                                        ((INSTANCE) == UART8))

/****************** UART Instances : Wake-up from Stop mode *******************/
#define IS_UART_WAKEUP_FROMSTOP_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                                    ((INSTANCE) == USART2) || \
                                                    ((INSTANCE) == USART3) || \
                                                    ((INSTANCE) == UART4)  || \
                                                    ((INSTANCE) == UART5)  || \
                                                    ((INSTANCE) == USART6) || \
                                                   ((INSTANCE) == UART7)  || \
                                                    ((INSTANCE) == UART8)  || \
                                                    ((INSTANCE) == LPUART1))

/************************* UART Instances : IRDA mode *************************/
#define IS_IRDA_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                    ((INSTANCE) == USART2) || \
                                    ((INSTANCE) == USART3) || \
                                    ((INSTANCE) == UART4)  || \
                                    ((INSTANCE) == UART5)  || \
                                    ((INSTANCE) == USART6) || \
                                    ((INSTANCE) == UART7)  || \
                                    ((INSTANCE) == UART8))
                                          

/********************* USART Instances : Smard card mode **********************/
#define IS_SMARTCARD_INSTANCE(INSTANCE) (((INSTANCE) == USART1) || \
                                         ((INSTANCE) == USART2) || \
                                         ((INSTANCE) == USART3) || \
                                         ((INSTANCE) == USART6))

/****************************** LPUART Instance *******************************/
#define IS_LPUART_INSTANCE(INSTANCE) ((INSTANCE) == LPUART1)

/****************************** IWDG Instances ********************************/
#define IS_IWDG_ALL_INSTANCE(INSTANCE)  ((INSTANCE) == IWDG1) 
/****************************** USB Instances ********************************/
#define IS_USB_ALL_INSTANCE(INSTANCE) ((INSTANCE) == USB)

/****************************** WWDG Instances ********************************/
#define IS_WWDG_ALL_INSTANCE(INSTANCE)  ((INSTANCE) == WWDG1)                                      
/****************************** MDIOS Instances ********************************/
#define IS_MDIOS_ALL_INSTANCE(INSTANCE)  ((INSTANCE) == MDIOS)

/****************************** CEC Instances *********************************/
#define IS_CEC_ALL_INSTANCE(__INSTANCE__) ((__INSTANCE__) == CEC)

/****************************** SAI Instances ********************************/
#define IS_SAI_ALL_INSTANCE(INSTANCE) (((INSTANCE) == SAI1_Block_A) || \
                    ((INSTANCE) == SAI1_Block_B) || \
                     ((INSTANCE) == SAI2_Block_A) || \
                     ((INSTANCE) == SAI2_Block_B) || \
                     ((INSTANCE) == SAI3_Block_A) || \
                     ((INSTANCE) == SAI3_Block_B) || \
                     ((INSTANCE) == SAI4_Block_A) || \
                     ((INSTANCE) == SAI4_Block_B))
                                       
/****************************** SPDIFRX Instances ********************************/
#define IS_SPDIFRX_ALL_INSTANCE(INSTANCE) ((INSTANCE) == SPDIFRX)

/****************************** OPAMP Instances *******************************/
#define IS_OPAMP_ALL_INSTANCE(INSTANCE) (((INSTANCE) == OPAMP1) || \
                                         ((INSTANCE) == OPAMP2))

#define IS_OPAMP_COMMON_INSTANCE(COMMON_INSTANCE) ((COMMON_INSTANCE) == OPAMP12_COMMON)

/******************************************************************************/
/*  For a painless codes migration between the STM32H7xx device product       */
/*  lines, or with STM32F7xx devices the aliases defined below are put        */
/*   in place to overcome the differences in the interrupt handlers and IRQn  */
/*   definitions. No need to update developed interrupt code when moving      */
/*  across product lines within the same STM32H7 Family                       */
/******************************************************************************/

/* Aliases for __IRQn */
#define HASH_RNG_IRQn              RNG_IRQn
#define  TIM1_BRK_IRQn             TIM1_BRK_TIM9_IRQn          
#define  TIM1_UP_IRQn              TIM1_UP_TIM10_IRQn          
  
/* Aliases for __IRQHandler */
#define HASH_RNG_IRQHandler        RNG_IRQHandler
#define TIM1_BRK_IRQHandler        TIM1_BRK_TIM9_IRQHandler
#define TIM1_UP_IRQHandler         TIM1_UP_TIM9_IRQHandler

/**
  * @}
  */
/****************************** Product define *********************************/

#define FLASH_SIZE                         0x200000  /* 2MB */
#define FLASH_BANK_SIZE                    (FLASH_SIZE >> 1)   /* 1MB */

#define FLASH_SECTOR_SIZE 0x00020000 /* 128 KB */



/**
  * @}
  */

/**
  * @}
  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __STM32H7xx_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
